<div class="quarto-about-broadside column-page">
  <div class="about-main">
    <div
      class="about-entity"
      style="background-image: url('<%= about.image %>')"
    ></div>
    <div class="about-contents"><%= about.title %><%= about.body %></div>
  </div>
  <% partial('_links.ejs.html', { about, imgOpts: {} }) %>
</div>
