import { dew } from "/npm:jszip@3.5.0/lib/index.dew.js";
export default dew();
import "/npm:jszip@3.5.0/lib/object.dew.js";
import "/npm:jszip@3.5.0/lib/load.dew.js";
import "/npm:jszip@3.5.0/lib/support.dew.js";
import "/npm:jszip@3.5.0/lib/defaults.dew.js";
import "/npm:jszip@3.5.0/lib/external.dew.js";
import "/npm:jszip@3.5.0/lib/utf8.dew.js";
import "/npm:jszip@3.5.0/lib/utils.dew.js";
import "/npm:jszip@3.5.0/lib/stream/GenericWorker.dew.js";
import "/npm:jszip@3.5.0/lib/stream/StreamHelper.dew.js";
import "/npm:jszip@3.5.0/lib/compressedObject.dew.js";
import "/npm:jszip@3.5.0/lib/zipObject.dew.js";
import "/npm:jszip@3.5.0/lib/generate/index.dew.js";
import "/npm:jszip@3.5.0/lib/nodejsUtils.dew.js";
import "/npm:jszip@3.5.0/lib/nodejs/NodejsStreamInputAdapter.dew.js";
import "/npm:jszip@3.5.0/lib/base64.dew.js";
import "/npm:set-immediate-shim@1.0?dew";
import "/npm:jszip@3.5.0/lib/stream/ConvertWorker.dew.js";
import "/npm:jszip@3.5.0/lib/nodejs/NodejsStreamOutputAdapter.dew.js";
import "/npm:@jspm/core@1/nodelibs/buffer.js";
import "/npm:jszip@3.5.0/lib/readable-stream-browser.dew.js";
import "/npm:@jspm/core@1/nodelibs/stream.js";
import "/npm:jszip@3.5.0/lib/stream/DataWorker.dew.js";
import "/npm:jszip@3.5.0/lib/stream/DataLengthProbe.dew.js";
import "/npm:jszip@3.5.0/lib/stream/Crc32Probe.dew.js";
import "/npm:jszip@3.5.0/lib/crc32.dew.js";
import "/npm:jszip@3.5.0/lib/compressions.dew.js";
import "/npm:jszip@3.5.0/lib/generate/ZipFileWorker.dew.js";
import "/npm:jszip@3.5.0/lib/flate.dew.js";
import "/npm:pako@1.0?dew";
import "/npm:jszip@3.5.0/lib/signature.dew.js";
import "/npm:jszip@3.5.0/lib/zipEntries.dew.js";
import "/npm:jszip@3.5.0/lib/reader/readerFor.dew.js";
import "/npm:jszip@3.5.0/lib/zipEntry.dew.js";
import "/npm:jszip@3.5.0/lib/reader/ArrayReader.dew.js";
import "/npm:jszip@3.5.0/lib/reader/StringReader.dew.js";
import "/npm:jszip@3.5.0/lib/reader/NodeBufferReader.dew.js";
import "/npm:jszip@3.5.0/lib/reader/Uint8ArrayReader.dew.js";
import "/npm:jszip@3.5.0/lib/reader/DataReader.dew.js";
import "/npm:lie@3.3?dew";
