
<% /* Container that holds search results (when using the non-floating style.) */ %>
<div id="quarto-search-results"></div>

  
  <% /* The header will hold the navbar (if present) and/or a container for the collapsed sidebar */ %>
  <% if (nav.navbar || nav.sidebar) { %>  
  <header id="quarto-header" class="headroom fixed-top">

  <% if (nav.navbar) { %>  
    <nav class="navbar navbar-expand<%- nav.navbar["collapse-below"] %> navbar-dark <%- nav.navbar.background === "none" || nav.navbar.background === "body" ? "border-bottom" : "" %>">
      <div class="navbar-container container-fluid">
      <% partial('navbrand.ejs', nav.navbar) %>
      <% if (nav.navbar.left || nav.navbar.right) { %>  
        <% if (nav.navbar.collapse) { %>
          <% partial('navtoggle.ejs') %>
          <% partial('navcollapse.ejs') %>
            <% partial('navitems.ejs', { align: 'start', items: nav.navbar.left}) %>
            <% partial('navitems.ejs', { align: 'end', items: nav.navbar.right }) %>
            <% if (nav.navbar.darkToggle || nav.navbar.readerToggle) { %>
              <div class="quarto-toggle-container">
                <% if (nav.navbar.darkToggle) { %>
                  <% partial('navdarktoggle.ejs', { classes: 'nav-link' }) %>
                <% } %>
                <% if (nav.navbar.readerToggle) { %>
                  <% partial('navreadertoggle.ejs', { classes: 'nav-link' }) %>
                <% } %>
              </div>
            <% } %>    
            <% if (nav.navbar.search) { %>
              <% partial('navsearch.ejs',  { classes: '' }) %>
            <% } %>
          </div> <!-- /navcollapse -->
        <% } else { %>
          <% partial('navitems.ejs', { align: 'start', items: nav.navbar.left}) %>
          <% partial('navitems.ejs', { align: 'end', items: nav.navbar.right }) %>
          <% if (nav.navbar.darkToggle || nav.navbar.readerToggle) { %>
            <div class="quarto-toggle-container">
              <% if (nav.navbar.darkToggle) { %>
                <% partial('navdarktoggle.ejs', { classes: 'nav-link' }) %>
              <% } %>
              <% if (nav.navbar.readerToggle) { %>
                <% partial('navreadertoggle.ejs', { classes: 'nav-link' }) %>
              <% } %>

            </div>
          <% } %>    
          <% if (nav.navbar.search) { %>
            <% partial('navsearch.ejs',  { classes: '' }) %>
          <% } %>
        <% } %> 
      <% } else { %>
        <% if (nav.navbar.darkToggle || nav.navbar.readerToggle) { %>
          <div class="quarto-toggle-container ms-auto">
            <% if (nav.navbar.darkToggle) { %>
              <% partial('navdarktoggle.ejs', { classes: 'nav-link' }) %>
            <% } %>
            <% if (nav.navbar.readerToggle) { %>
              <% partial('navreadertoggle.ejs', { classes: 'nav-link' }) %>
            <% } %>
          </div>
        <% } %>    
        <% if (nav.navbar.search) { %>
          <% partial('navsearch.ejs',  { classes: '' }) %>
        <% } %>
      <% } %>

      </div> <!-- /container-fluid -->
    </nav>
<% } %>

<% if (nav.sidebar && nav.layout) { %>
  <nav class="quarto-secondary-nav" 
        data-bs-toggle="collapse" data-bs-target="#quarto-sidebar" 
        aria-controls="quarto-sidebar" aria-expanded="false" aria-label="Toggle sidebar navigation"
        onclick="if (window.quartoToggleHeadroom) { window.quartoToggleHeadroom(); }"
  >
    <div class="container-fluid d-flex justify-content-between">
      <h1 class="quarto-secondary-nav-title"></h1>
      <button type="button" 
        class="quarto-btn-toggle btn" aria-label="Show secondary navigation">
        <i class="bi bi-chevron-right"></i>
      </button>
    </div>
  </nav>
<% } %>

</header>
<% } %> 

<% if (nav.layout) { %>

<!-- content -->
<% 
let gridClasses = "";
if (nav.layout === "article" || nav.layout === "full") {
  gridClasses = " page-columns page-rows-contents";
} 
%>
<div id="quarto-content" class="quarto-container<%- gridClasses %> page-layout-<%- nav.layout %><%- nav.navbar ? ' page-navbar': ''%>">

<!-- sidebar -->
<% if (nav.sidebar || nav['toc-location'] === "left") { %>
  <% partial('sidebar.ejs', { sidebar: nav.sidebar, sidebarStyle: nav.sidebarStyle, navbar: !!nav.navbar, toc: nav['toc-location'] === "left" }) %>
<% } %>

<!-- margin-sidebar -->
<% if (nav.layout === "article" || nav.layout === "full") { %>
    <div id="quarto-margin-sidebar" class="sidebar margin-sidebar">
      <% if (nav.hasToc && nav['toc-location'] === "right") { %>
        <div id="quarto-toc-target"></div>
      <% } %>
    </div>
<% } %>

<!-- main -->
<% if (nav.layout !== "custom") { %>
<main class="content" id="quarto-document-content">
<% } %>

<% } %>




