export { dew } from "/npm:pako@1.0.11/index.dew.js";
import "/npm:pako@1.0.11/lib/utils/common.dew.js";
import "/npm:pako@1.0.11/lib/deflate.dew.js";
import "/npm:pako@1.0.11/lib/inflate.dew.js";
import "/npm:pako@1.0.11/lib/zlib/constants.dew.js";
import "/npm:pako@1.0.11/lib/zlib/deflate.dew.js";
import "/npm:pako@1.0.11/lib/utils/strings.dew.js";
import "/npm:pako@1.0.11/lib/zlib/messages.dew.js";
import "/npm:pako@1.0.11/lib/zlib/zstream.dew.js";
import "/npm:pako@1.0.11/lib/zlib/trees.dew.js";
import "/npm:pako@1.0.11/lib/zlib/adler32.dew.js";
import "/npm:pako@1.0.11/lib/zlib/crc32.dew.js";
import "/npm:pako@1.0.11/lib/zlib/inflate.dew.js";
import "/npm:pako@1.0.11/lib/zlib/gzheader.dew.js";
import "/npm:pako@1.0.11/lib/zlib/inffast.dew.js";
import "/npm:pako@1.0.11/lib/zlib/inftrees.dew.js";
