"undefined"===typeof PDFJS&&(("undefined"!==typeof window?window:"undefined"!==typeof global?global:this).PDFJS={});PDFJS.version="1.3.158";PDFJS.build="944d1e6";
(function(){(function(a,e){e(a.pdfjsCoreArithmeticDecoder={})})(this,function(a){var e=function(){function a(e,P,H){this.data=e;this.bp=P;this.dataEnd=H;this.chigh=e[P];this.clow=0;this.byteIn();this.chigh=this.chigh<<7&65535|this.clow>>9&127;this.clow=this.clow<<7&65535;this.ct-=7;this.a=32768}var e=[{qe:22017,nmps:1,nlps:1,switchFlag:1},{qe:13313,nmps:2,nlps:6,switchFlag:0},{qe:6145,nmps:3,nlps:9,switchFlag:0},{qe:2753,nmps:4,nlps:12,switchFlag:0},{qe:1313,nmps:5,nlps:29,switchFlag:0},{qe:545,nmps:38,
nlps:33,switchFlag:0},{qe:22017,nmps:7,nlps:6,switchFlag:1},{qe:21505,nmps:8,nlps:14,switchFlag:0},{qe:18433,nmps:9,nlps:14,switchFlag:0},{qe:14337,nmps:10,nlps:14,switchFlag:0},{qe:12289,nmps:11,nlps:17,switchFlag:0},{qe:9217,nmps:12,nlps:18,switchFlag:0},{qe:7169,nmps:13,nlps:20,switchFlag:0},{qe:5633,nmps:29,nlps:21,switchFlag:0},{qe:22017,nmps:15,nlps:14,switchFlag:1},{qe:21505,nmps:16,nlps:14,switchFlag:0},{qe:20737,nmps:17,nlps:15,switchFlag:0},{qe:18433,nmps:18,nlps:16,switchFlag:0},{qe:14337,
nmps:19,nlps:17,switchFlag:0},{qe:13313,nmps:20,nlps:18,switchFlag:0},{qe:12289,nmps:21,nlps:19,switchFlag:0},{qe:10241,nmps:22,nlps:19,switchFlag:0},{qe:9217,nmps:23,nlps:20,switchFlag:0},{qe:8705,nmps:24,nlps:21,switchFlag:0},{qe:7169,nmps:25,nlps:22,switchFlag:0},{qe:6145,nmps:26,nlps:23,switchFlag:0},{qe:5633,nmps:27,nlps:24,switchFlag:0},{qe:5121,nmps:28,nlps:25,switchFlag:0},{qe:4609,nmps:29,nlps:26,switchFlag:0},{qe:4353,nmps:30,nlps:27,switchFlag:0},{qe:2753,nmps:31,nlps:28,switchFlag:0},
{qe:2497,nmps:32,nlps:29,switchFlag:0},{qe:2209,nmps:33,nlps:30,switchFlag:0},{qe:1313,nmps:34,nlps:31,switchFlag:0},{qe:1089,nmps:35,nlps:32,switchFlag:0},{qe:673,nmps:36,nlps:33,switchFlag:0},{qe:545,nmps:37,nlps:34,switchFlag:0},{qe:321,nmps:38,nlps:35,switchFlag:0},{qe:273,nmps:39,nlps:36,switchFlag:0},{qe:133,nmps:40,nlps:37,switchFlag:0},{qe:73,nmps:41,nlps:38,switchFlag:0},{qe:37,nmps:42,nlps:39,switchFlag:0},{qe:21,nmps:43,nlps:40,switchFlag:0},{qe:9,nmps:44,nlps:41,switchFlag:0},{qe:5,nmps:45,
nlps:42,switchFlag:0},{qe:1,nmps:45,nlps:43,switchFlag:0},{qe:22017,nmps:46,nlps:46,switchFlag:0}];a.prototype={byteIn:function(){var a=this.data,e=this.bp;255===a[e]?143<a[e+1]?(this.clow+=65280,this.ct=8):(e++,this.clow+=a[e]<<9,this.ct=7,this.bp=e):(e++,this.clow+=e<this.dataEnd?a[e]<<8:65280,this.ct=8,this.bp=e);65535<this.clow&&(this.chigh+=this.clow>>16,this.clow&=65535)},readBit:function(a,L){var H=a[L]>>1,K=a[L]&1,H=e[H],I=H.qe,J=this.a-I;if(this.chigh<I)J<I?(J=I,I=K,H=H.nmps):(J=I,I=1^K,
1===H.switchFlag&&(K=I),H=H.nlps);else{this.chigh-=I;if(0!==(J&32768))return this.a=J,K;J<I?(I=1^K,1===H.switchFlag&&(K=I),H=H.nlps):(I=K,H=H.nmps)}do 0===this.ct&&this.byteIn(),J<<=1,this.chigh=this.chigh<<1&65535|this.clow>>15&1,this.clow=this.clow<<1&65535,this.ct--;while(0===(J&32768));this.a=J;a[L]=H<<1|K;return I}};return a}();a.ArithmeticDecoder=e});(function(a,e){e(a.pdfjsCoreCharsets={})})(this,function(a){a.ISOAdobeCharset=".notdef,space,exclam,quotedbl,numbersign,dollar,percent,ampersand,quoteright,parenleft,parenright,asterisk,plus,comma,hyphen,period,slash,zero,one,two,three,four,five,six,seven,eight,nine,colon,semicolon,less,equal,greater,question,at,A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,bracketleft,backslash,bracketright,asciicircum,underscore,quoteleft,a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,braceleft,bar,braceright,asciitilde,exclamdown,cent,sterling,fraction,yen,florin,section,currency,quotesingle,quotedblleft,guillemotleft,guilsinglleft,guilsinglright,fi,fl,endash,dagger,daggerdbl,periodcentered,paragraph,bullet,quotesinglbase,quotedblbase,quotedblright,guillemotright,ellipsis,perthousand,questiondown,grave,acute,circumflex,tilde,macron,breve,dotaccent,dieresis,ring,cedilla,hungarumlaut,ogonek,caron,emdash,AE,ordfeminine,Lslash,Oslash,OE,ordmasculine,ae,dotlessi,lslash,oslash,oe,germandbls,onesuperior,logicalnot,mu,trademark,Eth,onehalf,plusminus,Thorn,onequarter,divide,brokenbar,degree,thorn,threequarters,twosuperior,registered,minus,eth,multiply,threesuperior,copyright,Aacute,Acircumflex,Adieresis,Agrave,Aring,Atilde,Ccedilla,Eacute,Ecircumflex,Edieresis,Egrave,Iacute,Icircumflex,Idieresis,Igrave,Ntilde,Oacute,Ocircumflex,Odieresis,Ograve,Otilde,Scaron,Uacute,Ucircumflex,Udieresis,Ugrave,Yacute,Ydieresis,Zcaron,aacute,acircumflex,adieresis,agrave,aring,atilde,ccedilla,eacute,ecircumflex,edieresis,egrave,iacute,icircumflex,idieresis,igrave,ntilde,oacute,ocircumflex,odieresis,ograve,otilde,scaron,uacute,ucircumflex,udieresis,ugrave,yacute,ydieresis,zcaron".split(",");
a.ExpertCharset=".notdef,space,exclamsmall,Hungarumlautsmall,dollaroldstyle,dollarsuperior,ampersandsmall,Acutesmall,parenleftsuperior,parenrightsuperior,twodotenleader,onedotenleader,comma,hyphen,period,fraction,zerooldstyle,oneoldstyle,twooldstyle,threeoldstyle,fouroldstyle,fiveoldstyle,sixoldstyle,sevenoldstyle,eightoldstyle,nineoldstyle,colon,semicolon,commasuperior,threequartersemdash,periodsuperior,questionsmall,asuperior,bsuperior,centsuperior,dsuperior,esuperior,isuperior,lsuperior,msuperior,nsuperior,osuperior,rsuperior,ssuperior,tsuperior,ff,fi,fl,ffi,ffl,parenleftinferior,parenrightinferior,Circumflexsmall,hyphensuperior,Gravesmall,Asmall,Bsmall,Csmall,Dsmall,Esmall,Fsmall,Gsmall,Hsmall,Ismall,Jsmall,Ksmall,Lsmall,Msmall,Nsmall,Osmall,Psmall,Qsmall,Rsmall,Ssmall,Tsmall,Usmall,Vsmall,Wsmall,Xsmall,Ysmall,Zsmall,colonmonetary,onefitted,rupiah,Tildesmall,exclamdownsmall,centoldstyle,Lslashsmall,Scaronsmall,Zcaronsmall,Dieresissmall,Brevesmall,Caronsmall,Dotaccentsmall,Macronsmall,figuredash,hypheninferior,Ogoneksmall,Ringsmall,Cedillasmall,onequarter,onehalf,threequarters,questiondownsmall,oneeighth,threeeighths,fiveeighths,seveneighths,onethird,twothirds,zerosuperior,onesuperior,twosuperior,threesuperior,foursuperior,fivesuperior,sixsuperior,sevensuperior,eightsuperior,ninesuperior,zeroinferior,oneinferior,twoinferior,threeinferior,fourinferior,fiveinferior,sixinferior,seveninferior,eightinferior,nineinferior,centinferior,dollarinferior,periodinferior,commainferior,Agravesmall,Aacutesmall,Acircumflexsmall,Atildesmall,Adieresissmall,Aringsmall,AEsmall,Ccedillasmall,Egravesmall,Eacutesmall,Ecircumflexsmall,Edieresissmall,Igravesmall,Iacutesmall,Icircumflexsmall,Idieresissmall,Ethsmall,Ntildesmall,Ogravesmall,Oacutesmall,Ocircumflexsmall,Otildesmall,Odieresissmall,OEsmall,Oslashsmall,Ugravesmall,Uacutesmall,Ucircumflexsmall,Udieresissmall,Yacutesmall,Thornsmall,Ydieresissmall".split(",");
a.ExpertSubsetCharset=".notdef,space,dollaroldstyle,dollarsuperior,parenleftsuperior,parenrightsuperior,twodotenleader,onedotenleader,comma,hyphen,period,fraction,zerooldstyle,oneoldstyle,twooldstyle,threeoldstyle,fouroldstyle,fiveoldstyle,sixoldstyle,sevenoldstyle,eightoldstyle,nineoldstyle,colon,semicolon,commasuperior,threequartersemdash,periodsuperior,asuperior,bsuperior,centsuperior,dsuperior,esuperior,isuperior,lsuperior,msuperior,nsuperior,osuperior,rsuperior,ssuperior,tsuperior,ff,fi,fl,ffi,ffl,parenleftinferior,parenrightinferior,hyphensuperior,colonmonetary,onefitted,rupiah,centoldstyle,figuredash,hypheninferior,onequarter,onehalf,threequarters,oneeighth,threeeighths,fiveeighths,seveneighths,onethird,twothirds,zerosuperior,onesuperior,twosuperior,threesuperior,foursuperior,fivesuperior,sixsuperior,sevensuperior,eightsuperior,ninesuperior,zeroinferior,oneinferior,twoinferior,threeinferior,fourinferior,fiveinferior,sixinferior,seveninferior,eightinferior,nineinferior,centinferior,dollarinferior,periodinferior,commainferior".split(",")});
(function(a,e){e(a.pdfjsCoreGlyphList={})})(this,function(a){a.GlyphsUnicode={A:65,AE:198,AEacute:508,AEmacron:482,AEsmall:63462,Aacute:193,Aacutesmall:63457,Abreve:258,Abreveacute:7854,Abrevecyrillic:1232,Abrevedotbelow:7862,Abrevegrave:7856,Abrevehookabove:7858,Abrevetilde:7860,Acaron:461,Acircle:9398,Acircumflex:194,Acircumflexacute:7844,Acircumflexdotbelow:7852,Acircumflexgrave:7846,Acircumflexhookabove:7848,Acircumflexsmall:63458,Acircumflextilde:7850,Acute:63177,Acutesmall:63412,Acyrillic:1040,
Adblgrave:512,Adieresis:196,Adieresiscyrillic:1234,Adieresismacron:478,Adieresissmall:63460,Adotbelow:7840,Adotmacron:480,Agrave:192,Agravesmall:63456,Ahookabove:7842,Aiecyrillic:1236,Ainvertedbreve:514,Alpha:913,Alphatonos:902,Amacron:256,Amonospace:65313,Aogonek:260,Aring:197,Aringacute:506,Aringbelow:7680,Aringsmall:63461,Asmall:63329,Atilde:195,Atildesmall:63459,Aybarmenian:1329,B:66,Bcircle:9399,Bdotaccent:7682,Bdotbelow:7684,Becyrillic:1041,Benarmenian:1330,Beta:914,Bhook:385,Blinebelow:7686,
Bmonospace:65314,Brevesmall:63220,Bsmall:63330,Btopbar:386,C:67,Caarmenian:1342,Cacute:262,Caron:63178,Caronsmall:63221,Ccaron:268,Ccedilla:199,Ccedillaacute:7688,Ccedillasmall:63463,Ccircle:9400,Ccircumflex:264,Cdot:266,Cdotaccent:266,Cedillasmall:63416,Chaarmenian:1353,Cheabkhasiancyrillic:1212,Checyrillic:1063,Chedescenderabkhasiancyrillic:1214,Chedescendercyrillic:1206,Chedieresiscyrillic:1268,Cheharmenian:1347,Chekhakassiancyrillic:1227,Cheverticalstrokecyrillic:1208,Chi:935,Chook:391,Circumflexsmall:63222,
Cmonospace:65315,Coarmenian:1361,Csmall:63331,D:68,DZ:497,DZcaron:452,Daarmenian:1332,Dafrican:393,Dcaron:270,Dcedilla:7696,Dcircle:9401,Dcircumflexbelow:7698,Dcroat:272,Ddotaccent:7690,Ddotbelow:7692,Decyrillic:1044,Deicoptic:1006,Delta:8710,Deltagreek:916,Dhook:394,Dieresis:63179,DieresisAcute:63180,DieresisGrave:63181,Dieresissmall:63400,Digammagreek:988,Djecyrillic:1026,Dlinebelow:7694,Dmonospace:65316,Dotaccentsmall:63223,Dslash:272,Dsmall:63332,Dtopbar:395,Dz:498,Dzcaron:453,Dzeabkhasiancyrillic:1248,
Dzecyrillic:1029,Dzhecyrillic:1039,E:69,Eacute:201,Eacutesmall:63465,Ebreve:276,Ecaron:282,Ecedillabreve:7708,Echarmenian:1333,Ecircle:9402,Ecircumflex:202,Ecircumflexacute:7870,Ecircumflexbelow:7704,Ecircumflexdotbelow:7878,Ecircumflexgrave:7872,Ecircumflexhookabove:7874,Ecircumflexsmall:63466,Ecircumflextilde:7876,Ecyrillic:1028,Edblgrave:516,Edieresis:203,Edieresissmall:63467,Edot:278,Edotaccent:278,Edotbelow:7864,Efcyrillic:1060,Egrave:200,Egravesmall:63464,Eharmenian:1335,Ehookabove:7866,Eightroman:8551,
Einvertedbreve:518,Eiotifiedcyrillic:1124,Elcyrillic:1051,Elevenroman:8554,Emacron:274,Emacronacute:7702,Emacrongrave:7700,Emcyrillic:1052,Emonospace:65317,Encyrillic:1053,Endescendercyrillic:1186,Eng:330,Enghecyrillic:1188,Enhookcyrillic:1223,Eogonek:280,Eopen:400,Epsilon:917,Epsilontonos:904,Ercyrillic:1056,Ereversed:398,Ereversedcyrillic:1069,Escyrillic:1057,Esdescendercyrillic:1194,Esh:425,Esmall:63333,Eta:919,Etarmenian:1336,Etatonos:905,Eth:208,Ethsmall:63472,Etilde:7868,Etildebelow:7706,Euro:8364,
Ezh:439,Ezhcaron:494,Ezhreversed:440,F:70,Fcircle:9403,Fdotaccent:7710,Feharmenian:1366,Feicoptic:996,Fhook:401,Fitacyrillic:1138,Fiveroman:8548,Fmonospace:65318,Fourroman:8547,Fsmall:63334,G:71,GBsquare:13191,Gacute:500,Gamma:915,Gammaafrican:404,Gangiacoptic:1002,Gbreve:286,Gcaron:486,Gcedilla:290,Gcircle:9404,Gcircumflex:284,Gcommaaccent:290,Gdot:288,Gdotaccent:288,Gecyrillic:1043,Ghadarmenian:1346,Ghemiddlehookcyrillic:1172,Ghestrokecyrillic:1170,Gheupturncyrillic:1168,Ghook:403,Gimarmenian:1331,
Gjecyrillic:1027,Gmacron:7712,Gmonospace:65319,Grave:63182,Gravesmall:63328,Gsmall:63335,Gsmallhook:667,Gstroke:484,H:72,H18533:9679,H18543:9642,H18551:9643,H22073:9633,HPsquare:13259,Haabkhasiancyrillic:1192,Hadescendercyrillic:1202,Hardsigncyrillic:1066,Hbar:294,Hbrevebelow:7722,Hcedilla:7720,Hcircle:9405,Hcircumflex:292,Hdieresis:7718,Hdotaccent:7714,Hdotbelow:7716,Hmonospace:65320,Hoarmenian:1344,Horicoptic:1E3,Hsmall:63336,Hungarumlaut:63183,Hungarumlautsmall:63224,Hzsquare:13200,I:73,IAcyrillic:1071,
IJ:306,IUcyrillic:1070,Iacute:205,Iacutesmall:63469,Ibreve:300,Icaron:463,Icircle:9406,Icircumflex:206,Icircumflexsmall:63470,Icyrillic:1030,Idblgrave:520,Idieresis:207,Idieresisacute:7726,Idieresiscyrillic:1252,Idieresissmall:63471,Idot:304,Idotaccent:304,Idotbelow:7882,Iebrevecyrillic:1238,Iecyrillic:1045,Ifraktur:8465,Igrave:204,Igravesmall:63468,Ihookabove:7880,Iicyrillic:1048,Iinvertedbreve:522,Iishortcyrillic:1049,Imacron:298,Imacroncyrillic:1250,Imonospace:65321,Iniarmenian:1339,Iocyrillic:1025,
Iogonek:302,Iota:921,Iotaafrican:406,Iotadieresis:938,Iotatonos:906,Ismall:63337,Istroke:407,Itilde:296,Itildebelow:7724,Izhitsacyrillic:1140,Izhitsadblgravecyrillic:1142,J:74,Jaarmenian:1345,Jcircle:9407,Jcircumflex:308,Jecyrillic:1032,Jheharmenian:1355,Jmonospace:65322,Jsmall:63338,K:75,KBsquare:13189,KKsquare:13261,Kabashkircyrillic:1184,Kacute:7728,Kacyrillic:1050,Kadescendercyrillic:1178,Kahookcyrillic:1219,Kappa:922,Kastrokecyrillic:1182,Kaverticalstrokecyrillic:1180,Kcaron:488,Kcedilla:310,
Kcircle:9408,Kcommaaccent:310,Kdotbelow:7730,Keharmenian:1364,Kenarmenian:1343,Khacyrillic:1061,Kheicoptic:998,Khook:408,Kjecyrillic:1036,Klinebelow:7732,Kmonospace:65323,Koppacyrillic:1152,Koppagreek:990,Ksicyrillic:1134,Ksmall:63339,L:76,LJ:455,LL:63167,Lacute:313,Lambda:923,Lcaron:317,Lcedilla:315,Lcircle:9409,Lcircumflexbelow:7740,Lcommaaccent:315,Ldot:319,Ldotaccent:319,Ldotbelow:7734,Ldotbelowmacron:7736,Liwnarmenian:1340,Lj:456,Ljecyrillic:1033,Llinebelow:7738,Lmonospace:65324,Lslash:321,Lslashsmall:63225,
Lsmall:63340,M:77,MBsquare:13190,Macron:63184,Macronsmall:63407,Macute:7742,Mcircle:9410,Mdotaccent:7744,Mdotbelow:7746,Menarmenian:1348,Mmonospace:65325,Msmall:63341,Mturned:412,Mu:924,N:78,NJ:458,Nacute:323,Ncaron:327,Ncedilla:325,Ncircle:9411,Ncircumflexbelow:7754,Ncommaaccent:325,Ndotaccent:7748,Ndotbelow:7750,Nhookleft:413,Nineroman:8552,Nj:459,Njecyrillic:1034,Nlinebelow:7752,Nmonospace:65326,Nowarmenian:1350,Nsmall:63342,Ntilde:209,Ntildesmall:63473,Nu:925,O:79,OE:338,OEsmall:63226,Oacute:211,
Oacutesmall:63475,Obarredcyrillic:1256,Obarreddieresiscyrillic:1258,Obreve:334,Ocaron:465,Ocenteredtilde:415,Ocircle:9412,Ocircumflex:212,Ocircumflexacute:7888,Ocircumflexdotbelow:7896,Ocircumflexgrave:7890,Ocircumflexhookabove:7892,Ocircumflexsmall:63476,Ocircumflextilde:7894,Ocyrillic:1054,Odblacute:336,Odblgrave:524,Odieresis:214,Odieresiscyrillic:1254,Odieresissmall:63478,Odotbelow:7884,Ogoneksmall:63227,Ograve:210,Ogravesmall:63474,Oharmenian:1365,Ohm:8486,Ohookabove:7886,Ohorn:416,Ohornacute:7898,
Ohorndotbelow:7906,Ohorngrave:7900,Ohornhookabove:7902,Ohorntilde:7904,Ohungarumlaut:336,Oi:418,Oinvertedbreve:526,Omacron:332,Omacronacute:7762,Omacrongrave:7760,Omega:8486,Omegacyrillic:1120,Omegagreek:937,Omegaroundcyrillic:1146,Omegatitlocyrillic:1148,Omegatonos:911,Omicron:927,Omicrontonos:908,Omonospace:65327,Oneroman:8544,Oogonek:490,Oogonekmacron:492,Oopen:390,Oslash:216,Oslashacute:510,Oslashsmall:63480,Osmall:63343,Ostrokeacute:510,Otcyrillic:1150,Otilde:213,Otildeacute:7756,Otildedieresis:7758,
Otildesmall:63477,P:80,Pacute:7764,Pcircle:9413,Pdotaccent:7766,Pecyrillic:1055,Peharmenian:1354,Pemiddlehookcyrillic:1190,Phi:934,Phook:420,Pi:928,Piwrarmenian:1363,Pmonospace:65328,Psi:936,Psicyrillic:1136,Psmall:63344,Q:81,Qcircle:9414,Qmonospace:65329,Qsmall:63345,R:82,Raarmenian:1356,Racute:340,Rcaron:344,Rcedilla:342,Rcircle:9415,Rcommaaccent:342,Rdblgrave:528,Rdotaccent:7768,Rdotbelow:7770,Rdotbelowmacron:7772,Reharmenian:1360,Rfraktur:8476,Rho:929,Ringsmall:63228,Rinvertedbreve:530,Rlinebelow:7774,
Rmonospace:65330,Rsmall:63346,Rsmallinverted:641,Rsmallinvertedsuperior:694,S:83,SF010000:9484,SF020000:9492,SF030000:9488,SF040000:9496,SF050000:9532,SF060000:9516,SF070000:9524,SF080000:9500,SF090000:9508,SF100000:9472,SF110000:9474,SF190000:9569,SF200000:9570,SF210000:9558,SF220000:9557,SF230000:9571,SF240000:9553,SF250000:9559,SF260000:9565,SF270000:9564,SF280000:9563,SF360000:9566,SF370000:9567,SF380000:9562,SF390000:9556,SF400000:9577,SF410000:9574,SF420000:9568,SF430000:9552,SF440000:9580,
SF450000:9575,SF460000:9576,SF470000:9572,SF480000:9573,SF490000:9561,SF500000:9560,SF510000:9554,SF520000:9555,SF530000:9579,SF540000:9578,Sacute:346,Sacutedotaccent:7780,Sampigreek:992,Scaron:352,Scarondotaccent:7782,Scaronsmall:63229,Scedilla:350,Schwa:399,Schwacyrillic:1240,Schwadieresiscyrillic:1242,Scircle:9416,Scircumflex:348,Scommaaccent:536,Sdotaccent:7776,Sdotbelow:7778,Sdotbelowdotaccent:7784,Seharmenian:1357,Sevenroman:8550,Shaarmenian:1351,Shacyrillic:1064,Shchacyrillic:1065,Sheicoptic:994,
Shhacyrillic:1210,Shimacoptic:1004,Sigma:931,Sixroman:8549,Smonospace:65331,Softsigncyrillic:1068,Ssmall:63347,Stigmagreek:986,T:84,Tau:932,Tbar:358,Tcaron:356,Tcedilla:354,Tcircle:9417,Tcircumflexbelow:7792,Tcommaaccent:354,Tdotaccent:7786,Tdotbelow:7788,Tecyrillic:1058,Tedescendercyrillic:1196,Tenroman:8553,Tetsecyrillic:1204,Theta:920,Thook:428,Thorn:222,Thornsmall:63486,Threeroman:8546,Tildesmall:63230,Tiwnarmenian:1359,Tlinebelow:7790,Tmonospace:65332,Toarmenian:1337,Tonefive:444,Tonesix:388,
Tonetwo:423,Tretroflexhook:430,Tsecyrillic:1062,Tshecyrillic:1035,Tsmall:63348,Twelveroman:8555,Tworoman:8545,U:85,Uacute:218,Uacutesmall:63482,Ubreve:364,Ucaron:467,Ucircle:9418,Ucircumflex:219,Ucircumflexbelow:7798,Ucircumflexsmall:63483,Ucyrillic:1059,Udblacute:368,Udblgrave:532,Udieresis:220,Udieresisacute:471,Udieresisbelow:7794,Udieresiscaron:473,Udieresiscyrillic:1264,Udieresisgrave:475,Udieresismacron:469,Udieresissmall:63484,Udotbelow:7908,Ugrave:217,Ugravesmall:63481,Uhookabove:7910,Uhorn:431,
Uhornacute:7912,Uhorndotbelow:7920,Uhorngrave:7914,Uhornhookabove:7916,Uhorntilde:7918,Uhungarumlaut:368,Uhungarumlautcyrillic:1266,Uinvertedbreve:534,Ukcyrillic:1144,Umacron:362,Umacroncyrillic:1262,Umacrondieresis:7802,Umonospace:65333,Uogonek:370,Upsilon:933,Upsilon1:978,Upsilonacutehooksymbolgreek:979,Upsilonafrican:433,Upsilondieresis:939,Upsilondieresishooksymbolgreek:980,Upsilonhooksymbol:978,Upsilontonos:910,Uring:366,Ushortcyrillic:1038,Usmall:63349,Ustraightcyrillic:1198,Ustraightstrokecyrillic:1200,
Utilde:360,Utildeacute:7800,Utildebelow:7796,V:86,Vcircle:9419,Vdotbelow:7806,Vecyrillic:1042,Vewarmenian:1358,Vhook:434,Vmonospace:65334,Voarmenian:1352,Vsmall:63350,Vtilde:7804,W:87,Wacute:7810,Wcircle:9420,Wcircumflex:372,Wdieresis:7812,Wdotaccent:7814,Wdotbelow:7816,Wgrave:7808,Wmonospace:65335,Wsmall:63351,X:88,Xcircle:9421,Xdieresis:7820,Xdotaccent:7818,Xeharmenian:1341,Xi:926,Xmonospace:65336,Xsmall:63352,Y:89,Yacute:221,Yacutesmall:63485,Yatcyrillic:1122,Ycircle:9422,Ycircumflex:374,Ydieresis:376,
Ydieresissmall:63487,Ydotaccent:7822,Ydotbelow:7924,Yericyrillic:1067,Yerudieresiscyrillic:1272,Ygrave:7922,Yhook:435,Yhookabove:7926,Yiarmenian:1349,Yicyrillic:1031,Yiwnarmenian:1362,Ymonospace:65337,Ysmall:63353,Ytilde:7928,Yusbigcyrillic:1130,Yusbigiotifiedcyrillic:1132,Yuslittlecyrillic:1126,Yuslittleiotifiedcyrillic:1128,Z:90,Zaarmenian:1334,Zacute:377,Zcaron:381,Zcaronsmall:63231,Zcircle:9423,Zcircumflex:7824,Zdot:379,Zdotaccent:379,Zdotbelow:7826,Zecyrillic:1047,Zedescendercyrillic:1176,Zedieresiscyrillic:1246,
Zeta:918,Zhearmenian:1338,Zhebrevecyrillic:1217,Zhecyrillic:1046,Zhedescendercyrillic:1174,Zhedieresiscyrillic:1244,Zlinebelow:7828,Zmonospace:65338,Zsmall:63354,Zstroke:437,a:97,aabengali:2438,aacute:225,aadeva:2310,aagujarati:2694,aagurmukhi:2566,aamatragurmukhi:2622,aarusquare:13059,aavowelsignbengali:2494,aavowelsigndeva:2366,aavowelsigngujarati:2750,abbreviationmarkarmenian:1375,abbreviationsigndeva:2416,abengali:2437,abopomofo:12570,abreve:259,abreveacute:7855,abrevecyrillic:1233,abrevedotbelow:7863,
abrevegrave:7857,abrevehookabove:7859,abrevetilde:7861,acaron:462,acircle:9424,acircumflex:226,acircumflexacute:7845,acircumflexdotbelow:7853,acircumflexgrave:7847,acircumflexhookabove:7849,acircumflextilde:7851,acute:180,acutebelowcmb:791,acutecmb:769,acutecomb:769,acutedeva:2388,acutelowmod:719,acutetonecmb:833,acyrillic:1072,adblgrave:513,addakgurmukhi:2673,adeva:2309,adieresis:228,adieresiscyrillic:1235,adieresismacron:479,adotbelow:7841,adotmacron:481,ae:230,aeacute:509,aekorean:12624,aemacron:483,
afii00208:8213,afii08941:8356,afii10017:1040,afii10018:1041,afii10019:1042,afii10020:1043,afii10021:1044,afii10022:1045,afii10023:1025,afii10024:1046,afii10025:1047,afii10026:1048,afii10027:1049,afii10028:1050,afii10029:1051,afii10030:1052,afii10031:1053,afii10032:1054,afii10033:1055,afii10034:1056,afii10035:1057,afii10036:1058,afii10037:1059,afii10038:1060,afii10039:1061,afii10040:1062,afii10041:1063,afii10042:1064,afii10043:1065,afii10044:1066,afii10045:1067,afii10046:1068,afii10047:1069,afii10048:1070,
afii10049:1071,afii10050:1168,afii10051:1026,afii10052:1027,afii10053:1028,afii10054:1029,afii10055:1030,afii10056:1031,afii10057:1032,afii10058:1033,afii10059:1034,afii10060:1035,afii10061:1036,afii10062:1038,afii10063:63172,afii10064:63173,afii10065:1072,afii10066:1073,afii10067:1074,afii10068:1075,afii10069:1076,afii10070:1077,afii10071:1105,afii10072:1078,afii10073:1079,afii10074:1080,afii10075:1081,afii10076:1082,afii10077:1083,afii10078:1084,afii10079:1085,afii10080:1086,afii10081:1087,afii10082:1088,
afii10083:1089,afii10084:1090,afii10085:1091,afii10086:1092,afii10087:1093,afii10088:1094,afii10089:1095,afii10090:1096,afii10091:1097,afii10092:1098,afii10093:1099,afii10094:1100,afii10095:1101,afii10096:1102,afii10097:1103,afii10098:1169,afii10099:1106,afii10100:1107,afii10101:1108,afii10102:1109,afii10103:1110,afii10104:1111,afii10105:1112,afii10106:1113,afii10107:1114,afii10108:1115,afii10109:1116,afii10110:1118,afii10145:1039,afii10146:1122,afii10147:1138,afii10148:1140,afii10192:63174,afii10193:1119,
afii10194:1123,afii10195:1139,afii10196:1141,afii10831:63175,afii10832:63176,afii10846:1241,afii299:8206,afii300:8207,afii301:8205,afii57381:1642,afii57388:1548,afii57392:1632,afii57393:1633,afii57394:1634,afii57395:1635,afii57396:1636,afii57397:1637,afii57398:1638,afii57399:1639,afii57400:1640,afii57401:1641,afii57403:1563,afii57407:1567,afii57409:1569,afii57410:1570,afii57411:1571,afii57412:1572,afii57413:1573,afii57414:1574,afii57415:1575,afii57416:1576,afii57417:1577,afii57418:1578,afii57419:1579,
afii57420:1580,afii57421:1581,afii57422:1582,afii57423:1583,afii57424:1584,afii57425:1585,afii57426:1586,afii57427:1587,afii57428:1588,afii57429:1589,afii57430:1590,afii57431:1591,afii57432:1592,afii57433:1593,afii57434:1594,afii57440:1600,afii57441:1601,afii57442:1602,afii57443:1603,afii57444:1604,afii57445:1605,afii57446:1606,afii57448:1608,afii57449:1609,afii57450:1610,afii57451:1611,afii57452:1612,afii57453:1613,afii57454:1614,afii57455:1615,afii57456:1616,afii57457:1617,afii57458:1618,afii57470:1607,
afii57505:1700,afii57506:1662,afii57507:1670,afii57508:1688,afii57509:1711,afii57511:1657,afii57512:1672,afii57513:1681,afii57514:1722,afii57519:1746,afii57534:1749,afii57636:8362,afii57645:1470,afii57658:1475,afii57664:1488,afii57665:1489,afii57666:1490,afii57667:1491,afii57668:1492,afii57669:1493,afii57670:1494,afii57671:1495,afii57672:1496,afii57673:1497,afii57674:1498,afii57675:1499,afii57676:1500,afii57677:1501,afii57678:1502,afii57679:1503,afii57680:1504,afii57681:1505,afii57682:1506,afii57683:1507,
afii57684:1508,afii57685:1509,afii57686:1510,afii57687:1511,afii57688:1512,afii57689:1513,afii57690:1514,afii57694:64298,afii57695:64299,afii57700:64331,afii57705:64287,afii57716:1520,afii57717:1521,afii57718:1522,afii57723:64309,afii57793:1460,afii57794:1461,afii57795:1462,afii57796:1467,afii57797:1464,afii57798:1463,afii57799:1456,afii57800:1458,afii57801:1457,afii57802:1459,afii57803:1474,afii57804:1473,afii57806:1465,afii57807:1468,afii57839:1469,afii57841:1471,afii57842:1472,afii57929:700,afii61248:8453,
afii61289:8467,afii61352:8470,afii61573:8236,afii61574:8237,afii61575:8238,afii61664:8204,afii63167:1645,afii64937:701,agrave:224,agujarati:2693,agurmukhi:2565,ahiragana:12354,ahookabove:7843,aibengali:2448,aibopomofo:12574,aideva:2320,aiecyrillic:1237,aigujarati:2704,aigurmukhi:2576,aimatragurmukhi:2632,ainarabic:1593,ainfinalarabic:65226,aininitialarabic:65227,ainmedialarabic:65228,ainvertedbreve:515,aivowelsignbengali:2504,aivowelsigndeva:2376,aivowelsigngujarati:2760,akatakana:12450,akatakanahalfwidth:65393,
akorean:12623,alef:1488,alefarabic:1575,alefdageshhebrew:64304,aleffinalarabic:65166,alefhamzaabovearabic:1571,alefhamzaabovefinalarabic:65156,alefhamzabelowarabic:1573,alefhamzabelowfinalarabic:65160,alefhebrew:1488,aleflamedhebrew:64335,alefmaddaabovearabic:1570,alefmaddaabovefinalarabic:65154,alefmaksuraarabic:1609,alefmaksurafinalarabic:65264,alefmaksurainitialarabic:65267,alefmaksuramedialarabic:65268,alefpatahhebrew:64302,alefqamatshebrew:64303,aleph:8501,allequal:8780,alpha:945,alphatonos:940,
amacron:257,amonospace:65345,ampersand:38,ampersandmonospace:65286,ampersandsmall:63270,amsquare:13250,anbopomofo:12578,angbopomofo:12580,angbracketleft:12296,angbracketright:12297,angkhankhuthai:3674,angle:8736,anglebracketleft:12296,anglebracketleftvertical:65087,anglebracketright:12297,anglebracketrightvertical:65088,angleleft:9001,angleright:9002,angstrom:8491,anoteleia:903,anudattadeva:2386,anusvarabengali:2434,anusvaradeva:2306,anusvaragujarati:2690,aogonek:261,apaatosquare:13056,aparen:9372,
apostrophearmenian:1370,apostrophemod:700,apple:63743,approaches:8784,approxequal:8776,approxequalorimage:8786,approximatelyequal:8773,araeaekorean:12686,araeakorean:12685,arc:8978,arighthalfring:7834,aring:229,aringacute:507,aringbelow:7681,arrowboth:8596,arrowdashdown:8675,arrowdashleft:8672,arrowdashright:8674,arrowdashup:8673,arrowdblboth:8660,arrowdbldown:8659,arrowdblleft:8656,arrowdblright:8658,arrowdblup:8657,arrowdown:8595,arrowdownleft:8601,arrowdownright:8600,arrowdownwhite:8681,arrowheaddownmod:709,
arrowheadleftmod:706,arrowheadrightmod:707,arrowheadupmod:708,arrowhorizex:63719,arrowleft:8592,arrowleftdbl:8656,arrowleftdblstroke:8653,arrowleftoverright:8646,arrowleftwhite:8678,arrowright:8594,arrowrightdblstroke:8655,arrowrightheavy:10142,arrowrightoverleft:8644,arrowrightwhite:8680,arrowtableft:8676,arrowtabright:8677,arrowup:8593,arrowupdn:8597,arrowupdnbse:8616,arrowupdownbase:8616,arrowupleft:8598,arrowupleftofdown:8645,arrowupright:8599,arrowupwhite:8679,arrowvertex:63718,asciicircum:94,
asciicircummonospace:65342,asciitilde:126,asciitildemonospace:65374,ascript:593,ascriptturned:594,asmallhiragana:12353,asmallkatakana:12449,asmallkatakanahalfwidth:65383,asterisk:42,asteriskaltonearabic:1645,asteriskarabic:1645,asteriskmath:8727,asteriskmonospace:65290,asterisksmall:65121,asterism:8258,asuperior:63209,asymptoticallyequal:8771,at:64,atilde:227,atmonospace:65312,atsmall:65131,aturned:592,aubengali:2452,aubopomofo:12576,audeva:2324,augujarati:2708,augurmukhi:2580,aulengthmarkbengali:2519,
aumatragurmukhi:2636,auvowelsignbengali:2508,auvowelsigndeva:2380,auvowelsigngujarati:2764,avagrahadeva:2365,aybarmenian:1377,ayin:1506,ayinaltonehebrew:64288,ayinhebrew:1506,b:98,babengali:2476,backslash:92,backslashmonospace:65340,badeva:2348,bagujarati:2732,bagurmukhi:2604,bahiragana:12400,bahtthai:3647,bakatakana:12496,bar:124,barmonospace:65372,bbopomofo:12549,bcircle:9425,bdotaccent:7683,bdotbelow:7685,beamedsixteenthnotes:9836,because:8757,becyrillic:1073,beharabic:1576,behfinalarabic:65168,
behinitialarabic:65169,behiragana:12409,behmedialarabic:65170,behmeeminitialarabic:64671,behmeemisolatedarabic:64520,behnoonfinalarabic:64621,bekatakana:12505,benarmenian:1378,bet:1489,beta:946,betasymbolgreek:976,betdagesh:64305,betdageshhebrew:64305,bethebrew:1489,betrafehebrew:64332,bhabengali:2477,bhadeva:2349,bhagujarati:2733,bhagurmukhi:2605,bhook:595,bihiragana:12403,bikatakana:12499,bilabialclick:664,bindigurmukhi:2562,birusquare:13105,blackcircle:9679,blackdiamond:9670,blackdownpointingtriangle:9660,
blackleftpointingpointer:9668,blackleftpointingtriangle:9664,blacklenticularbracketleft:12304,blacklenticularbracketleftvertical:65083,blacklenticularbracketright:12305,blacklenticularbracketrightvertical:65084,blacklowerlefttriangle:9699,blacklowerrighttriangle:9698,blackrectangle:9644,blackrightpointingpointer:9658,blackrightpointingtriangle:9654,blacksmallsquare:9642,blacksmilingface:9787,blacksquare:9632,blackstar:9733,blackupperlefttriangle:9700,blackupperrighttriangle:9701,blackuppointingsmalltriangle:9652,
blackuppointingtriangle:9650,blank:9251,blinebelow:7687,block:9608,bmonospace:65346,bobaimaithai:3610,bohiragana:12412,bokatakana:12508,bparen:9373,bqsquare:13251,braceex:63732,braceleft:123,braceleftbt:63731,braceleftmid:63730,braceleftmonospace:65371,braceleftsmall:65115,bracelefttp:63729,braceleftvertical:65079,braceright:125,bracerightbt:63742,bracerightmid:63741,bracerightmonospace:65373,bracerightsmall:65116,bracerighttp:63740,bracerightvertical:65080,bracketleft:91,bracketleftbt:63728,bracketleftex:63727,
bracketleftmonospace:65339,bracketlefttp:63726,bracketright:93,bracketrightbt:63739,bracketrightex:63738,bracketrightmonospace:65341,bracketrighttp:63737,breve:728,brevebelowcmb:814,brevecmb:774,breveinvertedbelowcmb:815,breveinvertedcmb:785,breveinverteddoublecmb:865,bridgebelowcmb:810,bridgeinvertedbelowcmb:826,brokenbar:166,bstroke:384,bsuperior:63210,btopbar:387,buhiragana:12406,bukatakana:12502,bullet:8226,bulletinverse:9688,bulletoperator:8729,bullseye:9678,c:99,caarmenian:1390,cabengali:2458,
cacute:263,cadeva:2330,cagujarati:2714,cagurmukhi:2586,calsquare:13192,candrabindubengali:2433,candrabinducmb:784,candrabindudeva:2305,candrabindugujarati:2689,capslock:8682,careof:8453,caron:711,caronbelowcmb:812,caroncmb:780,carriagereturn:8629,cbopomofo:12568,ccaron:269,ccedilla:231,ccedillaacute:7689,ccircle:9426,ccircumflex:265,ccurl:597,cdot:267,cdotaccent:267,cdsquare:13253,cedilla:184,cedillacmb:807,cent:162,centigrade:8451,centinferior:63199,centmonospace:65504,centoldstyle:63394,centsuperior:63200,
chaarmenian:1401,chabengali:2459,chadeva:2331,chagujarati:2715,chagurmukhi:2587,chbopomofo:12564,cheabkhasiancyrillic:1213,checkmark:10003,checyrillic:1095,chedescenderabkhasiancyrillic:1215,chedescendercyrillic:1207,chedieresiscyrillic:1269,cheharmenian:1395,chekhakassiancyrillic:1228,cheverticalstrokecyrillic:1209,chi:967,chieuchacirclekorean:12919,chieuchaparenkorean:12823,chieuchcirclekorean:12905,chieuchkorean:12618,chieuchparenkorean:12809,chochangthai:3594,chochanthai:3592,chochingthai:3593,
chochoethai:3596,chook:392,cieucacirclekorean:12918,cieucaparenkorean:12822,cieuccirclekorean:12904,cieuckorean:12616,cieucparenkorean:12808,cieucuparenkorean:12828,circle:9675,circlecopyrt:169,circlemultiply:8855,circleot:8857,circleplus:8853,circlepostalmark:12342,circlewithlefthalfblack:9680,circlewithrighthalfblack:9681,circumflex:710,circumflexbelowcmb:813,circumflexcmb:770,clear:8999,clickalveolar:450,clickdental:448,clicklateral:449,clickretroflex:451,club:9827,clubsuitblack:9827,clubsuitwhite:9831,
cmcubedsquare:13220,cmonospace:65347,cmsquaredsquare:13216,coarmenian:1409,colon:58,colonmonetary:8353,colonmonospace:65306,colonsign:8353,colonsmall:65109,colontriangularhalfmod:721,colontriangularmod:720,comma:44,commaabovecmb:787,commaaboverightcmb:789,commaaccent:63171,commaarabic:1548,commaarmenian:1373,commainferior:63201,commamonospace:65292,commareversedabovecmb:788,commareversedmod:701,commasmall:65104,commasuperior:63202,commaturnedabovecmb:786,commaturnedmod:699,compass:9788,congruent:8773,
contourintegral:8750,control:8963,controlACK:6,controlBEL:7,controlBS:8,controlCAN:24,controlCR:13,controlDC1:17,controlDC2:18,controlDC3:19,controlDC4:20,controlDEL:127,controlDLE:16,controlEM:25,controlENQ:5,controlEOT:4,controlESC:27,controlETB:23,controlETX:3,controlFF:12,controlFS:28,controlGS:29,controlHT:9,controlLF:10,controlNAK:21,controlRS:30,controlSI:15,controlSO:14,controlSOT:2,controlSTX:1,controlSUB:26,controlSYN:22,controlUS:31,controlVT:11,copyright:169,copyrightsans:63721,copyrightserif:63193,
cornerbracketleft:12300,cornerbracketlefthalfwidth:65378,cornerbracketleftvertical:65089,cornerbracketright:12301,cornerbracketrighthalfwidth:65379,cornerbracketrightvertical:65090,corporationsquare:13183,cosquare:13255,coverkgsquare:13254,cparen:9374,cruzeiro:8354,cstretched:663,curlyand:8911,curlyor:8910,currency:164,cyrBreve:63185,cyrFlex:63186,cyrbreve:63188,cyrflex:63189,d:100,daarmenian:1380,dabengali:2470,dadarabic:1590,dadeva:2342,dadfinalarabic:65214,dadinitialarabic:65215,dadmedialarabic:65216,
dagesh:1468,dageshhebrew:1468,dagger:8224,daggerdbl:8225,dagujarati:2726,dagurmukhi:2598,dahiragana:12384,dakatakana:12480,dalarabic:1583,dalet:1491,daletdagesh:64307,daletdageshhebrew:64307,dalethebrew:1491,dalfinalarabic:65194,dammaarabic:1615,dammalowarabic:1615,dammatanaltonearabic:1612,dammatanarabic:1612,danda:2404,dargahebrew:1447,dargalefthebrew:1447,dasiapneumatacyrilliccmb:1157,dblGrave:63187,dblanglebracketleft:12298,dblanglebracketleftvertical:65085,dblanglebracketright:12299,dblanglebracketrightvertical:65086,
dblarchinvertedbelowcmb:811,dblarrowleft:8660,dblarrowright:8658,dbldanda:2405,dblgrave:63190,dblgravecmb:783,dblintegral:8748,dbllowline:8215,dbllowlinecmb:819,dbloverlinecmb:831,dblprimemod:698,dblverticalbar:8214,dblverticallineabovecmb:782,dbopomofo:12553,dbsquare:13256,dcaron:271,dcedilla:7697,dcircle:9427,dcircumflexbelow:7699,dcroat:273,ddabengali:2465,ddadeva:2337,ddagujarati:2721,ddagurmukhi:2593,ddalarabic:1672,ddalfinalarabic:64393,dddhadeva:2396,ddhabengali:2466,ddhadeva:2338,ddhagujarati:2722,
ddhagurmukhi:2594,ddotaccent:7691,ddotbelow:7693,decimalseparatorarabic:1643,decimalseparatorpersian:1643,decyrillic:1076,degree:176,dehihebrew:1453,dehiragana:12391,deicoptic:1007,dekatakana:12487,deleteleft:9003,deleteright:8998,delta:948,deltaturned:397,denominatorminusonenumeratorbengali:2552,dezh:676,dhabengali:2471,dhadeva:2343,dhagujarati:2727,dhagurmukhi:2599,dhook:599,dialytikatonos:901,dialytikatonoscmb:836,diamond:9830,diamondsuitwhite:9826,dieresis:168,dieresisacute:63191,dieresisbelowcmb:804,
dieresiscmb:776,dieresisgrave:63192,dieresistonos:901,dihiragana:12386,dikatakana:12482,dittomark:12291,divide:247,divides:8739,divisionslash:8725,djecyrillic:1106,dkshade:9619,dlinebelow:7695,dlsquare:13207,dmacron:273,dmonospace:65348,dnblock:9604,dochadathai:3598,dodekthai:3604,dohiragana:12393,dokatakana:12489,dollar:36,dollarinferior:63203,dollarmonospace:65284,dollaroldstyle:63268,dollarsmall:65129,dollarsuperior:63204,dong:8363,dorusquare:13094,dotaccent:729,dotaccentcmb:775,dotbelowcmb:803,
dotbelowcomb:803,dotkatakana:12539,dotlessi:305,dotlessj:63166,dotlessjstrokehook:644,dotmath:8901,dottedcircle:9676,doubleyodpatah:64287,doubleyodpatahhebrew:64287,downtackbelowcmb:798,downtackmod:725,dparen:9375,dsuperior:63211,dtail:598,dtopbar:396,duhiragana:12389,dukatakana:12485,dz:499,dzaltone:675,dzcaron:454,dzcurl:677,dzeabkhasiancyrillic:1249,dzecyrillic:1109,dzhecyrillic:1119,e:101,eacute:233,earth:9793,ebengali:2447,ebopomofo:12572,ebreve:277,ecandradeva:2317,ecandragujarati:2701,ecandravowelsigndeva:2373,
ecandravowelsigngujarati:2757,ecaron:283,ecedillabreve:7709,echarmenian:1381,echyiwnarmenian:1415,ecircle:9428,ecircumflex:234,ecircumflexacute:7871,ecircumflexbelow:7705,ecircumflexdotbelow:7879,ecircumflexgrave:7873,ecircumflexhookabove:7875,ecircumflextilde:7877,ecyrillic:1108,edblgrave:517,edeva:2319,edieresis:235,edot:279,edotaccent:279,edotbelow:7865,eegurmukhi:2575,eematragurmukhi:2631,efcyrillic:1092,egrave:232,egujarati:2703,eharmenian:1383,ehbopomofo:12573,ehiragana:12360,ehookabove:7867,
eibopomofo:12575,eight:56,eightarabic:1640,eightbengali:2542,eightcircle:9319,eightcircleinversesansserif:10129,eightdeva:2414,eighteencircle:9329,eighteenparen:9349,eighteenperiod:9369,eightgujarati:2798,eightgurmukhi:2670,eighthackarabic:1640,eighthangzhou:12328,eighthnotebeamed:9835,eightideographicparen:12839,eightinferior:8328,eightmonospace:65304,eightoldstyle:63288,eightparen:9339,eightperiod:9359,eightpersian:1784,eightroman:8567,eightsuperior:8312,eightthai:3672,einvertedbreve:519,eiotifiedcyrillic:1125,
ekatakana:12456,ekatakanahalfwidth:65396,ekonkargurmukhi:2676,ekorean:12628,elcyrillic:1083,element:8712,elevencircle:9322,elevenparen:9342,elevenperiod:9362,elevenroman:8570,ellipsis:8230,ellipsisvertical:8942,emacron:275,emacronacute:7703,emacrongrave:7701,emcyrillic:1084,emdash:8212,emdashvertical:65073,emonospace:65349,emphasismarkarmenian:1371,emptyset:8709,enbopomofo:12579,encyrillic:1085,endash:8211,endashvertical:65074,endescendercyrillic:1187,eng:331,engbopomofo:12581,enghecyrillic:1189,
enhookcyrillic:1224,enspace:8194,eogonek:281,eokorean:12627,eopen:603,eopenclosed:666,eopenreversed:604,eopenreversedclosed:606,eopenreversedhook:605,eparen:9376,epsilon:949,epsilontonos:941,equal:61,equalmonospace:65309,equalsmall:65126,equalsuperior:8316,equivalence:8801,erbopomofo:12582,ercyrillic:1088,ereversed:600,ereversedcyrillic:1101,escyrillic:1089,esdescendercyrillic:1195,esh:643,eshcurl:646,eshortdeva:2318,eshortvowelsigndeva:2374,eshreversedloop:426,eshsquatreversed:645,esmallhiragana:12359,
esmallkatakana:12455,esmallkatakanahalfwidth:65386,estimated:8494,esuperior:63212,eta:951,etarmenian:1384,etatonos:942,eth:240,etilde:7869,etildebelow:7707,etnahtafoukhhebrew:1425,etnahtafoukhlefthebrew:1425,etnahtahebrew:1425,etnahtalefthebrew:1425,eturned:477,eukorean:12641,euro:8364,evowelsignbengali:2503,evowelsigndeva:2375,evowelsigngujarati:2759,exclam:33,exclamarmenian:1372,exclamdbl:8252,exclamdown:161,exclamdownsmall:63393,exclammonospace:65281,exclamsmall:63265,existential:8707,ezh:658,
ezhcaron:495,ezhcurl:659,ezhreversed:441,ezhtail:442,f:102,fadeva:2398,fagurmukhi:2654,fahrenheit:8457,fathaarabic:1614,fathalowarabic:1614,fathatanarabic:1611,fbopomofo:12552,fcircle:9429,fdotaccent:7711,feharabic:1601,feharmenian:1414,fehfinalarabic:65234,fehinitialarabic:65235,fehmedialarabic:65236,feicoptic:997,female:9792,ff:64256,ffi:64259,ffl:64260,fi:64257,fifteencircle:9326,fifteenparen:9346,fifteenperiod:9366,figuredash:8210,filledbox:9632,filledrect:9644,finalkaf:1498,finalkafdagesh:64314,
finalkafdageshhebrew:64314,finalkafhebrew:1498,finalmem:1501,finalmemhebrew:1501,finalnun:1503,finalnunhebrew:1503,finalpe:1507,finalpehebrew:1507,finaltsadi:1509,finaltsadihebrew:1509,firsttonechinese:713,fisheye:9673,fitacyrillic:1139,five:53,fivearabic:1637,fivebengali:2539,fivecircle:9316,fivecircleinversesansserif:10126,fivedeva:2411,fiveeighths:8541,fivegujarati:2795,fivegurmukhi:2667,fivehackarabic:1637,fivehangzhou:12325,fiveideographicparen:12836,fiveinferior:8325,fivemonospace:65301,fiveoldstyle:63285,
fiveparen:9336,fiveperiod:9356,fivepersian:1781,fiveroman:8564,fivesuperior:8309,fivethai:3669,fl:64258,florin:402,fmonospace:65350,fmsquare:13209,fofanthai:3615,fofathai:3613,fongmanthai:3663,forall:8704,four:52,fourarabic:1636,fourbengali:2538,fourcircle:9315,fourcircleinversesansserif:10125,fourdeva:2410,fourgujarati:2794,fourgurmukhi:2666,fourhackarabic:1636,fourhangzhou:12324,fourideographicparen:12835,fourinferior:8324,fourmonospace:65300,fournumeratorbengali:2551,fouroldstyle:63284,fourparen:9335,
fourperiod:9355,fourpersian:1780,fourroman:8563,foursuperior:8308,fourteencircle:9325,fourteenparen:9345,fourteenperiod:9365,fourthai:3668,fourthtonechinese:715,fparen:9377,fraction:8260,franc:8355,g:103,gabengali:2455,gacute:501,gadeva:2327,gafarabic:1711,gaffinalarabic:64403,gafinitialarabic:64404,gafmedialarabic:64405,gagujarati:2711,gagurmukhi:2583,gahiragana:12364,gakatakana:12460,gamma:947,gammalatinsmall:611,gammasuperior:736,gangiacoptic:1003,gbopomofo:12557,gbreve:287,gcaron:487,gcedilla:291,
gcircle:9430,gcircumflex:285,gcommaaccent:291,gdot:289,gdotaccent:289,gecyrillic:1075,gehiragana:12370,gekatakana:12466,geometricallyequal:8785,gereshaccenthebrew:1436,gereshhebrew:1523,gereshmuqdamhebrew:1437,germandbls:223,gershayimaccenthebrew:1438,gershayimhebrew:1524,getamark:12307,ghabengali:2456,ghadarmenian:1394,ghadeva:2328,ghagujarati:2712,ghagurmukhi:2584,ghainarabic:1594,ghainfinalarabic:65230,ghaininitialarabic:65231,ghainmedialarabic:65232,ghemiddlehookcyrillic:1173,ghestrokecyrillic:1171,
gheupturncyrillic:1169,ghhadeva:2394,ghhagurmukhi:2650,ghook:608,ghzsquare:13203,gihiragana:12366,gikatakana:12462,gimarmenian:1379,gimel:1490,gimeldagesh:64306,gimeldageshhebrew:64306,gimelhebrew:1490,gjecyrillic:1107,glottalinvertedstroke:446,glottalstop:660,glottalstopinverted:662,glottalstopmod:704,glottalstopreversed:661,glottalstopreversedmod:705,glottalstopreversedsuperior:740,glottalstopstroke:673,glottalstopstrokereversed:674,gmacron:7713,gmonospace:65351,gohiragana:12372,gokatakana:12468,
gparen:9378,gpasquare:13228,gradient:8711,grave:96,gravebelowcmb:790,gravecmb:768,gravecomb:768,gravedeva:2387,gravelowmod:718,gravemonospace:65344,gravetonecmb:832,greater:62,greaterequal:8805,greaterequalorless:8923,greatermonospace:65310,greaterorequivalent:8819,greaterorless:8823,greateroverequal:8807,greatersmall:65125,gscript:609,gstroke:485,guhiragana:12368,guillemotleft:171,guillemotright:187,guilsinglleft:8249,guilsinglright:8250,gukatakana:12464,guramusquare:13080,gysquare:13257,h:104,haabkhasiancyrillic:1193,
haaltonearabic:1729,habengali:2489,hadescendercyrillic:1203,hadeva:2361,hagujarati:2745,hagurmukhi:2617,haharabic:1581,hahfinalarabic:65186,hahinitialarabic:65187,hahiragana:12399,hahmedialarabic:65188,haitusquare:13098,hakatakana:12495,hakatakanahalfwidth:65418,halantgurmukhi:2637,hamzaarabic:1569,hamzalowarabic:1569,hangulfiller:12644,hardsigncyrillic:1098,harpoonleftbarbup:8636,harpoonrightbarbup:8640,hasquare:13258,hatafpatah:1458,hatafpatah16:1458,hatafpatah23:1458,hatafpatah2f:1458,hatafpatahhebrew:1458,
hatafpatahnarrowhebrew:1458,hatafpatahquarterhebrew:1458,hatafpatahwidehebrew:1458,hatafqamats:1459,hatafqamats1b:1459,hatafqamats28:1459,hatafqamats34:1459,hatafqamatshebrew:1459,hatafqamatsnarrowhebrew:1459,hatafqamatsquarterhebrew:1459,hatafqamatswidehebrew:1459,hatafsegol:1457,hatafsegol17:1457,hatafsegol24:1457,hatafsegol30:1457,hatafsegolhebrew:1457,hatafsegolnarrowhebrew:1457,hatafsegolquarterhebrew:1457,hatafsegolwidehebrew:1457,hbar:295,hbopomofo:12559,hbrevebelow:7723,hcedilla:7721,hcircle:9431,
hcircumflex:293,hdieresis:7719,hdotaccent:7715,hdotbelow:7717,he:1492,heart:9829,heartsuitblack:9829,heartsuitwhite:9825,hedagesh:64308,hedageshhebrew:64308,hehaltonearabic:1729,heharabic:1607,hehebrew:1492,hehfinalaltonearabic:64423,hehfinalalttwoarabic:65258,hehfinalarabic:65258,hehhamzaabovefinalarabic:64421,hehhamzaaboveisolatedarabic:64420,hehinitialaltonearabic:64424,hehinitialarabic:65259,hehiragana:12408,hehmedialaltonearabic:64425,hehmedialarabic:65260,heiseierasquare:13179,hekatakana:12504,
hekatakanahalfwidth:65421,hekutaarusquare:13110,henghook:615,herutusquare:13113,het:1495,hethebrew:1495,hhook:614,hhooksuperior:689,hieuhacirclekorean:12923,hieuhaparenkorean:12827,hieuhcirclekorean:12909,hieuhkorean:12622,hieuhparenkorean:12813,hihiragana:12402,hikatakana:12498,hikatakanahalfwidth:65419,hiriq:1460,hiriq14:1460,hiriq21:1460,hiriq2d:1460,hiriqhebrew:1460,hiriqnarrowhebrew:1460,hiriqquarterhebrew:1460,hiriqwidehebrew:1460,hlinebelow:7830,hmonospace:65352,hoarmenian:1392,hohipthai:3627,
hohiragana:12411,hokatakana:12507,hokatakanahalfwidth:65422,holam:1465,holam19:1465,holam26:1465,holam32:1465,holamhebrew:1465,holamnarrowhebrew:1465,holamquarterhebrew:1465,holamwidehebrew:1465,honokhukthai:3630,hookabovecomb:777,hookcmb:777,hookpalatalizedbelowcmb:801,hookretroflexbelowcmb:802,hoonsquare:13122,horicoptic:1001,horizontalbar:8213,horncmb:795,hotsprings:9832,house:8962,hparen:9379,hsuperior:688,hturned:613,huhiragana:12405,huiitosquare:13107,hukatakana:12501,hukatakanahalfwidth:65420,
hungarumlaut:733,hungarumlautcmb:779,hv:405,hyphen:45,hypheninferior:63205,hyphenmonospace:65293,hyphensmall:65123,hyphensuperior:63206,hyphentwo:8208,i:105,iacute:237,iacyrillic:1103,ibengali:2439,ibopomofo:12583,ibreve:301,icaron:464,icircle:9432,icircumflex:238,icyrillic:1110,idblgrave:521,ideographearthcircle:12943,ideographfirecircle:12939,ideographicallianceparen:12863,ideographiccallparen:12858,ideographiccentrecircle:12965,ideographicclose:12294,ideographiccomma:12289,ideographiccommaleft:65380,
ideographiccongratulationparen:12855,ideographiccorrectcircle:12963,ideographicearthparen:12847,ideographicenterpriseparen:12861,ideographicexcellentcircle:12957,ideographicfestivalparen:12864,ideographicfinancialcircle:12950,ideographicfinancialparen:12854,ideographicfireparen:12843,ideographichaveparen:12850,ideographichighcircle:12964,ideographiciterationmark:12293,ideographiclaborcircle:12952,ideographiclaborparen:12856,ideographicleftcircle:12967,ideographiclowcircle:12966,ideographicmedicinecircle:12969,
ideographicmetalparen:12846,ideographicmoonparen:12842,ideographicnameparen:12852,ideographicperiod:12290,ideographicprintcircle:12958,ideographicreachparen:12867,ideographicrepresentparen:12857,ideographicresourceparen:12862,ideographicrightcircle:12968,ideographicsecretcircle:12953,ideographicselfparen:12866,ideographicsocietyparen:12851,ideographicspace:12288,ideographicspecialparen:12853,ideographicstockparen:12849,ideographicstudyparen:12859,ideographicsunparen:12848,ideographicsuperviseparen:12860,
ideographicwaterparen:12844,ideographicwoodparen:12845,ideographiczero:12295,ideographmetalcircle:12942,ideographmooncircle:12938,ideographnamecircle:12948,ideographsuncircle:12944,ideographwatercircle:12940,ideographwoodcircle:12941,ideva:2311,idieresis:239,idieresisacute:7727,idieresiscyrillic:1253,idotbelow:7883,iebrevecyrillic:1239,iecyrillic:1077,ieungacirclekorean:12917,ieungaparenkorean:12821,ieungcirclekorean:12903,ieungkorean:12615,ieungparenkorean:12807,igrave:236,igujarati:2695,igurmukhi:2567,
ihiragana:12356,ihookabove:7881,iibengali:2440,iicyrillic:1080,iideva:2312,iigujarati:2696,iigurmukhi:2568,iimatragurmukhi:2624,iinvertedbreve:523,iishortcyrillic:1081,iivowelsignbengali:2496,iivowelsigndeva:2368,iivowelsigngujarati:2752,ij:307,ikatakana:12452,ikatakanahalfwidth:65394,ikorean:12643,ilde:732,iluyhebrew:1452,imacron:299,imacroncyrillic:1251,imageorapproximatelyequal:8787,imatragurmukhi:2623,imonospace:65353,increment:8710,infinity:8734,iniarmenian:1387,integral:8747,integralbottom:8993,
integralbt:8993,integralex:63733,integraltop:8992,integraltp:8992,intersection:8745,intisquare:13061,invbullet:9688,invcircle:9689,invsmileface:9787,iocyrillic:1105,iogonek:303,iota:953,iotadieresis:970,iotadieresistonos:912,iotalatin:617,iotatonos:943,iparen:9380,irigurmukhi:2674,ismallhiragana:12355,ismallkatakana:12451,ismallkatakanahalfwidth:65384,issharbengali:2554,istroke:616,isuperior:63213,iterationhiragana:12445,iterationkatakana:12541,itilde:297,itildebelow:7725,iubopomofo:12585,iucyrillic:1102,
ivowelsignbengali:2495,ivowelsigndeva:2367,ivowelsigngujarati:2751,izhitsacyrillic:1141,izhitsadblgravecyrillic:1143,j:106,jaarmenian:1393,jabengali:2460,jadeva:2332,jagujarati:2716,jagurmukhi:2588,jbopomofo:12560,jcaron:496,jcircle:9433,jcircumflex:309,jcrossedtail:669,jdotlessstroke:607,jecyrillic:1112,jeemarabic:1580,jeemfinalarabic:65182,jeeminitialarabic:65183,jeemmedialarabic:65184,jeharabic:1688,jehfinalarabic:64395,jhabengali:2461,jhadeva:2333,jhagujarati:2717,jhagurmukhi:2589,jheharmenian:1403,
jis:12292,jmonospace:65354,jparen:9381,jsuperior:690,k:107,kabashkircyrillic:1185,kabengali:2453,kacute:7729,kacyrillic:1082,kadescendercyrillic:1179,kadeva:2325,kaf:1499,kafarabic:1603,kafdagesh:64315,kafdageshhebrew:64315,kaffinalarabic:65242,kafhebrew:1499,kafinitialarabic:65243,kafmedialarabic:65244,kafrafehebrew:64333,kagujarati:2709,kagurmukhi:2581,kahiragana:12363,kahookcyrillic:1220,kakatakana:12459,kakatakanahalfwidth:65398,kappa:954,kappasymbolgreek:1008,kapyeounmieumkorean:12657,kapyeounphieuphkorean:12676,
kapyeounpieupkorean:12664,kapyeounssangpieupkorean:12665,karoriisquare:13069,kashidaautoarabic:1600,kashidaautonosidebearingarabic:1600,kasmallkatakana:12533,kasquare:13188,kasraarabic:1616,kasratanarabic:1613,kastrokecyrillic:1183,katahiraprolongmarkhalfwidth:65392,kaverticalstrokecyrillic:1181,kbopomofo:12558,kcalsquare:13193,kcaron:489,kcedilla:311,kcircle:9434,kcommaaccent:311,kdotbelow:7731,keharmenian:1412,kehiragana:12369,kekatakana:12465,kekatakanahalfwidth:65401,kenarmenian:1391,kesmallkatakana:12534,
kgreenlandic:312,khabengali:2454,khacyrillic:1093,khadeva:2326,khagujarati:2710,khagurmukhi:2582,khaharabic:1582,khahfinalarabic:65190,khahinitialarabic:65191,khahmedialarabic:65192,kheicoptic:999,khhadeva:2393,khhagurmukhi:2649,khieukhacirclekorean:12920,khieukhaparenkorean:12824,khieukhcirclekorean:12906,khieukhkorean:12619,khieukhparenkorean:12810,khokhaithai:3586,khokhonthai:3589,khokhuatthai:3587,khokhwaithai:3588,khomutthai:3675,khook:409,khorakhangthai:3590,khzsquare:13201,kihiragana:12365,
kikatakana:12461,kikatakanahalfwidth:65399,kiroguramusquare:13077,kiromeetorusquare:13078,kirosquare:13076,kiyeokacirclekorean:12910,kiyeokaparenkorean:12814,kiyeokcirclekorean:12896,kiyeokkorean:12593,kiyeokparenkorean:12800,kiyeoksioskorean:12595,kjecyrillic:1116,klinebelow:7733,klsquare:13208,kmcubedsquare:13222,kmonospace:65355,kmsquaredsquare:13218,kohiragana:12371,kohmsquare:13248,kokaithai:3585,kokatakana:12467,kokatakanahalfwidth:65402,kooposquare:13086,koppacyrillic:1153,koreanstandardsymbol:12927,
koroniscmb:835,kparen:9382,kpasquare:13226,ksicyrillic:1135,ktsquare:13263,kturned:670,kuhiragana:12367,kukatakana:12463,kukatakanahalfwidth:65400,kvsquare:13240,kwsquare:13246,l:108,labengali:2482,lacute:314,ladeva:2354,lagujarati:2738,lagurmukhi:2610,lakkhangyaothai:3653,lamaleffinalarabic:65276,lamalefhamzaabovefinalarabic:65272,lamalefhamzaaboveisolatedarabic:65271,lamalefhamzabelowfinalarabic:65274,lamalefhamzabelowisolatedarabic:65273,lamalefisolatedarabic:65275,lamalefmaddaabovefinalarabic:65270,
lamalefmaddaaboveisolatedarabic:65269,lamarabic:1604,lambda:955,lambdastroke:411,lamed:1500,lameddagesh:64316,lameddageshhebrew:64316,lamedhebrew:1500,lamfinalarabic:65246,lamhahinitialarabic:64714,laminitialarabic:65247,lamjeeminitialarabic:64713,lamkhahinitialarabic:64715,lamlamhehisolatedarabic:65010,lammedialarabic:65248,lammeemhahinitialarabic:64904,lammeeminitialarabic:64716,largecircle:9711,lbar:410,lbelt:620,lbopomofo:12556,lcaron:318,lcedilla:316,lcircle:9435,lcircumflexbelow:7741,lcommaaccent:316,
ldot:320,ldotaccent:320,ldotbelow:7735,ldotbelowmacron:7737,leftangleabovecmb:794,lefttackbelowcmb:792,less:60,lessequal:8804,lessequalorgreater:8922,lessmonospace:65308,lessorequivalent:8818,lessorgreater:8822,lessoverequal:8806,lesssmall:65124,lezh:622,lfblock:9612,lhookretroflex:621,lira:8356,liwnarmenian:1388,lj:457,ljecyrillic:1113,ll:63168,lladeva:2355,llagujarati:2739,llinebelow:7739,llladeva:2356,llvocalicbengali:2529,llvocalicdeva:2401,llvocalicvowelsignbengali:2531,llvocalicvowelsigndeva:2403,
lmiddletilde:619,lmonospace:65356,lmsquare:13264,lochulathai:3628,logicaland:8743,logicalnot:172,logicalnotreversed:8976,logicalor:8744,lolingthai:3621,longs:383,lowlinecenterline:65102,lowlinecmb:818,lowlinedashed:65101,lozenge:9674,lparen:9383,lslash:322,lsquare:8467,lsuperior:63214,ltshade:9617,luthai:3622,lvocalicbengali:2444,lvocalicdeva:2316,lvocalicvowelsignbengali:2530,lvocalicvowelsigndeva:2402,lxsquare:13267,m:109,mabengali:2478,macron:175,macronbelowcmb:817,macroncmb:772,macronlowmod:717,
macronmonospace:65507,macute:7743,madeva:2350,magujarati:2734,magurmukhi:2606,mahapakhhebrew:1444,mahapakhlefthebrew:1444,mahiragana:12414,maichattawalowleftthai:63637,maichattawalowrightthai:63636,maichattawathai:3659,maichattawaupperleftthai:63635,maieklowleftthai:63628,maieklowrightthai:63627,maiekthai:3656,maiekupperleftthai:63626,maihanakatleftthai:63620,maihanakatthai:3633,maitaikhuleftthai:63625,maitaikhuthai:3655,maitholowleftthai:63631,maitholowrightthai:63630,maithothai:3657,maithoupperleftthai:63629,
maitrilowleftthai:63634,maitrilowrightthai:63633,maitrithai:3658,maitriupperleftthai:63632,maiyamokthai:3654,makatakana:12510,makatakanahalfwidth:65423,male:9794,mansyonsquare:13127,maqafhebrew:1470,mars:9794,masoracirclehebrew:1455,masquare:13187,mbopomofo:12551,mbsquare:13268,mcircle:9436,mcubedsquare:13221,mdotaccent:7745,mdotbelow:7747,meemarabic:1605,meemfinalarabic:65250,meeminitialarabic:65251,meemmedialarabic:65252,meemmeeminitialarabic:64721,meemmeemisolatedarabic:64584,meetorusquare:13133,
mehiragana:12417,meizierasquare:13182,mekatakana:12513,mekatakanahalfwidth:65426,mem:1502,memdagesh:64318,memdageshhebrew:64318,memhebrew:1502,menarmenian:1396,merkhahebrew:1445,merkhakefulahebrew:1446,merkhakefulalefthebrew:1446,merkhalefthebrew:1445,mhook:625,mhzsquare:13202,middledotkatakanahalfwidth:65381,middot:183,mieumacirclekorean:12914,mieumaparenkorean:12818,mieumcirclekorean:12900,mieumkorean:12609,mieumpansioskorean:12656,mieumparenkorean:12804,mieumpieupkorean:12654,mieumsioskorean:12655,
mihiragana:12415,mikatakana:12511,mikatakanahalfwidth:65424,minus:8722,minusbelowcmb:800,minuscircle:8854,minusmod:727,minusplus:8723,minute:8242,miribaarusquare:13130,mirisquare:13129,mlonglegturned:624,mlsquare:13206,mmcubedsquare:13219,mmonospace:65357,mmsquaredsquare:13215,mohiragana:12418,mohmsquare:13249,mokatakana:12514,mokatakanahalfwidth:65427,molsquare:13270,momathai:3617,moverssquare:13223,moverssquaredsquare:13224,mparen:9384,mpasquare:13227,mssquare:13235,msuperior:63215,mturned:623,
mu:181,mu1:181,muasquare:13186,muchgreater:8811,muchless:8810,mufsquare:13196,mugreek:956,mugsquare:13197,muhiragana:12416,mukatakana:12512,mukatakanahalfwidth:65425,mulsquare:13205,multiply:215,mumsquare:13211,munahhebrew:1443,munahlefthebrew:1443,musicalnote:9834,musicalnotedbl:9835,musicflatsign:9837,musicsharpsign:9839,mussquare:13234,muvsquare:13238,muwsquare:13244,mvmegasquare:13241,mvsquare:13239,mwmegasquare:13247,mwsquare:13245,n:110,nabengali:2472,nabla:8711,nacute:324,nadeva:2344,nagujarati:2728,
nagurmukhi:2600,nahiragana:12394,nakatakana:12490,nakatakanahalfwidth:65413,napostrophe:329,nasquare:13185,nbopomofo:12555,nbspace:160,ncaron:328,ncedilla:326,ncircle:9437,ncircumflexbelow:7755,ncommaaccent:326,ndotaccent:7749,ndotbelow:7751,nehiragana:12397,nekatakana:12493,nekatakanahalfwidth:65416,newsheqelsign:8362,nfsquare:13195,ngabengali:2457,ngadeva:2329,ngagujarati:2713,ngagurmukhi:2585,ngonguthai:3591,nhiragana:12435,nhookleft:626,nhookretroflex:627,nieunacirclekorean:12911,nieunaparenkorean:12815,
nieuncieuckorean:12597,nieuncirclekorean:12897,nieunhieuhkorean:12598,nieunkorean:12596,nieunpansioskorean:12648,nieunparenkorean:12801,nieunsioskorean:12647,nieuntikeutkorean:12646,nihiragana:12395,nikatakana:12491,nikatakanahalfwidth:65414,nikhahitleftthai:63641,nikhahitthai:3661,nine:57,ninearabic:1641,ninebengali:2543,ninecircle:9320,ninecircleinversesansserif:10130,ninedeva:2415,ninegujarati:2799,ninegurmukhi:2671,ninehackarabic:1641,ninehangzhou:12329,nineideographicparen:12840,nineinferior:8329,
ninemonospace:65305,nineoldstyle:63289,nineparen:9340,nineperiod:9360,ninepersian:1785,nineroman:8568,ninesuperior:8313,nineteencircle:9330,nineteenparen:9350,nineteenperiod:9370,ninethai:3673,nj:460,njecyrillic:1114,nkatakana:12531,nkatakanahalfwidth:65437,nlegrightlong:414,nlinebelow:7753,nmonospace:65358,nmsquare:13210,nnabengali:2467,nnadeva:2339,nnagujarati:2723,nnagurmukhi:2595,nnnadeva:2345,nohiragana:12398,nokatakana:12494,nokatakanahalfwidth:65417,nonbreakingspace:160,nonenthai:3603,nonuthai:3609,
noonarabic:1606,noonfinalarabic:65254,noonghunnaarabic:1722,noonghunnafinalarabic:64415,nooninitialarabic:65255,noonjeeminitialarabic:64722,noonjeemisolatedarabic:64587,noonmedialarabic:65256,noonmeeminitialarabic:64725,noonmeemisolatedarabic:64590,noonnoonfinalarabic:64653,notcontains:8716,notelement:8713,notelementof:8713,notequal:8800,notgreater:8815,notgreaternorequal:8817,notgreaternorless:8825,notidentical:8802,notless:8814,notlessnorequal:8816,notparallel:8742,notprecedes:8832,notsubset:8836,
notsucceeds:8833,notsuperset:8837,nowarmenian:1398,nparen:9385,nssquare:13233,nsuperior:8319,ntilde:241,nu:957,nuhiragana:12396,nukatakana:12492,nukatakanahalfwidth:65415,nuktabengali:2492,nuktadeva:2364,nuktagujarati:2748,nuktagurmukhi:2620,numbersign:35,numbersignmonospace:65283,numbersignsmall:65119,numeralsigngreek:884,numeralsignlowergreek:885,numero:8470,nun:1504,nundagesh:64320,nundageshhebrew:64320,nunhebrew:1504,nvsquare:13237,nwsquare:13243,nyabengali:2462,nyadeva:2334,nyagujarati:2718,
nyagurmukhi:2590,o:111,oacute:243,oangthai:3629,obarred:629,obarredcyrillic:1257,obarreddieresiscyrillic:1259,obengali:2451,obopomofo:12571,obreve:335,ocandradeva:2321,ocandragujarati:2705,ocandravowelsigndeva:2377,ocandravowelsigngujarati:2761,ocaron:466,ocircle:9438,ocircumflex:244,ocircumflexacute:7889,ocircumflexdotbelow:7897,ocircumflexgrave:7891,ocircumflexhookabove:7893,ocircumflextilde:7895,ocyrillic:1086,odblacute:337,odblgrave:525,odeva:2323,odieresis:246,odieresiscyrillic:1255,odotbelow:7885,
oe:339,oekorean:12634,ogonek:731,ogonekcmb:808,ograve:242,ogujarati:2707,oharmenian:1413,ohiragana:12362,ohookabove:7887,ohorn:417,ohornacute:7899,ohorndotbelow:7907,ohorngrave:7901,ohornhookabove:7903,ohorntilde:7905,ohungarumlaut:337,oi:419,oinvertedbreve:527,okatakana:12458,okatakanahalfwidth:65397,okorean:12631,olehebrew:1451,omacron:333,omacronacute:7763,omacrongrave:7761,omdeva:2384,omega:969,omega1:982,omegacyrillic:1121,omegalatinclosed:631,omegaroundcyrillic:1147,omegatitlocyrillic:1149,
omegatonos:974,omgujarati:2768,omicron:959,omicrontonos:972,omonospace:65359,one:49,onearabic:1633,onebengali:2535,onecircle:9312,onecircleinversesansserif:10122,onedeva:2407,onedotenleader:8228,oneeighth:8539,onefitted:63196,onegujarati:2791,onegurmukhi:2663,onehackarabic:1633,onehalf:189,onehangzhou:12321,oneideographicparen:12832,oneinferior:8321,onemonospace:65297,onenumeratorbengali:2548,oneoldstyle:63281,oneparen:9332,oneperiod:9352,onepersian:1777,onequarter:188,oneroman:8560,onesuperior:185,
onethai:3665,onethird:8531,oogonek:491,oogonekmacron:493,oogurmukhi:2579,oomatragurmukhi:2635,oopen:596,oparen:9386,openbullet:9702,option:8997,ordfeminine:170,ordmasculine:186,orthogonal:8735,oshortdeva:2322,oshortvowelsigndeva:2378,oslash:248,oslashacute:511,osmallhiragana:12361,osmallkatakana:12457,osmallkatakanahalfwidth:65387,ostrokeacute:511,osuperior:63216,otcyrillic:1151,otilde:245,otildeacute:7757,otildedieresis:7759,oubopomofo:12577,overline:8254,overlinecenterline:65098,overlinecmb:773,
overlinedashed:65097,overlinedblwavy:65100,overlinewavy:65099,overscore:175,ovowelsignbengali:2507,ovowelsigndeva:2379,ovowelsigngujarati:2763,p:112,paampssquare:13184,paasentosquare:13099,pabengali:2474,pacute:7765,padeva:2346,pagedown:8671,pageup:8670,pagujarati:2730,pagurmukhi:2602,pahiragana:12401,paiyannoithai:3631,pakatakana:12497,palatalizationcyrilliccmb:1156,palochkacyrillic:1216,pansioskorean:12671,paragraph:182,parallel:8741,parenleft:40,parenleftaltonearabic:64830,parenleftbt:63725,parenleftex:63724,
parenleftinferior:8333,parenleftmonospace:65288,parenleftsmall:65113,parenleftsuperior:8317,parenlefttp:63723,parenleftvertical:65077,parenright:41,parenrightaltonearabic:64831,parenrightbt:63736,parenrightex:63735,parenrightinferior:8334,parenrightmonospace:65289,parenrightsmall:65114,parenrightsuperior:8318,parenrighttp:63734,parenrightvertical:65078,partialdiff:8706,paseqhebrew:1472,pashtahebrew:1433,pasquare:13225,patah:1463,patah11:1463,patah1d:1463,patah2a:1463,patahhebrew:1463,patahnarrowhebrew:1463,
patahquarterhebrew:1463,patahwidehebrew:1463,pazerhebrew:1441,pbopomofo:12550,pcircle:9439,pdotaccent:7767,pe:1508,pecyrillic:1087,pedagesh:64324,pedageshhebrew:64324,peezisquare:13115,pefinaldageshhebrew:64323,peharabic:1662,peharmenian:1402,pehebrew:1508,pehfinalarabic:64343,pehinitialarabic:64344,pehiragana:12410,pehmedialarabic:64345,pekatakana:12506,pemiddlehookcyrillic:1191,perafehebrew:64334,percent:37,percentarabic:1642,percentmonospace:65285,percentsmall:65130,period:46,periodarmenian:1417,
periodcentered:183,periodhalfwidth:65377,periodinferior:63207,periodmonospace:65294,periodsmall:65106,periodsuperior:63208,perispomenigreekcmb:834,perpendicular:8869,perthousand:8240,peseta:8359,pfsquare:13194,phabengali:2475,phadeva:2347,phagujarati:2731,phagurmukhi:2603,phi:966,phi1:981,phieuphacirclekorean:12922,phieuphaparenkorean:12826,phieuphcirclekorean:12908,phieuphkorean:12621,phieuphparenkorean:12812,philatin:632,phinthuthai:3642,phisymbolgreek:981,phook:421,phophanthai:3614,phophungthai:3612,
phosamphaothai:3616,pi:960,pieupacirclekorean:12915,pieupaparenkorean:12819,pieupcieuckorean:12662,pieupcirclekorean:12901,pieupkiyeokkorean:12658,pieupkorean:12610,pieupparenkorean:12805,pieupsioskiyeokkorean:12660,pieupsioskorean:12612,pieupsiostikeutkorean:12661,pieupthieuthkorean:12663,pieuptikeutkorean:12659,pihiragana:12404,pikatakana:12500,pisymbolgreek:982,piwrarmenian:1411,plus:43,plusbelowcmb:799,pluscircle:8853,plusminus:177,plusmod:726,plusmonospace:65291,plussmall:65122,plussuperior:8314,
pmonospace:65360,pmsquare:13272,pohiragana:12413,pointingindexdownwhite:9759,pointingindexleftwhite:9756,pointingindexrightwhite:9758,pointingindexupwhite:9757,pokatakana:12509,poplathai:3611,postalmark:12306,postalmarkface:12320,pparen:9387,precedes:8826,prescription:8478,primemod:697,primereversed:8245,product:8719,projective:8965,prolongedkana:12540,propellor:8984,propersubset:8834,propersuperset:8835,proportion:8759,proportional:8733,psi:968,psicyrillic:1137,psilipneumatacyrilliccmb:1158,pssquare:13232,
puhiragana:12407,pukatakana:12503,pvsquare:13236,pwsquare:13242,q:113,qadeva:2392,qadmahebrew:1448,qafarabic:1602,qaffinalarabic:65238,qafinitialarabic:65239,qafmedialarabic:65240,qamats:1464,qamats10:1464,qamats1a:1464,qamats1c:1464,qamats27:1464,qamats29:1464,qamats33:1464,qamatsde:1464,qamatshebrew:1464,qamatsnarrowhebrew:1464,qamatsqatanhebrew:1464,qamatsqatannarrowhebrew:1464,qamatsqatanquarterhebrew:1464,qamatsqatanwidehebrew:1464,qamatsquarterhebrew:1464,qamatswidehebrew:1464,qarneyparahebrew:1439,
qbopomofo:12561,qcircle:9440,qhook:672,qmonospace:65361,qof:1511,qofdagesh:64327,qofdageshhebrew:64327,qofhebrew:1511,qparen:9388,quarternote:9833,qubuts:1467,qubuts18:1467,qubuts25:1467,qubuts31:1467,qubutshebrew:1467,qubutsnarrowhebrew:1467,qubutsquarterhebrew:1467,qubutswidehebrew:1467,question:63,questionarabic:1567,questionarmenian:1374,questiondown:191,questiondownsmall:63423,questiongreek:894,questionmonospace:65311,questionsmall:63295,quotedbl:34,quotedblbase:8222,quotedblleft:8220,quotedblmonospace:65282,
quotedblprime:12318,quotedblprimereversed:12317,quotedblright:8221,quoteleft:8216,quoteleftreversed:8219,quotereversed:8219,quoteright:8217,quoterightn:329,quotesinglbase:8218,quotesingle:39,quotesinglemonospace:65287,r:114,raarmenian:1404,rabengali:2480,racute:341,radeva:2352,radical:8730,radicalex:63717,radoverssquare:13230,radoverssquaredsquare:13231,radsquare:13229,rafe:1471,rafehebrew:1471,ragujarati:2736,ragurmukhi:2608,rahiragana:12425,rakatakana:12521,rakatakanahalfwidth:65431,ralowerdiagonalbengali:2545,
ramiddlediagonalbengali:2544,ramshorn:612,ratio:8758,rbopomofo:12566,rcaron:345,rcedilla:343,rcircle:9441,rcommaaccent:343,rdblgrave:529,rdotaccent:7769,rdotbelow:7771,rdotbelowmacron:7773,referencemark:8251,reflexsubset:8838,reflexsuperset:8839,registered:174,registersans:63720,registerserif:63194,reharabic:1585,reharmenian:1408,rehfinalarabic:65198,rehiragana:12428,rekatakana:12524,rekatakanahalfwidth:65434,resh:1512,reshdageshhebrew:64328,reshhebrew:1512,reversedtilde:8765,reviahebrew:1431,reviamugrashhebrew:1431,
revlogicalnot:8976,rfishhook:638,rfishhookreversed:639,rhabengali:2525,rhadeva:2397,rho:961,rhook:637,rhookturned:635,rhookturnedsuperior:693,rhosymbolgreek:1009,rhotichookmod:734,rieulacirclekorean:12913,rieulaparenkorean:12817,rieulcirclekorean:12899,rieulhieuhkorean:12608,rieulkiyeokkorean:12602,rieulkiyeoksioskorean:12649,rieulkorean:12601,rieulmieumkorean:12603,rieulpansioskorean:12652,rieulparenkorean:12803,rieulphieuphkorean:12607,rieulpieupkorean:12604,rieulpieupsioskorean:12651,rieulsioskorean:12605,
rieulthieuthkorean:12606,rieultikeutkorean:12650,rieulyeorinhieuhkorean:12653,rightangle:8735,righttackbelowcmb:793,righttriangle:8895,rihiragana:12426,rikatakana:12522,rikatakanahalfwidth:65432,ring:730,ringbelowcmb:805,ringcmb:778,ringhalfleft:703,ringhalfleftarmenian:1369,ringhalfleftbelowcmb:796,ringhalfleftcentered:723,ringhalfright:702,ringhalfrightbelowcmb:825,ringhalfrightcentered:722,rinvertedbreve:531,rittorusquare:13137,rlinebelow:7775,rlongleg:636,rlonglegturned:634,rmonospace:65362,rohiragana:12429,
rokatakana:12525,rokatakanahalfwidth:65435,roruathai:3619,rparen:9389,rrabengali:2524,rradeva:2353,rragurmukhi:2652,rreharabic:1681,rrehfinalarabic:64397,rrvocalicbengali:2528,rrvocalicdeva:2400,rrvocalicgujarati:2784,rrvocalicvowelsignbengali:2500,rrvocalicvowelsigndeva:2372,rrvocalicvowelsigngujarati:2756,rsuperior:63217,rtblock:9616,rturned:633,rturnedsuperior:692,ruhiragana:12427,rukatakana:12523,rukatakanahalfwidth:65433,rupeemarkbengali:2546,rupeesignbengali:2547,rupiah:63197,ruthai:3620,rvocalicbengali:2443,
rvocalicdeva:2315,rvocalicgujarati:2699,rvocalicvowelsignbengali:2499,rvocalicvowelsigndeva:2371,rvocalicvowelsigngujarati:2755,s:115,sabengali:2488,sacute:347,sacutedotaccent:7781,sadarabic:1589,sadeva:2360,sadfinalarabic:65210,sadinitialarabic:65211,sadmedialarabic:65212,sagujarati:2744,sagurmukhi:2616,sahiragana:12373,sakatakana:12469,sakatakanahalfwidth:65403,sallallahoualayhewasallamarabic:65018,samekh:1505,samekhdagesh:64321,samekhdageshhebrew:64321,samekhhebrew:1505,saraaathai:3634,saraaethai:3649,
saraaimaimalaithai:3652,saraaimaimuanthai:3651,saraamthai:3635,saraathai:3632,saraethai:3648,saraiileftthai:63622,saraiithai:3637,saraileftthai:63621,saraithai:3636,saraothai:3650,saraueeleftthai:63624,saraueethai:3639,saraueleftthai:63623,sarauethai:3638,sarauthai:3640,sarauuthai:3641,sbopomofo:12569,scaron:353,scarondotaccent:7783,scedilla:351,schwa:601,schwacyrillic:1241,schwadieresiscyrillic:1243,schwahook:602,scircle:9442,scircumflex:349,scommaaccent:537,sdotaccent:7777,sdotbelow:7779,sdotbelowdotaccent:7785,
seagullbelowcmb:828,second:8243,secondtonechinese:714,section:167,seenarabic:1587,seenfinalarabic:65202,seeninitialarabic:65203,seenmedialarabic:65204,segol:1462,segol13:1462,segol1f:1462,segol2c:1462,segolhebrew:1462,segolnarrowhebrew:1462,segolquarterhebrew:1462,segoltahebrew:1426,segolwidehebrew:1462,seharmenian:1405,sehiragana:12379,sekatakana:12475,sekatakanahalfwidth:65406,semicolon:59,semicolonarabic:1563,semicolonmonospace:65307,semicolonsmall:65108,semivoicedmarkkana:12444,semivoicedmarkkanahalfwidth:65439,
sentisquare:13090,sentosquare:13091,seven:55,sevenarabic:1639,sevenbengali:2541,sevencircle:9318,sevencircleinversesansserif:10128,sevendeva:2413,seveneighths:8542,sevengujarati:2797,sevengurmukhi:2669,sevenhackarabic:1639,sevenhangzhou:12327,sevenideographicparen:12838,seveninferior:8327,sevenmonospace:65303,sevenoldstyle:63287,sevenparen:9338,sevenperiod:9358,sevenpersian:1783,sevenroman:8566,sevensuperior:8311,seventeencircle:9328,seventeenparen:9348,seventeenperiod:9368,seventhai:3671,sfthyphen:173,
shaarmenian:1399,shabengali:2486,shacyrillic:1096,shaddaarabic:1617,shaddadammaarabic:64609,shaddadammatanarabic:64606,shaddafathaarabic:64608,shaddakasraarabic:64610,shaddakasratanarabic:64607,shade:9618,shadedark:9619,shadelight:9617,shademedium:9618,shadeva:2358,shagujarati:2742,shagurmukhi:2614,shalshelethebrew:1427,shbopomofo:12565,shchacyrillic:1097,sheenarabic:1588,sheenfinalarabic:65206,sheeninitialarabic:65207,sheenmedialarabic:65208,sheicoptic:995,sheqel:8362,sheqelhebrew:8362,sheva:1456,
sheva115:1456,sheva15:1456,sheva22:1456,sheva2e:1456,shevahebrew:1456,shevanarrowhebrew:1456,shevaquarterhebrew:1456,shevawidehebrew:1456,shhacyrillic:1211,shimacoptic:1005,shin:1513,shindagesh:64329,shindageshhebrew:64329,shindageshshindot:64300,shindageshshindothebrew:64300,shindageshsindot:64301,shindageshsindothebrew:64301,shindothebrew:1473,shinhebrew:1513,shinshindot:64298,shinshindothebrew:64298,shinsindot:64299,shinsindothebrew:64299,shook:642,sigma:963,sigma1:962,sigmafinal:962,sigmalunatesymbolgreek:1010,
sihiragana:12375,sikatakana:12471,sikatakanahalfwidth:65404,siluqhebrew:1469,siluqlefthebrew:1469,similar:8764,sindothebrew:1474,siosacirclekorean:12916,siosaparenkorean:12820,sioscieuckorean:12670,sioscirclekorean:12902,sioskiyeokkorean:12666,sioskorean:12613,siosnieunkorean:12667,siosparenkorean:12806,siospieupkorean:12669,siostikeutkorean:12668,six:54,sixarabic:1638,sixbengali:2540,sixcircle:9317,sixcircleinversesansserif:10127,sixdeva:2412,sixgujarati:2796,sixgurmukhi:2668,sixhackarabic:1638,
sixhangzhou:12326,sixideographicparen:12837,sixinferior:8326,sixmonospace:65302,sixoldstyle:63286,sixparen:9337,sixperiod:9357,sixpersian:1782,sixroman:8565,sixsuperior:8310,sixteencircle:9327,sixteencurrencydenominatorbengali:2553,sixteenparen:9347,sixteenperiod:9367,sixthai:3670,slash:47,slashmonospace:65295,slong:383,slongdotaccent:7835,smileface:9786,smonospace:65363,sofpasuqhebrew:1475,softhyphen:173,softsigncyrillic:1100,sohiragana:12381,sokatakana:12477,sokatakanahalfwidth:65407,soliduslongoverlaycmb:824,
solidusshortoverlaycmb:823,sorusithai:3625,sosalathai:3624,sosothai:3595,sosuathai:3626,space:32,spacehackarabic:32,spade:9824,spadesuitblack:9824,spadesuitwhite:9828,sparen:9390,squarebelowcmb:827,squarecc:13252,squarecm:13213,squarediagonalcrosshatchfill:9641,squarehorizontalfill:9636,squarekg:13199,squarekm:13214,squarekmcapital:13262,squareln:13265,squarelog:13266,squaremg:13198,squaremil:13269,squaremm:13212,squaremsquared:13217,squareorthogonalcrosshatchfill:9638,squareupperlefttolowerrightfill:9639,
squareupperrighttolowerleftfill:9640,squareverticalfill:9637,squarewhitewithsmallblack:9635,srsquare:13275,ssabengali:2487,ssadeva:2359,ssagujarati:2743,ssangcieuckorean:12617,ssanghieuhkorean:12677,ssangieungkorean:12672,ssangkiyeokkorean:12594,ssangnieunkorean:12645,ssangpieupkorean:12611,ssangsioskorean:12614,ssangtikeutkorean:12600,ssuperior:63218,sterling:163,sterlingmonospace:65505,strokelongoverlaycmb:822,strokeshortoverlaycmb:821,subset:8834,subsetnotequal:8842,subsetorequal:8838,succeeds:8827,
suchthat:8715,suhiragana:12377,sukatakana:12473,sukatakanahalfwidth:65405,sukunarabic:1618,summation:8721,sun:9788,superset:8835,supersetnotequal:8843,supersetorequal:8839,svsquare:13276,syouwaerasquare:13180,t:116,tabengali:2468,tackdown:8868,tackleft:8867,tadeva:2340,tagujarati:2724,tagurmukhi:2596,taharabic:1591,tahfinalarabic:65218,tahinitialarabic:65219,tahiragana:12383,tahmedialarabic:65220,taisyouerasquare:13181,takatakana:12479,takatakanahalfwidth:65408,tatweelarabic:1600,tau:964,tav:1514,
tavdages:64330,tavdagesh:64330,tavdageshhebrew:64330,tavhebrew:1514,tbar:359,tbopomofo:12554,tcaron:357,tccurl:680,tcedilla:355,tcheharabic:1670,tchehfinalarabic:64379,tchehinitialarabic:64380,tchehmedialarabic:64381,tcircle:9443,tcircumflexbelow:7793,tcommaaccent:355,tdieresis:7831,tdotaccent:7787,tdotbelow:7789,tecyrillic:1090,tedescendercyrillic:1197,teharabic:1578,tehfinalarabic:65174,tehhahinitialarabic:64674,tehhahisolatedarabic:64524,tehinitialarabic:65175,tehiragana:12390,tehjeeminitialarabic:64673,
tehjeemisolatedarabic:64523,tehmarbutaarabic:1577,tehmarbutafinalarabic:65172,tehmedialarabic:65176,tehmeeminitialarabic:64676,tehmeemisolatedarabic:64526,tehnoonfinalarabic:64627,tekatakana:12486,tekatakanahalfwidth:65411,telephone:8481,telephoneblack:9742,telishagedolahebrew:1440,telishaqetanahebrew:1449,tencircle:9321,tenideographicparen:12841,tenparen:9341,tenperiod:9361,tenroman:8569,tesh:679,tet:1496,tetdagesh:64312,tetdageshhebrew:64312,tethebrew:1496,tetsecyrillic:1205,tevirhebrew:1435,tevirlefthebrew:1435,
thabengali:2469,thadeva:2341,thagujarati:2725,thagurmukhi:2597,thalarabic:1584,thalfinalarabic:65196,thanthakhatlowleftthai:63640,thanthakhatlowrightthai:63639,thanthakhatthai:3660,thanthakhatupperleftthai:63638,theharabic:1579,thehfinalarabic:65178,thehinitialarabic:65179,thehmedialarabic:65180,thereexists:8707,therefore:8756,theta:952,theta1:977,thetasymbolgreek:977,thieuthacirclekorean:12921,thieuthaparenkorean:12825,thieuthcirclekorean:12907,thieuthkorean:12620,thieuthparenkorean:12811,thirteencircle:9324,
thirteenparen:9344,thirteenperiod:9364,thonangmonthothai:3601,thook:429,thophuthaothai:3602,thorn:254,thothahanthai:3607,thothanthai:3600,thothongthai:3608,thothungthai:3606,thousandcyrillic:1154,thousandsseparatorarabic:1644,thousandsseparatorpersian:1644,three:51,threearabic:1635,threebengali:2537,threecircle:9314,threecircleinversesansserif:10124,threedeva:2409,threeeighths:8540,threegujarati:2793,threegurmukhi:2665,threehackarabic:1635,threehangzhou:12323,threeideographicparen:12834,threeinferior:8323,
threemonospace:65299,threenumeratorbengali:2550,threeoldstyle:63283,threeparen:9334,threeperiod:9354,threepersian:1779,threequarters:190,threequartersemdash:63198,threeroman:8562,threesuperior:179,threethai:3667,thzsquare:13204,tihiragana:12385,tikatakana:12481,tikatakanahalfwidth:65409,tikeutacirclekorean:12912,tikeutaparenkorean:12816,tikeutcirclekorean:12898,tikeutkorean:12599,tikeutparenkorean:12802,tilde:732,tildebelowcmb:816,tildecmb:771,tildecomb:771,tildedoublecmb:864,tildeoperator:8764,tildeoverlaycmb:820,
tildeverticalcmb:830,timescircle:8855,tipehahebrew:1430,tipehalefthebrew:1430,tippigurmukhi:2672,titlocyrilliccmb:1155,tiwnarmenian:1407,tlinebelow:7791,tmonospace:65364,toarmenian:1385,tohiragana:12392,tokatakana:12488,tokatakanahalfwidth:65412,tonebarextrahighmod:741,tonebarextralowmod:745,tonebarhighmod:742,tonebarlowmod:744,tonebarmidmod:743,tonefive:445,tonesix:389,tonetwo:424,tonos:900,tonsquare:13095,topatakthai:3599,tortoiseshellbracketleft:12308,tortoiseshellbracketleftsmall:65117,tortoiseshellbracketleftvertical:65081,
tortoiseshellbracketright:12309,tortoiseshellbracketrightsmall:65118,tortoiseshellbracketrightvertical:65082,totaothai:3605,tpalatalhook:427,tparen:9391,trademark:8482,trademarksans:63722,trademarkserif:63195,tretroflexhook:648,triagdn:9660,triaglf:9668,triagrt:9658,triagup:9650,ts:678,tsadi:1510,tsadidagesh:64326,tsadidageshhebrew:64326,tsadihebrew:1510,tsecyrillic:1094,tsere:1461,tsere12:1461,tsere1e:1461,tsere2b:1461,tserehebrew:1461,tserenarrowhebrew:1461,tserequarterhebrew:1461,tserewidehebrew:1461,
tshecyrillic:1115,tsuperior:63219,ttabengali:2463,ttadeva:2335,ttagujarati:2719,ttagurmukhi:2591,tteharabic:1657,ttehfinalarabic:64359,ttehinitialarabic:64360,ttehmedialarabic:64361,tthabengali:2464,tthadeva:2336,tthagujarati:2720,tthagurmukhi:2592,tturned:647,tuhiragana:12388,tukatakana:12484,tukatakanahalfwidth:65410,tusmallhiragana:12387,tusmallkatakana:12483,tusmallkatakanahalfwidth:65391,twelvecircle:9323,twelveparen:9343,twelveperiod:9363,twelveroman:8571,twentycircle:9331,twentyhangzhou:21316,
twentyparen:9351,twentyperiod:9371,two:50,twoarabic:1634,twobengali:2536,twocircle:9313,twocircleinversesansserif:10123,twodeva:2408,twodotenleader:8229,twodotleader:8229,twodotleadervertical:65072,twogujarati:2792,twogurmukhi:2664,twohackarabic:1634,twohangzhou:12322,twoideographicparen:12833,twoinferior:8322,twomonospace:65298,twonumeratorbengali:2549,twooldstyle:63282,twoparen:9333,twoperiod:9353,twopersian:1778,tworoman:8561,twostroke:443,twosuperior:178,twothai:3666,twothirds:8532,u:117,uacute:250,
ubar:649,ubengali:2441,ubopomofo:12584,ubreve:365,ucaron:468,ucircle:9444,ucircumflex:251,ucircumflexbelow:7799,ucyrillic:1091,udattadeva:2385,udblacute:369,udblgrave:533,udeva:2313,udieresis:252,udieresisacute:472,udieresisbelow:7795,udieresiscaron:474,udieresiscyrillic:1265,udieresisgrave:476,udieresismacron:470,udotbelow:7909,ugrave:249,ugujarati:2697,ugurmukhi:2569,uhiragana:12358,uhookabove:7911,uhorn:432,uhornacute:7913,uhorndotbelow:7921,uhorngrave:7915,uhornhookabove:7917,uhorntilde:7919,
uhungarumlaut:369,uhungarumlautcyrillic:1267,uinvertedbreve:535,ukatakana:12454,ukatakanahalfwidth:65395,ukcyrillic:1145,ukorean:12636,umacron:363,umacroncyrillic:1263,umacrondieresis:7803,umatragurmukhi:2625,umonospace:65365,underscore:95,underscoredbl:8215,underscoremonospace:65343,underscorevertical:65075,underscorewavy:65103,union:8746,universal:8704,uogonek:371,uparen:9392,upblock:9600,upperdothebrew:1476,upsilon:965,upsilondieresis:971,upsilondieresistonos:944,upsilonlatin:650,upsilontonos:973,
uptackbelowcmb:797,uptackmod:724,uragurmukhi:2675,uring:367,ushortcyrillic:1118,usmallhiragana:12357,usmallkatakana:12453,usmallkatakanahalfwidth:65385,ustraightcyrillic:1199,ustraightstrokecyrillic:1201,utilde:361,utildeacute:7801,utildebelow:7797,uubengali:2442,uudeva:2314,uugujarati:2698,uugurmukhi:2570,uumatragurmukhi:2626,uuvowelsignbengali:2498,uuvowelsigndeva:2370,uuvowelsigngujarati:2754,uvowelsignbengali:2497,uvowelsigndeva:2369,uvowelsigngujarati:2753,v:118,vadeva:2357,vagujarati:2741,vagurmukhi:2613,
vakatakana:12535,vav:1493,vavdagesh:64309,vavdagesh65:64309,vavdageshhebrew:64309,vavhebrew:1493,vavholam:64331,vavholamhebrew:64331,vavvavhebrew:1520,vavyodhebrew:1521,vcircle:9445,vdotbelow:7807,vecyrillic:1074,veharabic:1700,vehfinalarabic:64363,vehinitialarabic:64364,vehmedialarabic:64365,vekatakana:12537,venus:9792,verticalbar:124,verticallineabovecmb:781,verticallinebelowcmb:809,verticallinelowmod:716,verticallinemod:712,vewarmenian:1406,vhook:651,vikatakana:12536,viramabengali:2509,viramadeva:2381,
viramagujarati:2765,visargabengali:2435,visargadeva:2307,visargagujarati:2691,vmonospace:65366,voarmenian:1400,voicediterationhiragana:12446,voicediterationkatakana:12542,voicedmarkkana:12443,voicedmarkkanahalfwidth:65438,vokatakana:12538,vparen:9393,vtilde:7805,vturned:652,vuhiragana:12436,vukatakana:12532,w:119,wacute:7811,waekorean:12633,wahiragana:12431,wakatakana:12527,wakatakanahalfwidth:65436,wakorean:12632,wasmallhiragana:12430,wasmallkatakana:12526,wattosquare:13143,wavedash:12316,wavyunderscorevertical:65076,
wawarabic:1608,wawfinalarabic:65262,wawhamzaabovearabic:1572,wawhamzaabovefinalarabic:65158,wbsquare:13277,wcircle:9446,wcircumflex:373,wdieresis:7813,wdotaccent:7815,wdotbelow:7817,wehiragana:12433,weierstrass:8472,wekatakana:12529,wekorean:12638,weokorean:12637,wgrave:7809,whitebullet:9702,whitecircle:9675,whitecircleinverse:9689,whitecornerbracketleft:12302,whitecornerbracketleftvertical:65091,whitecornerbracketright:12303,whitecornerbracketrightvertical:65092,whitediamond:9671,whitediamondcontainingblacksmalldiamond:9672,
whitedownpointingsmalltriangle:9663,whitedownpointingtriangle:9661,whiteleftpointingsmalltriangle:9667,whiteleftpointingtriangle:9665,whitelenticularbracketleft:12310,whitelenticularbracketright:12311,whiterightpointingsmalltriangle:9657,whiterightpointingtriangle:9655,whitesmallsquare:9643,whitesmilingface:9786,whitesquare:9633,whitestar:9734,whitetelephone:9743,whitetortoiseshellbracketleft:12312,whitetortoiseshellbracketright:12313,whiteuppointingsmalltriangle:9653,whiteuppointingtriangle:9651,
wihiragana:12432,wikatakana:12528,wikorean:12639,wmonospace:65367,wohiragana:12434,wokatakana:12530,wokatakanahalfwidth:65382,won:8361,wonmonospace:65510,wowaenthai:3623,wparen:9394,wring:7832,wsuperior:695,wturned:653,wynn:447,x:120,xabovecmb:829,xbopomofo:12562,xcircle:9447,xdieresis:7821,xdotaccent:7819,xeharmenian:1389,xi:958,xmonospace:65368,xparen:9395,xsuperior:739,y:121,yaadosquare:13134,yabengali:2479,yacute:253,yadeva:2351,yaekorean:12626,yagujarati:2735,yagurmukhi:2607,yahiragana:12420,
yakatakana:12516,yakatakanahalfwidth:65428,yakorean:12625,yamakkanthai:3662,yasmallhiragana:12419,yasmallkatakana:12515,yasmallkatakanahalfwidth:65388,yatcyrillic:1123,ycircle:9448,ycircumflex:375,ydieresis:255,ydotaccent:7823,ydotbelow:7925,yeharabic:1610,yehbarreearabic:1746,yehbarreefinalarabic:64431,yehfinalarabic:65266,yehhamzaabovearabic:1574,yehhamzaabovefinalarabic:65162,yehhamzaaboveinitialarabic:65163,yehhamzaabovemedialarabic:65164,yehinitialarabic:65267,yehmedialarabic:65268,yehmeeminitialarabic:64733,
yehmeemisolatedarabic:64600,yehnoonfinalarabic:64660,yehthreedotsbelowarabic:1745,yekorean:12630,yen:165,yenmonospace:65509,yeokorean:12629,yeorinhieuhkorean:12678,yerahbenyomohebrew:1450,yerahbenyomolefthebrew:1450,yericyrillic:1099,yerudieresiscyrillic:1273,yesieungkorean:12673,yesieungpansioskorean:12675,yesieungsioskorean:12674,yetivhebrew:1434,ygrave:7923,yhook:436,yhookabove:7927,yiarmenian:1397,yicyrillic:1111,yikorean:12642,yinyang:9775,yiwnarmenian:1410,ymonospace:65369,yod:1497,yoddagesh:64313,
yoddageshhebrew:64313,yodhebrew:1497,yodyodhebrew:1522,yodyodpatahhebrew:64287,yohiragana:12424,yoikorean:12681,yokatakana:12520,yokatakanahalfwidth:65430,yokorean:12635,yosmallhiragana:12423,yosmallkatakana:12519,yosmallkatakanahalfwidth:65390,yotgreek:1011,yoyaekorean:12680,yoyakorean:12679,yoyakthai:3618,yoyingthai:3597,yparen:9396,ypogegrammeni:890,ypogegrammenigreekcmb:837,yr:422,yring:7833,ysuperior:696,ytilde:7929,yturned:654,yuhiragana:12422,yuikorean:12684,yukatakana:12518,yukatakanahalfwidth:65429,
yukorean:12640,yusbigcyrillic:1131,yusbigiotifiedcyrillic:1133,yuslittlecyrillic:1127,yuslittleiotifiedcyrillic:1129,yusmallhiragana:12421,yusmallkatakana:12517,yusmallkatakanahalfwidth:65389,yuyekorean:12683,yuyeokorean:12682,yyabengali:2527,yyadeva:2399,z:122,zaarmenian:1382,zacute:378,zadeva:2395,zagurmukhi:2651,zaharabic:1592,zahfinalarabic:65222,zahinitialarabic:65223,zahiragana:12374,zahmedialarabic:65224,zainarabic:1586,zainfinalarabic:65200,zakatakana:12470,zaqefgadolhebrew:1429,zaqefqatanhebrew:1428,
zarqahebrew:1432,zayin:1494,zayindagesh:64310,zayindageshhebrew:64310,zayinhebrew:1494,zbopomofo:12567,zcaron:382,zcircle:9449,zcircumflex:7825,zcurl:657,zdot:380,zdotaccent:380,zdotbelow:7827,zecyrillic:1079,zedescendercyrillic:1177,zedieresiscyrillic:1247,zehiragana:12380,zekatakana:12476,zero:48,zeroarabic:1632,zerobengali:2534,zerodeva:2406,zerogujarati:2790,zerogurmukhi:2662,zerohackarabic:1632,zeroinferior:8320,zeromonospace:65296,zerooldstyle:63280,zeropersian:1776,zerosuperior:8304,zerothai:3664,
zerowidthjoiner:65279,zerowidthnonjoiner:8204,zerowidthspace:8203,zeta:950,zhbopomofo:12563,zhearmenian:1386,zhebrevecyrillic:1218,zhecyrillic:1078,zhedescendercyrillic:1175,zhedieresiscyrillic:1245,zihiragana:12376,zikatakana:12472,zinorhebrew:1454,zlinebelow:7829,zmonospace:65370,zohiragana:12382,zokatakana:12478,zparen:9397,zretroflexhook:656,zstroke:438,zuhiragana:12378,zukatakana:12474,".notdef":0};a.DingbatsGlyphsUnicode={space:32,a1:9985,a2:9986,a202:9987,a3:9988,a4:9742,a5:9990,a119:9991,
a118:9992,a117:9993,a11:9755,a12:9758,a13:9996,a14:9997,a15:9998,a16:9999,a105:1E4,a17:10001,a18:10002,a19:10003,a20:10004,a21:10005,a22:10006,a23:10007,a24:10008,a25:10009,a26:10010,a27:10011,a28:10012,a6:10013,a7:10014,a8:10015,a9:10016,a10:10017,a29:10018,a30:10019,a31:10020,a32:10021,a33:10022,a34:10023,a35:9733,a36:10025,a37:10026,a38:10027,a39:10028,a40:10029,a41:10030,a42:10031,a43:10032,a44:10033,a45:10034,a46:10035,a47:10036,a48:10037,a49:10038,a50:10039,a51:10040,a52:10041,a53:10042,a54:10043,
a55:10044,a56:10045,a57:10046,a58:10047,a59:10048,a60:10049,a61:10050,a62:10051,a63:10052,a64:10053,a65:10054,a66:10055,a67:10056,a68:10057,a69:10058,a70:10059,a71:9679,a72:10061,a73:9632,a74:10063,a203:10064,a75:10065,a204:10066,a76:9650,a77:9660,a78:9670,a79:10070,a81:9687,a82:10072,a83:10073,a84:10074,a97:10075,a98:10076,a99:10077,a100:10078,a101:10081,a102:10082,a103:10083,a104:10084,a106:10085,a107:10086,a108:10087,a112:9827,a111:9830,a110:9829,a109:9824,a120:9312,a121:9313,a122:9314,a123:9315,
a124:9316,a125:9317,a126:9318,a127:9319,a128:9320,a129:9321,a130:10102,a131:10103,a132:10104,a133:10105,a134:10106,a135:10107,a136:10108,a137:10109,a138:10110,a139:10111,a140:10112,a141:10113,a142:10114,a143:10115,a144:10116,a145:10117,a146:10118,a147:10119,a148:10120,a149:10121,a150:10122,a151:10123,a152:10124,a153:10125,a154:10126,a155:10127,a156:10128,a157:10129,a158:10130,a159:10131,a160:10132,a161:8594,a163:8596,a164:8597,a196:10136,a165:10137,a192:10138,a166:10139,a167:10140,a168:10141,a169:10142,
a170:10143,a171:10144,a172:10145,a173:10146,a162:10147,a174:10148,a175:10149,a176:10150,a177:10151,a178:10152,a179:10153,a193:10154,a180:10155,a199:10156,a181:10157,a200:10158,a182:10159,a201:10161,a183:10162,a184:10163,a197:10164,a185:10165,a194:10166,a198:10167,a186:10168,a195:10169,a187:10170,a188:10171,a189:10172,a190:10173,a191:10174,a89:10088,a90:10089,a93:10090,a94:10091,a91:10092,a92:10093,a205:10094,a85:10095,a206:10096,a86:10097,a87:10098,a88:10099,a95:10100,a96:10101,".notdef":0}});(function(a,
e){e(a.pdfjsCoreJpg={})})(this,function(a){var e=function(){function a(){}function e(a,h){for(var z=0,o=[],m,w,t=16;0<t&&!a[t-1];)t--;o.push({children:[],index:0});var u=o[0],y;for(m=0;m<t;m++){for(w=0;w<a[m];w++){u=o.pop();for(u.children[u.index]=h[z];0<u.index;)u=o.pop();u.index++;for(o.push(u);o.length<=m;)o.push(y={children:[],index:0}),u.children[u.index]=y.children,u=y;z++}m+1<t&&(o.push(y={children:[],index:0}),u.children[u.index]=y.children,u=y)}return o[0].children}function N(a,h,z,e,m,w,
t,u,y){function s(){if(0<p)return p--,j>>p&1;j=a[h++];if(255===j){var b=a[h++];if(b)throw"unexpected marker: "+(j<<8|b).toString(16);}p=7;return j>>>7}function M(b){for(;;){b=b[s()];if("number"===typeof b)return b;if("object"!==typeof b)throw"invalid huffman sequence";}}function g(b){for(var c=0;0<b;)c=c<<1|s(),b--;return c}function f(b){if(1===b)return 1===s()?1:-1;var c=g(b);return c>=1<<b-1?c:c+(-1<<b)+1}function d(b,c){var i=M(b.huffmanTableDC),i=0===i?0:f(i);b.blockData[c]=b.pred+=i;for(i=1;64>
i;){var j=M(b.huffmanTableAC),p=j&15,j=j>>4;if(0===p){if(15>j)break;i+=16}else i+=j,b.blockData[c+K[i]]=f(p),i++}}function k(b,c){var i=M(b.huffmanTableDC),i=0===i?0:f(i)<<y;b.blockData[c]=b.pred+=i}function c(b,c){b.blockData[c]|=s()<<y}function b(b,c){if(0<v)v--;else for(var i=w,j=t;i<=j;){var p=M(b.huffmanTableAC),n=p&15,p=p>>4;if(0===n){if(15>p){v=g(p)+(1<<p)-1;break}i+=16}else i+=p,b.blockData[c+K[i]]=f(n)*(1<<y),i++}}function i(b,c){for(var i=w,j=t,p=0,l;i<=j;){l=K[i];switch(n){case 0:p=M(b.huffmanTableAC);
l=p&15;p>>=4;if(0===l)15>p?(v=g(p)+(1<<p),n=4):(p=16,n=1);else{if(1!==l)throw"invalid ACn encoding";r=f(l);n=p?2:3}continue;case 1:case 2:b.blockData[c+l]?b.blockData[c+l]+=s()<<y:(p--,0===p&&(n=2===n?3:0));break;case 3:b.blockData[c+l]?b.blockData[c+l]+=s()<<y:(b.blockData[c+l]=r<<y,n=0);break;case 4:b.blockData[c+l]&&(b.blockData[c+l]+=s()<<y)}i++}4===n&&(v--,0===v&&(n=0))}var l=z.mcusPerLine,q=h,j=0,p=0,v=0,n=0,r,B=e.length,F,A,$,V,W,u=z.progressive?0===w?0===u?k:c:0===u?b:i:d,o=0,z=1===B?e[0].blocksPerLine*
e[0].blocksPerColumn:l*z.mcusPerColumn;m||(m=z);for(var E,D;o<z;){for(A=0;A<B;A++)e[A].pred=0;v=0;if(1===B){F=e[0];for(W=0;W<m;W++)u(F,64*((F.blocksPerLine+1)*(o/F.blocksPerLine|0)+o%F.blocksPerLine)),o++}else for(W=0;W<m;W++){for(A=0;A<B;A++){F=e[A];E=F.h;D=F.v;for($=0;$<D;$++)for(V=0;V<E;V++)u(F,64*((F.blocksPerLine+1)*((o/l|0)*F.v+$)+(o%l*F.h+V)))}o++}p=0;F=a[h]<<8|a[h+1];if(65280>=F)throw"marker was not found";if(65488<=F&&65495>=F)h+=2;else break}return h-q}function L(a,h){for(var z=h.blocksPerLine,
e=h.blocksPerColumn,m=new Int16Array(64),w=0;w<e;w++)for(var t=0;t<z;t++){for(var u=64*((h.blocksPerLine+1)*w+t),y=m,s=h.quantizationTable,M=h.blockData,g=void 0,f=void 0,d=void 0,k=void 0,c=void 0,b=void 0,i=void 0,l=void 0,q=void 0,j=l=void 0,p=i=f=b=void 0,v=void 0,q=void 0,n=0;64>n;n+=8)q=M[u+n],l=M[u+n+1],j=M[u+n+2],b=M[u+n+3],f=M[u+n+4],i=M[u+n+5],p=M[u+n+6],v=M[u+n+7],q*=s[n],0===(l|j|b|f|i|p|v)?(q=x*q+512>>10,y[n]=q,y[n+1]=q,y[n+2]=q,y[n+3]=q,y[n+4]=q,y[n+5]=q,y[n+6]=q,y[n+7]=q):(l*=s[n+1],
j*=s[n+2],b*=s[n+3],f*=s[n+4],i*=s[n+5],p*=s[n+6],v*=s[n+7],g=x*q+128>>8,f=x*f+128>>8,d=j,k=p,c=D*(l-v)+128>>8,l=D*(l+v)+128>>8,b<<=4,i<<=4,g=g+f+1>>1,f=g-f,q=d*o+k*C+128>>8,d=d*C-k*o+128>>8,k=q,c=c+i+1>>1,i=c-i,l=l+b+1>>1,b=l-b,g=g+k+1>>1,k=g-k,f=f+d+1>>1,d=f-d,q=c*E+l*Q+2048>>12,c=c*Q-l*E+2048>>12,l=q,q=b*J+i*I+2048>>12,b=b*I-i*J+2048>>12,i=q,y[n]=g+l,y[n+7]=g-l,y[n+1]=f+i,y[n+6]=f-i,y[n+2]=d+b,y[n+5]=d-b,y[n+3]=k+c,y[n+4]=k-c);for(s=0;8>s;++s)q=y[s],l=y[s+8],j=y[s+16],b=y[s+24],f=y[s+32],i=y[s+
40],p=y[s+48],v=y[s+56],0===(l|j|b|f|i|p|v)?(q=x*q+8192>>14,q=-2040>q?0:2024<=q?255:q+2056>>4,M[u+s]=q,M[u+s+8]=q,M[u+s+16]=q,M[u+s+24]=q,M[u+s+32]=q,M[u+s+40]=q,M[u+s+48]=q,M[u+s+56]=q):(g=x*q+2048>>12,f=x*f+2048>>12,d=j,k=p,c=D*(l-v)+2048>>12,l=D*(l+v)+2048>>12,g=(g+f+1>>1)+4112,f=g-f,q=d*o+k*C+2048>>12,d=d*C-k*o+2048>>12,k=q,c=c+i+1>>1,i=c-i,l=l+b+1>>1,b=l-b,g=g+k+1>>1,k=g-k,f=f+d+1>>1,d=f-d,q=c*E+l*Q+2048>>12,c=c*Q-l*E+2048>>12,l=q,q=b*J+i*I+2048>>12,b=b*I-i*J+2048>>12,i=q,q=g+l,v=g-l,l=f+i,p=
f-i,j=d+b,i=d-b,b=k+c,f=k-c,q=16>q?0:4080<=q?255:q>>4,l=16>l?0:4080<=l?255:l>>4,j=16>j?0:4080<=j?255:j>>4,b=16>b?0:4080<=b?255:b>>4,f=16>f?0:4080<=f?255:f>>4,i=16>i?0:4080<=i?255:i>>4,p=16>p?0:4080<=p?255:p>>4,v=16>v?0:4080<=v?255:v>>4,M[u+s]=q,M[u+s+8]=l,M[u+s+16]=j,M[u+s+24]=b,M[u+s+32]=f,M[u+s+40]=i,M[u+s+48]=p,M[u+s+56]=v)}return h.blockData}function H(a){return 0>=a?0:255<=a?255:a}var K=new Uint8Array([0,1,8,16,9,2,3,10,17,24,32,25,18,11,4,5,12,19,26,33,40,48,41,34,27,20,13,6,7,14,21,28,35,42,
49,56,57,50,43,36,29,22,15,23,30,37,44,51,58,59,52,45,38,31,39,46,53,60,61,54,47,55,62,63]),I=4017,J=799,Q=3406,E=2276,C=1567,o=3784,x=5793,D=2896;a.prototype={parse:function(a){function h(){var b=a[m]<<8|a[m+1];m+=2;return b}function z(){var b=h(),b=a.subarray(m,m+b-2);m+=b.length;return b}function o(b){for(var c=Math.ceil(b.samplesPerLine/8/b.maxH),i=Math.ceil(b.scanLines/8/b.maxV),n=0;n<b.components.length;n++){q=b.components[n];var l=Math.ceil(Math.ceil(b.samplesPerLine/8)*q.h/b.maxH),d=Math.ceil(Math.ceil(b.scanLines/
8)*q.v/b.maxV);q.blockData=new Int16Array(64*i*q.v*(c*q.h+1));q.blocksPerLine=l;q.blocksPerColumn=d}b.mcusPerLine=c;b.mcusPerColumn=i}var m=0,w=null,t=null,u,y,s=[],M=[],g=[],f=h();if(65496!==f)throw"SOI not found";for(f=h();65497!==f;){var d,k;switch(f){case 65504:case 65505:case 65506:case 65507:case 65508:case 65509:case 65510:case 65511:case 65512:case 65513:case 65514:case 65515:case 65516:case 65517:case 65518:case 65519:case 65534:d=z();65504===f&&74===d[0]&&70===d[1]&&73===d[2]&&70===d[3]&&
0===d[4]&&(w={version:{major:d[5],minor:d[6]},densityUnits:d[7],xDensity:d[8]<<8|d[9],yDensity:d[10]<<8|d[11],thumbWidth:d[12],thumbHeight:d[13],thumbData:d.subarray(14,14+3*d[12]*d[13])});65518===f&&65===d[0]&&100===d[1]&&111===d[2]&&98===d[3]&&101===d[4]&&(t={version:d[5]<<8|d[6],flags0:d[7]<<8|d[8],flags1:d[9]<<8|d[10],transformCode:d[11]});break;case 65499:for(var f=h()+m-2,c;m<f;){var b=a[m++],i=new Uint16Array(64);if(0===b>>4)for(d=0;64>d;d++)c=K[d],i[c]=a[m++];else if(1===b>>4)for(d=0;64>d;d++)c=
K[d],i[c]=h();else throw"DQT: invalid table spec";s[b&15]=i}break;case 65472:case 65473:case 65474:if(u)throw"Only single frame JPEGs supported";h();u={};u.extended=65473===f;u.progressive=65474===f;u.precision=a[m++];u.scanLines=h();u.samplesPerLine=h();u.components=[];u.componentIds={};d=a[m++];for(f=i=b=0;f<d;f++){c=a[m];k=a[m+1]>>4;var l=a[m+1]&15;b<k&&(b=k);i<l&&(i=l);k=u.components.push({h:k,v:l,quantizationTable:s[a[m+2]]});u.componentIds[c]=k-1;m+=3}u.maxH=b;u.maxV=i;o(u);break;case 65476:c=
h();for(f=2;f<c;){b=a[m++];i=new Uint8Array(16);for(d=k=0;16>d;d++,m++)k+=i[d]=a[m];l=new Uint8Array(k);for(d=0;d<k;d++,m++)l[d]=a[m];f+=17+k;(0===b>>4?g:M)[b&15]=e(i,l)}break;case 65501:h();y=h();break;case 65498:h();c=a[m++];d=[];for(var q,f=0;f<c;f++)b=u.componentIds[a[m++]],q=u.components[b],b=a[m++],q.huffmanTableDC=g[b>>4],q.huffmanTableAC=M[b&15],d.push(q);f=a[m++];c=a[m++];b=a[m++];f=N(a,m,u,d,y,f,c,b>>4,b&15);m+=f;break;case 65535:255!==a[m]&&m--;break;default:if(255===a[m-3]&&192<=a[m-2]&&
254>=a[m-2]){m-=3;break}throw"unknown JPEG marker "+f.toString(16);}f=h()}this.width=u.samplesPerLine;this.height=u.scanLines;this.jfif=w;this.adobe=t;this.components=[];for(f=0;f<u.components.length;f++)q=u.components[f],this.components.push({output:L(u,q),scaleX:q.h/u.maxH,scaleY:q.v/u.maxV,blocksPerLine:q.blocksPerLine,blocksPerColumn:q.blocksPerColumn});this.numComponents=this.components.length},_getLinearizedBlockData:function(a,h){var z=this.width/a,e=this.height/h,m,w,t,u,y,s,M=0,g,f=this.components.length,
d=a*h*f,k=new Uint8Array(d),c=new Uint32Array(a);for(s=0;s<f;s++){m=this.components[s];w=m.scaleX*z;t=m.scaleY*e;M=s;g=m.output;u=m.blocksPerLine+1<<3;for(y=0;y<a;y++)m=0|y*w,c[y]=(m&4294967288)<<3|m&7;for(w=0;w<h;w++){m=0|w*t;m=u*(m&4294967288)|(m&7)<<3;for(y=0;y<a;y++)k[M]=g[m+c[y]],M+=f}}if(e=this.decodeTransform)for(s=0;s<d;)for(m=0,z=0;m<f;m++,s++,z+=2)k[s]=(k[s]*e[z]>>8)+e[z+1];return k},_isColorConversionNeeded:function(){return this.adobe&&this.adobe.transformCode?!0:3===this.numComponents?
!0:!1},_convertYccToRgb:function(a){for(var h,z,e,m=0,w=a.length;m<w;m+=3)h=a[m],z=a[m+1],e=a[m+2],a[m]=H(h-179.456+1.402*e),a[m+1]=H(h+135.459-0.344*z-0.714*e),a[m+2]=H(h-226.816+1.772*z);return a},_convertYcckToRgb:function(a){for(var h,e,o,m,w=0,t=0,u=a.length;t<u;t+=4){h=a[t];e=a[t+1];o=a[t+2];m=a[t+3];var y=-122.67195406894+e*(-6.60635669420364E-5*e+4.37130475926232E-4*o-5.4080610064599E-5*h+4.8449797120281E-4*m-0.154362151871126)+o*(-9.57964378445773E-4*o+8.17076911346625E-4*h-0.00477271405408747*
m+1.53380253221734)+h*(9.61250184130688E-4*h-0.00266257332283933*m+0.48357088451265)+m*(-3.36197177618394E-4*m+0.484791561490776),s=107.268039397724+e*(2.19927104525741E-5*e-6.40992018297945E-4*o+6.59397001245577E-4*h+4.26105652938837E-4*m-0.176491792462875)+o*(-7.78269941513683E-4*o+0.00130872261408275*h+7.70482631801132E-4*m-0.151051492775562)+h*(0.00126935368114843*h-0.00265090189010898*m+0.25802910206845)+m*(-3.18913117588328E-4*m-0.213742400323665);h=-20.810012546947+e*(-5.70115196973677E-4*
e-2.63409051004589E-5*o+0.0020741088115012*h-0.00288260236853442*m+0.814272968359295)+o*(-1.53496057440975E-5*o-1.32689043961446E-4*h+5.60833691242812E-4*m-0.195152027534049)+h*(0.00174418132927582*h-0.00255243321439347*m+0.116935020465145)+m*(-3.43531996510555E-4*m+0.24165260232407);a[w++]=H(y);a[w++]=H(s);a[w++]=H(h)}return a},_convertYcckToCmyk:function(a){for(var h,e,o,m=0,w=a.length;m<w;m+=4)h=a[m],e=a[m+1],o=a[m+2],a[m]=H(434.456-h-1.402*o),a[m+1]=H(119.541-h+0.344*e+0.714*o),a[m+2]=H(481.816-
h-1.772*e);return a},_convertCmykToRgb:function(a){for(var h,e,o,m,w=0,t=1/255/255,u=0,y=a.length;u<y;u+=4){h=a[u];e=a[u+1];o=a[u+2];m=a[u+3];var s=h*(-4.387332384609988*h+54.48615194189176*e+18.82290502165302*o+212.25662451639585*m-72734.4411664936)+e*(1.7149763477362134*e-5.6096736904047315*o-17.873870861415444*m-1401.7366389350734)+o*(-2.5217340131683033*o-21.248923337353073*m+4465.541406466231)-m*(21.86122147463605*m+48317.86113160301),M=h*(8.841041422036149*h+60.118027045597366*e+6.871425592049007*
o+31.159100130055922*m-20220.756542821975)+e*(-15.310361306967817*e+17.575251261109482*o+131.35250912493976*m-48691.05921601825)+o*(4.444339102852739*o+9.8632861493405*m-6341.191035517494)-m*(20.737325471181034*m+47890.15695978492);h=h*(0.8842522430003296*h+8.078677503112928*e+30.89978309703729*o-0.23883238689178934*m-3616.812083916688)+e*(10.49593273432072*e+63.02378494754052*o+50.606957656360734*m-28620.90484698408)+o*(0.03296041114873217*o+115.60384449646641*m-49363.43385999684)-m*(22.33816807309886*
m+45932.16563550634);a[w++]=0<=s?255:-16581375>=s?0:255+s*t|0;a[w++]=0<=M?255:-16581375>=M?0:255+M*t|0;a[w++]=0<=h?255:-16581375>=h?0:255+h*t|0}return a},getData:function(a,h,e){if(4<this.numComponents)throw"Unsupported color mode";a=this._getLinearizedBlockData(a,h);if(3===this.numComponents)return this._convertYccToRgb(a);if(4===this.numComponents){if(this._isColorConversionNeeded())return e?this._convertYcckToRgb(a):this._convertYcckToCmyk(a);if(e)return this._convertCmykToRgb(a)}return a}};return a}();
a.JpegImage=e});(function(a,e){e(a.pdfjsCoreMetrics={})})(this,function(a){a.Metrics={Courier:600,"Courier-Bold":600,"Courier-BoldOblique":600,"Courier-Oblique":600,Helvetica:{space:278,exclam:278,quotedbl:355,numbersign:556,dollar:556,percent:889,ampersand:667,quoteright:222,parenleft:333,parenright:333,asterisk:389,plus:584,comma:278,hyphen:333,period:278,slash:278,zero:556,one:556,two:556,three:556,four:556,five:556,six:556,seven:556,eight:556,nine:556,colon:278,semicolon:278,less:584,equal:584,
greater:584,question:556,at:1015,A:667,B:667,C:722,D:722,E:667,F:611,G:778,H:722,I:278,J:500,K:667,L:556,M:833,N:722,O:778,P:667,Q:778,R:722,S:667,T:611,U:722,V:667,W:944,X:667,Y:667,Z:611,bracketleft:278,backslash:278,bracketright:278,asciicircum:469,underscore:556,quoteleft:222,a:556,b:556,c:500,d:556,e:556,f:278,g:556,h:556,i:222,j:222,k:500,l:222,m:833,n:556,o:556,p:556,q:556,r:333,s:500,t:278,u:556,v:500,w:722,x:500,y:500,z:500,braceleft:334,bar:260,braceright:334,asciitilde:584,exclamdown:333,
cent:556,sterling:556,fraction:167,yen:556,florin:556,section:556,currency:556,quotesingle:191,quotedblleft:333,guillemotleft:556,guilsinglleft:333,guilsinglright:333,fi:500,fl:500,endash:556,dagger:556,daggerdbl:556,periodcentered:278,paragraph:537,bullet:350,quotesinglbase:222,quotedblbase:333,quotedblright:333,guillemotright:556,ellipsis:1E3,perthousand:1E3,questiondown:611,grave:333,acute:333,circumflex:333,tilde:333,macron:333,breve:333,dotaccent:333,dieresis:333,ring:333,cedilla:333,hungarumlaut:333,
ogonek:333,caron:333,emdash:1E3,AE:1E3,ordfeminine:370,Lslash:556,Oslash:778,OE:1E3,ordmasculine:365,ae:889,dotlessi:278,lslash:222,oslash:611,oe:944,germandbls:611,Idieresis:278,eacute:556,abreve:556,uhungarumlaut:556,ecaron:556,Ydieresis:667,divide:584,Yacute:667,Acircumflex:667,aacute:556,Ucircumflex:722,yacute:500,scommaaccent:500,ecircumflex:556,Uring:722,Udieresis:722,aogonek:556,Uacute:722,uogonek:556,Edieresis:667,Dcroat:722,commaaccent:250,copyright:737,Emacron:667,ccaron:500,aring:556,Ncommaaccent:722,
lacute:222,agrave:556,Tcommaaccent:611,Cacute:722,atilde:556,Edotaccent:667,scaron:500,scedilla:500,iacute:278,lozenge:471,Rcaron:722,Gcommaaccent:778,ucircumflex:556,acircumflex:556,Amacron:667,rcaron:333,ccedilla:500,Zdotaccent:611,Thorn:667,Omacron:778,Racute:722,Sacute:667,dcaron:643,Umacron:722,uring:556,threesuperior:333,Ograve:778,Agrave:667,Abreve:667,multiply:584,uacute:556,Tcaron:611,partialdiff:476,ydieresis:500,Nacute:722,icircumflex:278,Ecircumflex:667,adieresis:556,edieresis:556,cacute:500,
nacute:556,umacron:556,Ncaron:722,Iacute:278,plusminus:584,brokenbar:260,registered:737,Gbreve:778,Idotaccent:278,summation:600,Egrave:667,racute:333,omacron:556,Zacute:611,Zcaron:611,greaterequal:549,Eth:722,Ccedilla:722,lcommaaccent:222,tcaron:317,eogonek:556,Uogonek:722,Aacute:667,Adieresis:667,egrave:556,zacute:500,iogonek:222,Oacute:778,oacute:556,amacron:556,sacute:500,idieresis:278,Ocircumflex:778,Ugrave:722,Delta:612,thorn:556,twosuperior:333,Odieresis:778,mu:556,igrave:278,ohungarumlaut:556,
Eogonek:667,dcroat:556,threequarters:834,Scedilla:667,lcaron:299,Kcommaaccent:667,Lacute:556,trademark:1E3,edotaccent:556,Igrave:278,Imacron:278,Lcaron:556,onehalf:834,lessequal:549,ocircumflex:556,ntilde:556,Uhungarumlaut:722,Eacute:667,emacron:556,gbreve:556,onequarter:834,Scaron:667,Scommaaccent:667,Ohungarumlaut:778,degree:400,ograve:556,Ccaron:722,ugrave:556,radical:453,Dcaron:722,rcommaaccent:333,Ntilde:722,otilde:556,Rcommaaccent:722,Lcommaaccent:556,Atilde:667,Aogonek:667,Aring:667,Otilde:778,
zdotaccent:500,Ecaron:667,Iogonek:278,kcommaaccent:500,minus:584,Icircumflex:278,ncaron:556,tcommaaccent:278,logicalnot:584,odieresis:556,udieresis:556,notequal:549,gcommaaccent:556,eth:556,zcaron:500,ncommaaccent:556,onesuperior:333,imacron:278,Euro:556},"Helvetica-Bold":{space:278,exclam:333,quotedbl:474,numbersign:556,dollar:556,percent:889,ampersand:722,quoteright:278,parenleft:333,parenright:333,asterisk:389,plus:584,comma:278,hyphen:333,period:278,slash:278,zero:556,one:556,two:556,three:556,
four:556,five:556,six:556,seven:556,eight:556,nine:556,colon:333,semicolon:333,less:584,equal:584,greater:584,question:611,at:975,A:722,B:722,C:722,D:722,E:667,F:611,G:778,H:722,I:278,J:556,K:722,L:611,M:833,N:722,O:778,P:667,Q:778,R:722,S:667,T:611,U:722,V:667,W:944,X:667,Y:667,Z:611,bracketleft:333,backslash:278,bracketright:333,asciicircum:584,underscore:556,quoteleft:278,a:556,b:611,c:556,d:611,e:556,f:333,g:611,h:611,i:278,j:278,k:556,l:278,m:889,n:611,o:611,p:611,q:611,r:389,s:556,t:333,u:611,
v:556,w:778,x:556,y:556,z:500,braceleft:389,bar:280,braceright:389,asciitilde:584,exclamdown:333,cent:556,sterling:556,fraction:167,yen:556,florin:556,section:556,currency:556,quotesingle:238,quotedblleft:500,guillemotleft:556,guilsinglleft:333,guilsinglright:333,fi:611,fl:611,endash:556,dagger:556,daggerdbl:556,periodcentered:278,paragraph:556,bullet:350,quotesinglbase:278,quotedblbase:500,quotedblright:500,guillemotright:556,ellipsis:1E3,perthousand:1E3,questiondown:611,grave:333,acute:333,circumflex:333,
tilde:333,macron:333,breve:333,dotaccent:333,dieresis:333,ring:333,cedilla:333,hungarumlaut:333,ogonek:333,caron:333,emdash:1E3,AE:1E3,ordfeminine:370,Lslash:611,Oslash:778,OE:1E3,ordmasculine:365,ae:889,dotlessi:278,lslash:278,oslash:611,oe:944,germandbls:611,Idieresis:278,eacute:556,abreve:556,uhungarumlaut:611,ecaron:556,Ydieresis:667,divide:584,Yacute:667,Acircumflex:722,aacute:556,Ucircumflex:722,yacute:556,scommaaccent:556,ecircumflex:556,Uring:722,Udieresis:722,aogonek:556,Uacute:722,uogonek:611,
Edieresis:667,Dcroat:722,commaaccent:250,copyright:737,Emacron:667,ccaron:556,aring:556,Ncommaaccent:722,lacute:278,agrave:556,Tcommaaccent:611,Cacute:722,atilde:556,Edotaccent:667,scaron:556,scedilla:556,iacute:278,lozenge:494,Rcaron:722,Gcommaaccent:778,ucircumflex:611,acircumflex:556,Amacron:722,rcaron:389,ccedilla:556,Zdotaccent:611,Thorn:667,Omacron:778,Racute:722,Sacute:667,dcaron:743,Umacron:722,uring:611,threesuperior:333,Ograve:778,Agrave:722,Abreve:722,multiply:584,uacute:611,Tcaron:611,
partialdiff:494,ydieresis:556,Nacute:722,icircumflex:278,Ecircumflex:667,adieresis:556,edieresis:556,cacute:556,nacute:611,umacron:611,Ncaron:722,Iacute:278,plusminus:584,brokenbar:280,registered:737,Gbreve:778,Idotaccent:278,summation:600,Egrave:667,racute:389,omacron:611,Zacute:611,Zcaron:611,greaterequal:549,Eth:722,Ccedilla:722,lcommaaccent:278,tcaron:389,eogonek:556,Uogonek:722,Aacute:722,Adieresis:722,egrave:556,zacute:500,iogonek:278,Oacute:778,oacute:611,amacron:556,sacute:556,idieresis:278,
Ocircumflex:778,Ugrave:722,Delta:612,thorn:611,twosuperior:333,Odieresis:778,mu:611,igrave:278,ohungarumlaut:611,Eogonek:667,dcroat:611,threequarters:834,Scedilla:667,lcaron:400,Kcommaaccent:722,Lacute:611,trademark:1E3,edotaccent:556,Igrave:278,Imacron:278,Lcaron:611,onehalf:834,lessequal:549,ocircumflex:611,ntilde:611,Uhungarumlaut:722,Eacute:667,emacron:556,gbreve:611,onequarter:834,Scaron:667,Scommaaccent:667,Ohungarumlaut:778,degree:400,ograve:611,Ccaron:722,ugrave:611,radical:549,Dcaron:722,
rcommaaccent:389,Ntilde:722,otilde:611,Rcommaaccent:722,Lcommaaccent:611,Atilde:722,Aogonek:722,Aring:722,Otilde:778,zdotaccent:500,Ecaron:667,Iogonek:278,kcommaaccent:556,minus:584,Icircumflex:278,ncaron:611,tcommaaccent:333,logicalnot:584,odieresis:611,udieresis:611,notequal:549,gcommaaccent:611,eth:611,zcaron:500,ncommaaccent:611,onesuperior:333,imacron:278,Euro:556},"Helvetica-BoldOblique":{space:278,exclam:333,quotedbl:474,numbersign:556,dollar:556,percent:889,ampersand:722,quoteright:278,parenleft:333,
parenright:333,asterisk:389,plus:584,comma:278,hyphen:333,period:278,slash:278,zero:556,one:556,two:556,three:556,four:556,five:556,six:556,seven:556,eight:556,nine:556,colon:333,semicolon:333,less:584,equal:584,greater:584,question:611,at:975,A:722,B:722,C:722,D:722,E:667,F:611,G:778,H:722,I:278,J:556,K:722,L:611,M:833,N:722,O:778,P:667,Q:778,R:722,S:667,T:611,U:722,V:667,W:944,X:667,Y:667,Z:611,bracketleft:333,backslash:278,bracketright:333,asciicircum:584,underscore:556,quoteleft:278,a:556,b:611,
c:556,d:611,e:556,f:333,g:611,h:611,i:278,j:278,k:556,l:278,m:889,n:611,o:611,p:611,q:611,r:389,s:556,t:333,u:611,v:556,w:778,x:556,y:556,z:500,braceleft:389,bar:280,braceright:389,asciitilde:584,exclamdown:333,cent:556,sterling:556,fraction:167,yen:556,florin:556,section:556,currency:556,quotesingle:238,quotedblleft:500,guillemotleft:556,guilsinglleft:333,guilsinglright:333,fi:611,fl:611,endash:556,dagger:556,daggerdbl:556,periodcentered:278,paragraph:556,bullet:350,quotesinglbase:278,quotedblbase:500,
quotedblright:500,guillemotright:556,ellipsis:1E3,perthousand:1E3,questiondown:611,grave:333,acute:333,circumflex:333,tilde:333,macron:333,breve:333,dotaccent:333,dieresis:333,ring:333,cedilla:333,hungarumlaut:333,ogonek:333,caron:333,emdash:1E3,AE:1E3,ordfeminine:370,Lslash:611,Oslash:778,OE:1E3,ordmasculine:365,ae:889,dotlessi:278,lslash:278,oslash:611,oe:944,germandbls:611,Idieresis:278,eacute:556,abreve:556,uhungarumlaut:611,ecaron:556,Ydieresis:667,divide:584,Yacute:667,Acircumflex:722,aacute:556,
Ucircumflex:722,yacute:556,scommaaccent:556,ecircumflex:556,Uring:722,Udieresis:722,aogonek:556,Uacute:722,uogonek:611,Edieresis:667,Dcroat:722,commaaccent:250,copyright:737,Emacron:667,ccaron:556,aring:556,Ncommaaccent:722,lacute:278,agrave:556,Tcommaaccent:611,Cacute:722,atilde:556,Edotaccent:667,scaron:556,scedilla:556,iacute:278,lozenge:494,Rcaron:722,Gcommaaccent:778,ucircumflex:611,acircumflex:556,Amacron:722,rcaron:389,ccedilla:556,Zdotaccent:611,Thorn:667,Omacron:778,Racute:722,Sacute:667,
dcaron:743,Umacron:722,uring:611,threesuperior:333,Ograve:778,Agrave:722,Abreve:722,multiply:584,uacute:611,Tcaron:611,partialdiff:494,ydieresis:556,Nacute:722,icircumflex:278,Ecircumflex:667,adieresis:556,edieresis:556,cacute:556,nacute:611,umacron:611,Ncaron:722,Iacute:278,plusminus:584,brokenbar:280,registered:737,Gbreve:778,Idotaccent:278,summation:600,Egrave:667,racute:389,omacron:611,Zacute:611,Zcaron:611,greaterequal:549,Eth:722,Ccedilla:722,lcommaaccent:278,tcaron:389,eogonek:556,Uogonek:722,
Aacute:722,Adieresis:722,egrave:556,zacute:500,iogonek:278,Oacute:778,oacute:611,amacron:556,sacute:556,idieresis:278,Ocircumflex:778,Ugrave:722,Delta:612,thorn:611,twosuperior:333,Odieresis:778,mu:611,igrave:278,ohungarumlaut:611,Eogonek:667,dcroat:611,threequarters:834,Scedilla:667,lcaron:400,Kcommaaccent:722,Lacute:611,trademark:1E3,edotaccent:556,Igrave:278,Imacron:278,Lcaron:611,onehalf:834,lessequal:549,ocircumflex:611,ntilde:611,Uhungarumlaut:722,Eacute:667,emacron:556,gbreve:611,onequarter:834,
Scaron:667,Scommaaccent:667,Ohungarumlaut:778,degree:400,ograve:611,Ccaron:722,ugrave:611,radical:549,Dcaron:722,rcommaaccent:389,Ntilde:722,otilde:611,Rcommaaccent:722,Lcommaaccent:611,Atilde:722,Aogonek:722,Aring:722,Otilde:778,zdotaccent:500,Ecaron:667,Iogonek:278,kcommaaccent:556,minus:584,Icircumflex:278,ncaron:611,tcommaaccent:333,logicalnot:584,odieresis:611,udieresis:611,notequal:549,gcommaaccent:611,eth:611,zcaron:500,ncommaaccent:611,onesuperior:333,imacron:278,Euro:556},"Helvetica-Oblique":{space:278,
exclam:278,quotedbl:355,numbersign:556,dollar:556,percent:889,ampersand:667,quoteright:222,parenleft:333,parenright:333,asterisk:389,plus:584,comma:278,hyphen:333,period:278,slash:278,zero:556,one:556,two:556,three:556,four:556,five:556,six:556,seven:556,eight:556,nine:556,colon:278,semicolon:278,less:584,equal:584,greater:584,question:556,at:1015,A:667,B:667,C:722,D:722,E:667,F:611,G:778,H:722,I:278,J:500,K:667,L:556,M:833,N:722,O:778,P:667,Q:778,R:722,S:667,T:611,U:722,V:667,W:944,X:667,Y:667,Z:611,
bracketleft:278,backslash:278,bracketright:278,asciicircum:469,underscore:556,quoteleft:222,a:556,b:556,c:500,d:556,e:556,f:278,g:556,h:556,i:222,j:222,k:500,l:222,m:833,n:556,o:556,p:556,q:556,r:333,s:500,t:278,u:556,v:500,w:722,x:500,y:500,z:500,braceleft:334,bar:260,braceright:334,asciitilde:584,exclamdown:333,cent:556,sterling:556,fraction:167,yen:556,florin:556,section:556,currency:556,quotesingle:191,quotedblleft:333,guillemotleft:556,guilsinglleft:333,guilsinglright:333,fi:500,fl:500,endash:556,
dagger:556,daggerdbl:556,periodcentered:278,paragraph:537,bullet:350,quotesinglbase:222,quotedblbase:333,quotedblright:333,guillemotright:556,ellipsis:1E3,perthousand:1E3,questiondown:611,grave:333,acute:333,circumflex:333,tilde:333,macron:333,breve:333,dotaccent:333,dieresis:333,ring:333,cedilla:333,hungarumlaut:333,ogonek:333,caron:333,emdash:1E3,AE:1E3,ordfeminine:370,Lslash:556,Oslash:778,OE:1E3,ordmasculine:365,ae:889,dotlessi:278,lslash:222,oslash:611,oe:944,germandbls:611,Idieresis:278,eacute:556,
abreve:556,uhungarumlaut:556,ecaron:556,Ydieresis:667,divide:584,Yacute:667,Acircumflex:667,aacute:556,Ucircumflex:722,yacute:500,scommaaccent:500,ecircumflex:556,Uring:722,Udieresis:722,aogonek:556,Uacute:722,uogonek:556,Edieresis:667,Dcroat:722,commaaccent:250,copyright:737,Emacron:667,ccaron:500,aring:556,Ncommaaccent:722,lacute:222,agrave:556,Tcommaaccent:611,Cacute:722,atilde:556,Edotaccent:667,scaron:500,scedilla:500,iacute:278,lozenge:471,Rcaron:722,Gcommaaccent:778,ucircumflex:556,acircumflex:556,
Amacron:667,rcaron:333,ccedilla:500,Zdotaccent:611,Thorn:667,Omacron:778,Racute:722,Sacute:667,dcaron:643,Umacron:722,uring:556,threesuperior:333,Ograve:778,Agrave:667,Abreve:667,multiply:584,uacute:556,Tcaron:611,partialdiff:476,ydieresis:500,Nacute:722,icircumflex:278,Ecircumflex:667,adieresis:556,edieresis:556,cacute:500,nacute:556,umacron:556,Ncaron:722,Iacute:278,plusminus:584,brokenbar:260,registered:737,Gbreve:778,Idotaccent:278,summation:600,Egrave:667,racute:333,omacron:556,Zacute:611,Zcaron:611,
greaterequal:549,Eth:722,Ccedilla:722,lcommaaccent:222,tcaron:317,eogonek:556,Uogonek:722,Aacute:667,Adieresis:667,egrave:556,zacute:500,iogonek:222,Oacute:778,oacute:556,amacron:556,sacute:500,idieresis:278,Ocircumflex:778,Ugrave:722,Delta:612,thorn:556,twosuperior:333,Odieresis:778,mu:556,igrave:278,ohungarumlaut:556,Eogonek:667,dcroat:556,threequarters:834,Scedilla:667,lcaron:299,Kcommaaccent:667,Lacute:556,trademark:1E3,edotaccent:556,Igrave:278,Imacron:278,Lcaron:556,onehalf:834,lessequal:549,
ocircumflex:556,ntilde:556,Uhungarumlaut:722,Eacute:667,emacron:556,gbreve:556,onequarter:834,Scaron:667,Scommaaccent:667,Ohungarumlaut:778,degree:400,ograve:556,Ccaron:722,ugrave:556,radical:453,Dcaron:722,rcommaaccent:333,Ntilde:722,otilde:556,Rcommaaccent:722,Lcommaaccent:556,Atilde:667,Aogonek:667,Aring:667,Otilde:778,zdotaccent:500,Ecaron:667,Iogonek:278,kcommaaccent:500,minus:584,Icircumflex:278,ncaron:556,tcommaaccent:278,logicalnot:584,odieresis:556,udieresis:556,notequal:549,gcommaaccent:556,
eth:556,zcaron:500,ncommaaccent:556,onesuperior:333,imacron:278,Euro:556},Symbol:{space:250,exclam:333,universal:713,numbersign:500,existential:549,percent:833,ampersand:778,suchthat:439,parenleft:333,parenright:333,asteriskmath:500,plus:549,comma:250,minus:549,period:250,slash:278,zero:500,one:500,two:500,three:500,four:500,five:500,six:500,seven:500,eight:500,nine:500,colon:278,semicolon:278,less:549,equal:549,greater:549,question:444,congruent:549,Alpha:722,Beta:667,Chi:722,Delta:612,Epsilon:611,
Phi:763,Gamma:603,Eta:722,Iota:333,theta1:631,Kappa:722,Lambda:686,Mu:889,Nu:722,Omicron:722,Pi:768,Theta:741,Rho:556,Sigma:592,Tau:611,Upsilon:690,sigma1:439,Omega:768,Xi:645,Psi:795,Zeta:611,bracketleft:333,therefore:863,bracketright:333,perpendicular:658,underscore:500,radicalex:500,alpha:631,beta:549,chi:549,delta:494,epsilon:439,phi:521,gamma:411,eta:603,iota:329,phi1:603,kappa:549,lambda:549,mu:576,nu:521,omicron:549,pi:549,theta:521,rho:549,sigma:603,tau:439,upsilon:576,omega1:713,omega:686,
xi:493,psi:686,zeta:494,braceleft:480,bar:200,braceright:480,similar:549,Euro:750,Upsilon1:620,minute:247,lessequal:549,fraction:167,infinity:713,florin:500,club:753,diamond:753,heart:753,spade:753,arrowboth:1042,arrowleft:987,arrowup:603,arrowright:987,arrowdown:603,degree:400,plusminus:549,second:411,greaterequal:549,multiply:549,proportional:713,partialdiff:494,bullet:460,divide:549,notequal:549,equivalence:549,approxequal:549,ellipsis:1E3,arrowvertex:603,arrowhorizex:1E3,carriagereturn:658,aleph:823,
Ifraktur:686,Rfraktur:795,weierstrass:987,circlemultiply:768,circleplus:768,emptyset:823,intersection:768,union:768,propersuperset:713,reflexsuperset:713,notsubset:713,propersubset:713,reflexsubset:713,element:713,notelement:713,angle:768,gradient:713,registerserif:790,copyrightserif:790,trademarkserif:890,product:823,radical:549,dotmath:250,logicalnot:713,logicaland:603,logicalor:603,arrowdblboth:1042,arrowdblleft:987,arrowdblup:603,arrowdblright:987,arrowdbldown:603,lozenge:494,angleleft:329,registersans:790,
copyrightsans:790,trademarksans:786,summation:713,parenlefttp:384,parenleftex:384,parenleftbt:384,bracketlefttp:384,bracketleftex:384,bracketleftbt:384,bracelefttp:494,braceleftmid:494,braceleftbt:494,braceex:494,angleright:329,integral:274,integraltp:686,integralex:686,integralbt:686,parenrighttp:384,parenrightex:384,parenrightbt:384,bracketrighttp:384,bracketrightex:384,bracketrightbt:384,bracerighttp:494,bracerightmid:494,bracerightbt:494,apple:790},"Times-Roman":{space:250,exclam:333,quotedbl:408,
numbersign:500,dollar:500,percent:833,ampersand:778,quoteright:333,parenleft:333,parenright:333,asterisk:500,plus:564,comma:250,hyphen:333,period:250,slash:278,zero:500,one:500,two:500,three:500,four:500,five:500,six:500,seven:500,eight:500,nine:500,colon:278,semicolon:278,less:564,equal:564,greater:564,question:444,at:921,A:722,B:667,C:667,D:722,E:611,F:556,G:722,H:722,I:333,J:389,K:722,L:611,M:889,N:722,O:722,P:556,Q:722,R:667,S:556,T:611,U:722,V:722,W:944,X:722,Y:722,Z:611,bracketleft:333,backslash:278,
bracketright:333,asciicircum:469,underscore:500,quoteleft:333,a:444,b:500,c:444,d:500,e:444,f:333,g:500,h:500,i:278,j:278,k:500,l:278,m:778,n:500,o:500,p:500,q:500,r:333,s:389,t:278,u:500,v:500,w:722,x:500,y:500,z:444,braceleft:480,bar:200,braceright:480,asciitilde:541,exclamdown:333,cent:500,sterling:500,fraction:167,yen:500,florin:500,section:500,currency:500,quotesingle:180,quotedblleft:444,guillemotleft:500,guilsinglleft:333,guilsinglright:333,fi:556,fl:556,endash:500,dagger:500,daggerdbl:500,
periodcentered:250,paragraph:453,bullet:350,quotesinglbase:333,quotedblbase:444,quotedblright:444,guillemotright:500,ellipsis:1E3,perthousand:1E3,questiondown:444,grave:333,acute:333,circumflex:333,tilde:333,macron:333,breve:333,dotaccent:333,dieresis:333,ring:333,cedilla:333,hungarumlaut:333,ogonek:333,caron:333,emdash:1E3,AE:889,ordfeminine:276,Lslash:611,Oslash:722,OE:889,ordmasculine:310,ae:667,dotlessi:278,lslash:278,oslash:500,oe:722,germandbls:500,Idieresis:333,eacute:444,abreve:444,uhungarumlaut:500,
ecaron:444,Ydieresis:722,divide:564,Yacute:722,Acircumflex:722,aacute:444,Ucircumflex:722,yacute:500,scommaaccent:389,ecircumflex:444,Uring:722,Udieresis:722,aogonek:444,Uacute:722,uogonek:500,Edieresis:611,Dcroat:722,commaaccent:250,copyright:760,Emacron:611,ccaron:444,aring:444,Ncommaaccent:722,lacute:278,agrave:444,Tcommaaccent:611,Cacute:667,atilde:444,Edotaccent:611,scaron:389,scedilla:389,iacute:278,lozenge:471,Rcaron:667,Gcommaaccent:722,ucircumflex:500,acircumflex:444,Amacron:722,rcaron:333,
ccedilla:444,Zdotaccent:611,Thorn:556,Omacron:722,Racute:667,Sacute:556,dcaron:588,Umacron:722,uring:500,threesuperior:300,Ograve:722,Agrave:722,Abreve:722,multiply:564,uacute:500,Tcaron:611,partialdiff:476,ydieresis:500,Nacute:722,icircumflex:278,Ecircumflex:611,adieresis:444,edieresis:444,cacute:444,nacute:500,umacron:500,Ncaron:722,Iacute:333,plusminus:564,brokenbar:200,registered:760,Gbreve:722,Idotaccent:333,summation:600,Egrave:611,racute:333,omacron:500,Zacute:611,Zcaron:611,greaterequal:549,
Eth:722,Ccedilla:667,lcommaaccent:278,tcaron:326,eogonek:444,Uogonek:722,Aacute:722,Adieresis:722,egrave:444,zacute:444,iogonek:278,Oacute:722,oacute:500,amacron:444,sacute:389,idieresis:278,Ocircumflex:722,Ugrave:722,Delta:612,thorn:500,twosuperior:300,Odieresis:722,mu:500,igrave:278,ohungarumlaut:500,Eogonek:611,dcroat:500,threequarters:750,Scedilla:556,lcaron:344,Kcommaaccent:722,Lacute:611,trademark:980,edotaccent:444,Igrave:333,Imacron:333,Lcaron:611,onehalf:750,lessequal:549,ocircumflex:500,
ntilde:500,Uhungarumlaut:722,Eacute:611,emacron:444,gbreve:500,onequarter:750,Scaron:556,Scommaaccent:556,Ohungarumlaut:722,degree:400,ograve:500,Ccaron:667,ugrave:500,radical:453,Dcaron:722,rcommaaccent:333,Ntilde:722,otilde:500,Rcommaaccent:667,Lcommaaccent:611,Atilde:722,Aogonek:722,Aring:722,Otilde:722,zdotaccent:444,Ecaron:611,Iogonek:333,kcommaaccent:500,minus:564,Icircumflex:333,ncaron:500,tcommaaccent:278,logicalnot:564,odieresis:500,udieresis:500,notequal:549,gcommaaccent:500,eth:500,zcaron:444,
ncommaaccent:500,onesuperior:300,imacron:278,Euro:500},"Times-Bold":{space:250,exclam:333,quotedbl:555,numbersign:500,dollar:500,percent:1E3,ampersand:833,quoteright:333,parenleft:333,parenright:333,asterisk:500,plus:570,comma:250,hyphen:333,period:250,slash:278,zero:500,one:500,two:500,three:500,four:500,five:500,six:500,seven:500,eight:500,nine:500,colon:333,semicolon:333,less:570,equal:570,greater:570,question:500,at:930,A:722,B:667,C:722,D:722,E:667,F:611,G:778,H:778,I:389,J:500,K:778,L:667,M:944,
N:722,O:778,P:611,Q:778,R:722,S:556,T:667,U:722,V:722,W:1E3,X:722,Y:722,Z:667,bracketleft:333,backslash:278,bracketright:333,asciicircum:581,underscore:500,quoteleft:333,a:500,b:556,c:444,d:556,e:444,f:333,g:500,h:556,i:278,j:333,k:556,l:278,m:833,n:556,o:500,p:556,q:556,r:444,s:389,t:333,u:556,v:500,w:722,x:500,y:500,z:444,braceleft:394,bar:220,braceright:394,asciitilde:520,exclamdown:333,cent:500,sterling:500,fraction:167,yen:500,florin:500,section:500,currency:500,quotesingle:278,quotedblleft:500,
guillemotleft:500,guilsinglleft:333,guilsinglright:333,fi:556,fl:556,endash:500,dagger:500,daggerdbl:500,periodcentered:250,paragraph:540,bullet:350,quotesinglbase:333,quotedblbase:500,quotedblright:500,guillemotright:500,ellipsis:1E3,perthousand:1E3,questiondown:500,grave:333,acute:333,circumflex:333,tilde:333,macron:333,breve:333,dotaccent:333,dieresis:333,ring:333,cedilla:333,hungarumlaut:333,ogonek:333,caron:333,emdash:1E3,AE:1E3,ordfeminine:300,Lslash:667,Oslash:778,OE:1E3,ordmasculine:330,ae:722,
dotlessi:278,lslash:278,oslash:500,oe:722,germandbls:556,Idieresis:389,eacute:444,abreve:500,uhungarumlaut:556,ecaron:444,Ydieresis:722,divide:570,Yacute:722,Acircumflex:722,aacute:500,Ucircumflex:722,yacute:500,scommaaccent:389,ecircumflex:444,Uring:722,Udieresis:722,aogonek:500,Uacute:722,uogonek:556,Edieresis:667,Dcroat:722,commaaccent:250,copyright:747,Emacron:667,ccaron:444,aring:500,Ncommaaccent:722,lacute:278,agrave:500,Tcommaaccent:667,Cacute:722,atilde:500,Edotaccent:667,scaron:389,scedilla:389,
iacute:278,lozenge:494,Rcaron:722,Gcommaaccent:778,ucircumflex:556,acircumflex:500,Amacron:722,rcaron:444,ccedilla:444,Zdotaccent:667,Thorn:611,Omacron:778,Racute:722,Sacute:556,dcaron:672,Umacron:722,uring:556,threesuperior:300,Ograve:778,Agrave:722,Abreve:722,multiply:570,uacute:556,Tcaron:667,partialdiff:494,ydieresis:500,Nacute:722,icircumflex:278,Ecircumflex:667,adieresis:500,edieresis:444,cacute:444,nacute:556,umacron:556,Ncaron:722,Iacute:389,plusminus:570,brokenbar:220,registered:747,Gbreve:778,
Idotaccent:389,summation:600,Egrave:667,racute:444,omacron:500,Zacute:667,Zcaron:667,greaterequal:549,Eth:722,Ccedilla:722,lcommaaccent:278,tcaron:416,eogonek:444,Uogonek:722,Aacute:722,Adieresis:722,egrave:444,zacute:444,iogonek:278,Oacute:778,oacute:500,amacron:500,sacute:389,idieresis:278,Ocircumflex:778,Ugrave:722,Delta:612,thorn:556,twosuperior:300,Odieresis:778,mu:556,igrave:278,ohungarumlaut:500,Eogonek:667,dcroat:556,threequarters:750,Scedilla:556,lcaron:394,Kcommaaccent:778,Lacute:667,trademark:1E3,
edotaccent:444,Igrave:389,Imacron:389,Lcaron:667,onehalf:750,lessequal:549,ocircumflex:500,ntilde:556,Uhungarumlaut:722,Eacute:667,emacron:444,gbreve:500,onequarter:750,Scaron:556,Scommaaccent:556,Ohungarumlaut:778,degree:400,ograve:500,Ccaron:722,ugrave:556,radical:549,Dcaron:722,rcommaaccent:444,Ntilde:722,otilde:500,Rcommaaccent:722,Lcommaaccent:667,Atilde:722,Aogonek:722,Aring:722,Otilde:778,zdotaccent:444,Ecaron:667,Iogonek:389,kcommaaccent:556,minus:570,Icircumflex:389,ncaron:556,tcommaaccent:333,
logicalnot:570,odieresis:500,udieresis:556,notequal:549,gcommaaccent:500,eth:500,zcaron:444,ncommaaccent:556,onesuperior:300,imacron:278,Euro:500},"Times-BoldItalic":{space:250,exclam:389,quotedbl:555,numbersign:500,dollar:500,percent:833,ampersand:778,quoteright:333,parenleft:333,parenright:333,asterisk:500,plus:570,comma:250,hyphen:333,period:250,slash:278,zero:500,one:500,two:500,three:500,four:500,five:500,six:500,seven:500,eight:500,nine:500,colon:333,semicolon:333,less:570,equal:570,greater:570,
question:500,at:832,A:667,B:667,C:667,D:722,E:667,F:667,G:722,H:778,I:389,J:500,K:667,L:611,M:889,N:722,O:722,P:611,Q:722,R:667,S:556,T:611,U:722,V:667,W:889,X:667,Y:611,Z:611,bracketleft:333,backslash:278,bracketright:333,asciicircum:570,underscore:500,quoteleft:333,a:500,b:500,c:444,d:500,e:444,f:333,g:500,h:556,i:278,j:278,k:500,l:278,m:778,n:556,o:500,p:500,q:500,r:389,s:389,t:278,u:556,v:444,w:667,x:500,y:444,z:389,braceleft:348,bar:220,braceright:348,asciitilde:570,exclamdown:389,cent:500,sterling:500,
fraction:167,yen:500,florin:500,section:500,currency:500,quotesingle:278,quotedblleft:500,guillemotleft:500,guilsinglleft:333,guilsinglright:333,fi:556,fl:556,endash:500,dagger:500,daggerdbl:500,periodcentered:250,paragraph:500,bullet:350,quotesinglbase:333,quotedblbase:500,quotedblright:500,guillemotright:500,ellipsis:1E3,perthousand:1E3,questiondown:500,grave:333,acute:333,circumflex:333,tilde:333,macron:333,breve:333,dotaccent:333,dieresis:333,ring:333,cedilla:333,hungarumlaut:333,ogonek:333,caron:333,
emdash:1E3,AE:944,ordfeminine:266,Lslash:611,Oslash:722,OE:944,ordmasculine:300,ae:722,dotlessi:278,lslash:278,oslash:500,oe:722,germandbls:500,Idieresis:389,eacute:444,abreve:500,uhungarumlaut:556,ecaron:444,Ydieresis:611,divide:570,Yacute:611,Acircumflex:667,aacute:500,Ucircumflex:722,yacute:444,scommaaccent:389,ecircumflex:444,Uring:722,Udieresis:722,aogonek:500,Uacute:722,uogonek:556,Edieresis:667,Dcroat:722,commaaccent:250,copyright:747,Emacron:667,ccaron:444,aring:500,Ncommaaccent:722,lacute:278,
agrave:500,Tcommaaccent:611,Cacute:667,atilde:500,Edotaccent:667,scaron:389,scedilla:389,iacute:278,lozenge:494,Rcaron:667,Gcommaaccent:722,ucircumflex:556,acircumflex:500,Amacron:667,rcaron:389,ccedilla:444,Zdotaccent:611,Thorn:611,Omacron:722,Racute:667,Sacute:556,dcaron:608,Umacron:722,uring:556,threesuperior:300,Ograve:722,Agrave:667,Abreve:667,multiply:570,uacute:556,Tcaron:611,partialdiff:494,ydieresis:444,Nacute:722,icircumflex:278,Ecircumflex:667,adieresis:500,edieresis:444,cacute:444,nacute:556,
umacron:556,Ncaron:722,Iacute:389,plusminus:570,brokenbar:220,registered:747,Gbreve:722,Idotaccent:389,summation:600,Egrave:667,racute:389,omacron:500,Zacute:611,Zcaron:611,greaterequal:549,Eth:722,Ccedilla:667,lcommaaccent:278,tcaron:366,eogonek:444,Uogonek:722,Aacute:667,Adieresis:667,egrave:444,zacute:389,iogonek:278,Oacute:722,oacute:500,amacron:500,sacute:389,idieresis:278,Ocircumflex:722,Ugrave:722,Delta:612,thorn:500,twosuperior:300,Odieresis:722,mu:576,igrave:278,ohungarumlaut:500,Eogonek:667,
dcroat:500,threequarters:750,Scedilla:556,lcaron:382,Kcommaaccent:667,Lacute:611,trademark:1E3,edotaccent:444,Igrave:389,Imacron:389,Lcaron:611,onehalf:750,lessequal:549,ocircumflex:500,ntilde:556,Uhungarumlaut:722,Eacute:667,emacron:444,gbreve:500,onequarter:750,Scaron:556,Scommaaccent:556,Ohungarumlaut:722,degree:400,ograve:500,Ccaron:667,ugrave:556,radical:549,Dcaron:722,rcommaaccent:389,Ntilde:722,otilde:500,Rcommaaccent:667,Lcommaaccent:611,Atilde:667,Aogonek:667,Aring:667,Otilde:722,zdotaccent:389,
Ecaron:667,Iogonek:389,kcommaaccent:500,minus:606,Icircumflex:389,ncaron:556,tcommaaccent:278,logicalnot:606,odieresis:500,udieresis:556,notequal:549,gcommaaccent:500,eth:500,zcaron:389,ncommaaccent:556,onesuperior:300,imacron:278,Euro:500},"Times-Italic":{space:250,exclam:333,quotedbl:420,numbersign:500,dollar:500,percent:833,ampersand:778,quoteright:333,parenleft:333,parenright:333,asterisk:500,plus:675,comma:250,hyphen:333,period:250,slash:278,zero:500,one:500,two:500,three:500,four:500,five:500,
six:500,seven:500,eight:500,nine:500,colon:333,semicolon:333,less:675,equal:675,greater:675,question:500,at:920,A:611,B:611,C:667,D:722,E:611,F:611,G:722,H:722,I:333,J:444,K:667,L:556,M:833,N:667,O:722,P:611,Q:722,R:611,S:500,T:556,U:722,V:611,W:833,X:611,Y:556,Z:556,bracketleft:389,backslash:278,bracketright:389,asciicircum:422,underscore:500,quoteleft:333,a:500,b:500,c:444,d:500,e:444,f:278,g:500,h:500,i:278,j:278,k:444,l:278,m:722,n:500,o:500,p:500,q:500,r:389,s:389,t:278,u:500,v:444,w:667,x:444,
y:444,z:389,braceleft:400,bar:275,braceright:400,asciitilde:541,exclamdown:389,cent:500,sterling:500,fraction:167,yen:500,florin:500,section:500,currency:500,quotesingle:214,quotedblleft:556,guillemotleft:500,guilsinglleft:333,guilsinglright:333,fi:500,fl:500,endash:500,dagger:500,daggerdbl:500,periodcentered:250,paragraph:523,bullet:350,quotesinglbase:333,quotedblbase:556,quotedblright:556,guillemotright:500,ellipsis:889,perthousand:1E3,questiondown:500,grave:333,acute:333,circumflex:333,tilde:333,
macron:333,breve:333,dotaccent:333,dieresis:333,ring:333,cedilla:333,hungarumlaut:333,ogonek:333,caron:333,emdash:889,AE:889,ordfeminine:276,Lslash:556,Oslash:722,OE:944,ordmasculine:310,ae:667,dotlessi:278,lslash:278,oslash:500,oe:667,germandbls:500,Idieresis:333,eacute:444,abreve:500,uhungarumlaut:500,ecaron:444,Ydieresis:556,divide:675,Yacute:556,Acircumflex:611,aacute:500,Ucircumflex:722,yacute:444,scommaaccent:389,ecircumflex:444,Uring:722,Udieresis:722,aogonek:500,Uacute:722,uogonek:500,Edieresis:611,
Dcroat:722,commaaccent:250,copyright:760,Emacron:611,ccaron:444,aring:500,Ncommaaccent:667,lacute:278,agrave:500,Tcommaaccent:556,Cacute:667,atilde:500,Edotaccent:611,scaron:389,scedilla:389,iacute:278,lozenge:471,Rcaron:611,Gcommaaccent:722,ucircumflex:500,acircumflex:500,Amacron:611,rcaron:389,ccedilla:444,Zdotaccent:556,Thorn:611,Omacron:722,Racute:611,Sacute:500,dcaron:544,Umacron:722,uring:500,threesuperior:300,Ograve:722,Agrave:611,Abreve:611,multiply:675,uacute:500,Tcaron:556,partialdiff:476,
ydieresis:444,Nacute:667,icircumflex:278,Ecircumflex:611,adieresis:500,edieresis:444,cacute:444,nacute:500,umacron:500,Ncaron:667,Iacute:333,plusminus:675,brokenbar:275,registered:760,Gbreve:722,Idotaccent:333,summation:600,Egrave:611,racute:389,omacron:500,Zacute:556,Zcaron:556,greaterequal:549,Eth:722,Ccedilla:667,lcommaaccent:278,tcaron:300,eogonek:444,Uogonek:722,Aacute:611,Adieresis:611,egrave:444,zacute:389,iogonek:278,Oacute:722,oacute:500,amacron:500,sacute:389,idieresis:278,Ocircumflex:722,
Ugrave:722,Delta:612,thorn:500,twosuperior:300,Odieresis:722,mu:500,igrave:278,ohungarumlaut:500,Eogonek:611,dcroat:500,threequarters:750,Scedilla:500,lcaron:300,Kcommaaccent:667,Lacute:556,trademark:980,edotaccent:444,Igrave:333,Imacron:333,Lcaron:611,onehalf:750,lessequal:549,ocircumflex:500,ntilde:500,Uhungarumlaut:722,Eacute:611,emacron:444,gbreve:500,onequarter:750,Scaron:500,Scommaaccent:500,Ohungarumlaut:722,degree:400,ograve:500,Ccaron:667,ugrave:500,radical:453,Dcaron:722,rcommaaccent:389,
Ntilde:667,otilde:500,Rcommaaccent:611,Lcommaaccent:556,Atilde:611,Aogonek:611,Aring:611,Otilde:722,zdotaccent:389,Ecaron:611,Iogonek:333,kcommaaccent:444,minus:675,Icircumflex:333,ncaron:500,tcommaaccent:278,logicalnot:675,odieresis:500,udieresis:500,notequal:549,gcommaaccent:500,eth:500,zcaron:389,ncommaaccent:500,onesuperior:300,imacron:278,Euro:500},ZapfDingbats:{space:278,a1:974,a2:961,a202:974,a3:980,a4:719,a5:789,a119:790,a118:791,a117:690,a11:960,a12:939,a13:549,a14:855,a15:911,a16:933,a105:911,
a17:945,a18:974,a19:755,a20:846,a21:762,a22:761,a23:571,a24:677,a25:763,a26:760,a27:759,a28:754,a6:494,a7:552,a8:537,a9:577,a10:692,a29:786,a30:788,a31:788,a32:790,a33:793,a34:794,a35:816,a36:823,a37:789,a38:841,a39:823,a40:833,a41:816,a42:831,a43:923,a44:744,a45:723,a46:749,a47:790,a48:792,a49:695,a50:776,a51:768,a52:792,a53:759,a54:707,a55:708,a56:682,a57:701,a58:826,a59:815,a60:789,a61:789,a62:707,a63:687,a64:696,a65:689,a66:786,a67:787,a68:713,a69:791,a70:785,a71:791,a72:873,a73:761,a74:762,a203:762,
a75:759,a204:759,a76:892,a77:892,a78:788,a79:784,a81:438,a82:138,a83:277,a84:415,a97:392,a98:392,a99:668,a100:668,a89:390,a90:390,a93:317,a94:317,a91:276,a92:276,a205:509,a85:509,a206:410,a86:410,a87:234,a88:234,a95:334,a96:334,a101:732,a102:544,a103:544,a104:910,a106:667,a107:760,a108:760,a112:776,a111:595,a110:694,a109:626,a120:788,a121:788,a122:788,a123:788,a124:788,a125:788,a126:788,a127:788,a128:788,a129:788,a130:788,a131:788,a132:788,a133:788,a134:788,a135:788,a136:788,a137:788,a138:788,a139:788,
a140:788,a141:788,a142:788,a143:788,a144:788,a145:788,a146:788,a147:788,a148:788,a149:788,a150:788,a151:788,a152:788,a153:788,a154:788,a155:788,a156:788,a157:788,a158:788,a159:788,a160:894,a161:838,a163:1016,a164:458,a196:748,a165:924,a192:748,a166:918,a167:927,a168:928,a169:928,a170:834,a171:873,a172:828,a173:924,a162:924,a174:917,a175:930,a176:931,a177:463,a178:883,a179:836,a193:836,a180:867,a199:867,a181:696,a200:696,a182:874,a201:874,a183:760,a184:946,a197:771,a185:865,a194:771,a198:888,a186:967,
a195:888,a187:831,a188:873,a189:927,a190:970,a191:918}}});var ca=function(){function a(a,e){this.url=a;e=e||{};this.httpHeaders=(this.isHttp=/^https?:/i.test(a))&&e.httpHeaders||{};this.withCredentials=e.withCredentials||!1;this.getXhr=e.getXhr||function(){return new XMLHttpRequest};this.currXhrId=0;this.pendingRequests={};this.loadedRequests={}}function e(a){a=a.response;if("string"!==typeof a)return a;for(var e=a.length,L=new Uint8Array(e),H=0;H<e;H++)L[H]=a.charCodeAt(H)&255;return L.buffer}var O=
function(){try{var a=new XMLHttpRequest;a.open("GET","https://example.com");a.responseType="moz-chunked-arraybuffer";return"moz-chunked-arraybuffer"===a.responseType}catch(e){return!1}}();a.prototype={requestRange:function(a,e,L){var a={begin:a,end:e},H;for(H in L)a[H]=L[H];return this.request(a)},requestFull:function(a){return this.request(a)},request:function(a){var e=this.getXhr(),L=this.currXhrId++,H=this.pendingRequests[L]={xhr:e};e.open("GET",this.url);e.withCredentials=this.withCredentials;
for(var K in this.httpHeaders){var I=this.httpHeaders[K];"undefined"!==typeof I&&e.setRequestHeader(K,I)}this.isHttp&&"begin"in a&&"end"in a?(e.setRequestHeader("Range","bytes="+(a.begin+"-"+(a.end-1))),H.expectedStatus=206):H.expectedStatus=200;O&&a.onProgressiveData?(e.responseType="moz-chunked-arraybuffer",H.onProgressiveData=a.onProgressiveData,H.mozChunked=!0):e.responseType="arraybuffer";a.onError&&(e.onerror=function(){a.onError(e.status)});e.onreadystatechange=this.onStateChange.bind(this,
L);e.onprogress=this.onProgress.bind(this,L);H.onHeadersReceived=a.onHeadersReceived;H.onDone=a.onDone;H.onError=a.onError;H.onProgress=a.onProgress;e.send(null);return L},onProgress:function(a,N){var L=this.pendingRequests[a];if(L){if(L.mozChunked){var H=e(L.xhr);L.onProgressiveData(H)}(L=L.onProgress)&&L(N)}},onStateChange:function(a){var N=this.pendingRequests[a];if(N){var L=N.xhr;2<=L.readyState&&N.onHeadersReceived&&(N.onHeadersReceived(),delete N.onHeadersReceived);if(4===L.readyState&&a in
this.pendingRequests)if(delete this.pendingRequests[a],0===L.status&&this.isHttp){if(N.onError)N.onError(L.status)}else{var H=L.status||200;if(!(200===H&&206===N.expectedStatus)&&H!==N.expectedStatus){if(N.onError)N.onError(L.status)}else if(this.loadedRequests[a]=!0,a=e(L),206===H)L=/bytes (\d+)-(\d+)\/(\d+)/.exec(L.getResponseHeader("Content-Range")),L=parseInt(L[1],10),N.onDone({begin:L,chunk:a});else if(N.onProgressiveData)N.onDone(null);else if(a)N.onDone({begin:0,chunk:a});else if(N.onError)N.onError(L.status)}}},
hasPendingRequests:function(){for(var a in this.pendingRequests)return!0;return!1},getRequestXhr:function(a){return this.pendingRequests[a].xhr},isStreamingRequest:function(a){return!!this.pendingRequests[a].onProgressiveData},isPendingRequest:function(a){return a in this.pendingRequests},isLoadedRequest:function(a){return a in this.loadedRequests},abortAllRequests:function(){for(var a in this.pendingRequests)this.abortRequest(a|0)},abortRequest:function(a){var e=this.pendingRequests[a].xhr;delete this.pendingRequests[a];
e.abort()}};return a}();(function(a,e){e(a.pdfjsCoreNetwork={})})(this,function(a){a.NetworkManager=ca});(function(a,e){e(a.pdfjsSharedGlobal={})})(this,function(a){var e="undefined"!==typeof window?window:"undefined"!==typeof global?global:"undefined"!==typeof self?self:this;e.PDFJS||(e.PDFJS={});e.PDFJS.pdfBug=!1;a.globalScope=e;a.isWorker="undefined"===typeof window;a.PDFJS=e.PDFJS});(function(a,e){e(a.pdfjsCoreBidi={},a.pdfjsSharedGlobal)})(this,function(a,e){var O=e.PDFJS.bidi=function(){function a(e,
Q,E){for(E-=1;Q<E;++Q,--E){var C=e[Q];e[Q]=e[E];e[E]=C}}function e(a,Q,E){return{str:a,dir:E?"ttb":Q?"ltr":"rtl"}}var L="BN,BN,BN,BN,BN,BN,BN,BN,BN,S,B,S,WS,B,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,B,B,B,S,WS,ON,ON,ET,ET,ET,ON,ON,ON,ON,ON,ON,CS,ON,CS,ON,EN,EN,EN,EN,EN,EN,EN,EN,EN,EN,ON,ON,ON,ON,ON,ON,ON,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,ON,ON,ON,ON,ON,ON,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,ON,ON,ON,ON,BN,BN,BN,BN,BN,BN,B,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,BN,CS,ON,ET,ET,ET,ET,ON,ON,ON,ON,L,ON,ON,ON,ON,ON,ET,ET,EN,EN,ON,L,ON,ON,ON,EN,L,ON,ON,ON,ON,ON,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,ON,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,L,ON,L,L,L,L,L,L,L,L".split(","),
H="AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,CS,AL,ON,ON,NSM,NSM,NSM,NSM,NSM,NSM,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,AL,AL,AL,AL,AL,AL,AL,AN,AN,AN,AN,AN,AN,AN,AN,AN,AN,ET,AN,AN,AL,AL,AL,NSM,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,NSM,ON,NSM,NSM,NSM,NSM,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL,AL".split(","),
K=[],I=[];return function(J,Q,E){var C=!0,o=J.length;if(0===o||E)return e(J,C,E);K.length=o;I.length=o;for(var x=0,E=0;E<o;++E){K[E]=J.charAt(E);var D=J.charCodeAt(E),G="L";255>=D?G=L[D]:1424<=D&&1524>=D?G="R":1536<=D&&1791>=D?G=H[D&255]:1792<=D&&2220>=D&&(G="AL");("R"===G||"AL"===G||"AN"===G)&&x++;I[E]=G}if(0===x)return e(J,!0);-1===Q&&(0.3>o/x?(C=!0,Q=0):(C=!1,Q=1));J=[];for(E=0;E<o;++E)J[E]=Q;x=Q=0!==(Q&1)?"R":"L";for(E=0;E<o;++E)"NSM"===I[E]?I[E]=x:x=I[E];x=Q;for(E=0;E<o;++E)if(D=I[E],"EN"===
D)I[E]="AL"===x?"AN":"EN";else if("R"===D||"L"===D||"AL"===D)x=D;for(E=0;E<o;++E)D=I[E],"AL"===D&&(I[E]="R");for(E=1;E<o-1;++E)if("ES"===I[E]&&"EN"===I[E-1]&&"EN"===I[E+1]&&(I[E]="EN"),"CS"===I[E]&&("EN"===I[E-1]||"AN"===I[E-1])&&I[E+1]===I[E-1])I[E]=I[E-1];for(E=0;E<o;++E)if("EN"===I[E]){for(x=E-1;0<=x&&!("ET"!==I[x]);--x)I[x]="EN";for(x=E+1;x<o&&!("ET"!==I[x]);--x)I[x]="EN"}for(E=0;E<o;++E)if(D=I[E],"WS"===D||"ES"===D||"ET"===D||"CS"===D)I[E]="ON";x=Q;for(E=0;E<o;++E)if(D=I[E],"EN"===D)I[E]="L"===
x?"L":"EN";else if("R"===D||"L"===D)x=D;for(E=0;E<o;++E)if("ON"===I[E]){x=E+1;for(D=I.length;x<D&&!("ON"!==I[x]);++x);var h=Q;0<E&&(h=I[E-1]);D=Q;x+1<o&&(D=I[x+1]);"L"!==h&&(h="R");"L"!==D&&(D="R");if(h===D){D=I;for(G=x;E<G;++E)D[E]=h}E=x-1}for(E=0;E<o;++E)"ON"===I[E]&&(I[E]=Q);for(E=0;E<o;++E)if(D=I[E],0===(J[E]&1))if("R"===D)J[E]+=1;else{if("AN"===D||"EN"===D)J[E]+=2}else if("L"===D||"AN"===D||"EN"===D)J[E]+=1;D=-1;Q=99;for(E=0,o=J.length;E<o;++E)x=J[E],D<x&&(D=x),Q>x&&0!==(x&1)&&(Q=x);for(x=D;x>=
Q;--x){D=-1;for(E=0,o=J.length;E<o;++E)J[E]<x?0<=D&&(a(K,D,E),D=-1):0>D&&(D=E);0<=D&&a(K,D,J.length)}for(E=0,o=K.length;E<o;++E)if(J=K[E],"<"===J||">"===J)K[E]="";return e(K.join(""),C)}}();a.bidi=O});(function(a,e){e(a.pdfjsSharedUtil={},a.pdfjsSharedGlobal)})(this,function(a,e){function O(c){o.verbosity>=o.VERBOSITY_LEVELS.warnings&&console.log("Warning: "+c)}function P(c){O("Deprecated API usage: "+c)}function N(c){o.verbosity>=o.VERBOSITY_LEVELS.errors&&(console.log("Error: "+c),console.log(L()));
throw Error(c);}function L(){try{throw Error();}catch(c){return c.stack?c.stack.split("\n").slice(2).join("\n"):""}}function H(c,b){c||N(b)}function K(c,b){if(!c)return!1;var i=/^[a-z][a-z0-9+\-.]*(?=:)/i.exec(c);if(!i)return b;i=i[0].toLowerCase();switch(i){case "http":case "https":case "ftp":case "mailto":case "tel":return!0;default:return!1}}function I(c,b,i){Object.defineProperty(c,b,{value:i,enumerable:!0,configurable:!0,writable:!1});return i}function J(){o.openExternalLinksInNewWindow&&(P('PDFJS.openExternalLinksInNewWindow, please use "PDFJS.externalLinkTarget = PDFJS.LinkTarget.BLANK" instead.'),
o.externalLinkTarget===h.NONE&&(o.externalLinkTarget=h.BLANK),o.openExternalLinksInNewWindow=!1);switch(o.externalLinkTarget){case h.NONE:return!1;case h.SELF:case h.BLANK:case h.PARENT:case h.TOP:return!0}O("PDFJS.externalLinkTarget is invalid: "+o.externalLinkTarget);o.externalLinkTarget=h.NONE;return!1}function Q(c){return"string"!==typeof c?(O("The argument for removeNullCharacters must be a string."),c):c.replace(g,"")}function E(){var c={};c.promise=new Promise(function(b,i){c.resolve=b;c.reject=
i});return c}function C(c,b,i){this.sourceName=c;this.targetName=b;this.comObj=i;this.callbackIndex=1;this.postMessageTransfers=!0;var l=this.callbacksCapabilities={},d=this.actionHandler={};this._onComObjOnMessage=function(b){var c=b.data;if(c.targetName===this.sourceName)if(c.isReply)if(b=c.callbackId,c.callbackId in l){var v=l[b];delete l[b];"error"in c?v.reject(c.error):v.resolve(c.data)}else N("Cannot resolve callback "+b);else if(c.action in d){var n=d[c.action];if(c.callbackId){var r=this.sourceName,
f=c.sourceName;Promise.resolve().then(function(){return n[0].call(n[1],c.data)}).then(function(b){i.postMessage({sourceName:r,targetName:f,isReply:!0,callbackId:c.callbackId,data:b})},function(b){b instanceof Error&&(b+="");i.postMessage({sourceName:r,targetName:f,isReply:!0,callbackId:c.callbackId,error:b})})}else n[0].call(n[1],c.data)}else N("Unknown action from worker: "+c.action)}.bind(this);i.addEventListener("message",this._onComObjOnMessage)}var o=e.PDFJS,x=e.globalScope;o.VERBOSITY_LEVELS=
{errors:0,warnings:1,infos:5};var D=o.OPS={dependency:1,setLineWidth:2,setLineCap:3,setLineJoin:4,setMiterLimit:5,setDash:6,setRenderingIntent:7,setFlatness:8,setGState:9,save:10,restore:11,transform:12,moveTo:13,lineTo:14,curveTo:15,curveTo2:16,curveTo3:17,closePath:18,rectangle:19,stroke:20,closeStroke:21,fill:22,eoFill:23,fillStroke:24,eoFillStroke:25,closeFillStroke:26,closeEOFillStroke:27,endPath:28,clip:29,eoClip:30,beginText:31,endText:32,setCharSpacing:33,setWordSpacing:34,setHScale:35,setLeading:36,
setFont:37,setTextRenderingMode:38,setTextRise:39,moveText:40,setLeadingMoveText:41,setTextMatrix:42,nextLine:43,showText:44,showSpacedText:45,nextLineShowText:46,nextLineSetSpacingShowText:47,setCharWidth:48,setCharWidthAndBounds:49,setStrokeColorSpace:50,setFillColorSpace:51,setStrokeColor:52,setStrokeColorN:53,setFillColor:54,setFillColorN:55,setStrokeGray:56,setFillGray:57,setStrokeRGBColor:58,setFillRGBColor:59,setStrokeCMYKColor:60,setFillCMYKColor:61,shadingFill:62,beginInlineImage:63,beginImageData:64,
endInlineImage:65,paintXObject:66,markPoint:67,markPointProps:68,beginMarkedContent:69,beginMarkedContentProps:70,endMarkedContent:71,beginCompat:72,endCompat:73,paintFormXObjectBegin:74,paintFormXObjectEnd:75,beginGroup:76,endGroup:77,beginAnnotations:78,endAnnotations:79,beginAnnotation:80,endAnnotation:81,paintJpegXObject:82,paintImageMaskXObject:83,paintImageMaskXObjectGroup:84,paintImageXObject:85,paintInlineImageXObject:86,paintInlineImageXObjectGroup:87,paintImageXObjectRepeat:88,paintImageMaskXObjectRepeat:89,
paintSolidColorImageMask:90,constructPath:91},G=o.UNSUPPORTED_FEATURES={unknown:"unknown",forms:"forms",javaScript:"javaScript",smask:"smask",shadingPattern:"shadingPattern",font:"font"};o.isValidUrl=K;o.shadow=I;var h=o.LinkTarget={NONE:0,SELF:1,BLANK:2,PARENT:3,TOP:4};o.isExternalLinkTargetSet=J;var z=o.PasswordResponses={NEED_PASSWORD:1,INCORRECT_PASSWORD:2},R=function(){function c(b,c){this.name="PasswordException";this.message=b;this.code=c}c.prototype=Error();return c.constructor=c}();o.PasswordException=
R;var m=function(){function c(b,c){this.name="UnknownErrorException";this.message=b;this.details=c}c.prototype=Error();return c.constructor=c}();o.UnknownErrorException=m;var w=function(){function c(b){this.name="InvalidPDFException";this.message=b}c.prototype=Error();return c.constructor=c}();o.InvalidPDFException=w;var t=function(){function c(b){this.name="MissingPDFException";this.message=b}c.prototype=Error();return c.constructor=c}();o.MissingPDFException=t;var u=function(){function c(b,c){this.name=
"UnexpectedResponseException";this.message=b;this.status=c}c.prototype=Error();return c.constructor=c}();o.UnexpectedResponseException=u;var y=function(){function c(b){this.message=b}c.prototype=Error();c.prototype.name="NotImplementedException";return c.constructor=c}(),s=function(){function c(b,c){this.begin=b;this.end=c;this.message="Missing data ["+b+", "+c+")"}c.prototype=Error();c.prototype.name="MissingDataException";return c.constructor=c}(),M=function(){function c(b){this.message=b}c.prototype=
Error();c.prototype.name="XRefParseException";return c.constructor=c}(),g=/\x00/g;o.removeNullCharacters=Q;Object.defineProperty(o,"isLittleEndian",{configurable:!0,get:function(){var c=o,b;b=new Uint8Array(2);b[0]=1;b=1===(new Uint16Array(b.buffer))[0];return I(c,"isLittleEndian",b)}});Object.defineProperty(o,"hasCanvasTypedArrays",{configurable:!0,get:function(){var c=o,b;b=document.createElement("canvas");b.width=b.height=1;b="undefined"!==typeof b.getContext("2d").createImageData(1,1).data.buffer;
return I(c,"hasCanvasTypedArrays",b)}});var f=function(){function c(l,d){this.buffer=l;this.byteLength=l.length;for(var j=this.length=void 0===d?this.byteLength>>2:d;i<j;)Object.defineProperty(c.prototype,i,b(i)),i++}function b(b){return{get:function(){var c=this.buffer,i=b<<2;return(c[i]|c[i+1]<<8|c[i+2]<<16|c[i+3]<<24)>>>0},set:function(c){var i=this.buffer,p=b<<2;i[p]=c&255;i[p+1]=c>>8&255;i[p+2]=c>>16&255;i[p+3]=c>>>24&255}}}c.prototype=Object.create(null);var i=0;return c}();a.Uint32ArrayView=
f;var d=o.Util=function(){function c(){}var b=["rgb(",0,",",0,",",0,")"];c.makeCssRgb=function(c,l,d){b[1]=c;b[3]=l;b[5]=d;return b.join("")};c.transform=function(b,c){return[b[0]*c[0]+b[2]*c[1],b[1]*c[0]+b[3]*c[1],b[0]*c[2]+b[2]*c[3],b[1]*c[2]+b[3]*c[3],b[0]*c[4]+b[2]*c[5]+b[4],b[1]*c[4]+b[3]*c[5]+b[5]]};c.applyTransform=function(b,c){return[b[0]*c[0]+b[1]*c[2]+c[4],b[0]*c[1]+b[1]*c[3]+c[5]]};c.applyInverseTransform=function(b,c){var d=c[0]*c[3]-c[1]*c[2];return[(b[0]*c[3]-b[1]*c[2]+c[2]*c[5]-c[4]*
c[3])/d,(-b[0]*c[1]+b[1]*c[0]+c[4]*c[1]-c[5]*c[0])/d]};c.getAxialAlignedBoundingBox=function(b,l){var d=c.applyTransform(b,l),j=c.applyTransform(b.slice(2,4),l),p=c.applyTransform([b[0],b[3]],l),v=c.applyTransform([b[2],b[1]],l);return[Math.min(d[0],j[0],p[0],v[0]),Math.min(d[1],j[1],p[1],v[1]),Math.max(d[0],j[0],p[0],v[0]),Math.max(d[1],j[1],p[1],v[1])]};c.inverseTransform=function(b){var c=b[0]*b[3]-b[1]*b[2];return[b[3]/c,-b[1]/c,-b[2]/c,b[0]/c,(b[2]*b[5]-b[4]*b[3])/c,(b[4]*b[1]-b[5]*b[0])/c]};
c.apply3dTransform=function(b,c){return[b[0]*c[0]+b[1]*c[1]+b[2]*c[2],b[3]*c[0]+b[4]*c[1]+b[5]*c[2],b[6]*c[0]+b[7]*c[1]+b[8]*c[2]]};c.singularValueDecompose2dScale=function(b){var c=[b[0],b[2],b[1],b[3]],d=b[0]*c[0]+b[1]*c[2],j=b[2]*c[1]+b[3]*c[3],p=(d+j)/2,b=Math.sqrt((d+j)*(d+j)-4*(d*j-(b[2]*c[0]+b[3]*c[2])*(b[0]*c[1]+b[1]*c[3])))/2,c=p-b||1;return[Math.sqrt(p+b||1),Math.sqrt(c)]};c.normalizeRect=function(b){var c=b.slice(0);b[0]>b[2]&&(c[0]=b[2],c[2]=b[0]);b[1]>b[3]&&(c[1]=b[3],c[3]=b[1]);return c};
c.intersect=function(b,l){function d(b,c){return b-c}var j=[b[0],b[2],l[0],l[2]].sort(d),p=[b[1],b[3],l[1],l[3]].sort(d),v=[],b=c.normalizeRect(b),l=c.normalizeRect(l);if(j[0]===b[0]&&j[1]===l[0]||j[0]===l[0]&&j[1]===b[0])v[0]=j[1],v[2]=j[2];else return!1;if(p[0]===b[1]&&p[1]===l[1]||p[0]===l[1]&&p[1]===b[1])v[1]=p[1],v[3]=p[2];else return!1;return v};c.sign=function(b){return 0>b?-1:1};c.appendToArray=function(b,c){Array.prototype.push.apply(b,c)};c.prependToArray=function(b,c){Array.prototype.unshift.apply(b,
c)};c.extendObj=function(b,c){for(var d in c)b[d]=c[d]};c.getInheritableProperty=function(b,c){for(;b&&!b.has(c);)b=b.get("Parent");return!b?null:b.get(c)};c.inherit=function(b,c,d){b.prototype=Object.create(c.prototype);b.prototype.constructor=b;for(var j in d)b.prototype[j]=d[j]};c.loadScript=function(b,c){var d=document.createElement("script"),j=!1;d.setAttribute("src",b);c&&(d.onload=function(){j||c();j=!0});document.getElementsByTagName("head")[0].appendChild(d)};return c}();o.PageViewport=function(){function c(b,
c,l,d,j,p){this.viewBox=b;this.scale=c;this.rotation=l;this.offsetX=d;this.offsetY=j;var v=(b[2]+b[0])/2,n=(b[3]+b[1])/2,r,f,k,l=l%360;switch(0>l?l+360:l){case 180:l=-1;f=r=0;k=1;break;case 90:l=0;f=r=1;k=0;break;case 270:l=0;f=r=-1;k=0;break;default:l=1,f=r=0,k=-1}p&&(f=-f,k=-k);0===l?(d=Math.abs(n-b[1])*c+d,j=Math.abs(v-b[0])*c+j,p=Math.abs(b[3]-b[1])*c,b=Math.abs(b[2]-b[0])*c):(d=Math.abs(v-b[0])*c+d,j=Math.abs(n-b[1])*c+j,p=Math.abs(b[2]-b[0])*c,b=Math.abs(b[3]-b[1])*c);this.transform=[l*c,r*
c,f*c,k*c,d-l*c*v-f*c*n,j-r*c*v-k*c*n];this.width=p;this.height=b;this.fontScale=c}c.prototype={clone:function(b){var b=b||{},i="scale"in b?b.scale:this.scale,l="rotation"in b?b.rotation:this.rotation;return new c(this.viewBox.slice(),i,l,this.offsetX,this.offsetY,b.dontFlip)},convertToViewportPoint:function(b,c){return d.applyTransform([b,c],this.transform)},convertToViewportRectangle:function(b){var c=d.applyTransform([b[0],b[1]],this.transform),b=d.applyTransform([b[2],b[3]],this.transform);return[c[0],
c[1],b[0],b[1]]},convertToPdfPoint:function(b,c){return d.applyInverseTransform([b,c],this.transform)}};return c}();var k=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,728,711,710,729,733,731,730,732,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8226,8224,8225,8230,8212,8211,402,8260,8249,8250,8722,8240,8222,8220,8221,8216,8217,8218,8482,64257,64258,
321,338,352,376,381,305,322,339,353,382,0,8364];o.createPromiseCapability=E;(function(){function c(c){this._status=b;this._handlers=[];try{c.call(this,this._resolve.bind(this),this._reject.bind(this))}catch(j){this._reject(j)}}if(x.Promise)"function"!==typeof x.Promise.all&&(x.Promise.all=function(b){var c=0,p=[],i,n,r=new x.Promise(function(b,c){i=b;n=c});b.forEach(function(b,r){c++;b.then(function(b){p[r]=b;c--;0===c&&i(p)},n)});0===c&&i(p);return r}),"function"!==typeof x.Promise.resolve&&(x.Promise.resolve=
function(b){return new x.Promise(function(c){c(b)})}),"function"!==typeof x.Promise.reject&&(x.Promise.reject=function(b){return new x.Promise(function(c,p){p(b)})}),"function"!==typeof x.Promise.prototype.catch&&(x.Promise.prototype.catch=function(b){return x.Promise.prototype.then(void 0,b)});else{var b=0,i=2,l={handlers:[],running:!1,unhandledRejections:[],pendingRejectionCheck:!1,scheduleHandlers:function(c){c._status!==b&&(this.handlers=this.handlers.concat(c._handlers),c._handlers=[],this.running||
(this.running=!0,setTimeout(this.runHandlers.bind(this),0)))},runHandlers:function(){for(var b=Date.now()+1;0<this.handlers.length;){var c=this.handlers.shift(),p=c.thisPromise._status,l=c.thisPromise._value;try{1===p?"function"===typeof c.onResolve&&(l=c.onResolve(l)):"function"===typeof c.onReject&&(l=c.onReject(l),p=1,c.thisPromise._unhandledRejection&&this.removeUnhandeledRejection(c.thisPromise))}catch(n){p=i,l=n}c.nextPromise._updateStatus(p,l);if(Date.now()>=b)break}0<this.handlers.length?
setTimeout(this.runHandlers.bind(this),0):this.running=!1},addUnhandledRejection:function(b){this.unhandledRejections.push({promise:b,time:Date.now()});this.scheduleRejectionCheck()},removeUnhandeledRejection:function(b){b._unhandledRejection=!1;for(var c=0;c<this.unhandledRejections.length;c++)this.unhandledRejections[c].promise===b&&(this.unhandledRejections.splice(c),c--)},scheduleRejectionCheck:function(){this.pendingRejectionCheck||(this.pendingRejectionCheck=!0,setTimeout(function(){this.pendingRejectionCheck=
!1;for(var b=Date.now(),c=0;c<this.unhandledRejections.length;c++)if(500<b-this.unhandledRejections[c].time){var p=this.unhandledRejections[c].promise._value,i="Unhandled rejection: "+p;p.stack&&(i+="\n"+p.stack);O(i);this.unhandledRejections.splice(c);c--}this.unhandledRejections.length&&this.scheduleRejectionCheck()}.bind(this),500))}};c.all=function(b){function j(b){n._status!==i&&(d=[],l(b))}var p,l,n=new c(function(b,c){p=b;l=c}),r=b.length,d=[];if(0===r)return p(d),n;for(var f=0,k=b.length;f<
k;++f){var g=b[f],h=function(b){return function(c){n._status!==i&&(d[b]=c,r--,0===r&&p(d))}}(f);c.isPromise(g)?g.then(h,j):h(g)}return n};c.isPromise=function(b){return b&&"function"===typeof b.then};c.resolve=function(b){return new c(function(c){c(b)})};c.reject=function(b){return new c(function(c,p){p(b)})};c.prototype={_status:null,_value:null,_handlers:null,_unhandledRejection:null,_updateStatus:function(b,j){1===this._status||this._status===i||(1===b&&c.isPromise(j)?j.then(this._updateStatus.bind(this,
1),this._updateStatus.bind(this,i)):(this._status=b,this._value=j,b===i&&0===this._handlers.length&&(this._unhandledRejection=!0,l.addUnhandledRejection(this)),l.scheduleHandlers(this)))},_resolve:function(b){this._updateStatus(1,b)},_reject:function(b){this._updateStatus(i,b)},then:function(b,i){var p=new c(function(b,c){this.resolve=b;this.reject=c});this._handlers.push({thisPromise:this,onResolve:b,onReject:i,nextPromise:p});l.scheduleHandlers(this);return p},"catch":function(b){return this.then(void 0,
b)}};x.Promise=c}})();f=function(){function c(){this.started={};this.times=[];this.enabled=!0}c.prototype={time:function(b){this.enabled&&(b in this.started&&O("Timer is already running for "+b),this.started[b]=Date.now())},timeEnd:function(b){this.enabled&&(b in this.started||O("Timer has not been started for "+b),this.times.push({name:b,start:this.started[b],end:Date.now()}),delete this.started[b])},toString:function(){var b,c,l=this.times,d="",j=0;for(b=0,c=l.length;b<c;++b){var p=l[b].name;p.length>
j&&(j=p.length)}for(b=0,c=l.length;b<c;++b){for(var v=l[b],p=v.end-v.start,v=v.name;v.length<j;)v+=" ";d+=v+" "+p+"ms\n"}return d}};return c}();o.createBlob=function(c,b){if("undefined"!==typeof Blob)return new Blob([c],{type:b});var i=new MozBlobBuilder;i.append(c);return i.getBlob(b)};o.createObjectURL=function(){return function(c,b){if(!o.disableCreateObjectURL&&"undefined"!==typeof URL&&URL.createObjectURL){var i=o.createBlob(c,b);return URL.createObjectURL(i)}for(var i="data:"+b+";base64,",l=
0,d=c.length;l<d;l+=3)var j=c[l]&255,p=c[l+1]&255,v=c[l+2]&255,i=i+("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="[j>>2]+"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="[(j&3)<<4|p>>4]+"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="[l+1<d?(p&15)<<2|v>>6:64]+"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="[l+2<d?v&63:64]);return i}}();C.prototype={on:function(c,b,i){var d=this.actionHandler;d[c]&&N('There is already an actionName called "'+
c+'"');d[c]=[b,i]},send:function(c,b,i){this.postMessage({sourceName:this.sourceName,targetName:this.targetName,action:c,data:b},i)},sendWithPromise:function(c,b,i){var d=this.callbackIndex++,c={sourceName:this.sourceName,targetName:this.targetName,action:c,data:b,callbackId:d},b=E();this.callbacksCapabilities[d]=b;try{this.postMessage(c,i)}catch(f){b.reject(f)}return b.promise},postMessage:function(c,b){b&&this.postMessageTransfers?this.comObj.postMessage(c,b):this.comObj.postMessage(c)},destroy:function(){this.comObj.removeEventListener("message",
this._onComObjOnMessage)}};a.FONT_IDENTITY_MATRIX=[0.001,0,0,0.001,0,0];a.IDENTITY_MATRIX=[1,0,0,1,0,0];a.OPS=D;a.UNSUPPORTED_FEATURES=G;a.AnnotationBorderStyleType={SOLID:1,DASHED:2,BEVELED:3,INSET:4,UNDERLINE:5};a.AnnotationFlag={INVISIBLE:1,HIDDEN:2,PRINT:4,NOZOOM:8,NOROTATE:16,NOVIEW:32,READONLY:64,LOCKED:128,TOGGLENOVIEW:256,LOCKEDCONTENTS:512};a.AnnotationType={TEXT:1,LINK:2,FREETEXT:3,LINE:4,SQUARE:5,CIRCLE:6,POLYGON:7,POLYLINE:8,HIGHLIGHT:9,UNDERLINE:10,SQUIGGLY:11,STRIKEOUT:12,STAMP:13,CARET:14,
INK:15,POPUP:16,FILEATTACHMENT:17,SOUND:18,MOVIE:19,WIDGET:20,SCREEN:21,PRINTERMARK:22,TRAPNET:23,WATERMARK:24,THREED:25,REDACT:26};a.FontType={UNKNOWN:0,TYPE1:1,TYPE1C:2,CIDFONTTYPE0:3,CIDFONTTYPE0C:4,TRUETYPE:5,CIDFONTTYPE2:6,TYPE3:7,OPENTYPE:8,TYPE0:9,MMTYPE1:10};a.ImageKind={GRAYSCALE_1BPP:1,RGB_24BPP:2,RGBA_32BPP:3};a.InvalidPDFException=w;a.LinkTarget=h;a.LinkTargetStringMap=["","_self","_blank","_parent","_top"];a.MessageHandler=C;a.MissingDataException=s;a.MissingPDFException=t;a.NotImplementedException=
y;a.PasswordException=R;a.PasswordResponses=z;a.StatTimer=f;a.StreamType={UNKNOWN:0,FLATE:1,LZW:2,DCT:3,JPX:4,JBIG:5,A85:6,AHX:7,CCF:8,RL:9};a.TextRenderingMode={FILL:0,STROKE:1,FILL_STROKE:2,INVISIBLE:3,FILL_ADD_TO_PATH:4,STROKE_ADD_TO_PATH:5,FILL_STROKE_ADD_TO_PATH:6,ADD_TO_PATH:7,FILL_STROKE_MASK:3,ADD_TO_PATH_FLAG:4};a.UnexpectedResponseException=u;a.UnknownErrorException=m;a.Util=d;a.XRefParseException=M;a.assert=H;a.bytesToString=function(c){H(null!==c&&"object"===typeof c&&void 0!==c.length,
"Invalid argument for bytesToString");var b=c.length;if(8192>b)return String.fromCharCode.apply(null,c);for(var i=[],d=0;d<b;d+=8192){var f=Math.min(d+8192,b),f=c.subarray(d,f);i.push(String.fromCharCode.apply(null,f))}return i.join("")};a.combineUrl=function(c,b){if(!b)return c;if(/^[a-z][a-z0-9+\-.]*:/i.test(b))return b;var i;if("/"===b.charAt(0))return i=c.indexOf("://"),"/"===b.charAt(1)?++i:i=c.indexOf("/",i+3),c.substring(0,i)+b;var d=c.length;i=c.lastIndexOf("#");d=0<=i?i:d;i=c.lastIndexOf("?",
d);i=c.lastIndexOf("/",0<=i?i:d);return c.substring(0,i+1)+b};a.createPromiseCapability=E;a.deprecated=P;a.error=N;a.info=function(c){o.verbosity>=o.VERBOSITY_LEVELS.infos&&console.log("Info: "+c)};a.isArray=function(c){return c instanceof Array};a.isArrayBuffer=function(c){return"object"===typeof c&&null!==c&&void 0!==c.byteLength};a.isBool=function(c){return"boolean"===typeof c};a.isEmptyObj=function(c){for(var b in c)return!1;return!0};a.isExternalLinkTargetSet=J;a.isInt=function(c){return"number"===
typeof c&&(c|0)===c};a.isNum=function(c){return"number"===typeof c};a.isString=function(c){return"string"===typeof c};a.isValidUrl=K;a.loadJpegStream=function(c,b,i){var d=new Image;d.onload=function(){i.resolve(c,d)};d.onerror=function(){i.resolve(c,null);O("Error during JPEG image loading")};d.src=b};a.log2=function(c){for(var b=1,i=0;c>b;)b<<=1,i++;return i};a.readInt8=function(c,b){return c[b]<<24>>24};a.readUint16=function(c,b){return c[b]<<8|c[b+1]};a.readUint32=function(c,b){return(c[b]<<24|
c[b+1]<<16|c[b+2]<<8|c[b+3])>>>0};a.removeNullCharacters=Q;a.shadow=I;a.string32=function(c){return String.fromCharCode(c>>24&255,c>>16&255,c>>8&255,c&255)};a.stringToBytes=function(c){H("string"===typeof c,"Invalid argument for stringToBytes");for(var b=c.length,i=new Uint8Array(b),d=0;d<b;++d)i[d]=c.charCodeAt(d)&255;return i};a.stringToPDFString=function(c){var b,i=c.length,d=[];if("\u00fe"===c[0]&&"\u00ff"===c[1])for(b=2;b<i;b+=2)d.push(String.fromCharCode(c.charCodeAt(b)<<8|c.charCodeAt(b+1)));
else for(b=0;b<i;++b){var f=k[c.charCodeAt(b)];d.push(f?String.fromCharCode(f):c.charAt(b))}return d.join("")};a.stringToUTF8String=function(c){return decodeURIComponent(escape(c))};a.utf8StringToString=function(c){return unescape(encodeURIComponent(c))};a.warn=O});(function(a,e){e(a.pdfjsCoreChunkedStream={},a.pdfjsSharedUtil)})(this,function(a,e){var O=e.MissingDataException,P=e.assert,N=e.createPromiseCapability,L=e.isInt,H=e.isEmptyObj,K=function(){function a(e,E,C){this.bytes=new Uint8Array(e);
this.pos=this.start=0;this.end=e;this.chunkSize=E;this.loadedChunks=[];this.numChunksLoaded=0;this.numChunks=Math.ceil(e/E);this.manager=C;this.progressiveDataLength=0;this.lastSuccessfulEnsureByteChunk=-1}a.prototype={getMissingChunks:function(){for(var a=[],e=0,C=this.numChunks;e<C;++e)this.loadedChunks[e]||a.push(e);return a},getBaseStreams:function(){return[this]},allChunksLoaded:function(){return this.numChunksLoaded===this.numChunks},onReceiveData:function(a,e){var C=a+e.byteLength;P(0===a%
this.chunkSize,"Bad begin offset: "+a);var o=this.bytes.length;P(0===C%this.chunkSize||C===o,"Bad end offset: "+C);this.bytes.set(new Uint8Array(e),a);o=this.chunkSize;C=Math.floor((C-1)/o)+1;for(o=Math.floor(a/o);o<C;++o)this.loadedChunks[o]||(this.loadedChunks[o]=!0,++this.numChunksLoaded)},onReceiveProgressiveData:function(a){var e=this.progressiveDataLength,C=Math.floor(e/this.chunkSize);this.bytes.set(new Uint8Array(a),e);this.progressiveDataLength=e+=a.byteLength;for(a=e>=this.end?this.numChunks:
Math.floor(e/this.chunkSize);C<a;++C)this.loadedChunks[C]||(this.loadedChunks[C]=!0,++this.numChunksLoaded)},ensureByte:function(a){var e=Math.floor(a/this.chunkSize);if(e!==this.lastSuccessfulEnsureByteChunk){if(!this.loadedChunks[e])throw new O(a,a+1);this.lastSuccessfulEnsureByteChunk=e}},ensureRange:function(a,e){if(!(a>=e||e<=this.progressiveDataLength))for(var C=this.chunkSize,o=Math.floor((e-1)/C)+1,C=Math.floor(a/C);C<o;++C)if(!this.loadedChunks[C])throw new O(a,e);},nextEmptyChunk:function(a){for(var e,
C=this.numChunks,o=0;o<C;++o)if(e=(a+o)%C,!this.loadedChunks[e])return e;return null},hasChunk:function(a){return!!this.loadedChunks[a]},get length(){return this.end-this.start},get isEmpty(){return 0===this.length},getByte:function(){var a=this.pos;if(a>=this.end)return-1;this.ensureByte(a);return this.bytes[this.pos++]},getUint16:function(){var a=this.getByte(),e=this.getByte();return-1===a||-1===e?-1:(a<<8)+e},getInt32:function(){var a=this.getByte(),e=this.getByte(),C=this.getByte(),o=this.getByte();
return(a<<24)+(e<<16)+(C<<8)+o},getBytes:function(a){var e=this.bytes,C=this.pos,o=this.end;if(!a)return this.ensureRange(C,o),e.subarray(C,o);a=C+a;a>o&&(a=o);this.ensureRange(C,a);this.pos=a;return e.subarray(C,a)},peekByte:function(){var a=this.getByte();this.pos--;return a},peekBytes:function(a){a=this.getBytes(a);this.pos-=a.length;return a},getByteRange:function(a,e){this.ensureRange(a,e);return this.bytes.subarray(a,e)},skip:function(a){a||(a=1);this.pos+=a},reset:function(){this.pos=this.start},
moveStart:function(){this.start=this.pos},makeSubStream:function(a,e,C){function o(){}this.ensureRange(a,a+e);o.prototype=Object.create(this);o.prototype.getMissingChunks=function(){for(var a=this.chunkSize,e=Math.floor((this.end-1)/a)+1,h=[],a=Math.floor(this.start/a);a<e;++a)this.loadedChunks[a]||h.push(a);return h};var x=new o;x.pos=x.start=a;x.end=a+e||this.end;x.dict=C;return x},isStream:!0};return a}(),I=function(){function a(e,E,C,o){this.stream=new K(e,E,this);this.length=e;this.chunkSize=
E;this.url=C;this.disableAutoFetch=o.disableAutoFetch;var x=this.msgHandler=o.msgHandler;o.chunkedViewerLoading?(x.on("OnDataRange",this.onReceiveData.bind(this)),x.on("OnDataProgress",this.onProgress.bind(this)),this.sendRequest=function(a,e){x.send("RequestDataRange",{begin:a,end:e})}):(this.networkManager=new ca(this.url,{getXhr:function(){return new XMLHttpRequest},httpHeaders:o.httpHeaders,withCredentials:o.withCredentials}),this.sendRequest=function(a,e){this.networkManager.requestRange(a,e,
{onDone:this.onReceiveData.bind(this),onProgress:this.onProgress.bind(this)})});this.currRequestId=0;this.chunksNeededByRequest={};this.requestsByChunk={};this.promisesByRequest={};this.progressiveDataLength=0;this._loadedStreamCapability=N();if(o.initialData)this.onReceiveData({chunk:o.initialData})}a.prototype={onLoadedStream:function(){return this._loadedStreamCapability.promise},requestAllChunks:function(){this._requestChunks(this.stream.getMissingChunks());return this._loadedStreamCapability.promise},
_requestChunks:function(a){var e=this.currRequestId++,C,o,x;this.chunksNeededByRequest[e]=C={};for(o=0,x=a.length;o<x;o++)this.stream.hasChunk(a[o])||(C[a[o]]=!0);if(H(C))return Promise.resolve();a=N();this.promisesByRequest[e]=a;o=[];for(var D in C)D|=0,D in this.requestsByChunk||(this.requestsByChunk[D]=[],o.push(D)),this.requestsByChunk[D].push(e);if(!o.length)return a.promise;e=this.groupChunks(o);for(o=0;o<e.length;++o)D=e[o],C=D.beginChunk*this.chunkSize,D=Math.min(D.endChunk*this.chunkSize,
this.length),this.sendRequest(C,D);return a.promise},getStream:function(){return this.stream},requestRange:function(a,e){for(var e=Math.min(e,this.length),C=this.getBeginChunk(a),o=this.getEndChunk(e),x=[];C<o;++C)x.push(C);return this._requestChunks(x)},requestRanges:function(a){for(var a=a||[],e=[],C=0;C<a.length;C++)for(var o=this.getBeginChunk(a[C].begin),x=this.getEndChunk(a[C].end);o<x;++o)0>e.indexOf(o)&&e.push(o);e.sort(function(a,e){return a-e});return this._requestChunks(e)},groupChunks:function(a){for(var e=
[],C=-1,o=-1,x=0;x<a.length;++x){var D=a[x];0>C&&(C=D);0<=o&&o+1!==D&&(e.push({beginChunk:C,endChunk:o+1}),C=D);x+1===a.length&&e.push({beginChunk:C,endChunk:D+1});o=D}return e},onProgress:function(a){this.msgHandler.send("DocProgress",{loaded:this.stream.numChunksLoaded*this.chunkSize+a.loaded,total:this.length})},onReceiveData:function(a){var e=a.chunk,C=void 0===a.begin,o=C?this.progressiveDataLength:a.begin,x=o+e.byteLength,D=Math.floor(o/this.chunkSize),a=x<this.length?Math.floor(x/this.chunkSize):
Math.ceil(x/this.chunkSize);if(C)this.stream.onReceiveProgressiveData(e),this.progressiveDataLength=x;else this.stream.onReceiveData(o,e);this.stream.allChunksLoaded()&&this._loadedStreamCapability.resolve(this.stream);C=[];for(e=D;e<a;++e){x=this.requestsByChunk[e]||[];delete this.requestsByChunk[e];for(D=0;D<x.length;++D){var o=x[D],G=this.chunksNeededByRequest[o];e in G&&delete G[e];H(G)&&C.push(o)}}if(!this.disableAutoFetch&&H(this.requestsByChunk)){var h;1===this.stream.numChunksLoaded?(e=this.stream.numChunks-
1,this.stream.hasChunk(e)||(h=e)):h=this.stream.nextEmptyChunk(a);L(h)&&this._requestChunks([h])}for(D=0;D<C.length;++D)o=C[D],h=this.promisesByRequest[o],delete this.promisesByRequest[o],h.resolve();this.msgHandler.send("DocProgress",{loaded:this.stream.numChunksLoaded*this.chunkSize,total:this.length})},onError:function(a){this._loadedStreamCapability.reject(a)},getBeginChunk:function(a){return Math.floor(a/this.chunkSize)},getEndChunk:function(a){return Math.floor((a-1)/this.chunkSize)+1},abort:function(){this.networkManager&&
this.networkManager.abortAllRequests();for(var a in this.promisesByRequest)this.promisesByRequest[a].reject(Error("Request was aborted"))}};return a}();a.ChunkedStream=K;a.ChunkedStreamManager=I});(function(a,e){e(a.pdfjsCoreJbig2={},a.pdfjsSharedUtil,a.pdfjsCoreArithmeticDecoder)})(this,function(a,e,O){var P=e.error,N=e.log2,L=e.readInt8,H=e.readUint16,K=e.readUint32,I=e.shadow,J=O.ArithmeticDecoder,e=function(){function a(){}function e(a,g,f){this.data=a;this.start=g;this.end=f}function C(a,g,f){function d(b){for(var i=
0,d=0;d<b;d++){var g=f.readBit(k,c);c=256>c?c<<1|g:(c<<1|g)&511|256;i=i<<1|g}return i>>>0}var k=a.getContexts(g),c=1,a=d(1),g=d(1)?d(1)?d(1)?d(1)?d(1)?d(32)+4436:d(12)+340:d(8)+84:d(6)+20:d(4)+4:d(2);return 0===a?g:0<g?-g:null}function o(a,g,f){for(var a=a.getContexts("IAID"),d=1,k=0;k<f;k++)var c=g.readBit(a,d),d=d<<1|c;return 31>f?d&(1<<f)-1:d&2147483647}function x(a,g,f){var d=f.decoder,f=f.contextCache.getContexts("GB"),k,c,b,i,l,q,j,p=[];for(c=0;c<g;c++){l=p[c]=new Uint8Array(a);q=1>c?l:p[c-
1];j=2>c?l:p[c-2];k=j[0]<<13|j[1]<<12|j[2]<<11|q[0]<<7|q[1]<<6|q[2]<<5|q[3]<<4;for(b=0;b<a;b++)l[b]=i=d.readBit(f,k),k=(k&31735)<<1|(b+3<a?j[b+3]<<11:0)|(b+4<a?q[b+4]<<4:0)|i}return p}function D(a,g,f,d,k,c,b,i){a&&P("JBIG2 error: MMR encoding is not supported");if(0===d&&!c&&!k&&4===b.length&&3===b[0].x&&-1===b[0].y&&-3===b[1].x&&-1===b[1].y&&2===b[2].x&&-2===b[2].y&&-2===b[3].x&&-2===b[3].y)return x(g,f,i);var a=!!c,l=t[d].concat(b);l.sort(function(b,c){return b.y-c.y||b.x-c.x});var b=l.length,
q=new Int8Array(b),j=new Int8Array(b),p=[],v=0,n=0,r=0,B=0,F,A;for(A=0;A<b;A++)q[A]=l[A].x,j[A]=l[A].y,n=Math.min(n,l[A].x),r=Math.max(r,l[A].x),B=Math.min(B,l[A].y),A<b-1&&l[A].y===l[A+1].y&&l[A].x===l[A+1].x-1?v|=1<<b-1-A:p.push(A);var h=p.length,e=new Int8Array(h),u=new Int8Array(h),s=new Uint16Array(h);for(F=0;F<h;F++)A=p[F],e[F]=l[A].x,u[F]=l[A].y,s[F]=1<<b-1-A;l=-n;B=-B;r=g-r;d=y[d];p=new Uint8Array(g);n=[];F=i.decoder;for(var i=i.contextCache.getContexts("GB"),m=0,w,o,z,D=0,C,G=0;G<f;G++){if(k&&
(A=F.readBit(i,d),m^=A)){n.push(p);continue}p=new Uint8Array(p);n.push(p);for(w=0;w<g;w++)if(a&&c[G][w])p[w]=0;else{if(w>=l&&w<r&&G>=B){D=D<<1&v;for(A=0;A<h;A++)if(o=G+u[A],z=w+e[A],o=n[o][z])o=s[A],D|=o}else{D=0;C=b-1;for(A=0;A<b;A++,C--)z=w+q[A],0<=z&&z<g&&(o=G+j[A],0<=o&&(o=n[o][z])&&(D|=o<<C))}A=F.readBit(i,D);p[w]=A}}return n}function G(a,g,f,d,k,c,b,i,l){var q=u[f].coding;0===f&&(q=q.concat([i[0]]));var j=q.length,p=new Int32Array(j),v=new Int32Array(j),n;for(n=0;n<j;n++)p[n]=q[n].x,v[n]=q[n].y;
var r=u[f].reference;0===f&&(r=r.concat([i[1]]));var i=r.length,q=new Int32Array(i),B=new Int32Array(i);for(n=0;n<i;n++)q[n]=r[n].x,B[n]=r[n].y;for(var r=d[0].length,F=d.length,f=s[f],A=[],h=l.decoder,l=l.contextCache.getContexts("GR"),e=0,t=0;t<g;t++){b&&(n=h.readBit(l,f),(e^=n)&&P("JBIG2 error: prediction is not supported"));var m=new Uint8Array(a);A.push(m);for(var w=0;w<a;w++){var o,y,z=0;for(n=0;n<j;n++)o=t+v[n],y=w+p[n],z=0>o||0>y||y>=a?z<<1:z<<1|A[o][y];for(n=0;n<i;n++)o=t+B[n]+c,y=w+q[n]+
k,z=0>o||o>=F||0>y||y>=r?z<<1:z<<1|d[o][y];n=h.readBit(l,z);m[w]=n}}return A}function h(a,g,f,d,k,c,b,i,l,q,j,p,v,n,r,B,F){a&&P("JBIG2 error: huffman is not supported");for(var a=[],A,n=0;n<d;n++){A=new Uint8Array(f);if(k)for(var h=0;h<f;h++)A[h]=k;a.push(A)}for(var d=F.decoder,k=F.contextCache,h=-C(k,"IADT",d),e=0,n=0;n<c;){var u=C(k,"IADT",d),h=h+u,u=C(k,"IAFS",d),u=e+=u;do{var t=1===b?0:C(k,"IAIT",d);A=b*h+t;var t=o(k,d,l),s=g&&C(k,"IARI",d),t=i[t],m=t[0].length,w=t.length;if(s)var s=C(k,"IARDW",
d),y=C(k,"IARDH",d),z=C(k,"IARDX",d),D=C(k,"IARDY",d),m=m+s,w=w+y,t=G(m,w,r,t,(s>>1)+z,(y>>1)+D,!1,B,F);var s=A-(p&1?0:w),y=u-(p&2?m:0),x;if(q){for(z=0;z<w;z++)if(A=a[y+z]){x=t[z];var E=Math.min(f-s,m);switch(v){case 0:for(D=0;D<E;D++)A[s+D]|=x[D];break;case 2:for(D=0;D<E;D++)A[s+D]^=x[D];break;default:P("JBIG2 error: operator "+v+" is not supported")}}u+=w-1}else{for(D=0;D<w;D++)if(A=a[s+D])switch(x=t[D],v){case 0:for(z=0;z<m;z++)A[y+z]|=x[z];break;case 2:for(z=0;z<m;z++)A[y+z]^=x[z];break;default:P("JBIG2 error: operator "+
v+" is not supported")}u+=m-1}n++;t=C(k,"IADS",d);if(null===t)break;u+=t+j}while(1)}return a}function z(a,g){return{width:K(a,g),height:K(a,g+4),x:K(a,g+8),y:K(a,g+12),combinationOperator:a[g+16]&7}}function R(){}function m(){}a.prototype={getContexts:function(a){return a in this?this[a]:this[a]=new Int8Array(65536)}};e.prototype={get decoder(){var a=new J(this.data,this.start,this.end);return I(this,"decoder",a)},get contextCache(){var h=new a;return I(this,"contextCache",h)}};var w=["SymbolDictionary",
null,null,null,"IntermediateTextRegion",null,"ImmediateTextRegion","ImmediateLosslessTextRegion",null,null,null,null,null,null,null,null,"patternDictionary",null,null,null,"IntermediateHalftoneRegion",null,"ImmediateHalftoneRegion","ImmediateLosslessHalftoneRegion",null,null,null,null,null,null,null,null,null,null,null,null,"IntermediateGenericRegion",null,"ImmediateGenericRegion","ImmediateLosslessGenericRegion","IntermediateGenericRefinementRegion",null,"ImmediateGenericRefinementRegion","ImmediateLosslessGenericRefinementRegion",
null,null,null,null,"PageInformation","EndOfPage","EndOfStripe","EndOfFile","Profiles","Tables",null,null,null,null,null,null,null,null,"Extension"],t=[[{x:-1,y:-2},{x:0,y:-2},{x:1,y:-2},{x:-2,y:-1},{x:-1,y:-1},{x:0,y:-1},{x:1,y:-1},{x:2,y:-1},{x:-4,y:0},{x:-3,y:0},{x:-2,y:0},{x:-1,y:0}],[{x:-1,y:-2},{x:0,y:-2},{x:1,y:-2},{x:2,y:-2},{x:-2,y:-1},{x:-1,y:-1},{x:0,y:-1},{x:1,y:-1},{x:2,y:-1},{x:-3,y:0},{x:-2,y:0},{x:-1,y:0}],[{x:-1,y:-2},{x:0,y:-2},{x:1,y:-2},{x:-2,y:-1},{x:-1,y:-1},{x:0,y:-1},{x:1,
y:-1},{x:-2,y:0},{x:-1,y:0}],[{x:-3,y:-1},{x:-2,y:-1},{x:-1,y:-1},{x:0,y:-1},{x:1,y:-1},{x:-4,y:0},{x:-3,y:0},{x:-2,y:0},{x:-1,y:0}]],u=[{coding:[{x:0,y:-1},{x:1,y:-1},{x:-1,y:0}],reference:[{x:0,y:-1},{x:1,y:-1},{x:-1,y:0},{x:0,y:0},{x:1,y:0},{x:-1,y:1},{x:0,y:1},{x:1,y:1}]},{coding:[{x:-1,y:-1},{x:0,y:-1},{x:1,y:-1},{x:-1,y:0}],reference:[{x:0,y:-1},{x:-1,y:0},{x:0,y:0},{x:1,y:0},{x:0,y:1},{x:1,y:1}]}],y=[39717,1941,229,405],s=[32,8];R.prototype={onPageInformation:function(a){this.currentPageInfo=
a;var g=new Uint8Array((a.width+7>>3)*a.height);if(a.defaultPixelValue)for(var a=0,f=g.length;a<f;a++)g[a]=255;this.buffer=g},drawBitmap:function(a,g){var f=this.currentPageInfo,d=a.width,k=a.height,c=f.width+7>>3,b=f.combinationOperatorOverride?a.combinationOperator:f.combinationOperator,f=this.buffer,i=128>>(a.x&7),l=a.y*c+(a.x>>3),q,j,p;switch(b){case 0:for(b=0;b<k;b++){j=i;p=l;for(q=0;q<d;q++)g[b][q]&&(f[p]|=j),j>>=1,j||(j=128,p++);l+=c}break;case 2:for(b=0;b<k;b++){j=i;p=l;for(q=0;q<d;q++)g[b][q]&&
(f[p]^=j),j>>=1,j||(j=128,p++);l+=c}break;default:P("JBIG2 error: operator "+b+" is not supported")}},onImmediateGenericRegion:function(a,g,f,d){var k=a.info,g=new e(g,f,d),a=D(a.mmr,k.width,k.height,a.template,a.prediction,null,a.at,g);this.drawBitmap(k,a)},onImmediateLosslessGenericRegion:function(){this.onImmediateGenericRegion.apply(this,arguments)},onSymbolDictionary:function(a,g,f,d,k,c){a.huffman&&P("JBIG2 error: huffman is not supported");var b=this.symbols;b||(this.symbols=b={});for(var i=
[],l=0,q=f.length;l<q;l++)i=i.concat(b[f[l]]);var c=new e(d,k,c),l=a.huffman,q=a.refinement,f=i,i=a.numberOfNewSymbols,j=a.template,p=a.at,v=a.refinementTemplate,n=a.refinementAt;l&&P("JBIG2 error: huffman is not supported");for(var a=[],r=0,B=N(f.length+i),d=c.decoder,k=c.contextCache;a.length<i;)for(var F=C(k,"IADH",d),r=r+F,F=0;;){var A=C(k,"IADW",d);if(null===A)break;F+=A;if(q)if(A=C(k,"IAAI",d),1<A)A=h(l,q,F,r,0,A,1,f.concat(a),B,0,0,1,0,void 0,v,n,c);else var A=o(k,d,B),$=C(k,"IARDX",d),u=C(k,
"IARDY",d),A=G(F,r,v,A<f.length?f[A]:a[A-f.length],$,u,!1,n,c);else A=D(!1,F,r,j,!1,null,p,c);a.push(A)}c=[];l=[];q=!1;for(j=f.length+i;l.length<j;){for(p=C(k,"IAEX",d);p--;)l.push(q);q=!q}d=0;for(k=f.length;d<k;d++)l[d]&&c.push(f[d]);for(f=0;f<i;d++,f++)l[d]&&c.push(a[f]);b[g]=c},onImmediateTextRegion:function(a,g,f,d,k){for(var c=a.info,b=this.symbols,i=[],l=0,q=g.length;l<q;l++)i=i.concat(b[g[l]]);g=N(i.length);f=new e(f,d,k);a=h(a.huffman,a.refinement,c.width,c.height,a.defaultPixelValue,a.numberOfSymbolInstances,
a.stripSize,i,g,a.transposed,a.dsOffset,a.referenceCorner,a.combinationOperator,void 0,a.refinementTemplate,a.refinementAt,f);this.drawBitmap(c,a)},onImmediateLosslessTextRegion:function(){this.onImmediateTextRegion.apply(this,arguments)}};m.prototype={parseChunks:function(a){for(var g=new R,f=0,d=a.length;f<d;f++){for(var k=a[f],c=k.data,b=k.end,i=[],l=k.start;l<b;){var k=c,q=l,l={};l.number=K(k,q);var j=k[q+4],p=j&63;w[p]||P("JBIG2 error: invalid segment type: "+p);l.type=p;l.typeName=w[p];l.deferredNonRetain=
!!(j&128);var j=!!(j&64),v=k[q+5],n=v>>5&7,r=[v&31],q=q+6;if(7===v){n=K(k,q-1)&536870911;q+=3;v=n+7>>3;for(r[0]=k[q++];0<--v;)r.push(k[q++])}else(5===v||6===v)&&P("JBIG2 error: invalid referred-to flags");l.retainBits=r;for(var B=256>=l.number?1:65536>=l.number?2:4,F=[],v=r=void 0,r=0;r<n;r++)v=1===B?k[q]:2===B?H(k,q):K(k,q),F.push(v),q+=B;l.referredTo=F;j?(l.pageAssociation=K(k,q),q+=4):l.pageAssociation=k[q++];l.length=K(k,q);q+=4;if(4294967295===l.length)if(38===p){j=z(k,q);n=!!(k[q+17]&1);p=new Uint8Array(6);
n||(p[0]=255,p[1]=172);p[2]=j.height>>>24&255;p[3]=j.height>>16&255;p[4]=j.height>>8&255;p[5]=j.height&255;for(r=q,v=k.length;r<v;r++){for(j=0;6>j&&p[j]===k[r+j];)j++;if(6===j){l.length=r+6;break}}4294967295===l.length&&P("JBIG2 error: segment end was not found")}else P("JBIG2 error: invalid unknown segment length");l.headerEnd=q;k=l;l=k.headerEnd;q={header:k,data:c};q.start=l;l+=k.length;q.end=l;i.push(q);if(51===k.type)break}c=i;b=g;i=0;for(k=c.length;i<k;i++){n=c[i];l=b;q=n.header;p=n.data;j=n.start;
n=n.end;B=v=r=F=void 0;switch(q.type){case 0:F={};r=H(p,j);F.huffman=!!(r&1);F.refinement=!!(r&2);F.huffmanDHSelector=r>>2&3;F.huffmanDWSelector=r>>4&3;F.bitmapSizeSelector=r>>6&1;F.aggregationInstancesSelector=r>>7&1;F.bitmapCodingContextUsed=!!(r&256);F.bitmapCodingContextRetained=!!(r&512);F.template=r>>10&3;F.refinementTemplate=r>>12&1;j+=2;if(!F.huffman){B=0===F.template?4:1;r=[];for(v=0;v<B;v++)r.push({x:L(p,j),y:L(p,j+1)}),j+=2;F.at=r}if(F.refinement&&!F.refinementTemplate){r=[];for(v=0;2>
v;v++)r.push({x:L(p,j),y:L(p,j+1)}),j+=2;F.refinementAt=r}F.numberOfExportedSymbols=K(p,j);j+=4;F.numberOfNewSymbols=K(p,j);j+=4;F=[F,q.number,q.referredTo,p,j,n];break;case 6:case 7:B={};B.info=z(p,j);j+=17;r=H(p,j);j+=2;B.huffman=!!(r&1);B.refinement=!!(r&2);B.stripSize=1<<(r>>2&3);B.referenceCorner=r>>4&3;B.transposed=!!(r&64);B.combinationOperator=r>>7&3;B.defaultPixelValue=r>>9&1;B.dsOffset=r<<17>>27;B.refinementTemplate=r>>15&1;B.huffman&&(r=H(p,j),j+=2,B.huffmanFS=r&3,B.huffmanDS=r>>2&3,B.huffmanDT=
r>>4&3,B.huffmanRefinementDW=r>>6&3,B.huffmanRefinementDH=r>>8&3,B.huffmanRefinementDX=r>>10&3,B.huffmanRefinementDY=r>>12&3,B.huffmanRefinementSizeSelector=!!(r&14));if(B.refinement&&!B.refinementTemplate){r=[];for(v=0;2>v;v++)r.push({x:L(p,j),y:L(p,j+1)}),j+=2;B.refinementAt=r}B.numberOfSymbolInstances=K(p,j);j+=4;B.huffman&&P("JBIG2 error: huffman is not supported");F=[B,q.referredTo,p,j,n];break;case 38:case 39:F={};F.info=z(p,j);j+=17;r=p[j++];F.mmr=!!(r&1);F.template=r>>1&3;F.prediction=!!(r&
8);if(!F.mmr){B=0===F.template?4:1;r=[];for(v=0;v<B;v++)r.push({x:L(p,j),y:L(p,j+1)}),j+=2;F.at=r}F=[F,p,j,n];break;case 48:n={width:K(p,j),height:K(p,j+4),resolutionX:K(p,j+8),resolutionY:K(p,j+12)};4294967295===n.height&&delete n.height;r=p[j+16];H(p,j+17);n.lossless=!!(r&1);n.refinement=!!(r&2);n.defaultPixelValue=r>>2&1;n.combinationOperator=r>>3&3;n.requiresBuffer=!!(r&32);n.combinationOperatorOverride=!!(r&64);F=[n];break;case 49:break;case 50:break;case 51:break;case 62:break;default:P("JBIG2 error: segment type "+
q.typeName+"("+q.type+") is not implemented")}q="on"+q.typeName;q in l&&l[q].apply(l,F)}}return g.buffer}};return m}();a.Jbig2Image=e});(function(a,e){e(a.pdfjsCoreJpx={},a.pdfjsSharedUtil,a.pdfjsCoreArithmeticDecoder)})(this,function(a,e,O){var P=e.info,N=e.log2,L=e.readUint16,H=e.readUint32,K=e.warn,I=O.ArithmeticDecoder,e=function(){function a(){this.failOnCorruptedImage=!1}function e(g,f,d){var g=d.xcb_,d=d.ycb_,k=1<<g,c=1<<d,b=f.tbx0>>g,i=f.tby0>>d,l=f.tbx1+k-1>>g,q=f.tby1+c-1>>d,j=f.resolution.precinctParameters,
p=[],v=[],n,r,B,a;for(r=i;r<q;r++)for(n=b;n<l;n++)if(B={cbx:n,cby:r,tbx0:k*n,tby0:c*r,tbx1:k*(n+1),tby1:c*(r+1)},B.tbx0_=Math.max(f.tbx0,B.tbx0),B.tby0_=Math.max(f.tby0,B.tby0),B.tbx1_=Math.min(f.tbx1,B.tbx1),B.tby1_=Math.min(f.tby1,B.tby1),a=Math.floor((B.tbx0_-f.tbx0)/j.precinctWidthInSubband)+Math.floor((B.tby0_-f.tby0)/j.precinctHeightInSubband)*j.numprecinctswide,B.precinctNumber=a,B.subbandType=f.type,B.Lblock=3,!(B.tbx1_<=B.tbx0_||B.tby1_<=B.tby0_)){p.push(B);var A=v[a];void 0!==A?(n<A.cbxMin?
A.cbxMin=n:n>A.cbxMax&&(A.cbxMax=n),r<A.cbyMin?A.cbxMin=r:r>A.cbyMax&&(A.cbyMax=r)):v[a]=A={cbxMin:n,cbyMin:r,cbxMax:n,cbyMax:r};B.precinct=A}f.codeblockParameters={codeblockWidth:g,codeblockHeight:d,numcodeblockwide:l-b+1,numcodeblockhigh:q-i+1};f.codeblocks=p;f.precincts=v}function E(g,f,d){for(var k=[],g=g.subbands,c=0,b=g.length;c<b;c++)for(var i=g[c].codeblocks,l=0,q=i.length;l<q;l++){var j=i[l];j.precinctNumber===f&&k.push(j)}return{layerNumber:d,codeblocks:k}}function C(g){for(var f=g.tiles[g.currentTile.index],
d=f.codingStyleDefaultParameters.layersCount,k=g.SIZ.Csiz,c=0,g=0;g<k;g++)c=Math.max(c,f.components[g].codingStyleParameters.decompositionLevelsCount);var b=0,i=0,l=0,q=0;this.nextPacket=function(){for(;b<d;b++){for(;i<=c;i++){for(;l<k;l++){var j=f.components[l];if(!(i>j.codingStyleParameters.decompositionLevelsCount)){for(var j=j.resolutions[i],p=j.precinctParameters.numprecincts;q<p;)return j=E(j,q,b),q++,j;q=0}}l=0}i=0}throw Error("JPX Error: Out of packets");}}function o(g){for(var f=g.tiles[g.currentTile.index],
d=f.codingStyleDefaultParameters.layersCount,k=g.SIZ.Csiz,c=0,g=0;g<k;g++)c=Math.max(c,f.components[g].codingStyleParameters.decompositionLevelsCount);var b=0,i=0,l=0,q=0;this.nextPacket=function(){for(;b<=c;b++){for(;i<d;i++){for(;l<k;l++){var j=f.components[l];if(!(b>j.codingStyleParameters.decompositionLevelsCount)){for(var j=j.resolutions[b],p=j.precinctParameters.numprecincts;q<p;)return j=E(j,q,i),q++,j;q=0}}l=0}i=0}throw Error("JPX Error: Out of packets");}}function x(g){var f=g.tiles[g.currentTile.index],
d=f.codingStyleDefaultParameters.layersCount,k=g.SIZ.Csiz,c,b,i,l,q=0;for(i=0;i<k;i++)q=Math.max(q,f.components[i].codingStyleParameters.decompositionLevelsCount);var j=new Int32Array(q+1);for(b=0;b<=q;++b){for(i=g=0;i<k;++i){var p=f.components[i].resolutions;b<p.length&&(g=Math.max(g,p[b].precinctParameters.numprecincts))}j[b]=g}l=i=b=c=0;this.nextPacket=function(){for(;b<=q;b++){for(;l<j[b];l++){for(;i<k;i++){var p=f.components[i];if(!(b>p.codingStyleParameters.decompositionLevelsCount)&&(p=p.resolutions[b],
!(l>=p.precinctParameters.numprecincts))){for(;c<d;)return p=E(p,l,c),c++,p;c=0}}i=0}l=0}throw Error("JPX Error: Out of packets");}}function D(g){var f=g.tiles[g.currentTile.index],d=f.codingStyleDefaultParameters.layersCount,k=g.SIZ.Csiz,c=z(f),b=0,i=0,l=0,q=0,j=0;this.nextPacket=function(){for(;j<c.maxNumHigh;j++){for(;q<c.maxNumWide;q++){for(;l<k;l++){for(var p=f.components[l],v=p.codingStyleParameters.decompositionLevelsCount;i<=v;i++){var n=p.resolutions[i],r=h(q,j,c.components[l].resolutions[i],
c,n);if(null!==r){for(;b<d;)return p=E(n,r,b),b++,p;b=0}}i=0}l=0}q=0}throw Error("JPX Error: Out of packets");}}function G(g){var f=g.tiles[g.currentTile.index],d=f.codingStyleDefaultParameters.layersCount,k=g.SIZ.Csiz,c=z(f),b=0,i=0,l=0,q=0,j=0;this.nextPacket=function(){for(;l<k;++l){for(var p=f.components[l],v=c.components[l],n=p.codingStyleParameters.decompositionLevelsCount;j<v.maxNumHigh;j++){for(;q<v.maxNumWide;q++){for(;i<=n;i++){var r=p.resolutions[i],g=h(q,j,v.resolutions[i],v,r);if(null!==
g){for(;b<d;)return p=E(r,g,b),b++,p;b=0}}i=0}q=0}j=0}throw Error("JPX Error: Out of packets");}}function h(g,f,d,k,c){g*=k.minWidth;f*=k.minHeight;return 0!==g%d.width||0!==f%d.height?null:g/d.height+f/d.width*c.precinctParameters.numprecinctswide}function z(g){for(var f=g.components.length,d=Number.MAX_VALUE,k=Number.MAX_VALUE,c=0,b=0,i=Array(f),l=0;l<f;l++){for(var q=g.components[l],j=q.codingStyleParameters.decompositionLevelsCount,p=Array(j+1),v=Number.MAX_VALUE,n=Number.MAX_VALUE,r=0,B=0,a=
1;0<=j;--j){var A=q.resolutions[j],h=a*A.precinctParameters.precinctWidth,e=a*A.precinctParameters.precinctHeight,v=Math.min(v,h),n=Math.min(n,e),r=Math.max(r,A.precinctParameters.numprecinctswide),B=Math.max(B,A.precinctParameters.numprecinctshigh);p[j]={width:h,height:e};a<<=1}d=Math.min(d,v);k=Math.min(k,n);c=Math.max(c,r);b=Math.max(b,B);i[l]={resolutions:p,minWidth:v,minHeight:n,maxNumWide:r,maxNumHigh:B}}return{components:i,minWidth:d,minHeight:k,maxNumWide:c,maxNumHigh:b}}function R(g,f,d,
k){function c(b){for(;p<b;){var c=f[d+q];q++;v?(j=j<<7|c,p+=7,v=!1):(j=j<<8|c,p+=8);255===c&&(v=!0)}p-=b;return j>>>p&(1<<b)-1}function b(b){if(255===f[d+q-1]&&f[d+q]===b)return q+=1,!0;return 255===f[d+q]&&f[d+q+1]===b?(q+=2,!0):!1}function i(){p=0;v&&(q++,v=!1)}function l(){if(0===c(1))return 1;if(0===c(1))return 2;var b=c(2);if(3>b)return b+3;b=c(5);if(31>b)return b+6;b=c(7);return b+37}for(var q=0,j,p=0,v=!1,n=g.COD.sopMarkerUsed,r=g.COD.ephMarkerUsed,g=g.tiles[g.currentTile.index].packetsIterator;q<
k;){i();n&&b(145)&&(q+=4);var B=g.nextPacket();if(c(1)){for(var a=B.layerNumber,A=[],h,e=0,u=B.codeblocks.length;e<u;e++){h=B.codeblocks[e];var s=h.precinct,m=h.cbx-s.cbxMin,o=h.cby-s.cbyMin,y=!1,z=!1,M;if(void 0!==h.included)y=!!c(1);else{var s=h.precinct,D,x;void 0!==s.inclusionTree?D=s.inclusionTree:(M=s.cbxMax-s.cbxMin+1,x=s.cbyMax-s.cbyMin+1,D=new t(M,x,a),x=new w(M,x),s.inclusionTree=D,s.zeroBitPlanesTree=x);if(D.reset(m,o,a))for(;;)if(c(1)){if(M=!D.nextLevel()){y=z=h.included=!0;break}}else{D.incrementValue(a);
break}}if(y){if(z){x=s.zeroBitPlanesTree;for(x.reset(m,o);;)if(c(1)){if(M=!x.nextLevel())break}else x.incrementValue();h.zeroBitPlanes=x.value}for(s=l();c(1);)h.Lblock++;m=N(s);m=c((s<1<<m?m-1:m)+h.Lblock);A.push({codeblock:h,codingpasses:s,dataLength:m})}}i();for(r&&b(146);0<A.length;)B=A.shift(),h=B.codeblock,void 0===h.data&&(h.data=[]),h.data.push({data:f,start:d+q,end:d+q+B.dataLength,codingpasses:B.codingpasses}),q+=B.dataLength}}return q}var m={LL:0,LH:1,HL:1,HH:2};a.prototype={parse:function(g){if(65359===
L(g,0))this.parseCodestream(g,0,g.length);else for(var f=0,d=g.length;f<d;){var k=8,c=H(g,f),b=H(g,f+4),f=f+k;1===c&&(c=4294967296*H(g,f)+H(g,f+4),f+=8,k+=8);0===c&&(c=d-f+k);if(c<k)throw Error("JPX Error: Invalid box field size");k=c-k;c=!0;switch(b){case 1785737832:c=!1;break;case 1668246642:b=g[f];if(1===b)switch(b=H(g,f+3),b){case 16:case 17:case 18:break;default:K("Unknown colorspace "+b)}else 2===b&&P("ICC profile not supported");break;case 1785737827:this.parseCodestream(g,f,f+k);break;case 1783636E3:218793738!==
H(g,f)&&K("Invalid JP2 signature");break;case 1783634458:case 1718909296:case 1920099697:case 1919251232:case 1768449138:break;default:var i=String.fromCharCode(b>>24&255,b>>16&255,b>>8&255,b&255);K("Unsupported header type "+b+" ("+i+")")}c&&(f+=k)}},parseImageProperties:function(g){for(var f=g.getByte();0<=f;){var d=f,f=g.getByte();if(65361===(d<<8|f)){g.skip(4);var f=g.getInt32()>>>0,d=g.getInt32()>>>0,k=g.getInt32()>>>0,c=g.getInt32()>>>0;g.skip(16);g=g.getUint16();this.width=f-k;this.height=
d-c;this.componentsCount=g;this.bitsPerComponent=8;return}}throw Error("JPX Error: No size marker found in JPX stream");},parseCodestream:function(g,f,d){var k={};try{for(var c=!1,b=f;b+1<d;){var i=L(g,b),b=b+2,l=0,q,j,p,v,n,r;switch(i){case 65359:k.mainHeader=!0;break;case 65497:break;case 65361:var l=L(g,b),B={};B.Xsiz=H(g,b+4);B.Ysiz=H(g,b+8);B.XOsiz=H(g,b+12);B.YOsiz=H(g,b+16);B.XTsiz=H(g,b+20);B.YTsiz=H(g,b+24);B.XTOsiz=H(g,b+28);B.YTOsiz=H(g,b+32);var a=L(g,b+36);B.Csiz=a;var A=[];q=b+38;for(var h=
0;h<a;h++){var t={precision:(g[q]&127)+1,isSigned:!!(g[q]&128),XRsiz:g[q+1],YRsiz:g[q+1]},w=t,y=B;w.x0=Math.ceil(y.XOsiz/w.XRsiz);w.x1=Math.ceil(y.Xsiz/w.XRsiz);w.y0=Math.ceil(y.YOsiz/w.YRsiz);w.y1=Math.ceil(y.Ysiz/w.YRsiz);w.width=w.x1-w.x0;w.height=w.y1-w.y0;A.push(t)}k.SIZ=B;k.components=A;for(var z=k,E=A,J=z.SIZ,N=void 0,O=[],P=Math.ceil((J.Xsiz-J.XTOsiz)/J.XTsiz),qa=Math.ceil((J.Ysiz-J.YTOsiz)/J.YTsiz),Ka=0;Ka<qa;Ka++)for(var ha=0;ha<P;ha++)N={},N.tx0=Math.max(J.XTOsiz+ha*J.XTsiz,J.XOsiz),N.ty0=
Math.max(J.YTOsiz+Ka*J.YTsiz,J.YOsiz),N.tx1=Math.min(J.XTOsiz+(ha+1)*J.XTsiz,J.Xsiz),N.ty1=Math.min(J.YTOsiz+(Ka+1)*J.YTsiz,J.Ysiz),N.width=N.tx1-N.tx0,N.height=N.ty1-N.ty0,N.components=[],O.push(N);z.tiles=O;for(var ea=0,Ua=J.Csiz;ea<Ua;ea++)for(var ja=E[ea],bb=0,La=O.length;bb<La;bb++){var Y={},N=O[bb];Y.tcx0=Math.ceil(N.tx0/ja.XRsiz);Y.tcy0=Math.ceil(N.ty0/ja.YRsiz);Y.tcx1=Math.ceil(N.tx1/ja.XRsiz);Y.tcy1=Math.ceil(N.ty1/ja.YRsiz);Y.width=Y.tcx1-Y.tcx0;Y.height=Y.tcy1-Y.tcy0;N.components[ea]=Y}k.QCC=
[];k.COC=[];break;case 65372:var l=L(g,b),ka={};q=b+2;j=g[q++];switch(j&31){case 0:v=8;n=!0;break;case 1:v=16;n=!1;break;case 2:v=16;n=!0;break;default:throw Error("JPX Error: Invalid SQcd value "+j);}ka.noQuantization=8===v;ka.scalarExpounded=n;ka.guardBits=j>>5;for(p=[];q<l+b;){var fa={};8===v?(fa.epsilon=g[q++]>>3,fa.mu=0):(fa.epsilon=g[q]>>3,fa.mu=(g[q]&7)<<8|g[q+1],q+=2);p.push(fa)}ka.SPqcds=p;k.mainHeader?k.QCD=ka:(k.currentTile.QCD=ka,k.currentTile.QCC=[]);break;case 65373:var l=L(g,b),sa=
{};q=b+2;var Fa;257>k.SIZ.Csiz?Fa=g[q++]:(Fa=L(g,q),q+=2);j=g[q++];switch(j&31){case 0:v=8;n=!0;break;case 1:v=16;n=!1;break;case 2:v=16;n=!0;break;default:throw Error("JPX Error: Invalid SQcd value "+j);}sa.noQuantization=8===v;sa.scalarExpounded=n;sa.guardBits=j>>5;for(p=[];q<l+b;)fa={},8===v?(fa.epsilon=g[q++]>>3,fa.mu=0):(fa.epsilon=g[q]>>3,fa.mu=(g[q]&7)<<8|g[q+1],q+=2),p.push(fa);sa.SPqcds=p;k.mainHeader?k.QCC[Fa]=sa:k.currentTile.QCC[Fa]=sa;break;case 65362:var l=L(g,b),U={};q=b+2;var Ba=g[q++];
U.entropyCoderWithCustomPrecincts=!!(Ba&1);U.sopMarkerUsed=!!(Ba&2);U.ephMarkerUsed=!!(Ba&4);U.progressionOrder=g[q++];U.layersCount=L(g,q);q+=2;U.multipleComponentTransform=g[q++];U.decompositionLevelsCount=g[q++];U.xcb=(g[q++]&15)+2;U.ycb=(g[q++]&15)+2;var ia=g[q++];U.selectiveArithmeticCodingBypass=!!(ia&1);U.resetContextProbabilities=!!(ia&2);U.terminationOnEachCodingPass=!!(ia&4);U.verticalyStripe=!!(ia&8);U.predictableTermination=!!(ia&16);U.segmentationSymbolUsed=!!(ia&32);U.reversibleTransformation=
g[q++];if(U.entropyCoderWithCustomPrecincts){for(var Ga=[];q<l+b;){var cb=g[q++];Ga.push({PPx:cb&15,PPy:cb>>4})}U.precinctsSizes=Ga}var X=[];U.selectiveArithmeticCodingBypass&&X.push("selectiveArithmeticCodingBypass");U.resetContextProbabilities&&X.push("resetContextProbabilities");U.terminationOnEachCodingPass&&X.push("terminationOnEachCodingPass");U.verticalyStripe&&X.push("verticalyStripe");U.predictableTermination&&X.push("predictableTermination");if(0<X.length)throw c=!0,Error("JPX Error: Unsupported COD options ("+
X.join(", ")+")");k.mainHeader?k.COD=U:(k.currentTile.COD=U,k.currentTile.COC=[]);break;case 65424:l=L(g,b);r={};r.index=L(g,b+2);r.length=H(g,b+4);r.dataEnd=r.length+b-2;r.partIndex=g[b+8];r.partsCount=g[b+9];k.mainHeader=!1;0===r.partIndex&&(r.COD=k.COD,r.COC=k.COC.slice(0),r.QCD=k.QCD,r.QCC=k.QCC.slice(0));k.currentTile=r;break;case 65427:r=k.currentTile;if(0===r.partIndex){for(var aa=k,ga=aa.SIZ.Csiz,Va=aa.tiles[r.index],la=0;la<ga;la++){var Wa=Va.components[la];Wa.quantizationParameters=void 0!==
aa.currentTile.QCC[la]?aa.currentTile.QCC[la]:aa.currentTile.QCD;Wa.codingStyleParameters=void 0!==aa.currentTile.COC[la]?aa.currentTile.COC[la]:aa.currentTile.COD}Va.codingStyleDefaultParameters=aa.currentTile.COD;for(var ma=k,ta=ma.tiles[ma.currentTile.index],ua=ma.SIZ.Csiz,va=0;va<ua;va++){for(var S=ta.components[va],Eb=S.codingStyleParameters.decompositionLevelsCount,wa=[],mb=[],na=0;na<=Eb;na++){var Ha,rb=na,Xa=S.codingStyleParameters,za={};Xa.entropyCoderWithCustomPrecincts?(za.PPx=Xa.precinctsSizes[rb].PPx,
za.PPy=Xa.precinctsSizes[rb].PPy):(za.PPx=15,za.PPy=15);za.xcb_=0<rb?Math.min(Xa.xcb,za.PPx-1):Math.min(Xa.xcb,za.PPx);za.ycb_=0<rb?Math.min(Xa.ycb,za.PPy-1):Math.min(Xa.ycb,za.PPy);Ha=za;var ra={},Ma=1<<Eb-na;ra.trx0=Math.ceil(S.tcx0/Ma);ra.try0=Math.ceil(S.tcy0/Ma);ra.trx1=Math.ceil(S.tcx1/Ma);ra.try1=Math.ceil(S.tcy1/Ma);ra.resLevel=na;var Ca=ra,Fb=1<<Ha.PPx,Gb=1<<Ha.PPy,Yb=0===Ca.resLevel,tc=1<<Ha.PPx+(Yb?0:-1),db=1<<Ha.PPy+(Yb?0:-1),Zb=Ca.trx1>Ca.trx0?Math.ceil(Ca.trx1/Fb)-Math.floor(Ca.trx0/
Fb):0,$b=Ca.try1>Ca.try0?Math.ceil(Ca.try1/Gb)-Math.floor(Ca.try0/Gb):0;Ca.precinctParameters={precinctWidth:Fb,precinctHeight:Gb,numprecinctswide:Zb,numprecinctshigh:$b,numprecincts:Zb*$b,precinctWidthInSubband:tc,precinctHeightInSubband:db};wa.push(ra);var T;if(0===na)T={type:"LL"},T.tbx0=Math.ceil(S.tcx0/Ma),T.tby0=Math.ceil(S.tcy0/Ma),T.tbx1=Math.ceil(S.tcx1/Ma),T.tby1=Math.ceil(S.tcy1/Ma),T.resolution=ra,e(ma,T,Ha),mb.push(T),ra.subbands=[T];else{var xa=1<<Eb-na+1,sb=[];T={type:"HL"};T.tbx0=
Math.ceil(S.tcx0/xa-0.5);T.tby0=Math.ceil(S.tcy0/xa);T.tbx1=Math.ceil(S.tcx1/xa-0.5);T.tby1=Math.ceil(S.tcy1/xa);T.resolution=ra;e(ma,T,Ha);mb.push(T);sb.push(T);T={type:"LH"};T.tbx0=Math.ceil(S.tcx0/xa);T.tby0=Math.ceil(S.tcy0/xa-0.5);T.tbx1=Math.ceil(S.tcx1/xa);T.tby1=Math.ceil(S.tcy1/xa-0.5);T.resolution=ra;e(ma,T,Ha);mb.push(T);sb.push(T);T={type:"HH"};T.tbx0=Math.ceil(S.tcx0/xa-0.5);T.tby0=Math.ceil(S.tcy0/xa-0.5);T.tbx1=Math.ceil(S.tcx1/xa-0.5);T.tby1=Math.ceil(S.tcy1/xa-0.5);T.resolution=ra;
e(ma,T,Ha);mb.push(T);sb.push(T);ra.subbands=sb}}S.resolutions=wa;S.subbands=mb}var ac=ta.codingStyleDefaultParameters.progressionOrder;switch(ac){case 0:ta.packetsIterator=new C(ma);break;case 1:ta.packetsIterator=new o(ma);break;case 2:ta.packetsIterator=new x(ma);break;case 3:ta.packetsIterator=new D(ma);break;case 4:ta.packetsIterator=new G(ma);break;default:throw Error("JPX Error: Unsupported progression order "+ac);}}l=r.dataEnd-b;R(k,g,b,l);break;case 65365:case 65367:case 65368:case 65380:l=
L(g,b);break;case 65363:throw Error("JPX Error: Codestream code 0xFF53 (COC) is not implemented");default:throw Error("JPX Error: Unknown codestream code: "+i.toString(16));}b+=l}}catch(bc){if(c||this.failOnCorruptedImage)throw bc;K("Trying to recover from "+bc.message)}for(var cc=k.components,eb=k.SIZ.Csiz,dc=[],Hb=0,uc=k.tiles.length;Hb<uc;Hb++){var Ib=k.tiles[Hb],Ya=[],ya;for(ya=0;ya<eb;ya++){for(var vc=Ya,wc=ya,Za=Ib.components[ya],ca=Za.codingStyleParameters,Jb=Za.quantizationParameters,xc=ca.decompositionLevelsCount,
tb=Jb.SPqcds,yc=Jb.scalarExpounded,zc=Jb.guardBits,Ac=ca.segmentationSymbolUsed,Bc=k.components[ya].precision,Kb=ca.reversibleTransformation,Cc=Kb?new M:new s,ec=[],Lb=0,nb=0;nb<=xc;nb++){for(var fb=Za.resolutions[nb],Mb=fb.trx1-fb.trx0,fc=fb.try1-fb.try0,gc=new Float32Array(Mb*fc),Nb=0,Dc=fb.subbands.length;Nb<Dc;Nb++){var Ob,ub;yc?(Ob=tb[Lb].mu,ub=tb[Lb].epsilon,Lb++):(Ob=tb[0].mu,ub=tb[0].epsilon+(0<nb?1-nb:0));for(var hc=fb.subbands[Nb],Ec=m[hc.type],Fc=Kb?1:Math.pow(2,Bc+Ec-ub)*(1+Ob/2048),Gc=
gc,ic=Mb,Na=hc,Hc=Fc,Pb=zc+ub-1,jc=Kb,Ic=Ac,Jc=Na.tbx0,Kc=Na.tby0,vb=Na.tbx1-Na.tbx0,kc=Na.codeblocks,Lc="H"===Na.type.charAt(0)?1:0,Mc="H"===Na.type.charAt(1)?ic:0,Qb=0,Nc=kc.length;Qb<Nc;++Qb){var Da=kc[Qb],wb=Da.tbx1_-Da.tbx0_,Rb=Da.tby1_-Da.tby0_;if(!(0===wb||0===Rb)&&void 0!==Da.data){var Ia,xb;Ia=new u(wb,Rb,Da.subbandType,Da.zeroBitPlanes,Pb);xb=2;var yb=Da.data,zb=0,Sb=0,oa,Ab,Oa;for(oa=0,Ab=yb.length;oa<Ab;oa++)Oa=yb[oa],zb+=Oa.end-Oa.start,Sb+=Oa.codingpasses;var lc=new Uint8Array(zb),Pa=
0;for(oa=0,Ab=yb.length;oa<Ab;oa++){Oa=yb[oa];var mc=Oa.data.subarray(Oa.start,Oa.end);lc.set(mc,Pa);Pa+=mc.length}var Oc=new I(lc,0,zb);Ia.setDecoder(Oc);for(oa=0;oa<Sb;oa++){switch(xb){case 0:Ia.runSignificancePropogationPass();break;case 1:Ia.runMagnitudeRefinementPass();break;case 2:Ia.runCleanupPass(),Ic&&Ia.checkSegmentationSymbol()}xb=(xb+1)%3}var gb=Da.tbx0_-Jc+(Da.tby0_-Kc)*vb,Pc=Ia.coefficentsSign,Qc=Ia.coefficentsMagnitude,Rc=Ia.bitsDecoded,Sc=jc?0:0.5,Tb,Qa,Ub,Pa=0,Tc="LL"!==Na.type;for(oa=
0;oa<Rb;oa++){var Uc=2*(gb/vb|0)*(ic-vb)+Lc+Mc;for(Tb=0;Tb<wb;Tb++)Qa=Qc[Pa],0!==Qa&&(Qa=(Qa+Sc)*Hc,0!==Pc[Pa]&&(Qa=-Qa),Ub=Rc[Pa],Gc[Tc?Uc+(gb<<1):gb]=jc&&Ub>=Pb?Qa:Qa*(1<<Pb-Ub)),gb++,Pa++;gb+=vb-wb}}}}ec.push({width:Mb,height:fc,items:gc})}var Vb=Cc.calculate(ec,Za.tcx0,Za.tcy0);vc[wc]={left:Za.tcx0,top:Za.tcy0,width:Vb.width,height:Vb.height,items:Vb.items}}var ob=Ya[0],Ja=new Uint8Array(ob.items.length*eb),Vc={left:ob.left,top:ob.top,width:ob.width,height:ob.height,items:Ja},pa,hb,Aa,Bb,Wb,da=
0,Z,ib,jb,kb,lb,Ra,Ea,Sa,Cb,Db;if(Ib.codingStyleDefaultParameters.multipleComponentTransform){var nc=4===eb,Xb=Ya[0].items,oc=Ya[1].items,pc=Ya[2].items,Wc=nc?Ya[3].items:null;pa=cc[0].precision-8;hb=(128<<pa)+0.5;Aa=255*(1<<pa);Wb=0.5*Aa;Bb=-Wb;var Xc=Ib.components[0],qc=eb-3;ib=Xb.length;if(Xc.codingStyleParameters.reversibleTransformation)for(Z=0;Z<ib;Z++,da+=qc)jb=Xb[Z]+hb,kb=oc[Z],lb=pc[Z],Ea=jb-(lb+kb>>2),Ra=Ea+lb,Sa=Ea+kb,Ja[da++]=0>=Ra?0:Ra>=Aa?255:Ra>>pa,Ja[da++]=0>=Ea?0:Ea>=Aa?255:Ea>>pa,
Ja[da++]=0>=Sa?0:Sa>=Aa?255:Sa>>pa;else for(Z=0;Z<ib;Z++,da+=qc)jb=Xb[Z]+hb,kb=oc[Z],lb=pc[Z],Ra=jb+1.402*lb,Ea=jb-0.34413*kb-0.71414*lb,Sa=jb+1.772*kb,Ja[da++]=0>=Ra?0:Ra>=Aa?255:Ra>>pa,Ja[da++]=0>=Ea?0:Ea>=Aa?255:Ea>>pa,Ja[da++]=0>=Sa?0:Sa>=Aa?255:Sa>>pa;if(nc)for(Z=0,da=3;Z<ib;Z++,da+=4)Cb=Wc[Z],Ja[da]=Cb<=Bb?0:Cb>=Wb?255:Cb+hb>>pa}else for(ya=0;ya<eb;ya++){var rc=Ya[ya].items;pa=cc[ya].precision-8;hb=(128<<pa)+0.5;Aa=127.5*(1<<pa);Bb=-Aa;for(da=ya,Z=0,ib=rc.length;Z<ib;Z++)Db=rc[Z],Ja[da]=Db<=
Bb?0:Db>=Aa?255:Db+hb>>pa,da+=eb}dc.push(Vc)}this.tiles=dc;this.width=k.SIZ.Xsiz-k.SIZ.XOsiz;this.height=k.SIZ.Ysiz-k.SIZ.YOsiz;this.componentsCount=k.SIZ.Csiz}};var w=function(){function g(f,d){var k=N(Math.max(f,d))+1;this.levels=[];for(var c=0;c<k;c++)this.levels.push({width:f,height:d,items:[]}),f=Math.ceil(f/2),d=Math.ceil(d/2)}g.prototype={reset:function(f,d){for(var k=0,c=0,b;k<this.levels.length;){b=this.levels[k];var i=f+d*b.width;if(void 0!==b.items[i]){c=b.items[i];break}b.index=i;f>>=
1;d>>=1;k++}k--;b=this.levels[k];b.items[b.index]=c;this.currentLevel=k;delete this.value},incrementValue:function(){var f=this.levels[this.currentLevel];f.items[f.index]++},nextLevel:function(){var f=this.currentLevel,d=this.levels[f],k=d.items[d.index];f--;if(0>f)return this.value=k,!1;this.currentLevel=f;d=this.levels[f];d.items[d.index]=k;return!0}};return g}(),t=function(){function g(f,d,k){var c=N(Math.max(f,d))+1;this.levels=[];for(var b=0;b<c;b++){for(var i=new Uint8Array(f*d),l=0,g=i.length;l<
g;l++)i[l]=k;this.levels.push({width:f,height:d,items:i});f=Math.ceil(f/2);d=Math.ceil(d/2)}}g.prototype={reset:function(f,d,k){for(var c=0;c<this.levels.length;){var b=this.levels[c],i=f+d*b.width;b.index=i;b=b.items[i];if(255===b)break;if(b>k)return this.currentLevel=c,this.propagateValues(),!1;f>>=1;d>>=1;c++}this.currentLevel=c-1;return!0},incrementValue:function(f){var d=this.levels[this.currentLevel];d.items[d.index]=f+1;this.propagateValues()},propagateValues:function(){for(var f=this.currentLevel,
d=this.levels[f],k=d.items[d.index];0<=--f;)d=this.levels[f],d.items[d.index]=k},nextLevel:function(){var f=this.currentLevel,d=this.levels[f],k=d.items[d.index];d.items[d.index]=255;f--;if(0>f)return!1;this.currentLevel=f;d=this.levels[f];d.items[d.index]=k;return!0}};return g}(),u=function(){function g(c,b,i,l,g){this.width=c;this.height=b;this.contextLabelTable="HH"===i?k:"HL"===i?d:f;c*=b;this.neighborsSignificance=new Uint8Array(c);this.coefficentsSign=new Uint8Array(c);this.coefficentsMagnitude=
14<g?new Uint32Array(c):6<g?new Uint16Array(c):new Uint8Array(c);this.processingFlags=new Uint8Array(c);g=new Uint8Array(c);if(0!==l)for(b=0;b<c;b++)g[b]=l;this.bitsDecoded=g;this.reset()}var f=new Uint8Array([0,5,8,0,3,7,8,0,4,7,8,0,0,0,0,0,1,6,8,0,3,7,8,0,4,7,8,0,0,0,0,0,2,6,8,0,3,7,8,0,4,7,8,0,0,0,0,0,2,6,8,0,3,7,8,0,4,7,8,0,0,0,0,0,2,6,8,0,3,7,8,0,4,7,8]),d=new Uint8Array([0,3,4,0,5,7,7,0,8,8,8,0,0,0,0,0,1,3,4,0,6,7,7,0,8,8,8,0,0,0,0,0,2,3,4,0,6,7,7,0,8,8,8,0,0,0,0,0,2,3,4,0,6,7,7,0,8,8,8,0,0,
0,0,0,2,3,4,0,6,7,7,0,8,8,8]),k=new Uint8Array([0,1,2,0,1,2,2,0,2,2,2,0,0,0,0,0,3,4,5,0,4,5,5,0,5,5,5,0,0,0,0,0,6,7,7,0,7,7,7,0,7,7,7,0,0,0,0,0,8,8,8,0,8,8,8,0,8,8,8,0,0,0,0,0,8,8,8,0,8,8,8,0,8,8,8]);g.prototype={setDecoder:function(c){this.decoder=c},reset:function(){this.contexts=new Int8Array(19);this.contexts[0]=8;this.contexts[17]=92;this.contexts[18]=6},setNeighborsSignificance:function(c,b,i){var d=this.neighborsSignificance,f=this.width,j=this.height,p=0<b,b=b+1<f,v;0<c&&(v=i-f,p&&(d[v-1]+=
16),b&&(d[v+1]+=16),d[v]+=4);c+1<j&&(v=i+f,p&&(d[v-1]+=16),b&&(d[v+1]+=16),d[v]+=4);p&&(d[i-1]+=1);b&&(d[i+1]+=1);d[i]|=128},runSignificancePropogationPass:function(){for(var c=this.decoder,b=this.width,i=this.height,d=this.coefficentsMagnitude,f=this.coefficentsSign,j=this.neighborsSignificance,p=this.processingFlags,v=this.contexts,n=this.contextLabelTable,r=this.bitsDecoded,k=0;k<i;k+=4)for(var g=0;g<b;g++)for(var a=k*b+g,h=0;4>h;h++,a+=b){var e=k+h;if(e>=i)break;p[a]&=-2;if(!d[a]&&j[a]){if(c.readBit(v,
n[j[a]])){var u=this.decodeSignBit(e,g,a);f[a]=u;d[a]=1;this.setNeighborsSignificance(e,g,a);p[a]|=2}r[a]++;p[a]|=1}}},decodeSignBit:function(c,b,i){var d=this.width,f=this.height,j=this.coefficentsMagnitude,p=this.coefficentsSign,v;v=0<b&&0!==j[i-1];b+1<d&&0!==j[i+1]?(b=p[i+1],v?(v=p[i-1],b=1-b-v):b=1-b-b):v?(v=p[i-1],b=1-v-v):b=0;var n=3*b;v=0<c&&0!==j[i-d];c+1<f&&0!==j[i+d]?(b=p[i+d],v?(v=p[i-d],b=1-b-v+n):b=1-b-b+n):v?(v=p[i-d],b=1-v-v+n):b=n;return c=0<=b?this.decoder.readBit(this.contexts,9+
b):this.decoder.readBit(this.contexts,9-b)^1},runMagnitudeRefinementPass:function(){for(var c=this.decoder,b=this.width,i=this.coefficentsMagnitude,d=this.neighborsSignificance,f=this.contexts,j=this.bitsDecoded,p=this.processingFlags,v=b*this.height,n=4*b,r=0,k;r<v;r=k){k=Math.min(v,r+n);for(var g=0;g<b;g++)for(var a=r+g;a<k;a+=b)if(i[a]&&0===(p[a]&1)){var h=16;0!==(p[a]&2)&&(p[a]^=2,h=0===(d[a]&127)?15:14);h=c.readBit(f,h);i[a]=i[a]<<1|h;j[a]++;p[a]|=1}}},runCleanupPass:function(){for(var c=this.decoder,
b=this.width,d=this.height,f=this.neighborsSignificance,k=this.coefficentsMagnitude,j=this.coefficentsSign,p=this.contexts,v=this.contextLabelTable,n=this.bitsDecoded,r=this.processingFlags,g=2*b,a=3*b,A,h=0;h<d;h=A){A=Math.min(h+4,d);for(var e=h*b,u=h+3<d,t=0;t<b;t++){var s=e+t,w=0,m=s,y=h,o;if(u&&0===r[s]&&0===r[s+b]&&0===r[s+g]&&0===r[s+a]&&0===f[s]&&0===f[s+b]&&0===f[s+g]&&0===f[s+a]){if(!c.readBit(p,18)){n[s]++;n[s+b]++;n[s+g]++;n[s+a]++;continue}w=c.readBit(p,17)<<1|c.readBit(p,17);0!==w&&(y=
h+w,m+=w*b);o=this.decodeSignBit(y,t,m);j[m]=o;k[m]=1;this.setNeighborsSignificance(y,t,m);r[m]|=2;m=s;for(s=h;s<=y;s++,m+=b)n[m]++;w++}for(y=h+w;y<A;y++,m+=b)k[m]||0!==(r[m]&1)||(1===c.readBit(p,v[f[m]])&&(o=this.decodeSignBit(y,t,m),j[m]=o,k[m]=1,this.setNeighborsSignificance(y,t,m),r[m]|=2),n[m]++)}}},checkSegmentationSymbol:function(){var c=this.decoder,b=this.contexts;if(10!==(c.readBit(b,17)<<3|c.readBit(b,17)<<2|c.readBit(b,17)<<1|c.readBit(b,17)))throw Error("JPX Error: Invalid segmentation symbol");
}};return g}(),y=function(){function g(){}g.prototype.calculate=function(f,d,k){for(var c=f[0],b=1,i=f.length;b<i;b++)c=this.iterate(c,f[b],d,k);return c};g.prototype.extend=function(f,d,k){var c=d-1,b=d+1,i=d+k-2,d=d+k;f[c--]=f[b++];f[d++]=f[i--];f[c--]=f[b++];f[d++]=f[i--];f[c--]=f[b++];f[d++]=f[i--];f[c]=f[b];f[d]=f[i]};g.prototype.iterate=function(f,d,k,c){var b=f.width,i=f.height,l=f.items,g=d.width,j=d.height,d=d.items,p,v,n,r;for(n=0,p=0;p<i;p++){r=2*p*g;for(v=0;v<b;v++,n++,r+=2)d[r]=l[n]}f.items=
null;f=new Float32Array(g+8);if(1===g){if(0!==(k&1))for(r=0,n=0;r<j;r++,n+=g)d[n]*=0.5}else for(r=0,n=0;r<j;r++,n+=g)f.set(d.subarray(n,n+g),4),this.extend(f,4,g),this.filter(f,4,g),d.set(f.subarray(4,4+g),n);k=16;b=[];for(p=0;p<k;p++)b.push(new Float32Array(j+8));p=0;f=4+j;if(1===j){if(0!==(c&1))for(c=0;c<g;c++)d[c]*=0.5}else for(c=0;c<g;c++){if(0===p){k=Math.min(g-c,k);for(n=c,r=4;r<f;n+=g,r++)for(i=0;i<k;i++)b[i][r]=d[n+i];p=k}p--;n=b[p];this.extend(n,4,j);this.filter(n,4,j);if(0===p){n=c-k+1;
for(r=4;r<f;n+=g,r++)for(i=0;i<k;i++)d[n+i]=b[i][r]}}return{width:g,height:j,items:d}};return g}(),s=function(){function g(){y.call(this)}g.prototype=Object.create(y.prototype);g.prototype.filter=function(f,d,k){var k=k>>1,d=d|0,c,b,i,l;c=d-3;for(b=k+4;b--;c+=2)f[c]*=0.8128930661159609;c=d-2;i=0.443506852043971*f[c-1];for(b=k+3;b--;c+=2)if(l=0.443506852043971*f[c+1],f[c]=1.230174104914001*f[c]-i-l,b--)c+=2,i=0.443506852043971*f[c+1],f[c]=1.230174104914001*f[c]-i-l;else break;c=d-1;i=0.882911075530934*
f[c-1];for(b=k+2;b--;c+=2)if(l=0.882911075530934*f[c+1],f[c]-=i+l,b--)c+=2,i=0.882911075530934*f[c+1],f[c]-=i+l;else break;c=d;i=-0.052980118572961*f[c-1];for(b=k+1;b--;c+=2)if(l=-0.052980118572961*f[c+1],f[c]-=i+l,b--)c+=2,i=-0.052980118572961*f[c+1],f[c]-=i+l;else break;if(0!==k){c=d+1;i=-1.586134342059924*f[c-1];for(b=k;b--;c+=2)if(l=-1.586134342059924*f[c+1],f[c]-=i+l,b--)c+=2,i=-1.586134342059924*f[c+1],f[c]-=i+l;else break}};return g}(),M=function(){function g(){y.call(this)}g.prototype=Object.create(y.prototype);
g.prototype.filter=function(f,d,k){var k=k>>1,d=d|0,c,b;for(c=d,b=k+1;b--;c+=2)f[c]-=f[c-1]+f[c+1]+2>>2;for(c=d+1,b=k;b--;c+=2)f[c]+=f[c-1]+f[c+1]>>1};return g}();return a}();a.JpxImage=e});(function(a,e){e(a.pdfjsCoreMurmurHash3={},a.pdfjsSharedUtil)})(this,function(a,e){var O=e.Uint32ArrayView,P=function(){function a(e){this.h1=e?e&4294967295:3285377520;this.h2=e?e&4294967295:3285377520}var e=!1;try{new Uint32Array((new Uint8Array(5)).buffer,0,1)}catch(H){e=!0}a.prototype={update:function(a){var I=
e,J;if("string"===typeof a){var H=new Uint8Array(2*a.length),E=0;for(J=0;J<a.length;J++){var C=a.charCodeAt(J);255>=C?H[E++]=C:(H[E++]=C>>>8,H[E++]=C&255)}}else if(a instanceof Uint8Array)H=a,E=H.length;else if("object"===typeof a&&"length"in a)H=a,E=H.length,I=!0;else throw Error("Wrong data format in MurmurHash3_64_update. Input must be a string or array.");var a=E>>2,E=E-4*a,I=I?new O(H,a):new Uint32Array(H.buffer,0,a),o=0,o=0,C=this.h1,x=this.h2;for(J=0;J<a;J++)J&1?(o=I[J],o=3432918353*o&4294901760|
11601*o&65535,o=o<<15|o>>>17,o=461845907*o&4294901760|13715*o&65535,C^=o,C=C<<13|C>>>19,C=5*C+3864292196):(o=I[J],o=3432918353*o&4294901760|11601*o&65535,o=o<<15|o>>>17,o=461845907*o&4294901760|13715*o&65535,x^=o,x=x<<13|x>>>19,x=5*x+3864292196);o=0;switch(E){case 3:o^=H[4*a+2]<<16;case 2:o^=H[4*a+1]<<8;case 1:o^=H[4*a],o=3432918353*o&4294901760|11601*o&65535,o=o<<15|o>>>17,o=461845907*o&4294901760|13715*o&65535,a&1?C^=o:x^=o}this.h1=C;this.h2=x;return this},hexdigest:function(){for(var a=this.h1,
e=this.h2,a=a^e>>>1,a=3981806797*a&4294901760|36045*a&65535,e=4283543511*e&4294901760|(2950163797*(e<<16|a>>>16)&4294901760)>>>16,a=a^e>>>1,a=444984403*a&4294901760|60499*a&65535,e=3301882366*e&4294901760|(3120437893*(e<<16|a>>>16)&4294901760)>>>16,H=0,a=[a^e>>>1,e],e="";H<a.length;H++){for(var L=(a[H]>>>0).toString(16);8>L.length;)L="0"+L;e+=L}return e}};return a}();a.MurmurHash3_64=P});(function(a,e){e(a.pdfjsCorePrimitives={},a.pdfjsSharedUtil)})(this,function(a,e){function O(a){return a instanceof
H}function P(a,e){if(!(a instanceof I))return!1;if(!e)return!0;var x=a.get("Type");return O(x)&&x.name===e}function N(a){return a instanceof J}var L=e.isArray,H=function(){function a(e){this.name=e}a.prototype={};var e={};a.get=function(x){var D=e[x];return D?D:e[x]=new a(x)};return a}(),K=function(){function a(e){this.cmd=e}a.prototype={};var e={};a.get=function(x){var D=e[x];return D?D:e[x]=new a(x)};return a}(),I=function(){function a(D){this.map=Object.create(null);this.xref=D;this.objId=null;
this.__nonSerializable__=e}var e=function(){return e},x={Background:!0,ExtGState:!0,Halftone:!0,Layout:!0,Mask:!0,Pagination:!0,Printing:!0};a.prototype={assignXref:function(a){this.xref=a},get:function(a,e,h){var o,x=this.xref;if("undefined"!==typeof(o=this.map[a])||a in this.map||"undefined"===typeof e||"undefined"!==typeof(o=this.map[e])||e in this.map||"undefined"===typeof h)return x?x.fetchIfRef(o):o;o=this.map[h]||null;return x?x.fetchIfRef(o):o},getAsync:function(a,e,h){var o,x=this.xref;if("undefined"!==
typeof(o=this.map[a])||a in this.map||"undefined"===typeof e||"undefined"!==typeof(o=this.map[e])||e in this.map||"undefined"===typeof h)return x?x.fetchIfRefAsync(o):Promise.resolve(o);o=this.map[h]||null;return x?x.fetchIfRefAsync(o):Promise.resolve(o)},getArray:function(a,e,h){a=this.get(a,e,h);e=this.xref;if(!L(a)||!e)return a;for(var a=a.slice(),h=0,o=a.length;h<o;h++)N(a[h])&&(a[h]=e.fetch(a[h]));return a},getRaw:function(a){return this.map[a]},getAll:function(){var e=Object.create(null),o=
null,h,z;for(h in this.map)z=this.get(h),z instanceof a?!O(z.Type)||!0===x[z.Type.name]?(o||(o=[])).push({target:e,key:h,obj:z}):e[h]=this.getRaw(h):e[h]=z;if(!o)return e;for(var E=Object.create(null);0<o.length;){var m=o.shift(),w=m.obj,t=w.objId;if(t&&t in E)m.target[m.key]=E[t];else{var u=Object.create(null);for(h in w.map)z=w.get(h),z instanceof a?!O(z.Type)||!0===x[z.Type.name]?o.push({target:u,key:h,obj:z}):u[h]=w.getRaw(h):u[h]=z;t&&(E[t]=u);m.target[m.key]=u}}return e},getKeys:function(){return Object.keys(this.map)},
set:function(a,e){this.map[a]=e},has:function(a){return a in this.map},forEach:function(a){for(var e in this.map)a(e,this.get(e))}};a.empty=new a(null);a.merge=function(e,o){for(var h=new a(e),z=0,x=o.length;z<x;z++){var m=o[z];if(P(m))for(var w in m.map)h.map[w]||(h.map[w]=m.map[w])}return h};return a}(),J=function(){function a(e,x){this.num=e;this.gen=x}a.prototype={toString:function(){var a=this.num+"R";0!==this.gen&&(a+=this.gen);return a}};return a}(),Q=function(){function a(){this.dict={}}a.prototype=
{has:function(a){return a.toString()in this.dict},put:function(a){this.dict[a.toString()]=!0},remove:function(a){delete this.dict[a.toString()]}};return a}(),E=function(){function a(){this.dict=Object.create(null)}a.prototype={get:function(a){return this.dict[a.toString()]},has:function(a){return a.toString()in this.dict},put:function(a,e){this.dict[a.toString()]=e},putAlias:function(a,e){this.dict[a.toString()]=this.get(e)},forEach:function(a,e){for(var D in this.dict)a.call(e,this.dict[D])},clear:function(){this.dict=
Object.create(null)}};return a}();a.Cmd=K;a.Dict=I;a.Name=H;a.Ref=J;a.RefSet=Q;a.RefSetCache=E;a.isCmd=function(a,e){return a instanceof K&&(void 0===e||a.cmd===e)};a.isDict=P;a.isName=O;a.isRef=N;a.isStream=function(a){return"object"===typeof a&&null!==a&&void 0!==a.getBytes}});(function(a,e){e(a.pdfjsCoreStream={},a.pdfjsSharedUtil,a.pdfjsCorePrimitives,a.pdfjsCoreJbig2,a.pdfjsCoreJpg,a.pdfjsCoreJpx)})(this,function(a,e,O,P,N,L){var H=e.Util,K=e.error,I=e.info,J=e.isArray,Q=e.shadow,E=e.warn,C=
O.Dict,o=P.Jbig2Image,x=N.JpegImage,D=L.JpxImage,G,h,z,R=function(){function d(c,b,i,f){this.bytes=c instanceof Uint8Array?c:new Uint8Array(c);this.pos=this.start=b||0;this.end=b+i||this.bytes.length;this.dict=f}d.prototype={get length(){return this.end-this.start},get isEmpty(){return 0===this.length},getByte:function(){return this.pos>=this.end?-1:this.bytes[this.pos++]},getUint16:function(){var c=this.getByte(),b=this.getByte();return-1===c||-1===b?-1:(c<<8)+b},getInt32:function(){var c=this.getByte(),
b=this.getByte(),d=this.getByte(),f=this.getByte();return(c<<24)+(b<<16)+(d<<8)+f},getBytes:function(c){var b=this.bytes,d=this.pos,f=this.end;if(!c)return b.subarray(d,f);c=d+c;c>f&&(c=f);this.pos=c;return b.subarray(d,c)},peekByte:function(){var c=this.getByte();this.pos--;return c},peekBytes:function(c){c=this.getBytes(c);this.pos-=c.length;return c},skip:function(c){c||(c=1);this.pos+=c},reset:function(){this.pos=this.start},moveStart:function(){this.start=this.pos},makeSubStream:function(c,b,
i){return new d(this.bytes.buffer,c,b,i)},isStream:!0};return d}(),e=function(){function d(c){for(var b=c.length,i=new Uint8Array(b),f=0;f<b;++f)i[f]=c.charCodeAt(f);R.call(this,i)}d.prototype=R.prototype;return d}(),m=function(){function d(b){this.bufferLength=this.pos=0;this.eof=!1;this.buffer=c;this.minBufferLength=512;if(b)for(;this.minBufferLength<b;)this.minBufferLength*=2}var c=new Uint8Array(0);d.prototype={get isEmpty(){for(;!this.eof&&0===this.bufferLength;)this.readBlock();return 0===this.bufferLength},
ensureBuffer:function(b){var c=this.buffer;if(b<=c.byteLength)return c;for(var d=this.minBufferLength;d<b;)d*=2;b=new Uint8Array(d);b.set(c);return this.buffer=b},getByte:function(){for(var b=this.pos;this.bufferLength<=b;){if(this.eof)return-1;this.readBlock()}return this.buffer[this.pos++]},getUint16:function(){var b=this.getByte(),c=this.getByte();return-1===b||-1===c?-1:(b<<8)+c},getInt32:function(){var b=this.getByte(),c=this.getByte(),d=this.getByte(),f=this.getByte();return(b<<24)+(c<<16)+
(d<<8)+f},getBytes:function(b){var c=this.pos;if(b){this.ensureBuffer(c+b);for(b=c+b;!this.eof&&this.bufferLength<b;)this.readBlock();var d=this.bufferLength;b>d&&(b=d)}else{for(;!this.eof;)this.readBlock();b=this.bufferLength}this.pos=b;return this.buffer.subarray(c,b)},peekByte:function(){var b=this.getByte();this.pos--;return b},peekBytes:function(b){b=this.getBytes(b);this.pos-=b.length;return b},makeSubStream:function(b,c,d){for(var f=b+c;this.bufferLength<=f&&!this.eof;)this.readBlock();return new R(this.buffer,
b,c,d)},skip:function(b){b||(b=1);this.pos+=b},reset:function(){this.pos=0},getBaseStreams:function(){return this.str&&this.str.getBaseStreams?this.str.getBaseStreams():[]}};return d}(),O=function(){function d(c){this.streams=c;m.call(this,null)}d.prototype=Object.create(m.prototype);d.prototype.readBlock=function(){var c=this.streams;if(0===c.length)this.eof=!0;else{var c=c.shift().getBytes(),b=this.bufferLength,d=b+c.length;this.ensureBuffer(d).set(c,b);this.bufferLength=d}};d.prototype.getBaseStreams=
function(){for(var c=[],b=0,d=this.streams.length;b<d;b++){var f=this.streams[b];f.getBaseStreams&&H.appendToArray(c,f.getBaseStreams())}return c};return d}(),P=function(){function d(b,c){this.str=b;this.dict=b.dict;var i=b.getByte(),n=b.getByte();(-1===i||-1===n)&&K("Invalid header in flate stream: "+i+", "+n);8!==(i&15)&&K("Unknown compression method in flate stream: "+i+", "+n);0!==((i<<8)+n)%31&&K("Bad FCHECK in flate stream: "+i+", "+n);n&32&&K("FDICT bit set in flate stream: "+i+", "+n);this.codeBuf=
this.codeSize=0;m.call(this,c)}var c=new Int32Array([16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15]),b=new Int32Array([3,4,5,6,7,8,9,10,65547,65549,65551,65553,131091,131095,131099,131103,196643,196651,196659,196667,262211,262227,262243,262259,327811,327843,327875,327907,258,258,258]),i=new Int32Array([1,2,3,4,65541,65543,131081,131085,196625,196633,262177,262193,327745,327777,393345,393409,459009,459137,524801,525057,590849,591361,657409,658433,724993,727041,794625,798721,868353,876545]),f=[new Int32Array([459008,
524368,524304,524568,459024,524400,524336,590016,459016,524384,524320,589984,524288,524416,524352,590048,459012,524376,524312,589968,459028,524408,524344,590032,459020,524392,524328,59E4,524296,524424,524360,590064,459010,524372,524308,524572,459026,524404,524340,590024,459018,524388,524324,589992,524292,524420,524356,590056,459014,524380,524316,589976,459030,524412,524348,590040,459022,524396,524332,590008,524300,524428,524364,590072,459009,524370,524306,524570,459025,524402,524338,590020,459017,
524386,524322,589988,524290,524418,524354,590052,459013,524378,524314,589972,459029,524410,524346,590036,459021,524394,524330,590004,524298,524426,524362,590068,459011,524374,524310,524574,459027,524406,524342,590028,459019,524390,524326,589996,524294,524422,524358,590060,459015,524382,524318,589980,459031,524414,524350,590044,459023,524398,524334,590012,524302,524430,524366,590076,459008,524369,524305,524569,459024,524401,524337,590018,459016,524385,524321,589986,524289,524417,524353,590050,459012,
524377,524313,589970,459028,524409,524345,590034,459020,524393,524329,590002,524297,524425,524361,590066,459010,524373,524309,524573,459026,524405,524341,590026,459018,524389,524325,589994,524293,524421,524357,590058,459014,524381,524317,589978,459030,524413,524349,590042,459022,524397,524333,590010,524301,524429,524365,590074,459009,524371,524307,524571,459025,524403,524339,590022,459017,524387,524323,589990,524291,524419,524355,590054,459013,524379,524315,589974,459029,524411,524347,590038,459021,
524395,524331,590006,524299,524427,524363,590070,459011,524375,524311,524575,459027,524407,524343,590030,459019,524391,524327,589998,524295,524423,524359,590062,459015,524383,524319,589982,459031,524415,524351,590046,459023,524399,524335,590014,524303,524431,524367,590078,459008,524368,524304,524568,459024,524400,524336,590017,459016,524384,524320,589985,524288,524416,524352,590049,459012,524376,524312,589969,459028,524408,524344,590033,459020,524392,524328,590001,524296,524424,524360,590065,459010,
524372,524308,524572,459026,524404,524340,590025,459018,524388,524324,589993,524292,524420,524356,590057,459014,524380,524316,589977,459030,524412,524348,590041,459022,524396,524332,590009,524300,524428,524364,590073,459009,524370,524306,524570,459025,524402,524338,590021,459017,524386,524322,589989,524290,524418,524354,590053,459013,524378,524314,589973,459029,524410,524346,590037,459021,524394,524330,590005,524298,524426,524362,590069,459011,524374,524310,524574,459027,524406,524342,590029,459019,
524390,524326,589997,524294,524422,524358,590061,459015,524382,524318,589981,459031,524414,524350,590045,459023,524398,524334,590013,524302,524430,524366,590077,459008,524369,524305,524569,459024,524401,524337,590019,459016,524385,524321,589987,524289,524417,524353,590051,459012,524377,524313,589971,459028,524409,524345,590035,459020,524393,524329,590003,524297,524425,524361,590067,459010,524373,524309,524573,459026,524405,524341,590027,459018,524389,524325,589995,524293,524421,524357,590059,459014,
524381,524317,589979,459030,524413,524349,590043,459022,524397,524333,590011,524301,524429,524365,590075,459009,524371,524307,524571,459025,524403,524339,590023,459017,524387,524323,589991,524291,524419,524355,590055,459013,524379,524315,589975,459029,524411,524347,590039,459021,524395,524331,590007,524299,524427,524363,590071,459011,524375,524311,524575,459027,524407,524343,590031,459019,524391,524327,589999,524295,524423,524359,590063,459015,524383,524319,589983,459031,524415,524351,590047,459023,
524399,524335,590015,524303,524431,524367,590079]),9],a=[new Int32Array([327680,327696,327688,327704,327684,327700,327692,327708,327682,327698,327690,327706,327686,327702,327694,0,327681,327697,327689,327705,327685,327701,327693,327709,327683,327699,327691,327707,327687,327703,327695,0]),5];d.prototype=Object.create(m.prototype);d.prototype.getBits=function(b){for(var c=this.str,d=this.codeSize,n=this.codeBuf,i;d<b;)-1===(i=c.getByte())&&K("Bad encoding in flate stream"),n|=i<<d,d+=8;this.codeBuf=
n>>b;this.codeSize=d-b;return n&(1<<b)-1};d.prototype.getCode=function(b){for(var c=this.str,d=b[0],n=b[1],b=this.codeSize,i=this.codeBuf,f;b<n&&!(-1===(f=c.getByte()));){i|=f<<b;b+=8}d=d[i&(1<<n)-1];c=d>>16;d&=65535;(1>c||b<c)&&K("Bad encoding in flate stream");this.codeBuf=i>>c;this.codeSize=b-c;return d};d.prototype.generateHuffmanTable=function(b){var c=b.length,d=0,n;for(n=0;n<c;++n)b[n]>d&&(d=b[n]);for(var i=1<<d,f=new Int32Array(i),a=1,k=0,l=2;a<=d;++a,k<<=1,l<<=1)for(var g=0;g<c;++g)if(b[g]===
a){var q=0,h=k;for(n=0;n<a;++n)q=q<<1|h&1,h>>=1;for(n=q;n<i;n+=l)f[n]=a<<16|g;++k}return[f,d]};d.prototype.readBlock=function(){var d,p;p=this.str;d=this.getBits(3);d&1&&(this.eof=!0);d>>=1;if(0===d){var k;-1===(k=p.getByte())&&K("Bad block header in flate stream");var n=k;-1===(k=p.getByte())&&K("Bad block header in flate stream");n|=k<<8;-1===(k=p.getByte())&&K("Bad block header in flate stream");d=k;-1===(k=p.getByte())&&K("Bad block header in flate stream");d|=k<<8;d!==(~n&65535)&&(0!==n||0!==
d)&&K("Bad uncompressed block length in flate stream");this.codeSize=this.codeBuf=0;k=this.bufferLength;d=this.ensureBuffer(k+n);var r=k+n;this.bufferLength=r;if(0===n)-1===p.peekByte()&&(this.eof=!0);else for(n=k;n<r;++n){if(-1===(k=p.getByte())){this.eof=!0;break}d[n]=k}}else{if(1===d)k=f,n=a;else if(2===d){d=this.getBits(5)+257;r=this.getBits(5)+1;p=this.getBits(4)+4;n=new Uint8Array(c.length);for(k=0;k<p;++k)n[c[k]]=this.getBits(3);n=this.generateHuffmanTable(n);k=p=0;for(var r=d+r,g=new Uint8Array(r),
F,A,h;k<r;){h=this.getCode(n);if(16===h)F=2,A=3,h=p;else if(17===h)A=F=3,h=p=0;else if(18===h)F=7,A=11,h=p=0;else{g[k++]=p=h;continue}for(F=this.getBits(F)+A;0<F--;)g[k++]=h}k=this.generateHuffmanTable(g.subarray(0,d));n=this.generateHuffmanTable(g.subarray(d,r))}else K("Unknown block type in flate stream");r=(d=this.buffer)?d.length:0;for(g=this.bufferLength;;)if(h=this.getCode(k),256>h)g+1>=r&&(d=this.ensureBuffer(g+1),r=d.length),d[g++]=h;else{if(256===h){this.bufferLength=g;break}h-=257;h=b[h];
F=h>>16;0<F&&(F=this.getBits(F));p=(h&65535)+F;h=this.getCode(n);h=i[h];F=h>>16;0<F&&(F=this.getBits(F));h=(h&65535)+F;g+p>=r&&(d=this.ensureBuffer(g+p),r=d.length);for(F=0;F<p;++F,++g)d[g]=d[g-h]}}};return d}(),N=function(){function d(c,b,i){var f=this.predictor=i.get("Predictor")||1;if(1>=f)return c;2!==f&&(10>f||15<f)&&K("Unsupported predictor: "+f);this.readBlock=2===f?this.readBlockTiff:this.readBlockPng;this.str=c;this.dict=c.dict;c=this.colors=i.get("Colors")||1;f=this.bits=i.get("BitsPerComponent")||
8;i=this.columns=i.get("Columns")||1;this.pixBytes=c*f+7>>3;this.rowBytes=i*c*f+7>>3;m.call(this,b);return this}d.prototype=Object.create(m.prototype);d.prototype.readBlockTiff=function(){var c=this.rowBytes,b=this.bufferLength,d=this.ensureBuffer(b+c),f=this.bits,a=this.colors,j=this.str.getBytes(c);this.eof=!j.length;if(!this.eof){var p=0,k=0,n=0,r=0,g=b;if(1===f)for(b=0;b<c;++b)f=j[b],p=p<<8|f,d[g++]=(f^p>>a)&255,p&=65535;else if(8===f){for(b=0;b<a;++b)d[g++]=j[b];for(;b<c;++b)d[g]=d[g-a]+j[b],
g++}else{for(var g=new Uint8Array(a+1),h=(1<<f)-1,A=0,e=b,s=this.columns,b=0;b<s;++b)for(var m=0;m<a;++m)n<f&&(p=p<<8|j[A++]&255,n+=8),g[m]=g[m]+(p>>n-f)&h,n-=f,k=k<<f|g[m],r+=f,8<=r&&(d[e++]=k>>r-8&255,r-=8);0<r&&(d[e++]=(k<<8-r)+(p&(1<<8-r)-1))}this.bufferLength+=c}};d.prototype.readBlockPng=function(){var c=this.rowBytes,b=this.pixBytes,d=this.str.getByte(),f=this.str.getBytes(c);this.eof=!f.length;if(!this.eof){var a=this.bufferLength,j=this.ensureBuffer(a+c),p=j.subarray(a-c,a);0===p.length&&
(p=new Uint8Array(c));var k,n;switch(d){case 0:for(d=0;d<c;++d)j[a++]=f[d];break;case 1:for(d=0;d<b;++d)j[a++]=f[d];for(;d<c;++d)j[a]=j[a-b]+f[d]&255,a++;break;case 2:for(d=0;d<c;++d)j[a++]=p[d]+f[d]&255;break;case 3:for(d=0;d<b;++d)j[a++]=(p[d]>>1)+f[d];for(;d<c;++d)j[a]=(p[d]+j[a-b]>>1)+f[d]&255,a++;break;case 4:for(d=0;d<b;++d)k=p[d],n=f[d],j[a++]=k+n;for(;d<c;++d){k=p[d];var r=p[d-b],g=j[a-b];n=g+k-r;var h=n-g;0>h&&(h=-h);var A=n-k;0>A&&(A=-A);var e=n-r;0>e&&(e=-e);n=f[d];h<=A&&h<=e?j[a++]=g+
n:A<=e?j[a++]=k+n:j[a++]=r+n}break;default:K("Unsupported predictor: "+d)}this.bufferLength+=c}};return d}(),L=function(){function d(c,b,f){for(var a;-1!==(a=c.getByte());)if(255===a){c.skip(-1);break}this.stream=c;this.maybeLength=b;this.dict=f;m.call(this,b)}d.prototype=Object.create(m.prototype);Object.defineProperty(d.prototype,"bytes",{get:function(){return Q(this,"bytes",this.stream.getBytes(this.maybeLength))},configurable:!0});d.prototype.ensureBuffer=function(){if(!this.bufferLength)try{var c=
new x;if(this.forceRGB&&this.dict&&J(this.dict.get("Decode"))){for(var b=this.dict.get("Decode"),d=this.dict.get("BitsPerComponent")||8,f=b.length,a=new Int32Array(f),j=!1,d=(1<<d)-1,p=0;p<f;p+=2)if(a[p]=256*(b[p+1]-b[p])|0,a[p+1]=b[p]*d|0,256!==a[p]||0!==a[p+1])j=!0;j&&(c.decodeTransform=a)}c.parse(this.bytes);var k=c.getData(this.drawWidth,this.drawHeight,this.forceRGB);this.buffer=k;this.bufferLength=k.length;this.eof=!0}catch(n){K("JPEG error: "+n)}};d.prototype.getBytes=function(){this.ensureBuffer();
return this.buffer};d.prototype.getIR=function(){return PDFJS.createObjectURL(this.bytes,"image/jpeg")};d.prototype.isNativelySupported=function(c,b){var d=z.parse(this.dict.get("ColorSpace","CS"),c,b);return("DeviceGray"===d.name||"DeviceRGB"===d.name)&&d.isDefaultDecode(this.dict.get("Decode","D"))};d.prototype.isNativelyDecodable=function(c,b){var d=z.parse(this.dict.get("ColorSpace","CS"),c,b);return(1===d.numComps||3===d.numComps)&&d.isDefaultDecode(this.dict.get("Decode","D"))};return d}(),
w=function(){function d(c,b,f){this.stream=c;this.maybeLength=b;this.dict=f;m.call(this,b)}d.prototype=Object.create(m.prototype);Object.defineProperty(d.prototype,"bytes",{get:function(){return Q(this,"bytes",this.stream.getBytes(this.maybeLength))},configurable:!0});d.prototype.ensureBuffer=function(){if(!this.bufferLength){var c=new D;c.parse(this.bytes);var b=c.width,d=c.height,f=c.componentsCount,a=c.tiles.length;if(1===a)this.buffer=c.tiles[0].items;else{for(var d=new Uint8Array(b*d*f),j=0;j<
a;j++)for(var p=c.tiles[j],k=p.height,n=p.items,r=0,g=(b*p.top+p.left)*f,h=b*f,p=p.width*f,A=0;A<k;A++){var e=n.subarray(r,r+p);d.set(e,g);r+=p;g+=h}this.buffer=d}this.bufferLength=this.buffer.length;this.eof=!0}};return d}(),t=function(){function d(c,b,f){this.stream=c;this.maybeLength=b;this.dict=f;m.call(this,b)}d.prototype=Object.create(m.prototype);Object.defineProperty(d.prototype,"bytes",{get:function(){return Q(this,"bytes",this.stream.getBytes(this.maybeLength))},configurable:!0});d.prototype.ensureBuffer=
function(){if(!this.bufferLength){var c=new o,b=[],d=this.dict.xref,f=d.fetchIfRef(this.dict.get("DecodeParms"));J(f)&&(1<f.length&&E("JBIG2 - 'DecodeParms' array with multiple elements not supported."),f=d.fetchIfRef(f[0]));f&&f.has("JBIG2Globals")&&(d=f.get("JBIG2Globals").getBytes(),b.push({data:d,start:0,end:d.length}));b.push({data:this.bytes,start:0,end:this.bytes.length});c=c.parseChunks(b);b=c.length;for(d=0;d<b;d++)c[d]^=255;this.buffer=c;this.bufferLength=b;this.eof=!0}};return d}(),u=function(){function d(c,
b,f){this.str=c;this.dict=c.dict;this.decrypt=f;this.nextChunk=null;this.initialized=!1;m.call(this,b)}d.prototype=Object.create(m.prototype);d.prototype.readBlock=function(){var c;this.initialized?c=this.nextChunk:(c=this.str.getBytes(512),this.initialized=!0);if(!c||0===c.length)this.eof=!0;else{this.nextChunk=this.str.getBytes(512);var b=this.decrypt;c=b(c,!(this.nextChunk&&0<this.nextChunk.length));var b=this.bufferLength,d,f=c.length,a=this.ensureBuffer(b+f);for(d=0;d<f;d++)a[b++]=c[d];this.bufferLength=
b}};return d}(),y=function(){function d(c,b){this.str=c;this.dict=c.dict;this.input=new Uint8Array(5);b&&(b*=0.8);m.call(this,b)}d.prototype=Object.create(m.prototype);d.prototype.readBlock=function(){for(var c=this.str,b=c.getByte();h.isSpace(b);)b=c.getByte();if(-1===b||126===b)this.eof=!0;else{var d=this.bufferLength,f;if(122===b){c=this.ensureBuffer(d+4);for(f=0;4>f;++f)c[d+f]=0;this.bufferLength+=4}else{var a=this.input;a[0]=b;for(f=1;5>f;++f){for(b=c.getByte();h.isSpace(b);)b=c.getByte();a[f]=
b;if(-1===b||126===b)break}c=this.ensureBuffer(d+f-1);this.bufferLength+=f-1;if(5>f){for(;5>f;++f)a[f]=117;this.eof=!0}for(f=b=0;5>f;++f)b=85*b+(a[f]-33);for(f=3;0<=f;--f)c[d+f]=b&255,b>>=8}}};return d}(),s=function(){function d(c,b){this.str=c;this.dict=c.dict;this.firstDigit=-1;b&&(b*=0.5);m.call(this,b)}d.prototype=Object.create(m.prototype);d.prototype.readBlock=function(){var c=this.str.getBytes(8E3);if(c.length){for(var b=this.ensureBuffer(this.bufferLength+(c.length+1>>1)),d=this.bufferLength,
f=this.firstDigit,a=0,j=c.length;a<j;a++){var p=c[a];if(48<=p&&57>=p)p&=15;else if(65<=p&&70>=p||97<=p&&102>=p)p=(p&15)+9;else if(62===p){this.eof=!0;break}else continue;0>f?f=p:(b[d++]=f<<4|p,f=-1)}0<=f&&this.eof&&(b[d++]=f<<4,f=-1);this.firstDigit=f;this.bufferLength=d}else this.eof=!0};return d}(),M=function(){function d(c,b){this.str=c;this.dict=c.dict;m.call(this,b)}d.prototype=Object.create(m.prototype);d.prototype.readBlock=function(){var c=this.str.getBytes(2);if(!c||2>c.length||128===c[0])this.eof=
!0;else{var b,d=this.bufferLength,f=c[0];if(128>f)b=this.ensureBuffer(d+f+1),b[d++]=c[1],0<f&&(c=this.str.getBytes(f),b.set(c,d),d+=f);else{f=257-f;c=c[1];b=this.ensureBuffer(d+f+1);for(var a=0;a<f;a++)b[d++]=c}this.bufferLength=d}};return d}(),g=function(){function d(b,c,f){this.str=b;this.dict=b.dict;f=f||C.empty;this.encoding=f.get("K")||0;this.eoline=f.get("EndOfLine")||!1;this.byteAlign=f.get("EncodedByteAlign")||!1;this.columns=f.get("Columns")||1728;this.rows=f.get("Rows")||0;b=f.get("EndOfBlock");
if(null===b||void 0===b)b=!0;this.eoblock=b;this.black=f.get("BlackIs1")||!1;this.codingLine=new Uint32Array(this.columns+1);this.refLine=new Uint32Array(this.columns+2);this.codingLine[0]=this.columns;this.row=this.codingPos=0;this.nextLine2D=0>this.encoding;for(this.outputBits=this.inputBuf=this.inputBits=0;0===(f=this.lookBits(12));)this.eatBits(1);1===f&&this.eatBits(12);0<this.encoding&&(this.nextLine2D=!this.lookBits(1),this.eatBits(1));m.call(this,c)}var c=[[-1,-1],[-1,-1],[7,8],[7,7],[6,6],
[6,6],[6,5],[6,5],[4,0],[4,0],[4,0],[4,0],[4,0],[4,0],[4,0],[4,0],[3,1],[3,1],[3,1],[3,1],[3,1],[3,1],[3,1],[3,1],[3,1],[3,1],[3,1],[3,1],[3,1],[3,1],[3,1],[3,1],[3,4],[3,4],[3,4],[3,4],[3,4],[3,4],[3,4],[3,4],[3,4],[3,4],[3,4],[3,4],[3,4],[3,4],[3,4],[3,4],[3,3],[3,3],[3,3],[3,3],[3,3],[3,3],[3,3],[3,3],[3,3],[3,3],[3,3],[3,3],[3,3],[3,3],[3,3],[3,3],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,
2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2],[1,2]],b=[[-1,-1],[12,-2],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[11,1792],[11,1792],[12,1984],[12,2048],[12,2112],[12,2176],[12,2240],[12,2304],[11,1856],[11,1856],[11,1920],[11,1920],[12,2368],[12,
2432],[12,2496],[12,2560]],f=[[-1,-1],[-1,-1],[-1,-1],[-1,-1],[8,29],[8,29],[8,30],[8,30],[8,45],[8,45],[8,46],[8,46],[7,22],[7,22],[7,22],[7,22],[7,23],[7,23],[7,23],[7,23],[8,47],[8,47],[8,48],[8,48],[6,13],[6,13],[6,13],[6,13],[6,13],[6,13],[6,13],[6,13],[7,20],[7,20],[7,20],[7,20],[8,33],[8,33],[8,34],[8,34],[8,35],[8,35],[8,36],[8,36],[8,37],[8,37],[8,38],[8,38],[7,19],[7,19],[7,19],[7,19],[8,31],[8,31],[8,32],[8,32],[6,1],[6,1],[6,1],[6,1],[6,1],[6,1],[6,1],[6,1],[6,12],[6,12],[6,12],[6,12],
[6,12],[6,12],[6,12],[6,12],[8,53],[8,53],[8,54],[8,54],[7,26],[7,26],[7,26],[7,26],[8,39],[8,39],[8,40],[8,40],[8,41],[8,41],[8,42],[8,42],[8,43],[8,43],[8,44],[8,44],[7,21],[7,21],[7,21],[7,21],[7,28],[7,28],[7,28],[7,28],[8,61],[8,61],[8,62],[8,62],[8,63],[8,63],[8,0],[8,0],[8,320],[8,320],[8,384],[8,384],[5,10],[5,10],[5,10],[5,10],[5,10],[5,10],[5,10],[5,10],[5,10],[5,10],[5,10],[5,10],[5,10],[5,10],[5,10],[5,10],[5,11],[5,11],[5,11],[5,11],[5,11],[5,11],[5,11],[5,11],[5,11],[5,11],[5,11],[5,
11],[5,11],[5,11],[5,11],[5,11],[7,27],[7,27],[7,27],[7,27],[8,59],[8,59],[8,60],[8,60],[9,1472],[9,1536],[9,1600],[9,1728],[7,18],[7,18],[7,18],[7,18],[7,24],[7,24],[7,24],[7,24],[8,49],[8,49],[8,50],[8,50],[8,51],[8,51],[8,52],[8,52],[7,25],[7,25],[7,25],[7,25],[8,55],[8,55],[8,56],[8,56],[8,57],[8,57],[8,58],[8,58],[6,192],[6,192],[6,192],[6,192],[6,192],[6,192],[6,192],[6,192],[6,1664],[6,1664],[6,1664],[6,1664],[6,1664],[6,1664],[6,1664],[6,1664],[8,448],[8,448],[8,512],[8,512],[9,704],[9,768],
[8,640],[8,640],[8,576],[8,576],[9,832],[9,896],[9,960],[9,1024],[9,1088],[9,1152],[9,1216],[9,1280],[9,1344],[9,1408],[7,256],[7,256],[7,256],[7,256],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,2],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,3],[4,
3],[4,3],[4,3],[4,3],[4,3],[4,3],[5,128],[5,128],[5,128],[5,128],[5,128],[5,128],[5,128],[5,128],[5,128],[5,128],[5,128],[5,128],[5,128],[5,128],[5,128],[5,128],[5,8],[5,8],[5,8],[5,8],[5,8],[5,8],[5,8],[5,8],[5,8],[5,8],[5,8],[5,8],[5,8],[5,8],[5,8],[5,8],[5,9],[5,9],[5,9],[5,9],[5,9],[5,9],[5,9],[5,9],[5,9],[5,9],[5,9],[5,9],[5,9],[5,9],[5,9],[5,9],[6,16],[6,16],[6,16],[6,16],[6,16],[6,16],[6,16],[6,16],[6,17],[6,17],[6,17],[6,17],[6,17],[6,17],[6,17],[6,17],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],
[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,4],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[4,5],[6,14],[6,14],[6,14],[6,14],[6,14],[6,14],[6,14],[6,14],[6,15],[6,15],[6,15],[6,15],[6,15],[6,15],[6,15],[6,15],[5,64],[5,64],[5,64],[5,64],[5,64],[5,64],
[5,64],[5,64],[5,64],[5,64],[5,64],[5,64],[5,64],[5,64],[5,64],[5,64],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,6],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7],[4,7]],a=[[-1,-1],[-1,-1],[12,-2],[12,-2],[-1,-1],[-1,
-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[-1,-1],[11,1792],[11,1792],[11,1792],[11,1792],[12,1984],[12,1984],[12,2048],[12,2048],[12,2112],[12,2112],[12,2176],[12,2176],[12,2240],[12,2240],[12,2304],[12,2304],[11,1856],[11,1856],[11,1856],[11,1856],[11,1920],[11,1920],[11,1920],[11,1920],[12,2368],[12,2368],[12,2432],[12,2432],[12,2496],
[12,2496],[12,2560],[12,2560],[10,18],[10,18],[10,18],[10,18],[10,18],[10,18],[10,18],[10,18],[12,52],[12,52],[13,640],[13,704],[13,768],[13,832],[12,55],[12,55],[12,56],[12,56],[13,1280],[13,1344],[13,1408],[13,1472],[12,59],[12,59],[12,60],[12,60],[13,1536],[13,1600],[11,24],[11,24],[11,24],[11,24],[11,25],[11,25],[11,25],[11,25],[13,1664],[13,1728],[12,320],[12,320],[12,384],[12,384],[12,448],[12,448],[13,512],[13,576],[12,53],[12,53],[12,54],[12,54],[13,896],[13,960],[13,1024],[13,1088],[13,1152],
[13,1216],[10,64],[10,64],[10,64],[10,64],[10,64],[10,64],[10,64],[10,64]],g=[[8,13],[8,13],[8,13],[8,13],[8,13],[8,13],[8,13],[8,13],[8,13],[8,13],[8,13],[8,13],[8,13],[8,13],[8,13],[8,13],[11,23],[11,23],[12,50],[12,51],[12,44],[12,45],[12,46],[12,47],[12,57],[12,58],[12,61],[12,256],[10,16],[10,16],[10,16],[10,16],[10,17],[10,17],[10,17],[10,17],[12,48],[12,49],[12,62],[12,63],[12,30],[12,31],[12,32],[12,33],[12,40],[12,41],[11,22],[11,22],[8,14],[8,14],[8,14],[8,14],[8,14],[8,14],[8,14],[8,14],
[8,14],[8,14],[8,14],[8,14],[8,14],[8,14],[8,14],[8,14],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,10],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],[7,11],
[9,15],[9,15],[9,15],[9,15],[9,15],[9,15],[9,15],[9,15],[12,128],[12,192],[12,26],[12,27],[12,28],[12,29],[11,19],[11,19],[11,20],[11,20],[12,34],[12,35],[12,36],[12,37],[12,38],[12,39],[11,21],[11,21],[12,42],[12,43],[10,0],[10,0],[10,0],[10,0],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12],[7,12]],j=[[-1,-1],[-1,-1],[-1,-1],[-1,
-1],[6,9],[6,8],[5,7],[5,7],[4,6],[4,6],[4,6],[4,6],[4,5],[4,5],[4,5],[4,5],[3,1],[3,1],[3,1],[3,1],[3,1],[3,1],[3,1],[3,1],[3,4],[3,4],[3,4],[3,4],[3,4],[3,4],[3,4],[3,4],[2,3],[2,3],[2,3],[2,3],[2,3],[2,3],[2,3],[2,3],[2,3],[2,3],[2,3],[2,3],[2,3],[2,3],[2,3],[2,3],[2,2],[2,2],[2,2],[2,2],[2,2],[2,2],[2,2],[2,2],[2,2],[2,2],[2,2],[2,2],[2,2],[2,2],[2,2],[2,2]];d.prototype=Object.create(m.prototype);d.prototype.readBlock=function(){for(;!this.eof;){var b=this.lookChar();this.ensureBuffer(this.bufferLength+
1);this.buffer[this.bufferLength++]=b}};d.prototype.addPixels=function(b,c){var d=this.codingLine,f=this.codingPos;b>d[f]&&(b>this.columns&&(I("row is wrong length"),this.err=!0,b=this.columns),f&1^c&&++f,d[f]=b);this.codingPos=f};d.prototype.addPixelsNeg=function(b,c){var d=this.codingLine,f=this.codingPos;if(b>d[f])b>this.columns&&(I("row is wrong length"),this.err=!0,b=this.columns),f&1^c&&++f,d[f]=b;else if(b<d[f]){0>b&&(I("invalid code"),this.err=!0,b=0);for(;0<f&&b<d[f-1];)--f;d[f]=b}this.codingPos=
f};d.prototype.lookChar=function(){var b=this.refLine,c=this.codingLine,d=this.columns,f,a,j;if(0===this.outputBits){if(this.eof)return null;this.err=!1;var i,g;if(this.nextLine2D){for(f=0;c[f]<d;++f)b[f]=c[f];b[f++]=d;b[f]=d;for(a=f=this.codingPos=c[0]=0;c[this.codingPos]<d;)switch(j=this.getTwoDimCode(),j){case 0:this.addPixels(b[f+1],a);b[f+1]<d&&(f+=2);break;case 1:j=i=0;if(a){do j+=g=this.getBlackCode();while(64<=g);do i+=g=this.getWhiteCode();while(64<=g)}else{do j+=g=this.getWhiteCode();while(64<=
g);do i+=g=this.getBlackCode();while(64<=g)}this.addPixels(c[this.codingPos]+j,a);for(c[this.codingPos]<d&&this.addPixels(c[this.codingPos]+i,a^1);b[f]<=c[this.codingPos]&&b[f]<d;)f+=2;break;case 7:this.addPixels(b[f]+3,a);a^=1;if(c[this.codingPos]<d)for(++f;b[f]<=c[this.codingPos]&&b[f]<d;)f+=2;break;case 5:this.addPixels(b[f]+2,a);a^=1;if(c[this.codingPos]<d)for(++f;b[f]<=c[this.codingPos]&&b[f]<d;)f+=2;break;case 3:this.addPixels(b[f]+1,a);a^=1;if(c[this.codingPos]<d)for(++f;b[f]<=c[this.codingPos]&&
b[f]<d;)f+=2;break;case 2:this.addPixels(b[f],a);a^=1;if(c[this.codingPos]<d)for(++f;b[f]<=c[this.codingPos]&&b[f]<d;)f+=2;break;case 8:this.addPixelsNeg(b[f]-3,a);a^=1;if(c[this.codingPos]<d)for(0<f?--f:++f;b[f]<=c[this.codingPos]&&b[f]<d;)f+=2;break;case 6:this.addPixelsNeg(b[f]-2,a);a^=1;if(c[this.codingPos]<d)for(0<f?--f:++f;b[f]<=c[this.codingPos]&&b[f]<d;)f+=2;break;case 4:this.addPixelsNeg(b[f]-1,a);a^=1;if(c[this.codingPos]<d)for(0<f?--f:++f;b[f]<=c[this.codingPos]&&b[f]<d;)f+=2;break;case G:this.addPixels(d,
0);this.eof=!0;break;default:I("bad 2d code"),this.addPixels(d,0),this.err=!0}}else for(a=this.codingPos=c[0]=0;c[this.codingPos]<d;){j=0;if(a){do j+=g=this.getBlackCode();while(64<=g)}else{do j+=g=this.getWhiteCode();while(64<=g)}this.addPixels(c[this.codingPos]+j,a);a^=1}b=!1;this.byteAlign&&(this.inputBits&=-8);if(!this.eoblock&&this.row===this.rows-1)this.eof=!0;else{j=this.lookBits(12);if(this.eoline)for(;j!==G&&1!==j;)this.eatBits(1),j=this.lookBits(12);else for(;0===j;)this.eatBits(1),j=this.lookBits(12);
1===j?(this.eatBits(12),b=!0):j===G&&(this.eof=!0)}!this.eof&&0<this.encoding&&(this.nextLine2D=!this.lookBits(1),this.eatBits(1));if(this.eoblock&&b&&this.byteAlign){if(j=this.lookBits(12),1===j){this.eatBits(12);0<this.encoding&&(this.lookBits(1),this.eatBits(1));if(0<=this.encoding)for(f=0;4>f;++f)j=this.lookBits(12),1!==j&&I("bad rtc code: "+j),this.eatBits(12),0<this.encoding&&(this.lookBits(1),this.eatBits(1));this.eof=!0}}else if(this.err&&this.eoline){for(;;){j=this.lookBits(13);if(j===G)return this.eof=
!0,null;if(1===j>>1)break;this.eatBits(1)}this.eatBits(12);0<this.encoding&&(this.eatBits(1),this.nextLine2D=!(j&1))}this.outputBits=0<c[0]?c[this.codingPos=0]:c[this.codingPos=1];this.row++}if(8<=this.outputBits)b=this.codingPos&1?0:255,this.outputBits-=8,0===this.outputBits&&c[this.codingPos]<d&&(this.codingPos++,this.outputBits=c[this.codingPos]-c[this.codingPos-1]);else{j=8;b=0;do this.outputBits>j?(b<<=j,this.codingPos&1||(b|=255>>8-j),this.outputBits-=j,j=0):(b<<=this.outputBits,this.codingPos&
1||(b|=255>>8-this.outputBits),j-=this.outputBits,this.outputBits=0,c[this.codingPos]<d?(this.codingPos++,this.outputBits=c[this.codingPos]-c[this.codingPos-1]):0<j&&(b<<=j,j=0));while(j)}this.black&&(b^=255);return b};d.prototype.findTableCode=function(b,c,d,f){for(f=f||0;b<=c;++b){var a=this.lookBits(b);if(a===G)return[!0,1,!1];b<c&&(a<<=c-b);if(!f||a>=f)if(a=d[a-f],a[0]===b)return this.eatBits(b),[!0,a[1],!0]}return[!1,0,!1]};d.prototype.getTwoDimCode=function(){var b=0;if(this.eoblock){if(b=this.lookBits(7),
(b=c[b])&&0<b[0])return this.eatBits(b[0]),b[1]}else if(b=this.findTableCode(1,7,c),b[0]&&b[2])return b[1];I("Bad two dim code");return G};d.prototype.getWhiteCode=function(){var c=0;if(this.eoblock){c=this.lookBits(12);if(c===G)return 1;c=0===c>>5?b[c]:f[c>>3];if(0<c[0])return this.eatBits(c[0]),c[1]}else{c=this.findTableCode(1,9,f);if(c[0])return c[1];c=this.findTableCode(11,12,b);if(c[0])return c[1]}I("bad white code");this.eatBits(1);return 1};d.prototype.getBlackCode=function(){var b;if(this.eoblock){b=
this.lookBits(13);if(b===G)return 1;b=0===b>>7?a[b]:0===b>>9&&0!==b>>7?g[(b>>1)-64]:j[b>>7];if(0<b[0])return this.eatBits(b[0]),b[1]}else{b=this.findTableCode(2,6,j);if(b[0])return b[1];b=this.findTableCode(7,12,g,64);if(b[0])return b[1];b=this.findTableCode(10,13,a);if(b[0])return b[1]}I("bad black code");this.eatBits(1);return 1};d.prototype.lookBits=function(b){for(var c;this.inputBits<b;){if(-1===(c=this.str.getByte()))return 0===this.inputBits?G:this.inputBuf<<b-this.inputBits&65535>>16-b;this.inputBuf=
(this.inputBuf<<8)+c;this.inputBits+=8}return this.inputBuf>>this.inputBits-b&65535>>16-b};d.prototype.eatBits=function(b){if(0>(this.inputBits-=b))this.inputBits=0};return d}(),f=function(){function d(c,b,f){this.str=c;this.dict=c.dict;this.bitsCached=this.cachedData=0;c={earlyChange:f,codeLength:9,nextCode:258,dictionaryValues:new Uint8Array(4096),dictionaryLengths:new Uint16Array(4096),dictionaryPrevCodes:new Uint16Array(4096),currentSequence:new Uint8Array(4096),currentSequenceLength:0};for(f=
0;256>f;++f)c.dictionaryValues[f]=f,c.dictionaryLengths[f]=1;this.lzwState=c;m.call(this,b)}d.prototype=Object.create(m.prototype);d.prototype.readBits=function(c){for(var b=this.bitsCached,d=this.cachedData;b<c;){var f=this.str.getByte();if(-1===f)return this.eof=!0,null;d=d<<8|f;b+=8}this.bitsCached=b-=c;this.cachedData=d;this.lastCode=null;return d>>>b&(1<<c)-1};d.prototype.readBlock=function(){var c=1024,b,d,f,a=this.lzwState;if(a){var j=a.earlyChange,p=a.nextCode,g=a.dictionaryValues,n=a.dictionaryLengths,
k=a.dictionaryPrevCodes,B=a.codeLength,h=a.prevCode,A=a.currentSequence,e=a.currentSequenceLength,s=0,m=this.bufferLength,u=this.ensureBuffer(this.bufferLength+c);for(b=0;512>b;b++){var t=this.readBits(B),w=0<e;if(256>t)A[0]=t,e=1;else if(258<=t)if(t<p){e=n[t];for(d=e-1,f=t;0<=d;d--)A[d]=g[f],f=k[f]}else A[e++]=A[0];else if(256===t){B=9;p=258;e=0;continue}else{this.eof=!0;delete this.lzwState;break}w&&(k[p]=h,n[p]=n[h]+1,g[p]=A[0],p++,B=p+j&p+j-1?B:Math.min(Math.log(p+j)/0.6931471805599453+1,12)|
0);h=t;s+=e;if(c<s){do c+=512;while(c<s);u=this.ensureBuffer(this.bufferLength+c)}for(d=0;d<e;d++)u[m++]=A[d]}a.nextCode=p;a.codeLength=B;a.prevCode=h;a.currentSequenceLength=e;this.bufferLength=m}};return d}(),d=function(){function d(){R.call(this,new Uint8Array(0))}d.prototype=R.prototype;return d}();a._setCoreParser=function(d){G=d.EOF;h=d.Lexer};a._setCoreColorSpace=function(d){z=d.ColorSpace};a.Ascii85Stream=y;a.AsciiHexStream=s;a.CCITTFaxStream=g;a.DecryptStream=u;a.DecodeStream=m;a.FlateStream=
P;a.Jbig2Stream=t;a.JpegStream=L;a.JpxStream=w;a.NullStream=d;a.PredictorStream=N;a.RunLengthStream=M;a.Stream=R;a.StreamsSequenceStream=O;a.StringStream=e;a.LZWStream=f});(function(a,e){e(a.pdfjsCoreCrypto={},a.pdfjsSharedUtil,a.pdfjsCorePrimitives,a.pdfjsCoreStream)})(this,function(a,e,O,P){var N=e.PasswordException,L=e.PasswordResponses,H=e.bytesToString,K=e.error,I=e.isInt,J=e.stringToBytes,Q=e.utf8StringToString,E=e.warn,C=O.Name,o=O.isName,x=O.isDict,D=P.DecryptStream,G=function(){function f(d){this.b=
this.a=0;var f=new Uint8Array(256),c,b=0,a,g=d.length;for(c=0;256>c;++c)f[c]=c;for(c=0;256>c;++c)a=f[c],b=b+a+d[c%g]&255,f[c]=f[b],f[b]=a;this.s=f}f.prototype={encryptBlock:function(d){var f,c=d.length,b,a,g=this.a,h=this.b,j=this.s,p=new Uint8Array(c);for(f=0;f<c;++f)g=g+1&255,b=j[g],h=h+b&255,a=j[h],j[g]=a,j[h]=b,p[f]=d[f]^j[b+a&255];this.a=g;this.b=h;return p}};f.prototype.decryptBlock=f.prototype.encryptBlock;return f}(),h=function(){var f=new Uint8Array([7,12,17,22,7,12,17,22,7,12,17,22,7,12,
17,22,5,9,14,20,5,9,14,20,5,9,14,20,5,9,14,20,4,11,16,23,4,11,16,23,4,11,16,23,4,11,16,23,6,10,15,21,6,10,15,21,6,10,15,21,6,10,15,21]),d=new Int32Array([-680876936,-389564586,606105819,-1044525330,-176418897,1200080426,-1473231341,-45705983,1770035416,-1958414417,-42063,-1990404162,1804603682,-40341101,-1502002290,1236535329,-165796510,-1069501632,643717713,-373897302,-701558691,38016083,-660478335,-405537848,568446438,-1019803690,-187363961,1163531501,-1444681467,-51403784,1735328473,-1926607734,
-378558,-2022574463,1839030562,-35309556,-1530992060,1272893353,-155497632,-1094730640,681279174,-358537222,-722521979,76029189,-640364487,-421815835,530742520,-995338651,-198630844,1126891415,-1416354905,-57434055,1700485571,-1894986606,-1051523,-2054922799,1873313359,-30611744,-1560198380,1309151649,-145523070,-1120210379,718787259,-343485551]);return function(a,c,b){var g=1732584193,l=-271733879,h=-1732584194,j=271733878,p=b+72&-64,v=new Uint8Array(p),n;for(n=0;n<b;++n)v[n]=a[c++];v[n++]=128;for(a=
p-8;n<a;)v[n++]=0;v[n++]=b<<3&255;v[n++]=b>>5&255;v[n++]=b>>13&255;v[n++]=b>>21&255;v[n++]=b>>>29&255;v[n++]=0;v[n++]=0;v[n++]=0;a=new Int32Array(16);for(n=0;n<p;){for(b=0;16>b;++b,n+=4)a[b]=v[n]|v[n+1]<<8|v[n+2]<<16|v[n+3]<<24;for(var r=g,c=l,B=h,F=j,A,e,b=0;64>b;++b){16>b?(A=c&B|~c&F,e=b):32>b?(A=F&c|~F&B,e=5*b+1&15):48>b?(A=c^B^F,e=3*b+5&15):(A=B^(c|~F),e=7*b&15);var s=F,r=r+A+d[b]+a[e]|0;A=f[b];F=B;B=c;c=c+(r<<A|r>>>32-A)|0;r=s}g=g+r|0;l=l+c|0;h=h+B|0;j=j+F|0}return new Uint8Array([g&255,g>>8&
255,g>>16&255,g>>>24&255,l&255,l>>8&255,l>>16&255,l>>>24&255,h&255,h>>8&255,h>>16&255,h>>>24&255,j&255,j>>8&255,j>>16&255,j>>>24&255])}}(),z=function(){function f(d,f){this.high=d|0;this.low=f|0}f.prototype={and:function(d){this.high&=d.high;this.low&=d.low},xor:function(d){this.high^=d.high;this.low^=d.low},or:function(d){this.high|=d.high;this.low|=d.low},shiftRight:function(d){32<=d?(this.low=this.high>>>d-32|0,this.high=0):(this.low=this.low>>>d|this.high<<32-d,this.high=this.high>>>d|0)},shiftLeft:function(d){32<=
d?(this.high=this.low<<d-32,this.low=0):(this.high=this.high<<d|this.low>>>32-d,this.low<<=d)},rotateRight:function(d){var f,c;d&32?(c=this.low,f=this.high):(f=this.low,c=this.high);d&=31;this.low=f>>>d|c<<32-d;this.high=c>>>d|f<<32-d},not:function(){this.high=~this.high;this.low=~this.low},add:function(d){var f=(this.low>>>0)+(d.low>>>0),d=(this.high>>>0)+(d.high>>>0);4294967295<f&&(d+=1);this.low=f|0;this.high=d|0},copyTo:function(d,f){d[f]=this.high>>>24&255;d[f+1]=this.high>>16&255;d[f+2]=this.high>>
8&255;d[f+3]=this.high&255;d[f+4]=this.low>>>24&255;d[f+5]=this.low>>16&255;d[f+6]=this.low>>8&255;d[f+7]=this.low&255},assign:function(d){this.high=d.high;this.low=d.low}};return f}(),R=function(){function f(d,c){return d>>>c|d<<32-c}var d=[1116352408,1899447441,3049323471,3921009573,961987163,1508970993,2453635748,2870763221,3624381080,310598401,607225278,1426881987,1925078388,2162078206,2614888103,3248222580,3835390401,4022224774,264347078,604807628,770255983,1249150122,1555081692,1996064986,2554220882,
2821834349,2952996808,3210313671,3336571891,3584528711,113926993,338241895,666307205,773529912,1294757372,1396182291,1695183700,1986661051,2177026350,2456956037,2730485921,2820302411,3259730800,3345764771,3516065817,3600352804,4094571909,275423344,430227734,506948616,659060556,883997877,958139571,1322822218,1537002063,1747873779,1955562222,2024104815,2227730452,2361852424,2428436474,2756734187,3204031479,3329325298];return function(a,c,b){var g=1779033703,l=3144134277,h=1013904242,j=2773480762,p=
1359893119,v=2600822924,n=528734635,r=1541459225,B=64*Math.ceil((b+9)/64),F=new Uint8Array(B),A;for(A=0;A<b;++A)F[A]=a[c++];F[A++]=128;for(a=B-8;A<a;)F[A++]=0;F[A++]=0;F[A++]=0;F[A++]=0;F[A++]=b>>>29&255;F[A++]=b>>21&255;F[A++]=b>>13&255;F[A++]=b>>5&255;F[A++]=b<<3&255;a=new Uint32Array(64);for(A=0;A<B;){for(b=0;16>b;++b)a[b]=F[A]<<24|F[A+1]<<16|F[A+2]<<8|F[A+3],A+=4;for(b=16;64>b;++b)a[b]=(f(a[b-2],17)^f(a[b-2],19)^a[b-2]>>>10)+a[b-7]+(f(a[b-15],7)^f(a[b-15],18)^a[b-15]>>>3)+a[b-16]|0;for(var c=
g,e=l,s=h,m=j,t=p,u=v,w=n,y=r,o,M,b=0;64>b;++b)o=y+(f(t,6)^f(t,11)^f(t,25))+(t&u^~t&w)+d[b]+a[b],M=(f(c,2)^f(c,13)^f(c,22))+(c&e^c&s^e&s),y=w,w=u,u=t,t=m+o|0,m=s,s=e,e=c,c=o+M|0;g=g+c|0;l=l+e|0;h=h+s|0;j=j+m|0;p=p+t|0;v=v+u|0;n=n+w|0;r=r+y|0}return new Uint8Array([g>>24&255,g>>16&255,g>>8&255,g&255,l>>24&255,l>>16&255,l>>8&255,l&255,h>>24&255,h>>16&255,h>>8&255,h&255,j>>24&255,j>>16&255,j>>8&255,j&255,p>>24&255,p>>16&255,p>>8&255,p&255,v>>24&255,v>>16&255,v>>8&255,v&255,n>>24&255,n>>16&255,n>>8&255,
n&255,r>>24&255,r>>16&255,r>>8&255,r&255])}}(),m=function(){var f=[new z(1116352408,3609767458),new z(1899447441,602891725),new z(3049323471,3964484399),new z(3921009573,2173295548),new z(961987163,4081628472),new z(1508970993,3053834265),new z(2453635748,2937671579),new z(2870763221,3664609560),new z(3624381080,2734883394),new z(310598401,1164996542),new z(607225278,1323610764),new z(1426881987,3590304994),new z(1925078388,4068182383),new z(2162078206,991336113),new z(2614888103,633803317),new z(3248222580,
3479774868),new z(3835390401,2666613458),new z(4022224774,944711139),new z(264347078,2341262773),new z(604807628,2007800933),new z(770255983,1495990901),new z(1249150122,1856431235),new z(1555081692,3175218132),new z(1996064986,2198950837),new z(2554220882,3999719339),new z(2821834349,766784016),new z(2952996808,2566594879),new z(3210313671,3203337956),new z(3336571891,1034457026),new z(3584528711,2466948901),new z(113926993,3758326383),new z(338241895,168717936),new z(666307205,1188179964),new z(773529912,
1546045734),new z(1294757372,1522805485),new z(1396182291,2643833823),new z(1695183700,2343527390),new z(1986661051,1014477480),new z(2177026350,1206759142),new z(2456956037,344077627),new z(2730485921,1290863460),new z(2820302411,3158454273),new z(3259730800,3505952657),new z(3345764771,106217008),new z(3516065817,3606008344),new z(3600352804,1432725776),new z(4094571909,1467031594),new z(275423344,851169720),new z(430227734,3100823752),new z(506948616,1363258195),new z(659060556,3750685593),new z(883997877,
3785050280),new z(958139571,3318307427),new z(1322822218,3812723403),new z(1537002063,2003034995),new z(1747873779,3602036899),new z(1955562222,1575990012),new z(2024104815,1125592928),new z(2227730452,2716904306),new z(2361852424,442776044),new z(2428436474,593698344),new z(2756734187,3733110249),new z(3204031479,2999351573),new z(3329325298,3815920427),new z(3391569614,3928383900),new z(3515267271,566280711),new z(3940187606,3454069534),new z(4118630271,4000239992),new z(116418474,1914138554),new z(174292421,
2731055270),new z(289380356,3203993006),new z(460393269,320620315),new z(685471733,587496836),new z(852142971,1086792851),new z(1017036298,365543100),new z(1126000580,2618297676),new z(1288033470,3409855158),new z(1501505948,4234509866),new z(1607167915,987167468),new z(1816402316,1246189591)];return function(d,a,c,b){var b=!!b,g,l,h,j,p,v,n,r;b?(g=new z(3418070365,3238371032),l=new z(1654270250,914150663),h=new z(2438529370,812702999),j=new z(355462360,4144912697),p=new z(1731405415,4290775857),
v=new z(2394180231,1750603025),n=new z(3675008525,1694076839),r=new z(1203062813,3204075428)):(g=new z(1779033703,4089235720),l=new z(3144134277,2227873595),h=new z(1013904242,4271175723),j=new z(2773480762,1595750129),p=new z(1359893119,2917565137),v=new z(2600822924,725511199),n=new z(528734635,4215389547),r=new z(1541459225,327033209));var B=128*Math.ceil((c+17)/128),F=new Uint8Array(B),A;for(A=0;A<c;++A)F[A]=d[a++];F[A++]=128;for(d=B-16;A<d;)F[A++]=0;F[A++]=0;F[A++]=0;F[A++]=0;F[A++]=0;F[A++]=
0;F[A++]=0;F[A++]=0;F[A++]=0;F[A++]=0;F[A++]=0;F[A++]=0;F[A++]=c>>>29&255;F[A++]=c>>21&255;F[A++]=c>>13&255;F[A++]=c>>5&255;F[A++]=c<<3&255;d=Array(80);for(A=0;80>A;A++)d[A]=new z(0,0);var a=new z(0,0),e=new z(0,0),s=new z(0,0),m=new z(0,0),t=new z(0,0),u=new z(0,0),w=new z(0,0),y=new z(0,0),o=new z(0,0),M=new z(0,0),x=new z(0,0),D=new z(0,0),C;for(A=0;A<B;){for(c=0;16>c;++c)d[c].high=F[A]<<24|F[A+1]<<16|F[A+2]<<8|F[A+3],d[c].low=F[A+4]<<24|F[A+5]<<16|F[A+6]<<8|F[A+7],A+=8;for(c=16;80>c;++c){var G=
C=d[c],E=d[c-2],H=D;G.assign(E);G.rotateRight(19);H.assign(E);H.rotateRight(61);G.xor(H);H.assign(E);H.shiftRight(6);G.xor(H);C.add(d[c-7]);G=x;E=d[c-15];H=D;G.assign(E);G.rotateRight(1);H.assign(E);H.rotateRight(8);G.xor(H);H.assign(E);H.shiftRight(7);G.xor(H);C.add(x);C.add(d[c-16])}a.assign(g);e.assign(l);s.assign(h);m.assign(j);t.assign(p);u.assign(v);w.assign(n);y.assign(r);for(c=0;80>c;++c){o.assign(y);C=x;G=t;E=D;C.assign(G);C.rotateRight(14);E.assign(G);E.rotateRight(18);C.xor(E);E.assign(G);
E.rotateRight(41);C.xor(E);o.add(x);C=x;var G=t,E=u,H=w,I=D;C.assign(G);C.and(E);I.assign(G);I.not();I.and(H);C.xor(I);o.add(x);o.add(f[c]);o.add(d[c]);C=M;G=a;E=D;C.assign(G);C.rotateRight(28);E.assign(G);E.rotateRight(34);C.xor(E);E.assign(G);E.rotateRight(39);C.xor(E);C=x;G=a;E=e;H=s;I=D;C.assign(G);C.and(E);I.assign(G);I.and(H);C.xor(I);I.assign(E);I.and(H);C.xor(I);M.add(x);C=y;y=w;w=u;u=t;m.add(o);t=m;m=s;s=e;e=a;C.assign(o);C.add(M);a=C}g.add(a);l.add(e);h.add(s);j.add(m);p.add(t);v.add(u);
n.add(w);r.add(y)}b?(b=new Uint8Array(48),g.copyTo(b,0),l.copyTo(b,8),h.copyTo(b,16),j.copyTo(b,24),p.copyTo(b,32),v.copyTo(b,40)):(b=new Uint8Array(64),g.copyTo(b,0),l.copyTo(b,8),h.copyTo(b,16),j.copyTo(b,24),p.copyTo(b,32),v.copyTo(b,40),n.copyTo(b,48),r.copyTo(b,56));return b}}(),w=function(){return function(f,d,a){return m(f,d,a,!0)}}(),t=function(){function f(){}f.prototype={decryptBlock:function(d){return d}};return f}(),u=function(){function f(b){var d=new Uint8Array(176);d.set(b);for(var b=
16,f=1;176>b;++f)for(var n=d[b-3],g=d[b-2],i=d[b-1],l=d[b-4],n=c[n],g=c[g],i=c[i],l=c[l],n=n^a[f],h=0;4>h;++h)d[b]=n^=d[b-16],b++,d[b]=g^=d[b-16],b++,d[b]=i^=d[b-16],b++,d[b]=l^=d[b-16],b++;this.key=d;this.buffer=new Uint8Array(16);this.bufferPosition=0}function d(c,d){var f,a,g;g=c.length;var i=this.buffer;a=this.bufferPosition;var k=[],l=this.iv;for(f=0;f<g;++f)if(i[a]=c[f],++a,!(16>a)){var e,s=i;a=this.key;e=new Uint8Array(16);e.set(s);var t=s=void 0,m=void 0,u=t=m=void 0;for(t=0,m=160;16>t;++t,
++m)e[t]^=a[m];for(s=9;1<=s;--s){m=e[13];e[13]=e[9];e[9]=e[5];e[5]=e[1];e[1]=m;m=e[14];t=e[10];e[14]=e[6];e[10]=e[2];e[6]=m;e[2]=t;m=e[15];t=e[11];u=e[7];e[15]=e[3];e[11]=m;e[7]=t;e[3]=u;for(t=0;16>t;++t)e[t]=b[e[t]];for(t=0,m=16*s;16>t;++t,++m)e[t]^=a[m];for(t=0;16>t;t+=4){var m=h[e[t+1]],u=h[e[t+2]],w=h[e[t+3]],m=h[e[t]]^m>>>8^m<<24^u>>>16^u<<16^w>>>24^w<<8;e[t]=m>>>24&255;e[t+1]=m>>16&255;e[t+2]=m>>8&255;e[t+3]=m&255}}m=e[13];e[13]=e[9];e[9]=e[5];e[5]=e[1];e[1]=m;m=e[14];t=e[10];e[14]=e[6];e[10]=
e[2];e[6]=m;e[2]=t;m=e[15];t=e[11];u=e[7];e[15]=e[3];e[11]=m;e[7]=t;e[3]=u;for(t=0;16>t;++t)e[t]=b[e[t]],e[t]^=a[t];for(a=0;16>a;++a)e[a]^=l[a];l=i;k.push(e);i=new Uint8Array(16);a=0}this.buffer=i;this.bufferLength=a;this.iv=l;if(0===k.length)return new Uint8Array([]);i=16*k.length;if(d&&(l=k[k.length-1],a=l[15],16>=a)){for(f=15,g=16-a;f>=g;--f)if(l[f]!==a){a=0;break}i-=a;k[k.length-1]=l.subarray(0,16-a)}i=new Uint8Array(i);for(f=0,a=0,g=k.length;f<g;++f,a+=16)i.set(k[f],a);return i}for(var a=new Uint8Array([141,
1,2,4,8,16,32,64,128,27,54,108,216,171,77,154,47,94,188,99,198,151,53,106,212,179,125,250,239,197,145,57,114,228,211,189,97,194,159,37,74,148,51,102,204,131,29,58,116,232,203,141,1,2,4,8,16,32,64,128,27,54,108,216,171,77,154,47,94,188,99,198,151,53,106,212,179,125,250,239,197,145,57,114,228,211,189,97,194,159,37,74,148,51,102,204,131,29,58,116,232,203,141,1,2,4,8,16,32,64,128,27,54,108,216,171,77,154,47,94,188,99,198,151,53,106,212,179,125,250,239,197,145,57,114,228,211,189,97,194,159,37,74,148,51,
102,204,131,29,58,116,232,203,141,1,2,4,8,16,32,64,128,27,54,108,216,171,77,154,47,94,188,99,198,151,53,106,212,179,125,250,239,197,145,57,114,228,211,189,97,194,159,37,74,148,51,102,204,131,29,58,116,232,203,141,1,2,4,8,16,32,64,128,27,54,108,216,171,77,154,47,94,188,99,198,151,53,106,212,179,125,250,239,197,145,57,114,228,211,189,97,194,159,37,74,148,51,102,204,131,29,58,116,232,203,141]),c=new Uint8Array([99,124,119,123,242,107,111,197,48,1,103,43,254,215,171,118,202,130,201,125,250,89,71,240,
173,212,162,175,156,164,114,192,183,253,147,38,54,63,247,204,52,165,229,241,113,216,49,21,4,199,35,195,24,150,5,154,7,18,128,226,235,39,178,117,9,131,44,26,27,110,90,160,82,59,214,179,41,227,47,132,83,209,0,237,32,252,177,91,106,203,190,57,74,76,88,207,208,239,170,251,67,77,51,133,69,249,2,127,80,60,159,168,81,163,64,143,146,157,56,245,188,182,218,33,16,255,243,210,205,12,19,236,95,151,68,23,196,167,126,61,100,93,25,115,96,129,79,220,34,42,144,136,70,238,184,20,222,94,11,219,224,50,58,10,73,6,36,
92,194,211,172,98,145,149,228,121,231,200,55,109,141,213,78,169,108,86,244,234,101,122,174,8,186,120,37,46,28,166,180,198,232,221,116,31,75,189,139,138,112,62,181,102,72,3,246,14,97,53,87,185,134,193,29,158,225,248,152,17,105,217,142,148,155,30,135,233,206,85,40,223,140,161,137,13,191,230,66,104,65,153,45,15,176,84,187,22]),b=new Uint8Array([82,9,106,213,48,54,165,56,191,64,163,158,129,243,215,251,124,227,57,130,155,47,255,135,52,142,67,68,196,222,233,203,84,123,148,50,166,194,35,61,238,76,149,11,
66,250,195,78,8,46,161,102,40,217,36,178,118,91,162,73,109,139,209,37,114,248,246,100,134,104,152,22,212,164,92,204,93,101,182,146,108,112,72,80,253,237,185,218,94,21,70,87,167,141,157,132,144,216,171,0,140,188,211,10,247,228,88,5,184,179,69,6,208,44,30,143,202,63,15,2,193,175,189,3,1,19,138,107,58,145,17,65,79,103,220,234,151,242,207,206,240,180,230,115,150,172,116,34,231,173,53,133,226,249,55,232,28,117,223,110,71,241,26,113,29,41,197,137,111,183,98,14,170,24,190,27,252,86,62,75,198,210,121,32,
154,219,192,254,120,205,90,244,31,221,168,51,136,7,199,49,177,18,16,89,39,128,236,95,96,81,127,169,25,181,74,13,45,229,122,159,147,201,156,239,160,224,59,77,174,42,245,176,200,235,187,60,131,83,153,97,23,43,4,126,186,119,214,38,225,105,20,99,85,33,12,125]),g=new Uint8Array(256),l=0;256>l;l++)g[l]=128>l?l<<1:l<<1^27;var h=new Uint32Array([0,235474187,470948374,303765277,941896748,908933415,607530554,708780849,1883793496,2118214995,1817866830,1649639237,1215061108,1181045119,1417561698,1517767529,3767586992,
4003061179,4236429990,4069246893,3635733660,3602770327,3299278474,3400528769,2430122216,2664543715,2362090238,2193862645,2835123396,2801107407,3035535058,3135740889,3678124923,3576870512,3341394285,3374361702,3810496343,3977675356,4279080257,4043610186,2876494627,2776292904,3076639029,3110650942,2472011535,2640243204,2403728665,2169303058,1001089995,899835584,666464733,699432150,59727847,226906860,530400753,294930682,1273168787,1172967064,1475418501,1509430414,1942435775,2110667444,1876241833,1641816226,
2910219766,2743034109,2976151520,3211623147,2505202138,2606453969,2302690252,2269728455,3711829422,3543599269,3240894392,3475313331,3843699074,3943906441,4178062228,4144047775,1306967366,1139781709,1374988112,1610459739,1975683434,2076935265,1775276924,1742315127,1034867998,866637845,566021896,800440835,92987698,193195065,429456164,395441711,1984812685,2017778566,1784663195,1683407248,1315562145,1080094634,1383856311,1551037884,101039829,135050206,437757123,337553864,1042385657,807962610,573804783,
742039012,2531067453,2564033334,2328828971,2227573024,2935566865,2700099354,3001755655,3168937228,3868552805,3902563182,4203181171,4102977912,3736164937,3501741890,3265478751,3433712980,1106041591,1340463100,1576976609,1408749034,2043211483,2009195472,1708848333,1809054150,832877231,1068351396,766945465,599762354,159417987,126454664,361929877,463180190,2709260871,2943682380,3178106961,3009879386,2572697195,2538681184,2236228733,2336434550,3509871135,3745345300,3441850377,3274667266,3910161971,3877198648,
4110568485,4211818798,2597806476,2497604743,2261089178,2295101073,2733856160,2902087851,3202437046,2968011453,3936291284,3835036895,4136440770,4169408201,3535486456,3702665459,3467192302,3231722213,2051518780,1951317047,1716890410,1750902305,1113818384,1282050075,1584504582,1350078989,168810852,67556463,371049330,404016761,841739592,1008918595,775550814,540080725,3969562369,3801332234,4035489047,4269907996,3569255213,3669462566,3366754619,3332740144,2631065433,2463879762,2160117071,2395588676,2767645557,
2868897406,3102011747,3069049960,202008497,33778362,270040487,504459436,875451293,975658646,675039627,641025152,2084704233,1917518562,1615861247,1851332852,1147550661,1248802510,1484005843,1451044056,933301370,967311729,733156972,632953703,260388950,25965917,328671808,496906059,1206477858,1239443753,1543208500,1441952575,2144161806,1908694277,1675577880,1842759443,3610369226,3644379585,3408119516,3307916247,4011190502,3776767469,4077384432,4245618683,2809771154,2842737049,3144396420,3043140495,2673705150,
2438237621,2203032232,2370213795]);f.prototype={decryptBlock:function(b,c){var f,a=b.length,g=this.buffer,i=this.bufferPosition;for(f=0;16>i&&f<a;++f,++i)g[i]=b[f];if(16>i)return this.bufferLength=i,new Uint8Array([]);this.iv=g;this.buffer=new Uint8Array(16);this.bufferLength=0;this.decryptBlock=d;return this.decryptBlock(b.subarray(16),c)},encrypt:function(b,d){var f,a,r;r=b.length;var k=this.buffer;a=this.bufferPosition;var h=[];d||(d=new Uint8Array(16));for(f=0;f<r;++f)if(k[a]=b[f],++a,!(16>a)){for(a=
0;16>a;++a)k[a]^=d[a];var e=k;a=this.key;var q=void 0,t=void 0,m=void 0,q=void 0,k=new Uint8Array(16);k.set(e);for(e=0;16>e;++e)k[e]^=a[e];for(l=1;10>l;l++){for(e=0;16>e;++e)k[e]=c[k[e]];m=k[1];k[1]=k[5];k[5]=k[9];k[9]=k[13];k[13]=m;m=k[2];t=k[6];k[2]=k[10];k[6]=k[14];k[10]=m;k[14]=t;m=k[3];t=k[7];q=k[11];k[3]=k[15];k[7]=m;k[11]=t;k[15]=q;for(e=0;16>e;e+=4){var t=k[e+0],m=k[e+1],s=k[e+2],u=k[e+3],q=t^m^s^u;k[e+0]^=q^g[t^m];k[e+1]^=q^g[m^s];k[e+2]^=q^g[s^u];k[e+3]^=q^g[u^t]}for(e=0,q=16*l;16>e;++e,
++q)k[e]^=a[q]}for(e=0;16>e;++e)k[e]=c[k[e]];m=k[1];k[1]=k[5];k[5]=k[9];k[9]=k[13];k[13]=m;m=k[2];t=k[6];k[2]=k[10];k[6]=k[14];k[10]=m;k[14]=t;m=k[3];t=k[7];q=k[11];k[3]=k[15];k[7]=m;k[11]=t;k[15]=q;for(e=0,q=160;16>e;++e,++q)k[e]^=a[q];d=a=k;h.push(a);k=new Uint8Array(16);a=0}this.buffer=k;this.bufferLength=a;this.iv=d;if(0===h.length)return new Uint8Array([]);k=new Uint8Array(16*h.length);for(f=0,a=0,r=h.length;f<r;++f,a+=16)k.set(h[f],a);return k}};return f}(),y=function(){function f(b){var c=
new Uint8Array(240),d=1;c.set(b);for(var b=32,f=1;240>b;++f){if(16===b%32)g=a[g],i=a[i],l=a[l],h=a[h];else if(0===b%32){var g=c[b-3],i=c[b-2],l=c[b-1],h=c[b-4],g=a[g],i=a[i],l=a[l],h=a[h],g=g^d;if(256<=(d<<=1))d=(d^27)&255}for(var e=0;4>e;++e)c[b]=g^=c[b-32],b++,c[b]=i^=c[b-32],b++,c[b]=l^=c[b-32],b++,c[b]=h^=c[b-32],b++}this.key=c;this.buffer=new Uint8Array(16);this.bufferPosition=0}function d(b,d){var f,a,g;g=b.length;var k=this.buffer;a=this.bufferPosition;var i=[],h=this.iv;for(f=0;f<g;++f)if(k[a]=
b[f],++a,!(16>a)){var e,t=k;a=this.key;e=new Uint8Array(16);e.set(t);var m=t=void 0,s=void 0,u=m=s=void 0;for(m=0,s=224;16>m;++m,++s)e[m]^=a[s];for(t=13;1<=t;--t){s=e[13];e[13]=e[9];e[9]=e[5];e[5]=e[1];e[1]=s;s=e[14];m=e[10];e[14]=e[6];e[10]=e[2];e[6]=s;e[2]=m;s=e[15];m=e[11];u=e[7];e[15]=e[3];e[11]=s;e[7]=m;e[3]=u;for(m=0;16>m;++m)e[m]=c[e[m]];for(m=0,s=16*t;16>m;++m,++s)e[m]^=a[s];for(m=0;16>m;m+=4){var s=l[e[m+1]],u=l[e[m+2]],w=l[e[m+3]],s=l[e[m]]^s>>>8^s<<24^u>>>16^u<<16^w>>>24^w<<8;e[m]=s>>>
24&255;e[m+1]=s>>16&255;e[m+2]=s>>8&255;e[m+3]=s&255}}s=e[13];e[13]=e[9];e[9]=e[5];e[5]=e[1];e[1]=s;s=e[14];m=e[10];e[14]=e[6];e[10]=e[2];e[6]=s;e[2]=m;s=e[15];m=e[11];u=e[7];e[15]=e[3];e[11]=s;e[7]=m;e[3]=u;for(m=0;16>m;++m)e[m]=c[e[m]],e[m]^=a[m];for(a=0;16>a;++a)e[a]^=h[a];h=k;i.push(e);k=new Uint8Array(16);a=0}this.buffer=k;this.bufferLength=a;this.iv=h;if(0===i.length)return new Uint8Array([]);k=16*i.length;if(d&&(h=i[i.length-1],a=h[15],16>=a)){for(f=15,g=16-a;f>=g;--f)if(h[f]!==a){a=0;break}k-=
a;i[i.length-1]=h.subarray(0,16-a)}k=new Uint8Array(k);for(f=0,a=0,g=i.length;f<g;++f,a+=16)k.set(i[f],a);return k}new Uint8Array([141,1,2,4,8,16,32,64,128,27,54,108,216,171,77,154,47,94,188,99,198,151,53,106,212,179,125,250,239,197,145,57,114,228,211,189,97,194,159,37,74,148,51,102,204,131,29,58,116,232,203,141,1,2,4,8,16,32,64,128,27,54,108,216,171,77,154,47,94,188,99,198,151,53,106,212,179,125,250,239,197,145,57,114,228,211,189,97,194,159,37,74,148,51,102,204,131,29,58,116,232,203,141,1,2,4,8,
16,32,64,128,27,54,108,216,171,77,154,47,94,188,99,198,151,53,106,212,179,125,250,239,197,145,57,114,228,211,189,97,194,159,37,74,148,51,102,204,131,29,58,116,232,203,141,1,2,4,8,16,32,64,128,27,54,108,216,171,77,154,47,94,188,99,198,151,53,106,212,179,125,250,239,197,145,57,114,228,211,189,97,194,159,37,74,148,51,102,204,131,29,58,116,232,203,141,1,2,4,8,16,32,64,128,27,54,108,216,171,77,154,47,94,188,99,198,151,53,106,212,179,125,250,239,197,145,57,114,228,211,189,97,194,159,37,74,148,51,102,204,
131,29,58,116,232,203,141]);for(var a=new Uint8Array([99,124,119,123,242,107,111,197,48,1,103,43,254,215,171,118,202,130,201,125,250,89,71,240,173,212,162,175,156,164,114,192,183,253,147,38,54,63,247,204,52,165,229,241,113,216,49,21,4,199,35,195,24,150,5,154,7,18,128,226,235,39,178,117,9,131,44,26,27,110,90,160,82,59,214,179,41,227,47,132,83,209,0,237,32,252,177,91,106,203,190,57,74,76,88,207,208,239,170,251,67,77,51,133,69,249,2,127,80,60,159,168,81,163,64,143,146,157,56,245,188,182,218,33,16,255,
243,210,205,12,19,236,95,151,68,23,196,167,126,61,100,93,25,115,96,129,79,220,34,42,144,136,70,238,184,20,222,94,11,219,224,50,58,10,73,6,36,92,194,211,172,98,145,149,228,121,231,200,55,109,141,213,78,169,108,86,244,234,101,122,174,8,186,120,37,46,28,166,180,198,232,221,116,31,75,189,139,138,112,62,181,102,72,3,246,14,97,53,87,185,134,193,29,158,225,248,152,17,105,217,142,148,155,30,135,233,206,85,40,223,140,161,137,13,191,230,66,104,65,153,45,15,176,84,187,22]),c=new Uint8Array([82,9,106,213,48,
54,165,56,191,64,163,158,129,243,215,251,124,227,57,130,155,47,255,135,52,142,67,68,196,222,233,203,84,123,148,50,166,194,35,61,238,76,149,11,66,250,195,78,8,46,161,102,40,217,36,178,118,91,162,73,109,139,209,37,114,248,246,100,134,104,152,22,212,164,92,204,93,101,182,146,108,112,72,80,253,237,185,218,94,21,70,87,167,141,157,132,144,216,171,0,140,188,211,10,247,228,88,5,184,179,69,6,208,44,30,143,202,63,15,2,193,175,189,3,1,19,138,107,58,145,17,65,79,103,220,234,151,242,207,206,240,180,230,115,150,
172,116,34,231,173,53,133,226,249,55,232,28,117,223,110,71,241,26,113,29,41,197,137,111,183,98,14,170,24,190,27,252,86,62,75,198,210,121,32,154,219,192,254,120,205,90,244,31,221,168,51,136,7,199,49,177,18,16,89,39,128,236,95,96,81,127,169,25,181,74,13,45,229,122,159,147,201,156,239,160,224,59,77,174,42,245,176,200,235,187,60,131,83,153,97,23,43,4,126,186,119,214,38,225,105,20,99,85,33,12,125]),b=new Uint8Array(256),g=0;256>g;g++)b[g]=128>g?g<<1:g<<1^27;var l=new Uint32Array([0,235474187,470948374,
303765277,941896748,908933415,607530554,708780849,1883793496,2118214995,1817866830,1649639237,1215061108,1181045119,1417561698,1517767529,3767586992,4003061179,4236429990,4069246893,3635733660,3602770327,3299278474,3400528769,2430122216,2664543715,2362090238,2193862645,2835123396,2801107407,3035535058,3135740889,3678124923,3576870512,3341394285,3374361702,3810496343,3977675356,4279080257,4043610186,2876494627,2776292904,3076639029,3110650942,2472011535,2640243204,2403728665,2169303058,1001089995,
899835584,666464733,699432150,59727847,226906860,530400753,294930682,1273168787,1172967064,1475418501,1509430414,1942435775,2110667444,1876241833,1641816226,2910219766,2743034109,2976151520,3211623147,2505202138,2606453969,2302690252,2269728455,3711829422,3543599269,3240894392,3475313331,3843699074,3943906441,4178062228,4144047775,1306967366,1139781709,1374988112,1610459739,1975683434,2076935265,1775276924,1742315127,1034867998,866637845,566021896,800440835,92987698,193195065,429456164,395441711,
1984812685,2017778566,1784663195,1683407248,1315562145,1080094634,1383856311,1551037884,101039829,135050206,437757123,337553864,1042385657,807962610,573804783,742039012,2531067453,2564033334,2328828971,2227573024,2935566865,2700099354,3001755655,3168937228,3868552805,3902563182,4203181171,4102977912,3736164937,3501741890,3265478751,3433712980,1106041591,1340463100,1576976609,1408749034,2043211483,2009195472,1708848333,1809054150,832877231,1068351396,766945465,599762354,159417987,126454664,361929877,
463180190,2709260871,2943682380,3178106961,3009879386,2572697195,2538681184,2236228733,2336434550,3509871135,3745345300,3441850377,3274667266,3910161971,3877198648,4110568485,4211818798,2597806476,2497604743,2261089178,2295101073,2733856160,2902087851,3202437046,2968011453,3936291284,3835036895,4136440770,4169408201,3535486456,3702665459,3467192302,3231722213,2051518780,1951317047,1716890410,1750902305,1113818384,1282050075,1584504582,1350078989,168810852,67556463,371049330,404016761,841739592,1008918595,
775550814,540080725,3969562369,3801332234,4035489047,4269907996,3569255213,3669462566,3366754619,3332740144,2631065433,2463879762,2160117071,2395588676,2767645557,2868897406,3102011747,3069049960,202008497,33778362,270040487,504459436,875451293,975658646,675039627,641025152,2084704233,1917518562,1615861247,1851332852,1147550661,1248802510,1484005843,1451044056,933301370,967311729,733156972,632953703,260388950,25965917,328671808,496906059,1206477858,1239443753,1543208500,1441952575,2144161806,1908694277,
1675577880,1842759443,3610369226,3644379585,3408119516,3307916247,4011190502,3776767469,4077384432,4245618683,2809771154,2842737049,3144396420,3043140495,2673705150,2438237621,2203032232,2370213795]);f.prototype={decryptBlock:function(b,c,f){var a=b.length,g=this.buffer,k=this.bufferPosition;if(f)this.iv=f;else{for(f=0;16>k&&f<a;++f,++k)g[k]=b[f];if(16>k)return this.bufferLength=k,new Uint8Array([]);this.iv=g;b=b.subarray(16)}this.buffer=new Uint8Array(16);this.bufferLength=0;this.decryptBlock=d;
return this.decryptBlock(b,c)},encrypt:function(c,d){var f,e,n;n=c.length;var r=this.buffer;e=this.bufferPosition;var l=[];d||(d=new Uint8Array(16));for(f=0;f<n;++f)if(r[e]=c[f],++e,!(16>e)){for(e=0;16>e;++e)r[e]^=d[e];var h=r;e=this.key;var A=void 0,m=void 0,t=void 0,A=void 0,r=new Uint8Array(16);r.set(h);for(h=0;16>h;++h)r[h]^=e[h];for(g=1;14>g;g++){for(h=0;16>h;++h)r[h]=a[r[h]];t=r[1];r[1]=r[5];r[5]=r[9];r[9]=r[13];r[13]=t;t=r[2];m=r[6];r[2]=r[10];r[6]=r[14];r[10]=t;r[14]=m;t=r[3];m=r[7];A=r[11];
r[3]=r[15];r[7]=t;r[11]=m;r[15]=A;for(h=0;16>h;h+=4){var m=r[h+0],t=r[h+1],s=r[h+2],u=r[h+3],A=m^t^s^u;r[h+0]^=A^b[m^t];r[h+1]^=A^b[t^s];r[h+2]^=A^b[s^u];r[h+3]^=A^b[u^m]}for(h=0,A=16*g;16>h;++h,++A)r[h]^=e[A]}for(h=0;16>h;++h)r[h]=a[r[h]];t=r[1];r[1]=r[5];r[5]=r[9];r[9]=r[13];r[13]=t;t=r[2];m=r[6];r[2]=r[10];r[6]=r[14];r[10]=t;r[14]=m;t=r[3];m=r[7];A=r[11];r[3]=r[15];r[7]=t;r[11]=m;r[15]=A;for(h=0,A=224;16>h;++h,++A)r[h]^=e[A];this.iv=e=r;l.push(e);r=new Uint8Array(16);e=0}this.buffer=r;this.bufferLength=
e;this.iv=d;if(0===l.length)return new Uint8Array([]);r=new Uint8Array(16*l.length);for(f=0,e=0,n=l.length;f<n;++f,e+=16)r.set(l[f],e);return r}};return f}(),s=function(){function f(d,c){if(d.length!==c.length)return!1;for(var b=0;b<d.length;b++)if(d[b]!==c[b])return!1;return!0}function d(){}d.prototype={checkOwnerPassword:function(d,c,b,a){var g=new Uint8Array(d.length+56);g.set(d,0);g.set(c,d.length);g.set(b,d.length+c.length);d=R(g,0,g.length);return f(d,a)},checkUserPassword:function(d,c,b){var a=
new Uint8Array(d.length+8);a.set(d,0);a.set(c,d.length);d=R(a,0,a.length);return f(d,b)},getOwnerKey:function(d,c,b,f){var a=new Uint8Array(d.length+56);a.set(d,0);a.set(c,d.length);a.set(b,d.length+c.length);d=R(a,0,a.length);return(new y(d)).decryptBlock(f,!1,new Uint8Array(16))},getUserKey:function(d,c,b){var f=new Uint8Array(d.length+8);f.set(d,0);f.set(c,d.length);d=R(f,0,f.length);return(new y(d)).decryptBlock(b,!1,new Uint8Array(16))}};return d}(),M=function(){function f(b,c){var d=new Uint8Array(b.length+
c.length);d.set(b,0);d.set(c,b.length);return d}function d(b,c,d){for(var c=R(c,0,c.length).subarray(0,32),a=[0],g=0;64>g||a[a.length-1]>g-32;){for(var a=b.length+c.length+d.length,p=new Uint8Array(64*a),k=f(b,c),k=f(k,d),n=0,e=0;64>n;n++,e+=a)p.set(k,e);a=(new u(c.subarray(0,16))).encrypt(p,c.subarray(16,32));for(k=p=0;16>k;k++)p*=1,p%=3,p+=(a[k]>>>0)%3,p%=3;0===p?c=R(a,0,a.length):1===p?c=w(a,0,a.length):2===p&&(c=m(a,0,a.length));g++}return c.subarray(0,32)}function a(){}function c(b,c){if(b.length!==
c.length)return!1;for(var d=0;d<b.length;d++)if(b[d]!==c[d])return!1;return!0}a.prototype={hash:function(b,c,f){return d(b,c,f)},checkOwnerPassword:function(b,f,a,g){var j=new Uint8Array(b.length+56);j.set(b,0);j.set(f,b.length);j.set(a,b.length+f.length);b=d(b,j,a);return c(b,g)},checkUserPassword:function(b,f,a){var g=new Uint8Array(b.length+8);g.set(b,0);g.set(f,b.length);b=d(b,g,[]);return c(b,a)},getOwnerKey:function(b,c,f,a){var g=new Uint8Array(b.length+56);g.set(b,0);g.set(c,b.length);g.set(f,
b.length+c.length);b=d(b,g,f);return(new y(b)).decryptBlock(a,!1,new Uint8Array(16))},getUserKey:function(b,c,f){var a=new Uint8Array(b.length+8);a.set(b,0);a.set(c,b.length);b=d(b,a,[]);return(new y(b)).decryptBlock(f,!1,new Uint8Array(16))}};return a}(),g=function(){function f(d,f){this.stringCipherConstructor=d;this.streamCipherConstructor=f}f.prototype={createStream:function(d,f){var c=new this.streamCipherConstructor;return new D(d,f,function(b,d){return c.decryptBlock(b,d)})},decryptString:function(d){var f=
new this.stringCipherConstructor,d=J(d),d=f.decryptBlock(d,!0);return H(d)}};return f}(),e=function(){function f(c,d,f,a,g,n,k,i){var e=new Uint8Array(40+f.length+c.length),m=0,t;if(d)for(t=Math.min(32,d.length);m<t;++m)e[m]=d[m];for(d=0;32>m;)e[m++]=b[d++];for(d=0,t=f.length;d<t;++d)e[m++]=f[d];e[m++]=g&255;e[m++]=g>>8&255;e[m++]=g>>16&255;e[m++]=g>>>24&255;for(d=0,t=c.length;d<t;++d)e[m++]=c[d];4<=n&&!i&&(e[m++]=255,e[m++]=255,e[m++]=255,e[m++]=255);t=h(e,0,m);m=k>>3;if(3<=n)for(d=0;50>d;++d)t=
h(t,0,m);k=t.subarray(0,m);if(3<=n){for(m=0;32>m;++m)e[m]=b[m];for(d=0,t=c.length;d<t;++d)e[m++]=c[d];c=new G(k);e=c.encryptBlock(h(e,0,m));t=k.length;n=new Uint8Array(t);for(d=1;19>=d;++d){for(c=0;c<t;++c)n[c]=k[c]^d;c=new G(n);e=c.encryptBlock(e)}}else c=new G(k),e=c.encryptBlock(b);for(d=0,t=e.length;d<t;++d)if(a[d]!==e[d])return null;return k}function d(c,d,a){var g=c.get("Filter");(!o(g)||"Standard"!==g.name)&&K("unknown encryption method");this.dict=c;g=c.get("V");(!I(g)||1!==g&&2!==g&&4!==
g&&5!==g)&&K("unsupported encryption algorithm");this.algorithm=g;var k=c.get("Length");if(!k)if(3>=g)k=40;else{var n=c.get("CF"),e=c.get("StmF");x(n)&&o(e)&&(k=(k=n.get(e.name))&&k.get("Length")||128,40>k&&(k<<=3))}(!I(k)||40>k||0!==k%8)&&K("invalid key length");var n=J(c.get("O")).subarray(0,32),e=J(c.get("U")).subarray(0,32),m=c.get("P"),t=c.get("R"),A=(4===g||5===g)&&!1!==c.get("EncryptMetadata");this.encryptMetadata=A;var d=J(d),u;if(a){if(6===t)try{a=Q(a)}catch(w){E("CipherTransformFactory: Unable to convert UTF8 encoded password.")}u=
J(a)}var y;if(5!==g)y=f(d,u,n,e,m,t,k,A);else{y=J(c.get("O")).subarray(32,40);var z=J(c.get("O")).subarray(40,48),D=J(c.get("U")).subarray(0,48),C=J(c.get("U")).subarray(32,40),H=J(c.get("U")).subarray(40,48),R=J(c.get("OE")),O=J(c.get("UE"));J(c.get("Perms"));a:{var P=u;if(P)var qa=Math.min(127,P.length),P=P.subarray(0,qa);else P=[];if(qa=6===t?new M:new s){if(qa.checkUserPassword(P,C,e)){y=qa.getUserKey(P,H,O);break a}if(P.length&&qa.checkOwnerPassword(P,y,D,n)){y=qa.getOwnerKey(P,z,D,R);break a}}y=
null}}if(!y&&!a)throw new N("No password given",L.NEED_PASSWORD);if(!y&&a){a=u;y=k;u=new Uint8Array(32);z=0;for(D=Math.min(32,a.length);z<D;++z)u[z]=a[z];for(a=0;32>z;)u[z++]=b[a++];u=h(u,0,z);y>>=3;if(3<=t)for(a=0;50>a;++a)u=h(u,0,u.length);if(3<=t){z=n;D=new Uint8Array(y);for(a=19;0<=a;a--){for(C=0;C<y;++C)D[C]=u[C]^a;C=new G(D);z=C.encryptBlock(z)}}else C=new G(u.subarray(0,y)),z=C.encryptBlock(n);y=f(d,z,n,e,m,t,k,A)}if(!y)throw new N("Incorrect Password",L.INCORRECT_PASSWORD);this.encryptionKey=
y;4<=g&&(this.cf=c.get("CF"),this.stmf=c.get("StmF")||i,this.strf=c.get("StrF")||i,this.eff=c.get("EFF")||this.stmf)}function a(b,c,d,f){var g=new Uint8Array(d.length+9),n,k;for(n=0,k=d.length;n<k;++n)g[n]=d[n];g[n++]=b&255;g[n++]=b>>8&255;g[n++]=b>>16&255;g[n++]=c&255;g[n++]=c>>8&255;f&&(g[n++]=115,g[n++]=65,g[n++]=108,g[n++]=84);return h(g,0,n).subarray(0,Math.min(d.length+5,16))}function c(b,c,d,f,g){var b=b.get(c.name),n;null!==b&&void 0!==b&&(n=b.get("CFM"));if(!n||"None"===n.name)return function(){return new t};
if("V2"===n.name)return function(){return new G(a(d,f,g,!1))};if("AESV2"===n.name)return function(){return new u(a(d,f,g,!0))};if("AESV3"===n.name)return function(){return new y(g)};K("Unknown crypto method")}var b=new Uint8Array([40,191,78,94,78,117,138,65,100,0,78,86,255,250,1,8,46,46,0,182,208,104,62,128,47,12,169,254,100,83,105,122]),i=C.get("Identity");d.prototype={createCipherTransform:function(b,d){if(4===this.algorithm||5===this.algorithm)return new g(c(this.cf,this.stmf,b,d,this.encryptionKey),
c(this.cf,this.strf,b,d,this.encryptionKey));var f=a(b,d,this.encryptionKey,!1),e=function(){return new G(f)};return new g(e,e)}};return d}();a.AES128Cipher=u;a.AES256Cipher=y;a.ARCFourCipher=G;a.CipherTransformFactory=e;a.PDF17=s;a.PDF20=M;a.calculateMD5=h;a.calculateSHA256=R;a.calculateSHA384=w;a.calculateSHA512=m});(function(a,e){e(a.pdfjsCoreFontRenderer={},a.pdfjsSharedUtil,a.pdfjsCoreStream,a.pdfjsCoreGlyphList)})(this,function(a,e,O,P){var N=e.Util,L=e.bytesToString,H=e.error,K=O.Stream,I=
P.GlyphsUnicode,J,Q,e=function(){function a(e,h){return e[h]<<24|e[h+1]<<16|e[h+2]<<8|e[h+3]}function e(a,h){return a[h]<<8|a[h+1]}function o(a,e,h){var u;h?(h=4,u=function(f,d){return f[d]<<24|f[d+1]<<16|f[d+2]<<8|f[d+3]}):(h=2,u=function(f,d){return f[d]<<9|f[d+1]<<1});for(var y=[],s=u(e,0),o=h;o<e.length;o+=h){var g=u(e,o);y.push(a.subarray(s,g));s=g}return y}function x(a,e){for(var h=e.charCodeAt(0),u=0,y=a.length-1;u<y;){var s=u+y+1>>1;h<a[s].start?y=s-1:u=s}return a[u].start<=h&&h<=a[u].end?
a[u].idDelta+(a[u].ids?a[u].ids[h-a[u].start]:h)&65535:0}function D(a,e,h){var u=0,y=(a[u]<<24|a[u+1]<<16)>>16,s,o=0,g=0,u=u+10;if(0>y){do{s=a[u]<<8|a[u+1];y=a[u+2]<<8|a[u+3];u+=4;s&1?(o=(a[u]<<24|a[u+1]<<16)>>16,g=(a[u+2]<<24|a[u+3]<<16)>>16,u+=4):(o=a[u++],g=a[u++]);s&2||(g=o=0);var f=1,d=1,k=0,c=0;s&8?(f=d=(a[u]<<24|a[u+1]<<16)/1073741824,u+=2):s&64?(f=(a[u]<<24|a[u+1]<<16)/1073741824,d=(a[u+2]<<24|a[u+3]<<16)/1073741824,u+=4):s&128&&(f=(a[u]<<24|a[u+1]<<16)/1073741824,k=(a[u+2]<<24|a[u+3]<<16)/
1073741824,c=(a[u+4]<<24|a[u+5]<<16)/1073741824,d=(a[u+6]<<24|a[u+7]<<16)/1073741824,u+=8);if(y=h.glyphs[y])e.push({cmd:"save"}),e.push({cmd:"transform",args:[f,k,c,d,o,g]}),D(y,e,h),e.push({cmd:"restore"})}while(s&32)}else{h=[];for(s=0;s<y;s++)h.push(a[u]<<8|a[u+1]),u+=2;u+=2+(a[u]<<8|a[u+1]);d=h[h.length-1]+1;for(f=[];f.length<d;){s=a[u++];k=1;for(s&8&&(k+=a[u++]);0<k--;)f.push({flags:s})}for(s=0;s<d;s++){switch(f[s].flags&18){case 0:o+=(a[u]<<24|a[u+1]<<16)>>16;u+=2;break;case 2:o-=a[u++];break;
case 18:o+=a[u++]}f[s].x=o}for(s=0;s<d;s++){switch(f[s].flags&36){case 0:g+=(a[u]<<24|a[u+1]<<16)>>16;u+=2;break;case 4:g-=a[u++];break;case 36:g+=a[u++]}f[s].y=g}for(u=s=0;u<y;u++){a=h[u];o=f.slice(s,a+1);o[0].flags&1?o.push(o[0]):o[o.length-1].flags&1?o.unshift(o[o.length-1]):(s={flags:1,x:(o[0].x+o[o.length-1].x)/2,y:(o[0].y+o[o.length-1].y)/2},o.unshift(s),o.push(s));e.push({cmd:"moveTo",args:[o[0].x,o[0].y]});for(s=1,g=o.length;s<g;s++)o[s].flags&1?e.push({cmd:"lineTo",args:[o[s].x,o[s].y]}):
o[s+1].flags&1?(e.push({cmd:"quadraticCurveTo",args:[o[s].x,o[s].y,o[s+1].x,o[s+1].y]}),s++):e.push({cmd:"quadraticCurveTo",args:[o[s].x,o[s].y,(o[s].x+o[s+1].x)/2,(o[s].y+o[s+1].y)/2]});s=a+1}}}function G(a,e,h){function u(c,b){e.push({cmd:"moveTo",args:[c,b]})}function o(c,b){e.push({cmd:"lineTo",args:[c,b]})}function s(c,b,d,a,f,g){e.push({cmd:"bezierCurveTo",args:[c,b,d,a,f,g]})}function z(c){for(var b=0;b<c.length;){var a=!1,l=c[b++],q,j,p;switch(l){case 1:k+=g.length>>1;a=!0;break;case 3:k+=
g.length>>1;a=!0;break;case 4:d+=g.pop();u(f,d);a=!0;break;case 5:for(;0<g.length;)f+=g.shift(),d+=g.shift(),o(f,d);break;case 6:for(;0<g.length;){f+=g.shift();o(f,d);if(0===g.length)break;d+=g.shift();o(f,d)}break;case 7:for(;0<g.length;){d+=g.shift();o(f,d);if(0===g.length)break;f+=g.shift();o(f,d)}break;case 8:for(;0<g.length;)l=f+g.shift(),j=d+g.shift(),q=l+g.shift(),p=j+g.shift(),f=q+g.shift(),d=p+g.shift(),s(l,j,q,p,f,d);break;case 10:l=g.pop()+h.subrsBias;(l=h.subrs[l])&&z(l);break;case 11:return;
case 12:l=c[b++];switch(l){case 34:l=f+g.shift();q=l+g.shift();p=d+g.shift();f=q+g.shift();s(l,d,q,p,f,p);l=f+g.shift();q=l+g.shift();f=q+g.shift();s(l,p,q,d,f,d);break;case 35:l=f+g.shift();j=d+g.shift();q=l+g.shift();p=j+g.shift();f=q+g.shift();d=p+g.shift();s(l,j,q,p,f,d);l=f+g.shift();j=d+g.shift();q=l+g.shift();p=j+g.shift();f=q+g.shift();d=p+g.shift();s(l,j,q,p,f,d);g.pop();break;case 36:l=f+g.shift();p=d+g.shift();q=l+g.shift();j=p+g.shift();f=q+g.shift();s(l,p,q,j,f,j);l=f+g.shift();q=l+g.shift();
p=j+g.shift();f=q+g.shift();s(l,j,q,p,f,d);break;case 37:var v=f,n=d,l=f+g.shift();j=d+g.shift();q=l+g.shift();p=j+g.shift();f=q+g.shift();d=p+g.shift();s(l,j,q,p,f,d);l=f+g.shift();j=d+g.shift();q=l+g.shift();p=j+g.shift();f=q;d=p;Math.abs(f-v)>Math.abs(d-n)?f+=g.shift():d+=g.shift();s(l,j,q,p,f,d);break;default:H("unknown operator: 12 "+l)}break;case 14:4<=g.length&&(b=g.pop(),c=g.pop(),d=g.pop(),f=g.pop(),e.push({cmd:"save"}),e.push({cmd:"translate",args:[f,d]}),b=x(h.cmap,String.fromCharCode(h.glyphNameMap[Q.StandardEncoding[b]])),
G(h.glyphs[b],e,h),e.push({cmd:"restore"}),b=x(h.cmap,String.fromCharCode(h.glyphNameMap[Q.StandardEncoding[c]])),G(h.glyphs[b],e,h));return;case 18:k+=g.length>>1;a=!0;break;case 19:k+=g.length>>1;b+=k+7>>3;a=!0;break;case 20:k+=g.length>>1;b+=k+7>>3;a=!0;break;case 21:d+=g.pop();f+=g.pop();u(f,d);a=!0;break;case 22:f+=g.pop();u(f,d);a=!0;break;case 23:k+=g.length>>1;a=!0;break;case 24:for(;2<g.length;)l=f+g.shift(),j=d+g.shift(),q=l+g.shift(),p=j+g.shift(),f=q+g.shift(),d=p+g.shift(),s(l,j,q,p,
f,d);f+=g.shift();d+=g.shift();o(f,d);break;case 25:for(;6<g.length;)f+=g.shift(),d+=g.shift(),o(f,d);l=f+g.shift();j=d+g.shift();q=l+g.shift();p=j+g.shift();f=q+g.shift();d=p+g.shift();s(l,j,q,p,f,d);break;case 26:for(g.length%2&&(f+=g.shift());0<g.length;)l=f,j=d+g.shift(),q=l+g.shift(),p=j+g.shift(),f=q,d=p+g.shift(),s(l,j,q,p,f,d);break;case 27:for(g.length%2&&(d+=g.shift());0<g.length;)l=f+g.shift(),j=d,q=l+g.shift(),p=j+g.shift(),f=q+g.shift(),d=p,s(l,j,q,p,f,d);break;case 28:g.push((c[b]<<
24|c[b+1]<<16)>>16);b+=2;break;case 29:l=g.pop()+h.gsubrsBias;(l=h.gsubrs[l])&&z(l);break;case 30:for(;0<g.length;){l=f;j=d+g.shift();q=l+g.shift();p=j+g.shift();f=q+g.shift();d=p+(1===g.length?g.shift():0);s(l,j,q,p,f,d);if(0===g.length)break;l=f+g.shift();j=d;q=l+g.shift();p=j+g.shift();d=p+g.shift();f=q+(1===g.length?g.shift():0);s(l,j,q,p,f,d)}break;case 31:for(;0<g.length;){l=f+g.shift();j=d;q=l+g.shift();p=j+g.shift();d=p+g.shift();f=q+(1===g.length?g.shift():0);s(l,j,q,p,f,d);if(0===g.length)break;
l=f;j=d+g.shift();q=l+g.shift();p=j+g.shift();f=q+g.shift();d=p+(1===g.length?g.shift():0);s(l,j,q,p,f,d)}break;default:32>l&&H("unknown operator: "+l),247>l?g.push(l-139):251>l?g.push(256*(l-247)+c[b++]+108):255>l?g.push(256*-(l-251)-c[b++]-108):(g.push((c[b]<<24|c[b+1]<<16|c[b+2]<<8|c[b+3])/65536),b+=4)}a&&(g.length=0)}}var g=[],f=0,d=0,k=0;z(a)}function h(a){this.compiledGlyphs={};this.fontMatrix=a}function z(a,e,t){t=t||[4.88E-4,0,0,4.88E-4,0,0];h.call(this,t);this.glyphs=a;this.cmap=e;this.compiledGlyphs=
[]}function R(a,e,t,u){t=t||[0.001,0,0,0.001,0,0];h.call(this,t);this.glyphs=a.glyphs;this.gsubrs=a.gsubrs||[];this.subrs=a.subrs||[];this.cmap=e;this.glyphNameMap=u||I;this.compiledGlyphs=[];this.gsubrsBias=1240>this.gsubrs.length?107:33900>this.gsubrs.length?1131:32768;this.subrsBias=1240>this.subrs.length?107:33900>this.subrs.length?1131:32768}h.prototype={getPathJs:function(a){var a=x(this.cmap,a),e=this.compiledGlyphs[a];e||(this.compiledGlyphs[a]=e=this.compileGlyph(this.glyphs[a]));return e},
compileGlyph:function(a){if(!a||0===a.length||14===a[0])return"";var e=[];e.push({cmd:"save"});e.push({cmd:"transform",args:this.fontMatrix.slice()});e.push({cmd:"scale",args:["size","-size"]});this.compileGlyphImpl(a,e);e.push({cmd:"restore"});return e},compileGlyphImpl:function(){H("Children classes should implement this.")},hasBuiltPath:function(a){return x(this.cmap,a)in this.compiledGlyphs}};N.inherit(z,h,{compileGlyphImpl:function(a,e){D(a,e,this)}});N.inherit(R,h,{compileGlyphImpl:function(a,
e){G(a,e,this)}});return{create:function(h){for(var w=new Uint8Array(h.data),t,u,y,s,x,g,f=e(w,4),d=0,k=12;d<f;d++,k+=16){var c=L(w.subarray(k,k+4)),b=a(w,k+8),i=a(w,k+12);switch(c){case "cmap":t=w;var l=b,q=1===e(t,l+2)?a(t,l+8):a(t,l+16),j=e(t,l+q),i=c=b=void 0;if(4===j){e(t,l+q+2);j=e(t,l+q+6)>>1;c=l+q+14;b=[];for(i=0;i<j;i++,c+=2)b[i]={end:e(t,c)};c+=2;for(i=0;i<j;i++,c+=2)b[i].start=e(t,c);for(i=0;i<j;i++,c+=2)b[i].idDelta=e(t,c);for(i=0;i<j;i++,c+=2)if(l=e(t,c),0!==l){b[i].ids=[];for(var q=
0,p=b[i].end-b[i].start+1;q<p;q++)b[i].ids[q]=e(t,c+l),l+=2}t=b}else if(12===j){a(t,l+q+4);j=a(t,l+q+12);c=l+q+16;b=[];for(i=0;i<j;i++)b.push({start:a(t,c),end:a(t,c+4),idDelta:a(t,c+8)-a(t,c)}),c+=12;t=b}else H("not supported cmap: "+j),t=void 0;break;case "glyf":u=w.subarray(b,b+i);break;case "loca":y=w.subarray(b,b+i);break;case "head":g=e(w,b+18);x=e(w,b+50);break;case "CFF ":s=(new J(new K(w,b,b+i-b),{})).parse(),s={glyphs:s.charStrings.objects,subrs:s.topDict.privateDict&&s.topDict.privateDict.subrsIndex&&
s.topDict.privateDict.subrsIndex.objects,gsubrs:s.globalSubrIndex&&s.globalSubrIndex.objects}}}return u?(h=!g?h.fontMatrix:[1/g,0,0,1/g,0,0],new z(o(u,y,x),t,h)):new R(s,t,h.fontMatrix,h.glyphNameMap)}}}();a._setCoreFonts=function(a){Q=a.Encodings;J=a.CFFParser};a.FontRendererFactory=e});(function(a,e){e(a.pdfjsCoreParser={},a.pdfjsSharedUtil,a.pdfjsCorePrimitives,a.pdfjsCoreStream)})(this,function(a,e,O,P){function N(b){return b===i}var L=e.MissingDataException,H=e.StreamType,K=e.assert,I=e.error,
J=e.info,Q=e.isArray,E=e.isInt,C=e.isNum,o=e.isString,x=e.warn,D=O.Cmd,G=O.Dict,h=O.Name,z=O.Ref,R=O.isCmd,m=O.isDict,w=O.isName,t=P.Ascii85Stream,u=P.AsciiHexStream,y=P.CCITTFaxStream,s=P.FlateStream,M=P.Jbig2Stream,g=P.JpegStream,f=P.JpxStream,d=P.LZWStream,k=P.NullStream,c=P.PredictorStream,b=P.RunLengthStream,i={},l=function(){function a(b,c,d){this.lexer=b;this.allowStreams=c;this.xref=d;this.imageCache={};this.refill()}a.prototype={refill:function(){this.buf1=this.lexer.getObj();this.buf2=this.lexer.getObj()},
shift:function(){R(this.buf2,"ID")?(this.buf1=this.buf2,this.buf2=null):(this.buf1=this.buf2,this.buf2=this.lexer.getObj())},tryShift:function(){try{return this.shift(),!0}catch(b){if(b instanceof L)throw b;return!1}},getObj:function(b){var c=this.buf1;this.shift();if(c instanceof D)switch(c.cmd){case "BI":return this.makeInlineImage(b);case "[":for(c=[];!R(this.buf1,"]")&&!N(this.buf1);)c.push(this.getObj(b));N(this.buf1)&&I("End of file inside array");this.shift();return c;case "<<":for(c=new G(this.xref);!R(this.buf1,
">>")&&!N(this.buf1);)if(w(this.buf1)){var d=this.buf1.name;this.shift();if(N(this.buf1))break;c.set(d,this.getObj(b))}else J("Malformed dictionary: key must be a name object"),this.shift();N(this.buf1)&&I("End of file inside dictionary");if(R(this.buf2,"stream"))return this.allowStreams?this.makeStream(c,b):c;this.shift();return c;default:return c}if(E(c))return E(this.buf1)&&R(this.buf2,"R")?(b=new z(c,this.buf1),this.shift(),this.shift(),b):c;o(c)&&b&&(c=b.decryptString(c));return c},findDefaultInlineStreamEnd:function(b){for(var c=
b.pos,d=0,a,f,g;-1!==(a=b.getByte());)if(0===d)d=69===a?1:0;else if(1===d)d=73===a?2:0;else if(K(2===d),32===a||10===a||13===a){g=b.peekBytes(5);for(f=0;5>f;f++)if(a=g[f],10!==a&&13!==a&&(32>a||127<a)){d=0;break}if(2===d)break}else d=0;return b.pos-4-c},findDCTDecodeInlineStreamEnd:function(b){for(var c=b.pos,d=!1,a,f;-1!==(a=b.getByte());)if(255===a){switch(b.getByte()){case 255:b.skip(-1);break;case 217:d=!0;break;case 192:case 193:case 194:case 195:case 197:case 198:case 199:case 201:case 202:case 203:case 205:case 206:case 207:case 196:case 204:case 218:case 219:case 220:case 221:case 222:case 223:case 224:case 225:case 226:case 227:case 228:case 229:case 230:case 231:case 232:case 233:case 234:case 235:case 236:case 237:case 238:case 239:case 254:f=
b.getUint16(),2<f?b.skip(f-2):b.skip(-2)}if(d)break}c=b.pos-c;if(-1===a)return x("Inline DCTDecode image stream: EOI marker not found, searching for /EI/ instead."),b.skip(-c),this.findDefaultInlineStreamEnd(b);this.inlineStreamSkipEI(b);return c},findASCII85DecodeInlineStreamEnd:function(b){for(var c=b.pos,d;-1!==(d=b.getByte());)if(126===d&&62===b.peekByte()){b.skip();break}c=b.pos-c;if(-1===d)return x("Inline ASCII85Decode image stream: EOD marker not found, searching for /EI/ instead."),b.skip(-c),
this.findDefaultInlineStreamEnd(b);this.inlineStreamSkipEI(b);return c},findASCIIHexDecodeInlineStreamEnd:function(b){for(var c=b.pos,d;-1!==(d=b.getByte())&&!(62===d););c=b.pos-c;if(-1===d)return x("Inline ASCIIHexDecode image stream: EOD marker not found, searching for /EI/ instead."),b.skip(-c),this.findDefaultInlineStreamEnd(b);this.inlineStreamSkipEI(b);return c},inlineStreamSkipEI:function(b){for(var c=0,d;-1!==(d=b.getByte());)if(0===c)c=69===d?1:0;else if(1===c)c=73===d?2:0;else if(2===c)break},
makeInlineImage:function(b){for(var c=this.lexer.stream,d=new G(this.xref);!R(this.buf1,"ID")&&!N(this.buf1);){w(this.buf1)||I("Dictionary key must be a name object");var a=this.buf1.name;this.shift();if(N(this.buf1))break;d.set(a,this.getObj(b))}var a=d.get("Filter","F"),f;w(a)?f=a.name:Q(a)&&w(a[0])&&(f=a[0].name);var a=c.pos,g;f="DCTDecode"===f||"DCT"===f?this.findDCTDecodeInlineStreamEnd(c):"ASCII85Decide"===f||"A85"===f?this.findASCII85DecodeInlineStreamEnd(c):"ASCIIHexDecode"===f||"AHx"===f?
this.findASCIIHexDecodeInlineStreamEnd(c):this.findDefaultInlineStreamEnd(c);c=c.makeSubStream(a,f,d);if(1E3>f){var e=c.getBytes();c.reset();var j=1,k=0;for(g=0,a=e.length;g<a;++g)j+=e[g]&255,k+=j;g=k%65521<<16|j%65521;if(this.imageCache.adler32===g)return this.buf2=D.get("EI"),this.shift(),this.imageCache[g].reset(),this.imageCache[g]}b&&(c=b.createStream(c,f));c=this.filter(c,d,f);c.dict=d;void 0!==g&&(c.cacheKey="inline_"+f+"_"+g,this.imageCache[g]=c);this.buf2=D.get("EI");this.shift();return c},
makeStream:function(b,c){var d=this.lexer,a=d.stream;d.skipToNextLine();var f=a.pos-1,g=b.get("Length");E(g)||(J("Bad "+g+" attribute in stream"),g=0);a.pos=f+g;d.nextChar();if(!this.tryShift()||!R(this.buf2,"endstream")){a.pos=f;for(var g=[101,110,100,115,116,114,101,97,109],e=0,j=!1,k,h;a.pos<a.end;){var i=a.peekBytes(2048),l=i.length-9;if(0>=l)break;j=!1;for(k=0,h=0;k<l;k++)if(i[k]!==g[h])k-=h,h=0;else if(h++,9<=h){k++;j=!0;break}if(j){e+=k-9;a.pos+=k-9;break}e+=l;a.pos+=l}j||I("Missing endstream");
g=e;d.nextChar();this.shift()}this.shift();this.shift();a=a.makeSubStream(f,g,b);c&&(a=c.createStream(a,g));a=this.filter(a,b,g);a.dict=b;return a},filter:function(b,c,d){var a=c.get("Filter","F"),c=c.get("DecodeParms","DP");if(w(a))return this.makeFilter(b,a.name,d,c);if(Q(a))for(var f=a,g=c,e=0,j=f.length;e<j;++e)a=f[e],w(a)||I("Bad filter name: "+a),c=null,Q(g)&&e in g&&(c=g[e]),b=this.makeFilter(b,a.name,d,c),d=null;return b},makeFilter:function(a,e,j,h){if(0===a.dict.get("Length")&&!j)return x('Empty "'+
e+'" stream.'),new k(a);try{h&&this.xref&&(h=this.xref.fetchIfRef(h));var i=this.xref.stats.streamTypes;if("FlateDecode"===e||"Fl"===e)return i[H.FLATE]=!0,h?new c(new s(a,j),j,h):new s(a,j);if("LZWDecode"===e||"LZW"===e){i[H.LZW]=!0;e=1;return h?(h.has("EarlyChange")&&(e=h.get("EarlyChange")),new c(new d(a,j,e),j,h)):new d(a,j,e)}if("DCTDecode"===e||"DCT"===e)return i[H.DCT]=!0,new g(a,j,a.dict,this.xref);if("JPXDecode"===e||"JPX"===e)return i[H.JPX]=!0,new f(a,j,a.dict);if("ASCII85Decode"===e||
"A85"===e)return i[H.A85]=!0,new t(a,j);if("ASCIIHexDecode"===e||"AHx"===e)return i[H.AHX]=!0,new u(a,j);if("CCITTFaxDecode"===e||"CCF"===e)return i[H.CCF]=!0,new y(a,j,h);if("RunLengthDecode"===e||"RL"===e)return i[H.RL]=!0,new b(a,j);if("JBIG2Decode"===e)return i[H.JBIG]=!0,new M(a,j,a.dict);x('filter "'+e+'" not supported yet');return a}catch(l){if(l instanceof L)throw l;x('Invalid stream: "'+l+'"');return new k(a)}}};return a}(),q=function(){function b(c,d){this.stream=c;this.nextChar();this.strBuf=
[];this.knownCommands=d}function c(b){return 48<=b&&57>=b?b&15:65<=b&&70>=b||97<=b&&102>=b?(b&15)+9:-1}b.isSpace=function(b){return 32===b||9===b||13===b||10===b};var d=[1,0,0,0,0,0,0,0,0,1,1,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,2,0,0,2,2,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0];b.prototype={nextChar:function(){return this.currentChar=this.stream.getByte()},peekChar:function(){return this.stream.peekByte()},getNumber:function(){var b=this.currentChar,c=!1,d=0,a=1;45===b?(a=-1,b=this.nextChar(),45===b&&(b=this.nextChar())):43===b&&(b=this.nextChar());46===b&&(d=10,b=this.nextChar());if(48>b||57<
b)return I("Invalid number: "+String.fromCharCode(b)),0;for(var f=b-48,g=0,e=1;0<=(b=this.nextChar());)if(48<=b&&57>=b)b-=48,c?g=10*g+b:(0!==d&&(d*=10),f=10*f+b);else if(46===b)if(0===d)d=1;else break;else if(45===b)x("Badly formated number");else if(69===b||101===b){b=this.peekChar();if(43===b||45===b)e=45===b?-1:1,this.nextChar();else if(48>b||57<b)break;c=!0}else break;0!==d&&(f/=d);c&&(f*=Math.pow(10,e*g));return a*f},getString:function(){var b=1,c=!1,d=this.strBuf;d.length=0;for(var a=this.nextChar();;){var f=
!1;switch(a|0){case -1:x("Unterminated string");c=!0;break;case 40:++b;d.push("(");break;case 41:0===--b?(this.nextChar(),c=!0):d.push(")");break;case 92:a=this.nextChar();switch(a){case -1:x("Unterminated string");c=!0;break;case 110:d.push("\n");break;case 114:d.push("\r");break;case 116:d.push("\t");break;case 98:d.push("\u0008");break;case 102:d.push("\u000c");break;case 92:case 40:case 41:d.push(String.fromCharCode(a));break;case 48:case 49:case 50:case 51:case 52:case 53:case 54:case 55:var g=
a&15,a=this.nextChar(),f=!0;48<=a&&55>=a&&(g=(g<<3)+(a&15),a=this.nextChar(),48<=a&&55>=a&&(f=!1,g=(g<<3)+(a&15)));d.push(String.fromCharCode(g));break;case 13:10===this.peekChar()&&this.nextChar();break;case 10:break;default:d.push(String.fromCharCode(a))}break;default:d.push(String.fromCharCode(a))}if(c)break;f||(a=this.nextChar())}return d.join("")},getName:function(){var b,a,f=this.strBuf;for(f.length=0;0<=(b=this.nextChar())&&!d[b];)if(35===b){b=this.nextChar();if(d[b]){x("Lexer_getName: NUMBER SIGN (#) should be followed by a hexadecimal number.");
f.push("#");break}var g=c(b);if(-1!==g){a=b;b=this.nextChar();var e=c(b);if(-1===e){x("Lexer_getName: Illegal digit ("+String.fromCharCode(b)+") in hexadecimal number.");f.push("#",String.fromCharCode(a));if(d[b])break;f.push(String.fromCharCode(b))}else f.push(String.fromCharCode(g<<4|e))}else f.push("#",String.fromCharCode(b))}else f.push(String.fromCharCode(b));127<f.length&&x("name token is longer than allowed by the spec: "+f.length);return h.get(f.join(""))},getHexString:function(){var b=this.strBuf;
b.length=0;for(var a=this.currentChar,f=!0,g,e;;)if(0>a){x("Unterminated hex string");break}else if(62===a){this.nextChar();break}else{if(1!==d[a]){if(f){if(g=c(a),-1===g){x('Ignoring invalid character "'+a+'" in hex string');a=this.nextChar();continue}}else{e=c(a);if(-1===e){x('Ignoring invalid character "'+a+'" in hex string');a=this.nextChar();continue}b.push(String.fromCharCode(g<<4|e))}f=!f}a=this.nextChar()}return b.join("")},getObj:function(){for(var b=!1,c=this.currentChar;;){if(0>c)return i;
if(b){if(10===c||13===c)b=!1}else if(37===c)b=!0;else if(1!==d[c])break;c=this.nextChar()}switch(c|0){case 48:case 49:case 50:case 51:case 52:case 53:case 54:case 55:case 56:case 57:case 43:case 45:case 46:return this.getNumber();case 40:return this.getString();case 47:return this.getName();case 91:return this.nextChar(),D.get("[");case 93:return this.nextChar(),D.get("]");case 60:c=this.nextChar();return 60===c?(this.nextChar(),D.get("<<")):this.getHexString();case 62:c=this.nextChar();return 62===
c?(this.nextChar(),D.get(">>")):D.get(">");case 123:return this.nextChar(),D.get("{");case 125:return this.nextChar(),D.get("}");case 41:I("Illegal character: "+c)}for(var b=String.fromCharCode(c),a=this.knownCommands,f=a&&void 0!==a[b];0<=(c=this.nextChar())&&!d[c];){var g=b+String.fromCharCode(c);if(f&&void 0===a[g])break;128===b.length&&I("Command token too long: "+b.length);b=g;f=a&&void 0!==a[b]}return"true"===b?!0:"false"===b?!1:"null"===b?null:D.get(b)},skipToNextLine:function(){for(var b=
this.currentChar;0<=b;){if(13===b){b=this.nextChar();10===b&&this.nextChar();break}else if(10===b){this.nextChar();break}b=this.nextChar()}}};return b}();a.EOF=i;a.Lexer=q;a.Linearization={create:function(b){function c(b,d){var a=e.get(b);if(E(a)&&(d?0<=a:0<a))return a;throw Error('The "'+b+'" parameter in the linearization dictionary is invalid.');}var d=new l(new q(b),!1,null),a=d.getObj(),f=d.getObj(),g=d.getObj(),e=d.getObj(),k;if(!E(a)||!E(f)||!R(g,"obj")||!m(e)||!(C(k=e.get("Linearized"))&&
0<k))return null;if((d=c("L"))!==b.length)throw Error('The "L" parameter in the linearization dictionary does not equal the stream length.');return{length:d,hints:function(){var b=e.get("H"),c,d;if(Q(b)&&(2===(c=b.length)||4===c)){for(var a=0;a<c;a++)if(!(E(d=b[a])&&0<d))throw Error("Hint ("+a+") in the linearization dictionary is invalid.");return b}throw Error("Hint array in the linearization dictionary is invalid.");}(),objectNumberFirst:c("O"),endFirst:c("E"),numPages:c("N"),mainXRefEntriesOffset:c("T"),
pageFirst:e.has("P")?c("P",!0):0}}};a.Parser=l;a.isEOF=N;P._setCoreParser(a)});(function(a,e){e(a.pdfjsCoreCMap={},a.pdfjsSharedUtil,a.pdfjsCorePrimitives,a.pdfjsCoreStream,a.pdfjsCoreParser)})(this,function(a,e,O,P,N){var L=e.Util,H=e.assert,K=e.error,I=e.isInt,J=e.isString,Q=e.warn,E=O.isName,C=O.isCmd,o=O.isStream,x=P.StringStream,D=N.Lexer,G=N.isEOF,h="Adobe-GB1-UCS2,Adobe-CNS1-UCS2,Adobe-Japan1-UCS2,Adobe-Korea1-UCS2,78-EUC-H,78-EUC-V,78-H,78-RKSJ-H,78-RKSJ-V,78-V,78ms-RKSJ-H,78ms-RKSJ-V,83pv-RKSJ-H,90ms-RKSJ-H,90ms-RKSJ-V,90msp-RKSJ-H,90msp-RKSJ-V,90pv-RKSJ-H,90pv-RKSJ-V,Add-H,Add-RKSJ-H,Add-RKSJ-V,Add-V,Adobe-CNS1-0,Adobe-CNS1-1,Adobe-CNS1-2,Adobe-CNS1-3,Adobe-CNS1-4,Adobe-CNS1-5,Adobe-CNS1-6,Adobe-GB1-0,Adobe-GB1-1,Adobe-GB1-2,Adobe-GB1-3,Adobe-GB1-4,Adobe-GB1-5,Adobe-Japan1-0,Adobe-Japan1-1,Adobe-Japan1-2,Adobe-Japan1-3,Adobe-Japan1-4,Adobe-Japan1-5,Adobe-Japan1-6,Adobe-Korea1-0,Adobe-Korea1-1,Adobe-Korea1-2,B5-H,B5-V,B5pc-H,B5pc-V,CNS-EUC-H,CNS-EUC-V,CNS1-H,CNS1-V,CNS2-H,CNS2-V,ETHK-B5-H,ETHK-B5-V,ETen-B5-H,ETen-B5-V,ETenms-B5-H,ETenms-B5-V,EUC-H,EUC-V,Ext-H,Ext-RKSJ-H,Ext-RKSJ-V,Ext-V,GB-EUC-H,GB-EUC-V,GB-H,GB-V,GBK-EUC-H,GBK-EUC-V,GBK2K-H,GBK2K-V,GBKp-EUC-H,GBKp-EUC-V,GBT-EUC-H,GBT-EUC-V,GBT-H,GBT-V,GBTpc-EUC-H,GBTpc-EUC-V,GBpc-EUC-H,GBpc-EUC-V,H,HKdla-B5-H,HKdla-B5-V,HKdlb-B5-H,HKdlb-B5-V,HKgccs-B5-H,HKgccs-B5-V,HKm314-B5-H,HKm314-B5-V,HKm471-B5-H,HKm471-B5-V,HKscs-B5-H,HKscs-B5-V,Hankaku,Hiragana,KSC-EUC-H,KSC-EUC-V,KSC-H,KSC-Johab-H,KSC-Johab-V,KSC-V,KSCms-UHC-H,KSCms-UHC-HW-H,KSCms-UHC-HW-V,KSCms-UHC-V,KSCpc-EUC-H,KSCpc-EUC-V,Katakana,NWP-H,NWP-V,RKSJ-H,RKSJ-V,Roman,UniCNS-UCS2-H,UniCNS-UCS2-V,UniCNS-UTF16-H,UniCNS-UTF16-V,UniCNS-UTF32-H,UniCNS-UTF32-V,UniCNS-UTF8-H,UniCNS-UTF8-V,UniGB-UCS2-H,UniGB-UCS2-V,UniGB-UTF16-H,UniGB-UTF16-V,UniGB-UTF32-H,UniGB-UTF32-V,UniGB-UTF8-H,UniGB-UTF8-V,UniJIS-UCS2-H,UniJIS-UCS2-HW-H,UniJIS-UCS2-HW-V,UniJIS-UCS2-V,UniJIS-UTF16-H,UniJIS-UTF16-V,UniJIS-UTF32-H,UniJIS-UTF32-V,UniJIS-UTF8-H,UniJIS-UTF8-V,UniJIS2004-UTF16-H,UniJIS2004-UTF16-V,UniJIS2004-UTF32-H,UniJIS2004-UTF32-V,UniJIS2004-UTF8-H,UniJIS2004-UTF8-V,UniJISPro-UCS2-HW-V,UniJISPro-UCS2-V,UniJISPro-UTF8-V,UniJISX0213-UTF32-H,UniJISX0213-UTF32-V,UniJISX02132004-UTF32-H,UniJISX02132004-UTF32-V,UniKS-UCS2-H,UniKS-UCS2-V,UniKS-UTF16-H,UniKS-UTF16-V,UniKS-UTF32-H,UniKS-UTF32-V,UniKS-UTF8-H,UniKS-UTF8-V,V,WP-Symbol".split(","),
z=function(){function a(e){this.codespaceRanges=[[],[],[],[]];this.numCodespaceRanges=0;this._map=[];this.name="";this.vertical=!1;this.useCMap=null;this.builtInCMap=e}a.prototype={addCodespaceRange:function(a,e,h){this.codespaceRanges[a-1].push(e,h);this.numCodespaceRanges++},mapCidRange:function(a,e,h){for(;a<=e;)this._map[a++]=h++},mapBfRange:function(a,e,h){for(var s=h.length-1;a<=e;)this._map[a++]=h,h=h.substr(0,s)+String.fromCharCode(h.charCodeAt(s)+1)},mapBfRangeToArray:function(a,e,h){for(var s=
0,m=h.length;a<=e&&s<m;)this._map[a]=h[s++],++a},mapOne:function(a,e){this._map[a]=e},lookup:function(a){return this._map[a]},contains:function(a){return void 0!==this._map[a]},forEach:function(a){var e=this._map,h=e.length,s;if(65536>=h)for(s=0;s<h;s++)void 0!==e[s]&&a(s,e[s]);else for(s in this._map)a(s,e[s])},charCodeOf:function(a){return this._map.indexOf(a)},getMap:function(){return this._map},readCharCode:function(a,e,h){for(var s=0,m=this.codespaceRanges,g=this.codespaceRanges.length,f=0;f<
g;f++)for(var s=(s<<8|a.charCodeAt(e+f))>>>0,d=m[f],k=0,c=d.length;k<c;){var b=d[k++],i=d[k++];if(s>=b&&s<=i){h.charcode=s;h.length=f+1;return}}h.charcode=0;h.length=1},get length(){return this._map.length},get isIdentityCMap(){if(!("Identity-H"===this.name||"Identity-V"===this.name)||65536!==this._map.length)return!1;for(var a=0;65536>a;a++)if(this._map[a]!==a)return!1;return!0}};return a}(),R=function(){function a(e,h){z.call(this);this.vertical=e;this.addCodespaceRange(h,0,65535)}L.inherit(a,z,
{});a.prototype={addCodespaceRange:z.prototype.addCodespaceRange,mapCidRange:function(){K("should not call mapCidRange")},mapBfRange:function(){K("should not call mapBfRange")},mapBfRangeToArray:function(){K("should not call mapBfRangeToArray")},mapOne:function(){K("should not call mapCidOne")},lookup:function(a){return I(a)&&65535>=a?a:void 0},contains:function(a){return I(a)&&65535>=a},forEach:function(a){for(var e=0;65535>=e;e++)a(e,e)},charCodeOf:function(a){return I(a)&&65535>=a?a:-1},getMap:function(){for(var a=
Array(65536),e=0;65535>=e;e++)a[e]=e;return a},readCharCode:z.prototype.readCharCode,get length(){return 65536},get isIdentityCMap(){K("should not access .isIdentityCMap")}};return a}(),m=function(){function a(d){var f=PDFJS.disableWorker,c=new XMLHttpRequest;c.open("GET",d,!1);if(!f)try{c.responseType="arraybuffer",f="arraybuffer"!==c.responseType}catch(b){f=!0}f&&c.overrideMimeType&&c.overrideMimeType("text/plain; charset=x-user-defined");c.send(null);(f?!c.responseText:!c.response)&&K("Unable to get binary cMap at: "+
d);return f?(d=Array.prototype.map.call(c.responseText,function(b){return b.charCodeAt(0)&255}),new Uint8Array(d)):new Uint8Array(c.response)}function e(d,a){for(var c=0,b=0;b<=a;b++)c=c<<8|d[b];return c>>>0}function h(d,a){return 1===a?String.fromCharCode(d[0],d[1]):3===a?String.fromCharCode(d[0],d[1],d[2],d[3]):String.fromCharCode.apply(null,d.subarray(0,a+1))}function m(d,a,c){for(var b=0;0<=c;c--)b+=d[c]+a[c],d[c]=b&255,b>>=8}function s(d,a){for(var c=1,b=a;0<=b&&0<c;b--)c+=d[b],d[b]=c&255,c>>=
8}function o(d){this.buffer=d;this.pos=0;this.end=d.length;this.tmpBuf=new Uint8Array(f)}function g(){}var f=19;o.prototype={readByte:function(){return this.pos>=this.end?-1:this.buffer[this.pos++]},readNumber:function(){var d=0,a;do{var c=this.readByte();0>c&&K("unexpected EOF in bcmap");a=!(c&128);d=d<<7|c&127}while(!a);return d},readSigned:function(){var a=this.readNumber();return a&1?~(a>>>1):a>>>1},readHex:function(a,f){a.set(this.buffer.subarray(this.pos,this.pos+f+1));this.pos+=f+1},readHexNumber:function(a,
f){var c,b=this.tmpBuf,g=0;do{var e=this.readByte();0>e&&K("unexpected EOF in bcmap");c=!(e&128);b[g++]=e&127}while(!c);c=f;for(var h=e=0;0<=c;){for(;8>h&&0<b.length;)e|=b[--g]<<h,h+=7;a[c]=e&255;c--;e>>=8;h-=8}},readHexSigned:function(a,f){this.readHexNumber(a,f);for(var c=a[f]&1?255:0,b=0,g=0;g<=f;g++)b=(b&1)<<8|a[g],a[g]=b>>1^c},readString:function(){for(var a=this.readNumber(),f="",c=0;c<a;c++)f+=String.fromCharCode(this.readNumber());return f}};g.prototype={read:function(d,f,c){var d=a(d),d=
new o(d),b=d.readByte();f.vertical=!!(b&1);for(var b=null,g=new Uint8Array(16),l=new Uint8Array(16),q=new Uint8Array(16),j=new Uint8Array(16),p=new Uint8Array(16),v,n;0<=(n=d.readByte());)if(v=n>>5,7===v)switch(n&31){case 0:d.readString();break;case 1:b=d.readString()}else{var r=!!(n&16);n&=15;H(16>=n+1);var B=d.readNumber(),F;switch(v){case 0:d.readHex(g,n);d.readHexNumber(l,n);m(l,g,n);f.addCodespaceRange(n+1,e(g,n),e(l,n));for(F=1;F<B;F++)s(l,n),d.readHexNumber(g,n),m(g,l,n),d.readHexNumber(l,
n),m(l,g,n),f.addCodespaceRange(n+1,e(g,n),e(l,n));break;case 1:d.readHex(g,n);d.readHexNumber(l,n);m(l,g,n);d.readNumber();for(F=1;F<B;F++)s(l,n),d.readHexNumber(g,n),m(g,l,n),d.readHexNumber(l,n),m(l,g,n),d.readNumber();break;case 2:d.readHex(q,n);v=d.readNumber();f.mapOne(e(q,n),v);for(F=1;F<B;F++)s(q,n),r||(d.readHexNumber(p,n),m(q,p,n)),v=d.readSigned()+(v+1),f.mapOne(e(q,n),v);break;case 3:d.readHex(g,n);d.readHexNumber(l,n);m(l,g,n);v=d.readNumber();f.mapCidRange(e(g,n),e(l,n),v);for(F=1;F<
B;F++)s(l,n),r?g.set(l):(d.readHexNumber(g,n),m(g,l,n)),d.readHexNumber(l,n),m(l,g,n),v=d.readNumber(),f.mapCidRange(e(g,n),e(l,n),v);break;case 4:d.readHex(q,1);d.readHex(j,n);f.mapOne(e(q,1),h(j,n));for(F=1;F<B;F++)s(q,1),r||(d.readHexNumber(p,1),m(q,p,1)),s(j,n),d.readHexSigned(p,n),m(j,p,n),f.mapOne(e(q,1),h(j,n));break;case 5:d.readHex(g,1);d.readHexNumber(l,1);m(l,g,1);d.readHex(j,n);f.mapBfRange(e(g,1),e(l,1),h(j,n));for(F=1;F<B;F++)s(l,1),r?g.set(l):(d.readHexNumber(g,1),m(g,l,1)),d.readHexNumber(l,
1),m(l,g,1),d.readHex(j,n),f.mapBfRange(e(g,1),e(l,1),h(j,n));break;default:K("Unknown type: "+v)}}b&&c(b);return f}};return g}(),e=function(){function a(f){for(var d=0,g=0;g<f.length;g++)d=d<<8|f.charCodeAt(g);return d>>>0}function e(a){J(a)||K("Malformed CMap: expected string.")}function u(a){I(a)||K("Malformed CMap: expected int.")}function y(f,d,g,c){var b,h;a:for(;;){var l=d.getObj();if(G(l))break;else if(E(l)){if("WMode"===l.name){b=f;var q=d.getObj();I(q)&&(b.vertical=!!q)}else"CMapName"===
l.name&&(b=f,q=d.getObj(),E(q)&&J(q.name)&&(b.name=q.name));b=l}else if(C(l))switch(l.cmd){case "endcmap":break a;case "usecmap":E(b)&&(h=b.name);break;case "begincodespacerange":b:{l=f;for(q=d;;){var j=q.getObj();if(G(j))break;if(C(j,"endcodespacerange"))break b;if(!J(j))break;var p=a(j),j=q.getObj();if(!J(j))break;var v=a(j);l.addCodespaceRange(j.length,p,v)}K("Invalid codespace range.")}break;case "beginbfchar":l=f;for(q=d;;){j=q.getObj();if(G(j))break;if(C(j,"endbfchar"))break;e(j);p=a(j);j=q.getObj();
e(j);l.mapOne(p,j)}break;case "begincidchar":l=f;for(q=d;;){j=q.getObj();if(G(j))break;if(C(j,"endcidchar"))break;e(j);p=a(j);j=q.getObj();u(j);l.mapOne(p,j)}break;case "beginbfrange":b:{l=f;for(q=d;;){v=q.getObj();if(G(v))break;if(C(v,"endbfrange"))break b;e(v);j=a(v);v=q.getObj();e(v);p=a(v);v=q.getObj();if(I(v)||J(v))v=I(v)?String.fromCharCode(v):v,l.mapBfRange(j,p,v);else if(C(v,"[")){for(var v=q.getObj(),n=[];!C(v,"]")&&!G(v);)n.push(v),v=q.getObj();l.mapBfRangeToArray(j,p,n)}else break}K("Invalid bf range.")}break;
case "begincidrange":l=f;for(q=d;;){j=q.getObj();if(G(j))break;if(C(j,"endcidrange"))break;e(j);p=a(j);j=q.getObj();e(j);v=a(j);j=q.getObj();u(j);l.mapCidRange(p,v,j)}}}!c&&h&&(c=h);c&&s(f,g,c)}function s(a,d,e){a.useCMap=g(e,d);if(0===a.numCodespaceRanges){d=a.useCMap.codespaceRanges;for(e=0;e<d.length;e++)a.codespaceRanges[e]=d[e].slice();a.numCodespaceRanges=a.useCMap.numCodespaceRanges}a.useCMap.forEach(function(c){a.contains(c)||a.mapOne(c,a.useCMap.lookup(c))})}function M(a,d){var g=d.url+a+
".bcmap",c=new z(!0);(new m).read(g,c,function(b){s(c,d,b)});return c}function g(a,d){if("Identity-H"===a)return new R(!1,2);if("Identity-V"===a)return new R(!0,2);-1===h.indexOf(a)&&K("Unknown cMap name: "+a);H(d,"built-in cMap parameters are not provided");if(d.packed)return M(a,d);var g=new XMLHttpRequest,c=d.url+a;g.open("GET",c,!1);g.send(null);g.responseText||K("Unable to get cMap at: "+c);c=new z(!0);g=new D(new x(g.responseText));y(c,g,d,null);return c}return{create:function(a,d,e){if(E(a))return g(a.name,
d);if(o(a)){var c=new z,a=new D(a);try{y(c,a,d,e)}catch(b){Q("Invalid CMap data. "+b)}return c.isIdentityCMap?g(c.name,d):c}K("Encoding required.")}}}();a.CMap=z;a.CMapFactory=e;a.IdentityCMap=R});(function(a,e){e(a.pdfjsCoreObj={},a.pdfjsSharedUtil,a.pdfjsCorePrimitives,a.pdfjsCoreCrypto,a.pdfjsCoreParser,a.pdfjsCoreChunkedStream)})(this,function(a,e,O,P,N,L){var H=e.InvalidPDFException,K=e.MissingDataException,I=e.XRefParseException,J=e.assert,Q=e.bytesToString,E=e.createPromiseCapability,C=e.error,
o=e.info,x=e.isArray,D=e.isInt,G=e.isString,h=e.shadow,z=e.stringToPDFString,R=e.stringToUTF8String,m=e.warn,w=O.Ref,t=O.RefSet,u=O.RefSetCache,y=O.isName,s=O.isCmd,M=O.isDict,g=O.isRef,f=O.isStream,d=P.CipherTransformFactory,k=N.Lexer,c=N.Parser,b=L.ChunkedStream,e=function(){function b(c,a,d){this.pdfManager=c;this.xref=a;this.catDict=a.getCatalogObj();this.fontCache=new u;J(M(this.catDict),"catalog object is not a dictionary");this.pageFactory=d;this.pagePromises=[]}b.prototype={get metadata(){var b=
this.catDict.getRaw("Metadata");if(!g(b))return h(this,"metadata",null);var b=this.xref.fetch(b,!(!this.xref.encrypt?0:this.xref.encrypt.encryptMetadata)),c;if(b&&M(b.dict)){var a=b.dict.get("Type"),d=b.dict.get("Subtype");if(y(a)&&y(d)&&"Metadata"===a.name&&"XML"===d.name)try{c=R(Q(b.getBytes()))}catch(f){o("Skipping invalid metadata.")}}return h(this,"metadata",c)},get toplevelPagesDict(){var b=this.catDict.get("Pages");J(M(b),"invalid top-level pages dictionary");return h(this,"toplevelPagesDict",
b)},get documentOutline(){var b=null;try{b=this.readDocumentOutline()}catch(c){if(c instanceof K)throw c;m("Unable to read document outline")}return h(this,"documentOutline",b)},readDocumentOutline:function(){var b=this.xref,c=this.catDict.get("Outlines"),a={items:[]};if(M(c)){var c=c.getRaw("First"),d=new t;if(g(c)){var f=[{obj:c,parent:a}];for(d.put(c);0<f.length;){var e=f.shift(),h=b.fetchIfRef(e.obj);if(null!==h){h.has("Title")||C("Invalid outline item");(c=h.get("A"))?c=c.get("D"):h.has("Dest")&&
(c=h.getRaw("Dest"),y(c)&&(c=c.name));var k=h.get("Title"),k={dest:c,title:z(k),color:h.get("C")||[0,0,0],count:h.get("Count"),bold:!!(h.get("F")&2),italic:!!(h.get("F")&1),items:[]};e.parent.items.push(k);c=h.getRaw("First");g(c)&&!d.has(c)&&(f.push({obj:c,parent:k}),d.put(c));c=h.getRaw("Next");g(c)&&!d.has(c)&&(f.push({obj:c,parent:e.parent}),d.put(c))}}}}return 0<a.items.length?a.items:null},get numPages(){var b=this.toplevelPagesDict.get("Count");J(D(b),"page count in top level pages object is not an integer");
return h(this,"num",b)},get destinations(){var b=this.xref,c={},a,d,f=this.catDict.get("Names");f&&f.has("Dests")?a=f.getRaw("Dests"):this.catDict.has("Dests")&&(d=this.catDict.get("Dests"));d&&d.forEach(function(b,a){a&&(c[b]=M(a)?a.get("D"):a)});if(a){var b=(new i(a,b)).getAll(),g;for(g in b)b.hasOwnProperty(g)&&(c[g]=M(b[g])?b[g].get("D"):b[g])}return h(this,"destinations",c)},getDestination:function(b){var c=this.xref,a=null,d,f,g=this.catDict.get("Names");g&&g.has("Dests")?d=g.getRaw("Dests"):
this.catDict.has("Dests")&&(f=this.catDict.get("Dests"));f&&(f=f.get(b))&&(a=M(f)?f.get("D"):f);d&&(b=(new i(d,c)).get(b),a=M(b)?b.get("D"):b);return a},get attachments(){var b=this.xref,c=null,a,d=this.catDict.get("Names");d&&(a=d.getRaw("EmbeddedFiles"));if(a){a=(new i(a,b)).getAll();for(var f in a)a.hasOwnProperty(f)&&(d=new l(a[f],b),c||(c={}),c[z(f)]=d.serializable)}return h(this,"attachments",c)},get javaScript(){function b(c){var a=c.get("S");if(y(a)&&"JavaScript"===a.name){c=c.get("JS");if(f(c))c=
Q(c.getBytes());else if(!G(c))return;d.push(z(c))}}var c=this.xref,a=this.catDict.get("Names"),d=[];if(a&&a.has("JavaScript")){var c=(new i(a.getRaw("JavaScript"),c)).getAll(),g;for(g in c)c.hasOwnProperty(g)&&(a=c[g],M(a)&&b(a))}g=this.catDict.get("OpenAction");M(g,"Action")&&(c=g.get("S"),y(c)&&"Named"===c.name?(g=g.get("N"),y(g)&&"Print"===g.name&&d.push("print({});")):b(g));return h(this,"javaScript",d)},cleanup:function(){var b=[];this.fontCache.forEach(function(c){b.push(c)});return Promise.all(b).then(function(b){for(var c=
0,a=b.length;c<a;c++)delete b[c].dict.translated;this.fontCache.clear()}.bind(this))},getPage:function(b){b in this.pagePromises||(this.pagePromises[b]=this.getPageDict(b).then(function(c){return this.pageFactory.createPage(b,c[0],c[1],this.fontCache)}.bind(this)));return this.pagePromises[b]},getPageDict:function(b){function c(){for(;d.length;){var k=d.pop();if(g(k)){e.fetchAsync(k).then(function(g){M(g,"Page")||M(g)&&!g.has("Kids")?b===f?a.resolve([g,k]):(f++,c()):(d.push(g),c())},a.reject);return}J(M(k),
"page dictionary kid reference points to wrong type of object");var i=k.get("Count");0===i&&(h=!0);if(f+i<=b)f+=i;else{var l=k.get("Kids");J(x(l),"page dictionary kids object is not an array");if(!h&&i===l.length)d=[l[b-f]],f=b;else for(i=l.length-1;0<=i;i--)d.push(l[i])}}a.reject("Page index "+b+" not found.")}var a=E(),d=[this.catDict.getRaw("Pages")],f=0,e=this.xref,h=!1;c();return a.promise},getPageIndex:function(b){function c(b){var a=0,f;return d.fetchAsync(b).then(function(b){if(!b)return null;
f=b.getRaw("Parent");return b.getAsync("Parent")}).then(function(b){return!b?null:b.getAsync("Kids")}).then(function(c){if(!c)return null;for(var e=[],h=!1,j=0;j<c.length;j++){var k=c[j];J(g(k),"kids must be a ref");if(k.num===b.num){h=!0;break}e.push(d.fetchAsync(k).then(function(b){b.has("Count")?(b=b.get("Count"),a+=b):a++}))}h||C("kid ref not found in parents kids");return Promise.all(e).then(function(){return[a,f]})})}function a(b){return c(b).then(function(b){if(!b)return f;var c=b[1];f+=b[0];
return a(c)})}var d=this.xref,f=0;return a(b)}};return b}(),O=function(){function b(c,a){this.stream=c;this.entries=[];this.xrefstms={};this.cache=[];this.password=a;this.stats={streamTypes:[],fontTypes:[]}}b.prototype={setStartXRef:function(b){this.startXRefQueue=[b]},parse:function(b){b?(m("Indexing all PDF objects"),b=this.indexObjects()):b=this.readXRef();b.assignXref(this);this.trailer=b;var c=b.get("Encrypt");if(c){var a=b.get("ID");this.encrypt=new d(c,a&&a.length?a[0]:"",this.password)}(this.root=
b.get("Root"))||C("Invalid root reference")},processXRefTable:function(b){"tableState"in this||(this.tableState={entryNum:0,streamPos:b.lexer.stream.pos,parserBuf1:b.buf1,parserBuf2:b.buf2});var c=this.readXRefTable(b);s(c,"trailer")||C("Invalid XRef table: could not find trailer dictionary");b=b.getObj();!M(b)&&b.dict&&(b=b.dict);M(b)||C("Invalid XRef table: could not parse trailer dictionary");delete this.tableState;return b},readXRefTable:function(b){var c=b.lexer.stream,a=this.tableState;c.pos=
a.streamPos;b.buf1=a.parserBuf1;b.buf2=a.parserBuf2;for(var d;;){if(!("firstEntryNum"in a)||!("entryCount"in a)){if(s(d=b.getObj(),"trailer"))break;a.firstEntryNum=d;a.entryCount=b.getObj()}var f=a.firstEntryNum,g=a.entryCount;(!D(f)||!D(g))&&C("Invalid XRef table: wrong types in subsection header");for(var e=a.entryNum;e<g;e++){a.streamPos=c.pos;a.entryNum=e;a.parserBuf1=b.buf1;a.parserBuf2=b.buf2;var h={};h.offset=b.getObj();h.gen=b.getObj();var k=b.getObj();s(k,"f")?h.free=!0:s(k,"n")&&(h.uncompressed=
!0);(!D(h.offset)||!D(h.gen)||!h.free&&!h.uncompressed)&&C("Invalid entry in XRef subsection: "+f+", "+g);this.entries[e+f]||(this.entries[e+f]=h)}a.entryNum=0;a.streamPos=c.pos;a.parserBuf1=b.buf1;a.parserBuf2=b.buf2;delete a.firstEntryNum;delete a.entryCount}1===f&&this.entries[1]&&this.entries[1].free&&this.entries.shift();this.entries[0]&&!this.entries[0].free&&C("Invalid XRef table: unexpected first object");return d},processXRefStream:function(b){if(!("streamState"in this)){var c=b.dict,a=c.get("W"),
d=c.get("Index");d||(d=[0,c.get("Size")]);this.streamState={entryRanges:d,byteWidths:a,entryNum:0,streamPos:b.pos}}this.readXRefStream(b);delete this.streamState;return b.dict},readXRefStream:function(b){var c,a,d=this.streamState;b.pos=d.streamPos;c=d.byteWidths;for(var f=c[0],g=c[1],e=c[2],h=d.entryRanges;0<h.length;){var k=h[0],i=h[1];(!D(k)||!D(i))&&C("Invalid XRef range fields: "+k+", "+i);(!D(f)||!D(g)||!D(e))&&C("Invalid XRef entry fields length: "+k+", "+i);for(c=d.entryNum;c<i;++c){d.entryNum=
c;d.streamPos=b.pos;var l=0,q=0,m=0;for(a=0;a<f;++a)l=l<<8|b.getByte();0===f&&(l=1);for(a=0;a<g;++a)q=q<<8|b.getByte();for(a=0;a<e;++a)m=m<<8|b.getByte();a={};a.offset=q;a.gen=m;switch(l){case 0:a.free=!0;break;case 1:a.uncompressed=!0;break;case 2:break;default:C("Invalid XRef entry type: "+l)}this.entries[k+c]||(this.entries[k+c]=a)}d.entryNum=0;d.streamPos=b.pos;h.splice(0,2)}},indexObjects:function(){function b(c,a){for(var e="",h=c[a];h!==d&&h!==f&&h!==g&&!(++a>=c.length);){e+=String.fromCharCode(h);
h=c[a]}return e}function a(b,c,d){for(var f=d.length,g=b.length,e=0;c<g;){for(var h=0;h<f&&b[c+h]===d[h];)++h;if(h>=f)break;c++;e++}return e}var d=10,f=13,g=60,e=/^(\d+)\s+(\d+)\s+obj\b/,h=new Uint8Array([116,114,97,105,108,101,114]),i=new Uint8Array([115,116,97,114,116,120,114,101,102]),l=new Uint8Array([101,110,100,111,98,106]),q=new Uint8Array([47,88,82,101,102]);this.entries.length=0;var m=this.stream;m.pos=0;for(var t=m.getBytes(),u=m.start,o=t.length,w=[],y=[];u<o;){var z=t[u];if(9===z||z===
d||z===f||32===z)++u;else if(37===z){do{++u;if(u>=o)break;z=t[u]}while(z!==d&&z!==f)}else{var z=b(t,u),x;if(0===z.indexOf("xref")&&(4===z.length||/\s/.test(z[4])))u+=a(t,u,h),w.push(u),u+=a(t,u,i);else if(x=e.exec(z)){"undefined"===typeof this.entries[x[1]]&&(this.entries[x[1]]={offset:u-m.start,gen:x[2]|0,uncompressed:!0});z=a(t,u,l)+7;x=t.subarray(u,u+z);var D=a(x,0,q);D<z&&64>x[D+5]&&(y.push(u-m.start),this.xrefstms[u-m.start]=1);u+=z}else 0===z.indexOf("trailer")&&(7===z.length||/\s/.test(z[7]))?
(w.push(u),u+=a(t,u,i)):u+=z.length+1}}for(e=0,h=y.length;e<h;++e)this.startXRefQueue.push(y[e]),this.readXRef(!0);var C;for(e=0,h=w.length;e<h;++e)if(m.pos=w[e],y=new c(new k(m),!0,this),i=y.getObj(),s(i,"trailer")&&M(C=y.getObj())&&C.has("ID"))return C;if(C)return C;throw new H("Invalid PDF structure");},readXRef:function(b){var a=this.stream;try{for(;this.startXRefQueue.length;){a.pos=this.startXRefQueue[0]+a.start;var d=new c(new k(a),!0,this),e=d.getObj(),h;if(s(e,"xref")){if(h=this.processXRefTable(d),
this.topDict||(this.topDict=h),e=h.get("XRefStm"),D(e)){var i=e;i in this.xrefstms||(this.xrefstms[i]=1,this.startXRefQueue.push(i))}}else D(e)?((!D(d.getObj())||!s(d.getObj(),"obj")||!f(e=d.getObj()))&&C("Invalid XRef stream"),h=this.processXRefStream(e),this.topDict||(this.topDict=h),h||C("Failed to read XRef stream")):C("Invalid XRef stream header");e=h.get("Prev");D(e)?this.startXRefQueue.push(e):g(e)&&this.startXRefQueue.push(e.num);this.startXRefQueue.shift()}return this.topDict}catch(l){if(l instanceof
K)throw l;o("(while reading XRef): "+l)}if(!b)throw new I;},getEntry:function(b){return(b=this.entries[b])&&!b.free&&b.offset?b:null},fetchIfRef:function(b){return!g(b)?b:this.fetch(b)},fetch:function(b,c){J(g(b),"ref object is not a reference");var a=b.num;if(a in this.cache)return this.cache[a];var d=this.getEntry(a);if(null===d)return this.cache[a]=null;d=d.uncompressed?this.fetchUncompressed(b,d,c):this.fetchCompressed(d,c);M(d)?d.objId=b.toString():f(d)&&(d.dict.objId=b.toString());return d},
fetchUncompressed:function(b,a,d){var g=b.gen,b=b.num;a.gen!==g&&C("inconsistent generation in XRef");var a=this.stream.makeSubStream(a.offset+this.stream.start),a=new c(new k(a),!0,this),e=a.getObj(),h=a.getObj(),i=a.getObj();(!D(e)||parseInt(e,10)!==b||!D(h)||parseInt(h,10)!==g||!s(i))&&C("bad XRef entry");if(!s(i,"obj")){if(0===i.cmd.indexOf("obj")&&(b=parseInt(i.cmd.substring(3),10),!isNaN(b)))return b;C("bad XRef entry")}a=this.encrypt&&!d?a.getObj(this.encrypt.createCipherTransform(b,g)):a.getObj();
f(a)||(this.cache[b]=a);return a},fetchCompressed:function(b){var a=b.offset,d=this.fetch(new w(a,0));f(d)||C("bad ObjStm stream");var g=d.dict.get("First"),e=d.dict.get("N");(!D(g)||!D(e))&&C("invalid first and n parameters for ObjStm stream");d=new c(new k(d),!1,this);d.allowStreams=!0;for(var h=[],i,l=[],g=0;g<e;++g)i=d.getObj(),D(i)||C("invalid object number in the ObjStm stream: "+i),l.push(i),i=d.getObj(),D(i)||C("invalid object offset in the ObjStm stream: "+i);for(g=0;g<e;++g){h.push(d.getObj());
i=l[g];var q=this.entries[i];q&&q.offset===a&&q.gen===g&&(this.cache[i]=h[g])}b=h[b.gen];void 0===b&&C("bad XRef entry for compressed object");return b},fetchIfRefAsync:function(b){return!g(b)?Promise.resolve(b):this.fetchAsync(b)},fetchAsync:function(b,c){var a=this.stream.manager,d=this;return new Promise(function B(f,g){try{f(d.fetch(b,c))}catch(e){e instanceof K?a.requestRange(e.begin,e.end).then(function(){B(f,g)},g):g(e)}})},getCatalogObj:function(){return this.root}};return b}(),i=function(){function b(c,
a){this.root=c;this.xref=a}b.prototype={getAll:function(){var b={};if(!this.root)return b;var c=this.xref,a=new t;a.put(this.root);for(var d=[this.root];0<d.length;){var f,g;f=c.fetchIfRef(d.shift());if(M(f))if(f.has("Kids")){var e=f.get("Kids");for(f=0,g=e.length;f<g;f++){var h=e[f];a.has(h)&&C("invalid destinations");d.push(h);a.put(h)}}else if(e=f.get("Names"))for(f=0,g=e.length;f<g;f+=2)b[c.fetchIfRef(e[f])]=c.fetchIfRef(e[f+1])}return b},get:function(b){if(!this.root)return null;for(var c=this.xref,
a=c.fetchIfRef(this.root),d=0,f,g,e;a.has("Kids");){d++;if(10<d)return m("Search depth limit for named destionations has been reached."),null;var h=a.get("Kids");if(!x(h))return null;f=0;for(g=h.length-1;f<=g;){e=f+g>>1;var k=c.fetchIfRef(h[e]).get("Limits");if(b<c.fetchIfRef(k[0]))g=e-1;else if(b>c.fetchIfRef(k[1]))f=e+1;else{a=c.fetchIfRef(h[e]);break}}if(f>g)return null}a=a.get("Names");if(x(a)){f=0;for(g=a.length-2;f<=g;)if(e=f+g&-2,b<c.fetchIfRef(a[e]))g=e-2;else if(b>c.fetchIfRef(a[e]))f=e+
2;else return c.fetchIfRef(a[e+1])}return null}};return b}(),l=function(){function b(c,a){c&&M(c)&&(this.xref=a,this.root=c,c.has("FS")&&(this.fs=c.get("FS")),this.description=c.has("Desc")?z(c.get("Desc")):"",c.has("RF")&&m("Related file specifications are not supported"),this.contentAvailable=!0,c.has("EF")||(this.contentAvailable=!1,m("Non-embedded file specifications are not supported")))}function c(b){return b.has("UF")?b.get("UF"):b.has("F")?b.get("F"):b.has("Unix")?b.get("Unix"):b.has("Mac")?
b.get("Mac"):b.has("DOS")?b.get("DOS"):null}b.prototype={get filename(){if(!this._filename&&this.root){var b=c(this.root)||"unnamed";this._filename=z(b).replace(/\\\\/g,"\\").replace(/\\\//g,"/").replace(/\\/g,"/")}return this._filename},get content(){if(!this.contentAvailable)return null;!this.contentRef&&this.root&&(this.contentRef=c(this.root.get("EF")));var b=null;if(this.contentRef){var a=this.xref.fetchIfRef(this.contentRef);a&&f(a)?b=a.getBytes():m("Embedded file specification points to non-existing/invalid content")}else m("Embedded file specification does not have a content");
return b},get serializable(){return{filename:this.filename,content:this.content}}};return b}(),P=function(){function c(b,a){var d;if(M(b)||f(b)){var e;e=M(b)?b.map:b.dict.map;for(var h in e)d=e[h],(g(d)||M(d)||x(d)||f(d))&&a.push(d)}else if(x(b)){e=0;for(h=b.length;e<h;e++)d=b[e],(g(d)||M(d)||x(d)||f(d))&&a.push(d)}}function a(b,c,d){this.obj=b;this.keys=c;this.xref=d;this.capability=this.refSet=null}a.prototype={load:function(){var c=this.keys;this.capability=E();if(!(this.xref.stream instanceof
b)||0===this.xref.stream.getMissingChunks().length)return this.capability.resolve(),this.capability.promise;this.refSet=new t;for(var a=[],d=0;d<c.length;d++)a.push(this.obj[c[d]]);this._walk(a);return this.capability.promise},_walk:function(b){for(var a=[],d=[];b.length;){var f=b.pop();if(g(f)){if(this.refSet.has(f))continue;try{this.refSet.put(f),f=this.xref.fetch(f)}catch(e){if(!(e instanceof K))throw e;a.push(f);d.push({begin:e.begin,end:e.end})}}if(f&&f.getBaseStreams){for(var h=f.getBaseStreams(),
k=!1,i=0;i<h.length;i++){var j=h[i];j.getMissingChunks&&j.getMissingChunks().length&&(k=!0,d.push({begin:j.start,end:j.end}))}k&&a.push(f)}c(f,b)}d.length?this.xref.stream.manager.requestRanges(d).then(function(){b=a;for(var c=0;c<a.length;c++){var d=a[c];g(d)&&this.refSet.remove(d)}this._walk(b)}.bind(this),this.capability.reject):(this.refSet=null,this.capability.resolve())}};return a}();a.Catalog=e;a.ObjectLoader=P;a.XRef=O});(function(a,e){e(a.pdfjsCorePsParser={},a.pdfjsSharedUtil,a.pdfjsCoreParser)})(this,
function(a,e,O){var P,N,L,H,K,I,J=e.error,Q=O.EOF,E=O.Lexer,e=function(){function a(e){this.lexer=e;this.operators=[];this.prev=this.token=null}a.prototype={nextToken:function(){this.prev=this.token;this.token=this.lexer.getToken()},accept:function(a){return this.token.type===a?(this.nextToken(),!0):!1},expect:function(a){if(this.accept(a))return!0;J("Unexpected symbol: found "+this.token.type+" expected "+a+".")},parse:function(){this.nextToken();this.expect(P);this.parseBlock();this.expect(N);return this.operators},
parseBlock:function(){for(;;)if(this.accept(L))this.operators.push(this.prev.value);else if(this.accept(H))this.operators.push(this.prev.value);else if(this.accept(P))this.parseCondition();else break},parseCondition:function(){var a=this.operators.length;this.operators.push(null,null);this.parseBlock();this.expect(N);if(this.accept(K))this.operators[a]=this.operators.length,this.operators[a+1]="jz";else if(this.accept(P)){var e=this.operators.length;this.operators.push(null,null);var o=this.operators.length;
this.parseBlock();this.expect(N);this.expect(I);this.operators[e]=this.operators.length;this.operators[e+1]="j";this.operators[a]=o;this.operators[a+1]="jz"}else J("PS Function: error parsing conditional.")}};return a}();P=0;N=1;L=2;H=3;K=4;I=5;var C=function(){function a(e,o){this.type=e;this.value=o}var e={};a.getOperator=function(D){var C=e[D];return C?C:e[D]=new a(H,D)};a.LBRACE=new a(P,"{");a.RBRACE=new a(N,"}");a.IF=new a(K,"IF");a.IFELSE=new a(I,"IFELSE");return a}(),O=function(){function a(e){this.stream=
e;this.nextChar();this.strBuf=[]}a.prototype={nextChar:function(){return this.currentChar=this.stream.getByte()},getToken:function(){for(var a=!1,e=this.currentChar;;){if(0>e)return Q;if(a){if(10===e||13===e)a=!1}else if(37===e)a=!0;else if(!E.isSpace(e))break;e=this.nextChar()}switch(e|0){case 48:case 49:case 50:case 51:case 52:case 53:case 54:case 55:case 56:case 57:case 43:case 45:case 46:return new C(L,this.getNumber());case 123:return this.nextChar(),C.LBRACE;case 125:return this.nextChar(),
C.RBRACE}a=this.strBuf;a.length=0;for(a[0]=String.fromCharCode(e);0<=(e=this.nextChar())&&(65<=e&&90>=e||97<=e&&122>=e);)a.push(String.fromCharCode(e));e=a.join("");switch(e.toLowerCase()){case "if":return C.IF;case "ifelse":return C.IFELSE;default:return C.getOperator(e)}},getNumber:function(){var a=this.currentChar,e=this.strBuf;e.length=0;for(e[0]=String.fromCharCode(a);0<=(a=this.nextChar());)if(48<=a&&57>=a||45===a||46===a)e.push(String.fromCharCode(a));else break;a=parseFloat(e.join(""));isNaN(a)&&
J("Invalid floating point number: "+a);return a}};return a}();a.PostScriptLexer=O;a.PostScriptParser=e});(function(a,e){e(a.pdfjsCoreFonts={},a.pdfjsSharedUtil,a.pdfjsCorePrimitives,a.pdfjsCoreStream,a.pdfjsCoreParser,a.pdfjsCoreCMap,a.pdfjsCoreGlyphList,a.pdfjsCoreCharsets,a.pdfjsCoreFontRenderer)})(this,function(a,e,O,P,N,L,H,K,I){var J,Q,E;function C(b){if(b.fontMatrix&&b.fontMatrix[0]!==D[0]){var c=0.001/b.fontMatrix[0],a=b.widths,d;for(d in a)a[d]*=c;b.defaultWidth*=c}}function o(b,c){switch(b){case "Type1":return"Type1C"===
c?G.TYPE1C:G.TYPE1;case "CIDFontType0":return"CIDFontType0C"===c?G.CIDFONTTYPE0C:G.CIDFONTTYPE0;case "OpenType":return G.OPENTYPE;case "TrueType":return G.TRUETYPE;case "CIDFontType2":return G.CIDFONTTYPE2;case "MMType1":return G.MMTYPE1;case "Type0":return G.TYPE0;default:return G.UNKNOWN}}function x(b,c,a){var d=Object.create(null),f,g;if(b.baseEncodingName){g=ba[b.baseEncodingName];for(f=0;f<g.length;f++)c=a.indexOf(g[f]),d[f]=0<=c?c:0}else if(b.flags&W.Symbolic)for(f in c)d[f]=c[f];else{g=ba.StandardEncoding;
for(f=0;f<g.length;f++)c=a.indexOf(g[f]),d[f]=0<=c?c:0}if(b=b.differences)for(f in b)c=a.indexOf(b[f]),d[f]=0<=c?c:0;return d}var D=e.FONT_IDENTITY_MATRIX,G=e.FontType,h=e.Util,z=e.assert,R=e.bytesToString,m=e.error,w=e.info,t=e.isArray,u=e.isInt,y=e.isNum,s=e.readUint32,M=e.shadow,g=e.stringToBytes,f=e.string32,d=e.warn,k=O.Name,c=P.Stream,b=N.Lexer,i=L.CMapFactory,l=L.IdentityCMap,q=H.GlyphsUnicode,j=H.DingbatsGlyphsUnicode,p=K.ISOAdobeCharset,v=K.ExpertCharset,n=K.ExpertSubsetCharset,r=I.FontRendererFactory,
B=57344,F=63743,A=!1,$=1E3,V=!1,W={FixedPitch:1,Serif:2,Symbolic:4,Script:8,Nonsymbolic:32,Italic:64,AllCap:65536,SmallCap:131072,ForceBold:262144},ba={ExpertEncoding:",,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,space,exclamsmall,Hungarumlautsmall,,dollaroldstyle,dollarsuperior,ampersandsmall,Acutesmall,parenleftsuperior,parenrightsuperior,twodotenleader,onedotenleader,comma,hyphen,period,fraction,zerooldstyle,oneoldstyle,twooldstyle,threeoldstyle,fouroldstyle,fiveoldstyle,sixoldstyle,sevenoldstyle,eightoldstyle,nineoldstyle,colon,semicolon,commasuperior,threequartersemdash,periodsuperior,questionsmall,,asuperior,bsuperior,centsuperior,dsuperior,esuperior,,,isuperior,,,lsuperior,msuperior,nsuperior,osuperior,,,rsuperior,ssuperior,tsuperior,,ff,fi,fl,ffi,ffl,parenleftinferior,,parenrightinferior,Circumflexsmall,hyphensuperior,Gravesmall,Asmall,Bsmall,Csmall,Dsmall,Esmall,Fsmall,Gsmall,Hsmall,Ismall,Jsmall,Ksmall,Lsmall,Msmall,Nsmall,Osmall,Psmall,Qsmall,Rsmall,Ssmall,Tsmall,Usmall,Vsmall,Wsmall,Xsmall,Ysmall,Zsmall,colonmonetary,onefitted,rupiah,Tildesmall,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,exclamdownsmall,centoldstyle,Lslashsmall,,,Scaronsmall,Zcaronsmall,Dieresissmall,Brevesmall,Caronsmall,,Dotaccentsmall,,,Macronsmall,,,figuredash,hypheninferior,,,Ogoneksmall,Ringsmall,Cedillasmall,,,,onequarter,onehalf,threequarters,questiondownsmall,oneeighth,threeeighths,fiveeighths,seveneighths,onethird,twothirds,,,zerosuperior,onesuperior,twosuperior,threesuperior,foursuperior,fivesuperior,sixsuperior,sevensuperior,eightsuperior,ninesuperior,zeroinferior,oneinferior,twoinferior,threeinferior,fourinferior,fiveinferior,sixinferior,seveninferior,eightinferior,nineinferior,centinferior,dollarinferior,periodinferior,commainferior,Agravesmall,Aacutesmall,Acircumflexsmall,Atildesmall,Adieresissmall,Aringsmall,AEsmall,Ccedillasmall,Egravesmall,Eacutesmall,Ecircumflexsmall,Edieresissmall,Igravesmall,Iacutesmall,Icircumflexsmall,Idieresissmall,Ethsmall,Ntildesmall,Ogravesmall,Oacutesmall,Ocircumflexsmall,Otildesmall,Odieresissmall,OEsmall,Oslashsmall,Ugravesmall,Uacutesmall,Ucircumflexsmall,Udieresissmall,Yacutesmall,Thornsmall,Ydieresissmall".split(","),
MacExpertEncoding:",,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,space,exclamsmall,Hungarumlautsmall,centoldstyle,dollaroldstyle,dollarsuperior,ampersandsmall,Acutesmall,parenleftsuperior,parenrightsuperior,twodotenleader,onedotenleader,comma,hyphen,period,fraction,zerooldstyle,oneoldstyle,twooldstyle,threeoldstyle,fouroldstyle,fiveoldstyle,sixoldstyle,sevenoldstyle,eightoldstyle,nineoldstyle,colon,semicolon,,threequartersemdash,,questionsmall,,,,,Ethsmall,,,onequarter,onehalf,threequarters,oneeighth,threeeighths,fiveeighths,seveneighths,onethird,twothirds,,,,,,,ff,fi,fl,ffi,ffl,parenleftinferior,,parenrightinferior,Circumflexsmall,hypheninferior,Gravesmall,Asmall,Bsmall,Csmall,Dsmall,Esmall,Fsmall,Gsmall,Hsmall,Ismall,Jsmall,Ksmall,Lsmall,Msmall,Nsmall,Osmall,Psmall,Qsmall,Rsmall,Ssmall,Tsmall,Usmall,Vsmall,Wsmall,Xsmall,Ysmall,Zsmall,colonmonetary,onefitted,rupiah,Tildesmall,,,asuperior,centsuperior,,,,,Aacutesmall,Agravesmall,Acircumflexsmall,Adieresissmall,Atildesmall,Aringsmall,Ccedillasmall,Eacutesmall,Egravesmall,Ecircumflexsmall,Edieresissmall,Iacutesmall,Igravesmall,Icircumflexsmall,Idieresissmall,Ntildesmall,Oacutesmall,Ogravesmall,Ocircumflexsmall,Odieresissmall,Otildesmall,Uacutesmall,Ugravesmall,Ucircumflexsmall,Udieresissmall,,eightsuperior,fourinferior,threeinferior,sixinferior,eightinferior,seveninferior,Scaronsmall,,centinferior,twoinferior,,Dieresissmall,,Caronsmall,osuperior,fiveinferior,,commainferior,periodinferior,Yacutesmall,,dollarinferior,,Thornsmall,,nineinferior,zeroinferior,Zcaronsmall,AEsmall,Oslashsmall,questiondownsmall,oneinferior,Lslashsmall,,,,,,,Cedillasmall,,,,,,OEsmall,figuredash,hyphensuperior,,,,,exclamdownsmall,,Ydieresissmall,,onesuperior,twosuperior,threesuperior,foursuperior,fivesuperior,sixsuperior,sevensuperior,ninesuperior,zerosuperior,,esuperior,rsuperior,tsuperior,,,isuperior,ssuperior,dsuperior,,,,,,lsuperior,Ogoneksmall,Brevesmall,Macronsmall,bsuperior,nsuperior,msuperior,commasuperior,periodsuperior,Dotaccentsmall,Ringsmall".split(","),
MacRomanEncoding:",,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,space,exclam,quotedbl,numbersign,dollar,percent,ampersand,quotesingle,parenleft,parenright,asterisk,plus,comma,hyphen,period,slash,zero,one,two,three,four,five,six,seven,eight,nine,colon,semicolon,less,equal,greater,question,at,A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,bracketleft,backslash,bracketright,asciicircum,underscore,grave,a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,braceleft,bar,braceright,asciitilde,,Adieresis,Aring,Ccedilla,Eacute,Ntilde,Odieresis,Udieresis,aacute,agrave,acircumflex,adieresis,atilde,aring,ccedilla,eacute,egrave,ecircumflex,edieresis,iacute,igrave,icircumflex,idieresis,ntilde,oacute,ograve,ocircumflex,odieresis,otilde,uacute,ugrave,ucircumflex,udieresis,dagger,degree,cent,sterling,section,bullet,paragraph,germandbls,registered,copyright,trademark,acute,dieresis,notequal,AE,Oslash,infinity,plusminus,lessequal,greaterequal,yen,mu,partialdiff,summation,product,pi,integral,ordfeminine,ordmasculine,Omega,ae,oslash,questiondown,exclamdown,logicalnot,radical,florin,approxequal,Delta,guillemotleft,guillemotright,ellipsis,space,Agrave,Atilde,Otilde,OE,oe,endash,emdash,quotedblleft,quotedblright,quoteleft,quoteright,divide,lozenge,ydieresis,Ydieresis,fraction,currency,guilsinglleft,guilsinglright,fi,fl,daggerdbl,periodcentered,quotesinglbase,quotedblbase,perthousand,Acircumflex,Ecircumflex,Aacute,Edieresis,Egrave,Iacute,Icircumflex,Idieresis,Igrave,Oacute,Ocircumflex,apple,Ograve,Uacute,Ucircumflex,Ugrave,dotlessi,circumflex,tilde,macron,breve,dotaccent,ring,cedilla,hungarumlaut,ogonek,caron".split(","),
StandardEncoding:",,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,space,exclam,quotedbl,numbersign,dollar,percent,ampersand,quoteright,parenleft,parenright,asterisk,plus,comma,hyphen,period,slash,zero,one,two,three,four,five,six,seven,eight,nine,colon,semicolon,less,equal,greater,question,at,A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,bracketleft,backslash,bracketright,asciicircum,underscore,quoteleft,a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,braceleft,bar,braceright,asciitilde,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,exclamdown,cent,sterling,fraction,yen,florin,section,currency,quotesingle,quotedblleft,guillemotleft,guilsinglleft,guilsinglright,fi,fl,,endash,dagger,daggerdbl,periodcentered,,paragraph,bullet,quotesinglbase,quotedblbase,quotedblright,guillemotright,ellipsis,perthousand,,questiondown,,grave,acute,circumflex,tilde,macron,breve,dotaccent,dieresis,,ring,cedilla,,hungarumlaut,ogonek,caron,emdash,,,,,,,,,,,,,,,,,AE,,ordfeminine,,,,,Lslash,Oslash,OE,ordmasculine,,,,,,ae,,,,dotlessi,,,lslash,oslash,oe,germandbls".split(","),
WinAnsiEncoding:",,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,space,exclam,quotedbl,numbersign,dollar,percent,ampersand,quotesingle,parenleft,parenright,asterisk,plus,comma,hyphen,period,slash,zero,one,two,three,four,five,six,seven,eight,nine,colon,semicolon,less,equal,greater,question,at,A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,bracketleft,backslash,bracketright,asciicircum,underscore,grave,a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,braceleft,bar,braceright,asciitilde,bullet,Euro,bullet,quotesinglbase,florin,quotedblbase,ellipsis,dagger,daggerdbl,circumflex,perthousand,Scaron,guilsinglleft,OE,bullet,Zcaron,bullet,bullet,quoteleft,quoteright,quotedblleft,quotedblright,bullet,endash,emdash,tilde,trademark,scaron,guilsinglright,oe,bullet,zcaron,Ydieresis,space,exclamdown,cent,sterling,currency,yen,brokenbar,section,dieresis,copyright,ordfeminine,guillemotleft,logicalnot,hyphen,registered,macron,degree,plusminus,twosuperior,threesuperior,acute,mu,paragraph,periodcentered,cedilla,onesuperior,ordmasculine,guillemotright,onequarter,onehalf,threequarters,questiondown,Agrave,Aacute,Acircumflex,Atilde,Adieresis,Aring,AE,Ccedilla,Egrave,Eacute,Ecircumflex,Edieresis,Igrave,Iacute,Icircumflex,Idieresis,Eth,Ntilde,Ograve,Oacute,Ocircumflex,Otilde,Odieresis,multiply,Oslash,Ugrave,Uacute,Ucircumflex,Udieresis,Yacute,Thorn,germandbls,agrave,aacute,acircumflex,atilde,adieresis,aring,ae,ccedilla,egrave,eacute,ecircumflex,edieresis,igrave,iacute,icircumflex,idieresis,eth,ntilde,ograve,oacute,ocircumflex,otilde,odieresis,divide,oslash,ugrave,uacute,ucircumflex,udieresis,yacute,thorn,ydieresis".split(","),
SymbolSetEncoding:",,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,space,exclam,universal,numbersign,existential,percent,ampersand,suchthat,parenleft,parenright,asteriskmath,plus,comma,minus,period,slash,zero,one,two,three,four,five,six,seven,eight,nine,colon,semicolon,less,equal,greater,question,congruent,Alpha,Beta,Chi,Delta,Epsilon,Phi,Gamma,Eta,Iota,theta1,Kappa,Lambda,Mu,Nu,Omicron,Pi,Theta,Rho,Sigma,Tau,Upsilon,sigma1,Omega,Xi,Psi,Zeta,bracketleft,therefore,bracketright,perpendicular,underscore,radicalex,alpha,beta,chi,delta,epsilon,phi,gamma,eta,iota,phi1,kappa,lambda,mu,nu,omicron,pi,theta,rho,sigma,tau,upsilon,omega1,omega,xi,psi,zeta,braceleft,bar,braceright,similar,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,Euro,Upsilon1,minute,lessequal,fraction,infinity,florin,club,diamond,heart,spade,arrowboth,arrowleft,arrowup,arrowright,arrowdown,degree,plusminus,second,greaterequal,multiply,proportional,partialdiff,bullet,divide,notequal,equivalence,approxequal,ellipsis,arrowvertex,arrowhorizex,carriagereturn,aleph,Ifraktur,Rfraktur,weierstrass,circlemultiply,circleplus,emptyset,intersection,union,propersuperset,reflexsuperset,notsubset,propersubset,reflexsubset,element,notelement,angle,gradient,registerserif,copyrightserif,trademarkserif,product,radical,dotmath,logicalnot,logicaland,logicalor,arrowdblboth,arrowdblleft,arrowdblup,arrowdblright,arrowdbldown,lozenge,angleleft,registersans,copyrightsans,trademarksans,summation,parenlefttp,parenleftex,parenleftbt,bracketlefttp,bracketleftex,bracketleftbt,bracelefttp,braceleftmid,braceleftbt,braceex,,angleright,integral,integraltp,integralex,integralbt,parenrighttp,parenrightex,parenrightbt,bracketrighttp,bracketrightex,bracketrightbt,bracerighttp,bracerightmid,bracerightbt".split(","),
ZapfDingbatsEncoding:",,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,space,a1,a2,a202,a3,a4,a5,a119,a118,a117,a11,a12,a13,a14,a15,a16,a105,a17,a18,a19,a20,a21,a22,a23,a24,a25,a26,a27,a28,a6,a7,a8,a9,a10,a29,a30,a31,a32,a33,a34,a35,a36,a37,a38,a39,a40,a41,a42,a43,a44,a45,a46,a47,a48,a49,a50,a51,a52,a53,a54,a55,a56,a57,a58,a59,a60,a61,a62,a63,a64,a65,a66,a67,a68,a69,a70,a71,a72,a73,a74,a203,a75,a204,a76,a77,a78,a79,a81,a82,a83,a84,a97,a98,a99,a100,,a89,a90,a93,a94,a91,a92,a205,a85,a206,a86,a87,a88,a95,a96,,,,,,,,,,,,,,,,,,,,a101,a102,a103,a104,a106,a107,a108,a112,a111,a110,a109,a120,a121,a122,a123,a124,a125,a126,a127,a128,a129,a130,a131,a132,a133,a134,a135,a136,a137,a138,a139,a140,a141,a142,a143,a144,a145,a146,a147,a148,a149,a150,a151,a152,a153,a154,a155,a156,a157,a158,a159,a160,a161,a163,a164,a196,a165,a192,a166,a167,a168,a169,a170,a171,a172,a173,a162,a174,a175,a176,a177,a178,a179,a193,a180,a199,a181,a200,a182,,a201,a183,a184,a197,a185,a194,a198,a186,a195,a187,a188,a189,a190,a191".split(",")},
Ta={ArialNarrow:"Helvetica","ArialNarrow-Bold":"Helvetica-Bold","ArialNarrow-BoldItalic":"Helvetica-BoldOblique","ArialNarrow-Italic":"Helvetica-Oblique",ArialBlack:"Helvetica","ArialBlack-Bold":"Helvetica-Bold","ArialBlack-BoldItalic":"Helvetica-BoldOblique","ArialBlack-Italic":"Helvetica-Oblique",Arial:"Helvetica","Arial-Bold":"Helvetica-Bold","Arial-BoldItalic":"Helvetica-BoldOblique","Arial-Italic":"Helvetica-Oblique","Arial-BoldItalicMT":"Helvetica-BoldOblique","Arial-BoldMT":"Helvetica-Bold",
"Arial-ItalicMT":"Helvetica-Oblique",ArialMT:"Helvetica","Courier-Bold":"Courier-Bold","Courier-BoldItalic":"Courier-BoldOblique","Courier-Italic":"Courier-Oblique",CourierNew:"Courier","CourierNew-Bold":"Courier-Bold","CourierNew-BoldItalic":"Courier-BoldOblique","CourierNew-Italic":"Courier-Oblique","CourierNewPS-BoldItalicMT":"Courier-BoldOblique","CourierNewPS-BoldMT":"Courier-Bold","CourierNewPS-ItalicMT":"Courier-Oblique",CourierNewPSMT:"Courier",Helvetica:"Helvetica","Helvetica-Bold":"Helvetica-Bold",
"Helvetica-BoldItalic":"Helvetica-BoldOblique","Helvetica-BoldOblique":"Helvetica-BoldOblique","Helvetica-Italic":"Helvetica-Oblique","Helvetica-Oblique":"Helvetica-Oblique","Symbol-Bold":"Symbol","Symbol-BoldItalic":"Symbol","Symbol-Italic":"Symbol",TimesNewRoman:"Times-Roman","TimesNewRoman-Bold":"Times-Bold","TimesNewRoman-BoldItalic":"Times-BoldItalic","TimesNewRoman-Italic":"Times-Italic",TimesNewRomanPS:"Times-Roman","TimesNewRomanPS-Bold":"Times-Bold","TimesNewRomanPS-BoldItalic":"Times-BoldItalic",
"TimesNewRomanPS-BoldItalicMT":"Times-BoldItalic","TimesNewRomanPS-BoldMT":"Times-Bold","TimesNewRomanPS-Italic":"Times-Italic","TimesNewRomanPS-ItalicMT":"Times-Italic",TimesNewRomanPSMT:"Times-Roman","TimesNewRomanPSMT-Bold":"Times-Bold","TimesNewRomanPSMT-BoldItalic":"Times-BoldItalic","TimesNewRomanPSMT-Italic":"Times-Italic"},ab={CenturyGothic:"Helvetica","CenturyGothic-Bold":"Helvetica-Bold","CenturyGothic-BoldItalic":"Helvetica-BoldOblique","CenturyGothic-Italic":"Helvetica-Oblique",ComicSansMS:"Comic Sans MS",
"ComicSansMS-Bold":"Comic Sans MS-Bold","ComicSansMS-BoldItalic":"Comic Sans MS-BoldItalic","ComicSansMS-Italic":"Comic Sans MS-Italic",LucidaConsole:"Courier","LucidaConsole-Bold":"Courier-Bold","LucidaConsole-BoldItalic":"Courier-BoldOblique","LucidaConsole-Italic":"Courier-Oblique","MS-Gothic":"MS Gothic","MS-Gothic-Bold":"MS Gothic-Bold","MS-Gothic-BoldItalic":"MS Gothic-BoldItalic","MS-Gothic-Italic":"MS Gothic-Italic","MS-Mincho":"MS Mincho","MS-Mincho-Bold":"MS Mincho-Bold","MS-Mincho-BoldItalic":"MS Mincho-BoldItalic",
"MS-Mincho-Italic":"MS Mincho-Italic","MS-PGothic":"MS PGothic","MS-PGothic-Bold":"MS PGothic-Bold","MS-PGothic-BoldItalic":"MS PGothic-BoldItalic","MS-PGothic-Italic":"MS PGothic-Italic","MS-PMincho":"MS PMincho","MS-PMincho-Bold":"MS PMincho-Bold","MS-PMincho-BoldItalic":"MS PMincho-BoldItalic","MS-PMincho-Italic":"MS PMincho-Italic",Wingdings:"ZapfDingbats"},pb={2:10,3:32,4:33,5:34,6:35,7:36,8:37,9:38,10:39,11:40,12:41,13:42,14:43,15:44,16:45,17:46,18:47,19:48,20:49,21:50,22:51,23:52,24:53,25:54,
26:55,27:56,28:57,29:58,30:894,31:60,32:61,33:62,34:63,35:64,36:65,37:66,38:67,39:68,40:69,41:70,42:71,43:72,44:73,45:74,46:75,47:76,48:77,49:78,50:79,51:80,52:81,53:82,54:83,55:84,56:85,57:86,58:87,59:88,60:89,61:90,62:91,63:92,64:93,65:94,66:95,67:96,68:97,69:98,70:99,71:100,72:101,73:102,74:103,75:104,76:105,77:106,78:107,79:108,80:109,81:110,82:111,83:112,84:113,85:114,86:115,87:116,88:117,89:118,90:119,91:120,92:121,93:122,94:123,95:124,96:125,97:126,98:196,99:197,100:199,101:201,102:209,103:214,
104:220,105:225,106:224,107:226,108:228,109:227,110:229,111:231,112:233,113:232,114:234,115:235,116:237,117:236,118:238,119:239,120:241,121:243,122:242,123:244,124:246,125:245,126:250,127:249,128:251,129:252,130:8224,131:176,132:162,133:163,134:167,135:8226,136:182,137:223,138:174,139:169,140:8482,141:180,142:168,143:8800,144:198,145:216,146:8734,147:177,148:8804,149:8805,150:165,151:181,152:8706,153:8721,154:8719,156:8747,157:170,158:186,159:8486,160:230,161:248,162:191,163:161,164:172,165:8730,
166:402,167:8776,168:8710,169:171,170:187,171:8230,210:218,223:711,224:321,225:322,227:353,229:382,234:253,252:263,253:268,254:269,258:258,260:260,261:261,265:280,266:281,268:283,269:313,275:323,276:324,278:328,284:345,285:346,286:347,292:367,295:377,296:378,298:380,305:963,306:964,307:966,308:8215,309:8252,310:8319,311:8359,312:8592,313:8593,337:9552,493:1039,494:1040,705:1524,706:8362,710:64288,711:64298,759:1617,761:1776,763:1778,775:1652,777:1764,778:1780,779:1781,780:1782,782:771,783:64726,786:8363,
788:8532,790:768,791:769,792:768,795:803,797:64336,798:64337,799:64342,800:64343,801:64344,802:64345,803:64362,804:64363,805:64364,2424:7821,2425:7822,2426:7823,2427:7824,2428:7825,2429:7826,2430:7827,2433:7682,2678:8045,2679:8046,2830:1552,2838:686,2840:751,2842:753,2843:754,2844:755,2846:757,2856:767,2857:848,2858:849,2862:853,2863:854,2864:855,2865:861,2866:862,2906:7460,2908:7462,2909:7463,2910:7464,2912:7466,2913:7467,2914:7468,2916:7470,2917:7471,2918:7472,2920:7474,2921:7475,2922:7476,2924:7478,
2925:7479,2926:7480,2928:7482,2929:7483,2930:7484,2932:7486,2933:7487,2934:7488,2936:7490,2937:7491,2938:7492,2940:7494,2941:7495,2942:7496,2944:7498,2946:7500,2948:7502,2950:7504,2951:7505,2952:7506,2954:7508,2955:7509,2956:7510,2958:7512,2959:7513,2960:7514,2962:7516,2963:7517,2964:7518,2966:7520,2967:7521,2968:7522,2970:7524,2971:7525,2972:7526,2974:7528,2975:7529,2976:7530,2978:1537,2979:1538,2980:1539,2982:1549,2983:1551,2984:1552,2986:1554,2987:1555,2988:1556,2990:1623,2991:1624,2995:1775,2999:1791,
3002:64290,3003:64291,3004:64292,3006:64294,3007:64295,3008:64296,3011:1900,3014:8223,3015:8244,3017:7532,3018:7533,3019:7534,3075:7590,3076:7591,3079:7594,3080:7595,3083:7598,3084:7599,3087:7602,3088:7603,3091:7606,3092:7607,3095:7610,3096:7611,3099:7614,3100:7615,3103:7618,3104:7619,3107:8337,3108:8338,3116:1884,3119:1885,3120:1885,3123:1886,3124:1886,3127:1887,3128:1887,3131:1888,3132:1888,3135:1889,3136:1889,3139:1890,3140:1890,3143:1891,3144:1891,3147:1892,3148:1892,3153:580,3154:581,3157:584,
3158:585,3161:588,3162:589,3165:891,3166:892,3169:1274,3170:1275,3173:1278,3174:1279,3181:7622,3182:7623,3282:11799,3316:578,3379:42785,3393:1159,3416:8377},qb={227:322,264:261,291:346},sc={63721:169,63193:169,63720:174,63194:174,63722:8482,63195:8482,63729:9127,63730:9128,63731:9129,63740:9131,63741:9132,63742:9133,63726:9121,63727:9122,63728:9123,63737:9124,63738:9125,63739:9126,63723:9115,63724:9116,63725:9117,63734:9118,63735:9119,63736:9120},$a=[{begin:0,end:127},{begin:128,end:255},{begin:256,
end:383},{begin:384,end:591},{begin:592,end:687},{begin:688,end:767},{begin:768,end:879},{begin:880,end:1023},{begin:11392,end:11519},{begin:1024,end:1279},{begin:1328,end:1423},{begin:1424,end:1535},{begin:42240,end:42559},{begin:1536,end:1791},{begin:1984,end:2047},{begin:2304,end:2431},{begin:2432,end:2559},{begin:2560,end:2687},{begin:2688,end:2815},{begin:2816,end:2943},{begin:2944,end:3071},{begin:3072,end:3199},{begin:3200,end:3327},{begin:3328,end:3455},{begin:3584,end:3711},{begin:3712,end:3839},
{begin:4256,end:4351},{begin:6912,end:7039},{begin:4352,end:4607},{begin:7680,end:7935},{begin:7936,end:8191},{begin:8192,end:8303},{begin:8304,end:8351},{begin:8352,end:8399},{begin:8400,end:8447},{begin:8448,end:8527},{begin:8528,end:8591},{begin:8592,end:8703},{begin:8704,end:8959},{begin:8960,end:9215},{begin:9216,end:9279},{begin:9280,end:9311},{begin:9312,end:9471},{begin:9472,end:9599},{begin:9600,end:9631},{begin:9632,end:9727},{begin:9728,end:9983},{begin:9984,end:10175},{begin:12288,end:12351},
{begin:12352,end:12447},{begin:12448,end:12543},{begin:12544,end:12591},{begin:12592,end:12687},{begin:43072,end:43135},{begin:12800,end:13055},{begin:13056,end:13311},{begin:44032,end:55215},{begin:55296,end:57343},{begin:67840,end:67871},{begin:19968,end:40959},{begin:57344,end:63743},{begin:12736,end:12783},{begin:64256,end:64335},{begin:64336,end:65023},{begin:65056,end:65071},{begin:65040,end:65055},{begin:65104,end:65135},{begin:65136,end:65279},{begin:65280,end:65519},{begin:65520,end:65535},
{begin:3840,end:4095},{begin:1792,end:1871},{begin:1920,end:1983},{begin:3456,end:3583},{begin:4096,end:4255},{begin:4608,end:4991},{begin:5024,end:5119},{begin:5120,end:5759},{begin:5760,end:5791},{begin:5792,end:5887},{begin:6016,end:6143},{begin:6144,end:6319},{begin:10240,end:10495},{begin:40960,end:42127},{begin:5888,end:5919},{begin:66304,end:66351},{begin:66352,end:66383},{begin:66560,end:66639},{begin:118784,end:119039},{begin:119808,end:120831},{begin:1044480,end:1048573},{begin:65024,end:65039},
{begin:917504,end:917631},{begin:6400,end:6479},{begin:6480,end:6527},{begin:6528,end:6623},{begin:6656,end:6687},{begin:11264,end:11359},{begin:11568,end:11647},{begin:19904,end:19967},{begin:43008,end:43055},{begin:65536,end:65663},{begin:65856,end:65935},{begin:66432,end:66463},{begin:66464,end:66527},{begin:66640,end:66687},{begin:66688,end:66735},{begin:67584,end:67647},{begin:68096,end:68191},{begin:119552,end:119647},{begin:73728,end:74751},{begin:119648,end:119679},{begin:7040,end:7103},{begin:7168,
end:7247},{begin:7248,end:7295},{begin:43136,end:43231},{begin:43264,end:43311},{begin:43312,end:43359},{begin:43520,end:43615},{begin:65936,end:65999},{begin:66E3,end:66047},{begin:66208,end:66271},{begin:127024,end:127135}],qa=".notdef,.null,nonmarkingreturn,space,exclam,quotedbl,numbersign,dollar,percent,ampersand,quotesingle,parenleft,parenright,asterisk,plus,comma,hyphen,period,slash,zero,one,two,three,four,five,six,seven,eight,nine,colon,semicolon,less,equal,greater,question,at,A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,bracketleft,backslash,bracketright,asciicircum,underscore,grave,a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,braceleft,bar,braceright,asciitilde,Adieresis,Aring,Ccedilla,Eacute,Ntilde,Odieresis,Udieresis,aacute,agrave,acircumflex,adieresis,atilde,aring,ccedilla,eacute,egrave,ecircumflex,edieresis,iacute,igrave,icircumflex,idieresis,ntilde,oacute,ograve,ocircumflex,odieresis,otilde,uacute,ugrave,ucircumflex,udieresis,dagger,degree,cent,sterling,section,bullet,paragraph,germandbls,registered,copyright,trademark,acute,dieresis,notequal,AE,Oslash,infinity,plusminus,lessequal,greaterequal,yen,mu,partialdiff,summation,product,pi,integral,ordfeminine,ordmasculine,Omega,ae,oslash,questiondown,exclamdown,logicalnot,radical,florin,approxequal,Delta,guillemotleft,guillemotright,ellipsis,nonbreakingspace,Agrave,Atilde,Otilde,OE,oe,endash,emdash,quotedblleft,quotedblright,quoteleft,quoteright,divide,lozenge,ydieresis,Ydieresis,fraction,currency,guilsinglleft,guilsinglright,fi,fl,daggerdbl,periodcentered,quotesinglbase,quotedblbase,perthousand,Acircumflex,Ecircumflex,Aacute,Edieresis,Egrave,Iacute,Icircumflex,Idieresis,Igrave,Oacute,Ocircumflex,apple,Ograve,Uacute,Ucircumflex,Ugrave,dotlessi,circumflex,tilde,macron,breve,dotaccent,ring,cedilla,hungarumlaut,ogonek,caron,Lslash,lslash,Scaron,scaron,Zcaron,zcaron,brokenbar,Eth,eth,Yacute,yacute,Thorn,thorn,minus,multiply,onesuperior,twosuperior,threesuperior,onehalf,onequarter,threequarters,franc,Gbreve,gbreve,Idotaccent,Scedilla,scedilla,Cacute,cacute,Ccaron,ccaron,dcroat".split(","),
Ka=function(){function b(c,a,d,f,g,e,h){this.fontChar=c;this.unicode=a;this.accent=d;this.width=f;this.vmetric=g;this.operatorListId=e;this.isSpace=h}b.prototype.matchesForCache=function(b,c,a,d,f,g,e){return this.fontChar===b&&this.unicode===c&&this.accent===a&&this.width===d&&this.vmetric===f&&this.operatorListId===g&&this.isSpace===e};return b}(),ha=function(){function b(c){this._map=c}b.prototype={get length(){return this._map.length},forEach:function(b){for(var c in this._map)b(c,this._map[c].charCodeAt(0))},
has:function(b){return void 0!==this._map[b]},get:function(b){return this._map[b]},charCodeOf:function(b){return this._map.indexOf(b)}};return b}(),ea=function(){function b(c,a){this.firstChar=c;this.lastChar=a}b.prototype={get length(){return this.lastChar+1-this.firstChar},forEach:function(b){for(var c=this.firstChar,a=this.lastChar;c<=a;c++)b(c,c)},has:function(b){return this.firstChar<=b&&b<=this.lastChar},get:function(b){if(this.firstChar<=b&&b<=this.lastChar)return String.fromCharCode(b)},charCodeOf:function(b){return u(b)&&
b>=this.firstChar&&b<=this.lastChar?b:-1}};return b}(),Ua=function(){function b(c,a,d){c[a]=d>>8&255;c[a+1]=d&255}function c(b,a,d){b[a]=d>>24&255;b[a+1]=d>>16&255;b[a+2]=d>>8&255;b[a+3]=d&255}function a(b){this.sfnt=b;this.tables=Object.create(null)}a.getSearchParams=function(b,c){for(var a=1,d=0;(a^b)>a;)a<<=1,d++;a*=c;return{range:a,entry:d,rangeShift:c*b-a}};a.prototype={toArray:function(){var d=this.sfnt,g=this.tables,e=Object.keys(g);e.sort();var h=e.length,k,i,j,l=12+16*h,n=[l];for(k=0;k<h;k++)j=
g[e[k]],l+=(j.length+3&-4)>>>0,n.push(l);var r=new Uint8Array(l);for(k=0;k<h;k++){j=g[e[k]];l=r;i=n[k];var p=void 0,q=void 0;if(j instanceof Uint8Array)l.set(j,i);else if("string"===typeof j)for(p=0,q=j.length;p<q;p++)l[i++]=j.charCodeAt(p)&255;else for(p=0,q=j.length;p<q;p++)l[i++]=j[p]&255}"true"===d&&(d=f(65536));r[0]=d.charCodeAt(0)&255;r[1]=d.charCodeAt(1)&255;r[2]=d.charCodeAt(2)&255;r[3]=d.charCodeAt(3)&255;b(r,4,h);k=a.getSearchParams(h,16);b(r,6,k.range);b(r,8,k.entry);b(r,10,k.rangeShift);
l=12;for(k=0;k<h;k++){j=e[k];r[l]=j.charCodeAt(0)&255;r[l+1]=j.charCodeAt(1)&255;r[l+2]=j.charCodeAt(2)&255;r[l+3]=j.charCodeAt(3)&255;p=0;for(d=n[k],i=n[k+1];d<i;d+=4)p=p+((r[d]<<24)+(r[d+1]<<16)+(r[d+2]<<8)+r[d+3])|0;c(r,l+4,p);c(r,l+8,n[k]);c(r,l+12,g[j].length);l+=16}return r},addTable:function(b,c){if(b in this.tables)throw Error("Table "+b+" already exists");this.tables[b]=c}};return a}(),ja=new Int32Array([0,32,127,161,173,174,1536,1920,2208,4256,6016,6144,8192,8208,8209,8210,8232,8240,8287,
8304,9676,9677,43616,43648,65520,65536]),e=function(){function b(a,c,f){var g,k;this.name=a;this.loadedName=f.loadedName;this.isType3Font=f.isType3Font;this.sizes=[];this.glyphCache={};var i=a.split("+"),i=1<i.length?i[1]:i[0],i=i.split(/[-,_]/g)[0];this.isSerifFont=!!(f.flags&W.Serif);this.isSymbolicFont=!!(f.flags&W.Symbolic);this.isMonospace=!!(f.flags&W.FixedPitch);var i=f.type,l=f.subtype;this.type=i;this.fallbackName=this.isMonospace?"monospace":this.isSerifFont?"serif":"sans-serif";this.differences=
f.differences;this.widths=f.widths;this.defaultWidth=f.defaultWidth;this.composite=f.composite;this.wideChars=f.wideChars;this.cMap=f.cMap;this.ascent=f.ascent/$;this.descent=f.descent/$;this.fontMatrix=f.fontMatrix;this.bbox=f.bbox;this.toUnicode=f.toUnicode=this.buildToUnicode(f);this.toFontChar=[];if("Type3"===f.type){for(g=0;256>g;g++)this.toFontChar[g]=this.differences[g]||f.defaultEncoding[g];this.fontType=G.TYPE3}else{this.cidEncoding=f.cidEncoding;if(this.vertical=f.vertical)this.vmetrics=
f.vmetrics,this.defaultVMetrics=f.defaultVMetrics;if(!c||c.isEmpty){c&&d('Font file is empty in "'+a+'" ('+this.loadedName+")");this.missingFile=!0;var c=a.replace(/[,_]/g,"-"),n=!!Ta[c]||!(!ab[c]||!Ta[ab[c]]),c=Ta[c]||ab[c]||c;this.bold=-1!==c.search(/bold/gi);this.italic=-1!==c.search(/oblique/gi)||-1!==c.search(/italic/gi);this.black=-1!==a.search(/Black/g);this.remeasure=0<Object.keys(this.widths).length;if(n&&"CIDFontType2"===i&&0===f.cidEncoding.indexOf("Identity-")){var r=[];for(g in pb)r[+g]=
pb[g];if(/ArialBlack/i.test(a))for(g in qb)r[+g]=qb[g];this.toUnicode instanceof ea||this.toUnicode.forEach(function(b,a){r[+b]=a});this.toFontChar=r;this.toUnicode=new ha(r)}else if(/Symbol/i.test(c)){n=ba.SymbolSetEncoding;for(g in n)(a=q[n[g]])&&(this.toFontChar[g]=a);for(g in f.differences)(a=q[f.differences[g]])&&(this.toFontChar[g]=a)}else if(/Dingbats/i.test(c)){/Wingdings/i.test(a)&&d("Wingdings font without embedded font file, falling back to the ZapfDingbats encoding.");n=ba.ZapfDingbatsEncoding;
for(g in n)(a=j[n[g]])&&(this.toFontChar[g]=a);for(g in f.differences)(a=j[f.differences[g]])&&(this.toFontChar[g]=a)}else if(n)for(g in this.toFontChar=[],f.defaultEncoding)k=f.differences[g]||f.defaultEncoding[g],this.toFontChar[g]=q[k];else{var p=-1===i.indexOf("CIDFontType");this.toUnicode.forEach(function(b,a){p&&(k=f.differences[b]||f.defaultEncoding[b],a=q[k]||a);this.toFontChar[b]=a}.bind(this))}this.loadedName=c.split("-")[0];this.loading=!1;this.fontType=o(i,l)}else{"Type1C"===l&&"Type1"!==
i&&"MMType1"!==i&&(e(c)?l="TrueType":i="Type1");"CIDFontType0C"===l&&"CIDFontType0"!==i&&(i="CIDFontType0");"OpenType"===l&&(i="OpenType");"CIDFontType0"===i&&(l=h(c)?"CIDFontType0":"CIDFontType0C");switch(i){case "MMType1":w("MMType1 font ("+a+"), falling back to Type1.");case "Type1":case "CIDFontType0":this.mimetype="font/opentype";g="Type1C"===l||"CIDFontType0C"===l?new fa(c,f):new ka(a,c,f);C(f);n=this.convert(a,g,f);break;case "OpenType":case "TrueType":case "CIDFontType2":this.mimetype="font/opentype";
n=this.checkAndRepair(a,c,f);this.isOpenType&&(C(f),i="OpenType");break;default:m("Font "+i+" is not supported")}this.data=n;this.fontType=o(i,l);this.fontMatrix=f.fontMatrix;this.widths=f.widths;this.defaultWidth=f.defaultWidth;this.encoding=f.baseEncoding;this.seacMap=f.seacMap;this.loading=!0}}}function a(b){return String.fromCharCode(b>>8&255,b&255)}function g(b){b=32767<b?32767:-32768>b?-32768:b;return String.fromCharCode(b>>8&255,b&255)}function e(b){b=b.peekBytes(4);return 65536===s(b,0)}function h(b){b=
b.peekBytes(2);return 37===b[0]&&33===b[1]||128===b[0]&&1===b[1]?!0:!1}function n(b,a){var c=a.toUnicode,d=!!(a.flags&W.Symbolic),f=a.toUnicode instanceof ea,g=Object.create(null),e=[],h=[],k=B,i;for(i in b){i|=0;var j=b[i],l=i;if(!f&&c.has(i)){var r=c.get(l);1===r.length&&(l=r.charCodeAt(0))}if(!(r=void 0!==h[l])){for(var r=0,p=ja.length-1;r<p;){var q=r+p+1>>1;l<ja[q]?p=q-1:r=q}r=!(r&1)||d&&f}if(r&&k<=F){do l=k++,A&&61440===l&&(l=61472,k=l+1);while(void 0!==h[l]&&k<=F)}g[l]=j;e[i]=l;h[l]=!0}return{toFontChar:e,
charCodeToGlyphId:g,nextAvailableFontCharCode:k}}function p(b,a){var c=[],d;for(d in b)b[d]>=a||c.push({fontCharCode:d|0,glyphId:b[d]});c.sort(function(b,a){return b.fontCharCode-a.fontCharCode});d=[];for(var f=c.length,g=0;g<f;){var e=c[g].fontCharCode,h=[c[g].glyphId];++g;for(var k=e;g<f&&k+1===c[g].fontCharCode&&!(h.push(c[g].glyphId),++k,++g,65535===k););d.push([e,k,h])}return d}function u(b,c){var d=p(b,c),g=65535<d[d.length-1][1]?2:1,e="\x00\x00"+a(g)+"\x00\u0003\x00\u0001"+f(4+8*g),h,k,i,j;
for(h=d.length-1;0<=h&&!(65535>=d[h][0]);--h);k=h+1;65535>d[h][0]&&65535===d[h][1]&&(d[h][1]=65534);var l=65535>d[h][1]?1:0,n=k+l,r=Ua.getSearchParams(n,2),q="",m="",s="",t="",va="",A=0,o,B,v,w;for(h=0;h<k;h++){o=d[h];B=o[0];v=o[1];q+=a(B);m+=a(v);w=o[2];o=!0;for(i=1,j=w.length;i<j;++i)if(w[i]!==w[i-1]+1){o=!1;break}if(o)s+=a(w[0]-B&65535),t+=a(0);else{i=2*(n-h)+2*A;A+=v-B+1;s+=a(0);t+=a(i);for(i=0,j=w.length;i<j;++i)va+=a(w[i])}}0<l&&(m+="\u00ff\u00ff",q+="\u00ff\u00ff",s+="\x00\u0001",t+="\x00\x00");
l="\x00\x00"+a(2*n)+a(r.range)+a(r.entry)+a(r.rangeShift)+m+"\x00\x00"+q+s+t+va;h=n="";if(1<g){e+="\x00\u0003\x00\n"+f(8*g+8+l.length);n="";for(h=0,k=d.length;h<k;h++){o=d[h];B=o[0];w=o[2];g=w[0];for(i=1,j=w.length;i<j;++i)w[i]!==w[i-1]+1&&(v=o[0]+i-1,n+=f(B)+f(v)+f(g),B=v+1,g=w[i]);n+=f(B)+f(o[1])+f(g)}h="\x00\u000c\x00\x00"+f(n.length+16)+"\x00\x00\x00\x00"+f(n.length/12)}return e+"\x00\u0004"+a(l.length+4)+l+h+n}function t(b){var a=new c(b.data),d=a.getUint16();a.getBytes(60);var f=a.getUint16();
if(4>d&&f&768)return!1;d=a.getUint16();f=a.getUint16();if(d>f)return!1;a.getBytes(6);if(0===a.getUint16())return!1;b.data[8]=b.data[9]=0;return!0}function v(b,c,d){var d=d||{unitsPerEm:0,yMax:0,yMin:0,ascent:0,descent:0},g=0,e=0,h=0,k=0,i=null,j=0;if(c)for(var l in c){l|=0;if(i>l||!i)i=l;j<l&&(j=l);var n;a:{n=0;for(var r=$a.length;n<r;n++){var p=$a[n];if(l>=p.begin&&l<p.end)break a}n=-1}32>n?g|=1<<n:64>n?e|=1<<n-32:96>n?h|=1<<n-64:123>n?k|=1<<n-96:m("Unicode ranges Bits > 123 are reserved for internal usage")}else i=
0,j=255;l=b.bbox||[0,0,0,0];c=d.unitsPerEm||1/(b.fontMatrix||D)[0];n=b.ascentScaled?1:c/$;c=d.ascent||Math.round(n*(b.ascent||l[3]));n=d.descent||Math.round(n*(b.descent||l[1]));0<n&&0<b.descent&&0>l[1]&&(n=-n);l=d.yMax||c;d=-d.yMin||-n;return"\x00\u0003\u0002$\u0001\u00f4\x00\u0005\x00\x00\u0002\u008a\u0002\u00bb\x00\x00\x00\u008c\u0002\u008a\u0002\u00bb\x00\x00\u0001\u00df\x001\u0001\u0002\x00\x00\x00\x00\u0006"+String.fromCharCode(b.fixedPitch?9:0)+"\x00\x00\x00\x00\x00\x00"+f(g)+f(e)+f(h)+f(k)+
"*21*"+a(b.italicAngle?1:0)+a(i||b.firstChar)+a(j||b.lastChar)+a(c)+a(n)+"\x00d"+a(l)+a(d)+"\x00\x00\x00\x00\x00\x00\x00\x00"+a(b.xHeight)+a(b.capHeight)+a(0)+a(i||b.firstChar)+"\x00\u0003"}function x(b){var a=Math.floor(b.italicAngle*Math.pow(2,16));return"\x00\u0003\x00\x00"+f(a)+"\x00\x00\x00\x00"+f(b.fixedPitch)+"\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"}function X(b,c){c||(c=[[],[]]);var d=[c[0][0]||"Original licence",c[0][1]||b,c[0][2]||"Unknown",c[0][3]||"uniqueID",
c[0][4]||b,c[0][5]||"Version 0.11",c[0][6]||"",c[0][7]||"Unknown",c[0][8]||"Unknown",c[0][9]||"Unknown"],f=[],g,e,h,k,i;for(g=0,e=d.length;g<e;g++){i=c[1][g]||d[g];var j=[];for(h=0,k=i.length;h<k;h++)j.push(a(i.charCodeAt(h)));f.push(j.join(""))}var j=[d,f],l=["\x00\u0001","\x00\u0003"],n=["\x00\x00","\x00\u0001"],r=["\x00\x00","\u0004\t"];g=d.length*l.length;var p="\x00\x00"+a(g)+a(12*g+6),q=0;for(g=0,e=l.length;g<e;g++){var m=j[g];for(h=0,k=m.length;h<k;h++){i=m[h];var s=l[g]+n[g]+r[g]+a(h)+a(i.length)+
a(q),p=p+s,q=q+i.length}}return p+=d.join("")+f.join("")}b.getFontID=function(){var b=1;return function(){return""+b++}}();b.prototype={name:null,font:null,mimetype:null,encoding:null,get renderer(){var b=r.create(this);return M(this,"renderer",b)},exportData:function(){var b={},c;for(c in this)this.hasOwnProperty(c)&&(b[c]=this[c]);return b},checkAndRepair:function(b,a,f){function g(b){var a=R(b.getBytes(4)),c=b.getInt32(),d=b.getInt32()>>>0,f=b.getInt32()>>>0,e=b.pos;b.pos=b.start?b.start:0;b.skip(d);
var h=b.getBytes(f);b.pos=e;"head"===a&&(h[8]=h[9]=h[10]=h[11]=0,h[17]|=32);return{tag:a,checksum:c,length:f,offset:d,data:h}}function e(b,a,c,f){if(!b)return d("No cmap table available."),{platformId:-1,encodingId:-1,mappings:[],hasShortCmap:!1};var g,b=(a.start?a.start:0)+b.offset;a.pos=b;a.getUint16();var h=a.getUint16(),k,i=!1;for(g=0;g<h;g++){var j=a.getUint16(),l=a.getUint16(),n=a.getInt32()>>>0,r=!1;0===j&&0===l?r=!0:1===j&&0===l?r=!0:3===j&&1===l&&(!c&&f||!k)?(r=!0,c||(i=!0)):c&&3===j&&0===
l&&(i=r=!0);r&&(k={platformId:j,encodingId:l,offset:n});if(i)break}k&&(a.pos=b+k.offset);if(!k||-1===a.peekByte())return d("Could not find a preferred cmap table."),{platformId:-1,encodingId:-1,mappings:[],hasShortCmap:!1};b=a.getUint16();a.getUint16();a.getUint16();f=!1;c=[];if(0===b){for(g=0;256>g;g++)(b=a.getByte())&&c.push({charCode:g,glyphId:b});f=!0}else if(4===b){h=a.getUint16()>>1;a.getBytes(6);j=[];for(i=0;i<h;i++)j.push({end:a.getUint16()});a.getUint16();for(i=0;i<h;i++)j[i].start=a.getUint16();
for(i=0;i<h;i++)j[i].delta=a.getUint16();for(i=b=0;i<h;i++)g=j[i],(l=a.getUint16())?(n=(l>>1)-(h-i),g.offsetIndex=n,b=Math.max(b,n+g.end-g.start+1)):g.offsetIndex=-1;r=[];for(g=0;g<b;g++)r.push(a.getUint16());for(i=0;i<h;i++){g=j[i];var b=g.start,a=g.end,p=g.delta,n=g.offsetIndex;for(g=b;g<=a;g++)65535!==g&&(l=0>n?g:r[n+g-b],l=l+p&65535,0!==l&&c.push({charCode:g,glyphId:l}))}}else if(6===b){b=a.getUint16();h=a.getUint16();for(g=0;g<h;g++)l=a.getUint16(),c.push({charCode:b+g,glyphId:l})}else return d("cmap table has unsupported format: "+
b),{platformId:-1,encodingId:-1,mappings:[],hasShortCmap:!1};c.sort(function(b,a){return b.charCode-a.charCode});for(g=1;g<c.length;g++)c[g-1].charCode===c[g].charCode&&(c.splice(g,1),g--);return{platformId:k.platformId,encodingId:k.encodingId,mappings:c,hasShortCmap:f}}function h(b,a,c,d,f,g){if(12>=c-a)return 0;var b=b.subarray(a,c),e=b[0]<<8|b[1];if(e&32768)return d.set(b,f),b.length;for(var c=10,i=0,a=0;a<e;a++)i=(b[c]<<8|b[c+1])+1,c+=2;for(var e=c,k=b[c]<<8|b[c+1],j=c+=2+k,l=0,a=0;a<i;a++){var n=
b[c++];n&192&&(b[c-1]=n&63);var r=(n&2?1:n&16?0:2)+(n&4?1:n&32?0:2),l=l+r;n&8&&(n=b[c++],a+=n,l+=n*r)}if(0===l)return 0;a=c+l;if(a>b.length)return 0;if(!g&&0<k)return d.set(b.subarray(0,e),f),d.set([0,0],f+e),d.set(b.subarray(j,a),f+e+2),a-=k,3<b.length-a&&(a=a+3&-4),a;if(3<b.length-a)return a=a+3&-4,d.set(b.subarray(0,a),f),a;d.set(b,f);return b.length}function k(b,a,c,d,f,g){var e,i;d?(d=4,e=function(b,a){return b[a]<<24|b[a+1]<<16|b[a+2]<<8|b[a+3]},i=function(b,a,c){b[a]=c>>>24&255;b[a+1]=c>>16&
255;b[a+2]=c>>8&255;b[a+3]=c&255}):(d=2,e=function(b,a){return b[a]<<9|b[a+1]<<1},i=function(b,a,c){b[a]=c>>9&255;b[a+1]=c>>1&255});var j=b.data,l=d*(1+c);j.length!==l&&(j=new Uint8Array(l),j.set(b.data.subarray(0,l)),b.data=j);var n=a.data,r=n.length,p=new Uint8Array(r),q=e(j,0),m=0,l={};i(j,0,m);var s,B;for(s=0,B=d;s<c;s++,B+=d){var u=e(j,B);u>r&&(r+3&-4)===u&&(u=r);u>r||(q===u&&(l[s]=!0),q=h(n,q,u,p,m,f),m+=q);i(j,B,m);q=u}if(0===m){b=new Uint8Array([0,1,0,0,0,0,0,0,0,0,0,0,0,0,49,0]);for(s=0,
B=d;s<c;s++,B+=d)i(j,B,b.length);a.data=b;return l}g?(c=e(j,d),p.length>c+m?a.data=p.subarray(0,c+m):(a.data=new Uint8Array(c+m),a.data.set(p.subarray(0,m))),a.data.set(p.subarray(0,c),m),i(b.data,j.length-d,m+c)):a.data=p.subarray(0,m);return l}function i(b,c,f){var g=(a.start?a.start:0)+b.offset;a.pos=g;var g=g+b.length,e=a.getInt32();a.getBytes(28);var h,b=!0;switch(e){case 65536:h=qa;break;case 131072:e=a.getUint16();if(e!==f){b=!1;break}for(var k=[],f=0;f<e;++f){var j=a.getUint16();if(32768<=
j){b=!1;break}k.push(j)}if(!b)break;j=[];for(h=[];a.pos<g;){var l=a.getByte();h.length=l;for(f=0;f<l;++f)h[f]=String.fromCharCode(a.getByte());j.push(h.join(""))}h=[];for(f=0;f<e;++f)g=k[f],258>g?h.push(qa[g]):h.push(j[g-258]);break;case 196608:break;default:d("Unknown/unsupported post table version "+e),b=!1,c.defaultEncoding&&(h=c.defaultEncoding)}c.glyphNames=h;return b}function j(b){var c=(a.start?a.start:0)+b.offset;a.pos=c;var d=[[],[]],f=b.length,b=c+f;if(0!==a.getUint16()||6>f)return d;var g=
a.getUint16(),f=a.getUint16(),e=[],h;for(h=0;h<g&&a.pos+12<=b;h++){var i={platform:a.getUint16(),encoding:a.getUint16(),language:a.getUint16(),name:a.getUint16(),length:a.getUint16(),offset:a.getUint16()};(1===i.platform&&0===i.encoding&&0===i.language||3===i.platform&&1===i.encoding&&1033===i.language)&&e.push(i)}for(h=0,g=e.length;h<g;h++){var i=e[h],k=c+f+i.offset;if(!(k+i.length>b))if(a.pos=k,k=i.name,i.encoding){for(var l="",n=0,i=i.length;n<i;n+=2)l+=String.fromCharCode(a.getUint16());d[1][k]=
l}else d[0][k]=R(a.getBytes(i.length))}return d}function l(b,a){for(var c=b.data,f=0,g,e,h,i=0,k=0,j=[],n=[],r=[],q=a.tooComplexToFollowFunctions,m=!1,s=0,B=0,u=c.length;f<u;){var t=c[f++];if(64===t)if(e=c[f++],m||B)f+=e;else for(g=0;g<e;g++)j.push(c[f++]);else if(65===t)if(e=c[f++],m||B)f+=2*e;else for(g=0;g<e;g++)h=c[f++],j.push(h<<8|c[f++]);else if(176===(t&248))if(e=t-176+1,m||B)f+=e;else for(g=0;g<e;g++)j.push(c[f++]);else if(184===(t&248))if(e=t-184+1,m||B)f+=2*e;else for(g=0;g<e;g++)h=c[f++],
j.push(h<<8|c[f++]);else if(43===t&&!q){if(!m&&!B)if(e=j[j.length-1],a.functionsUsed[e]=!0,e in a.functionsStackDeltas)j.length+=a.functionsStackDeltas[e];else if(e in a.functionsDefined&&0>r.indexOf(e)){n.push({data:c,i:f,stackTop:j.length-1});r.push(e);g=a.functionsDefined[e];if(!g){d("TT: CALL non-existent function");a.hintsValid=!1;return}c=g.data;f=g.i}}else if(44===t&&!q){if(m||B)d("TT: nested FDEFs not allowed"),q=!0;m=!0;k=f;e=j.pop();a.functionsDefined[e]={data:c,i:f}}else if(45===t)if(m)m=
!1,i=f;else{g=n.pop();if(!g){d("TT: ENDF bad stack");a.hintsValid=!1;return}e=r.pop();c=g.data;f=g.i;a.functionsStackDeltas[e]=j.length-g.stackTop}else if(137===t){if(m||B)d("TT: nested IDEFs not allowed"),q=!0;m=!0;k=f}else 88===t?++s:27===t?B=s:89===t?(B===s&&(B=0),--s):28===t&&!m&&!B&&(e=j[j.length-1],0<e&&(f+=e-1));if(!m&&!B){g=142>=t?p[t]:192<=t&&223>=t?-1:224<=t?-2:0;113<=t&&117>=t&&(e=j.pop(),e===e&&(g=2*-e));for(;0>g&&0<j.length;)j.pop(),g++;for(;0<g;)j.push(NaN),g--}}a.tooComplexToFollowFunctions=
q;j=[c];f>c.length&&j.push(new Uint8Array(f-c.length));k>i&&(d("TT: complementing a missing function tail"),j.push(new Uint8Array([34,45])));if(1<j.length){c=0;for(f=0,i=j.length;f<i;f++)c+=j[f].length;c=c+3&-4;k=new Uint8Array(c);n=0;for(f=0,i=j.length;f<i;f++)k.set(j[f],n),n+=j[f].length;b.data=k;b.length=c}}function r(b,a,c){return!D[b]||!ma&&0<=a&&E.has(a)||Va&&0<=c&&y(Va[c])?!0:!1}var p=[0,0,0,0,0,0,0,0,-2,-2,-2,-2,0,0,-2,-5,-1,-1,-1,-1,-1,-1,-1,-1,0,0,-1,0,-1,-1,-1,-1,1,-1,-999,0,1,0,-1,-2,
0,-1,-2,-1,-1,0,-1,-1,0,0,-999,-999,-1,-1,-1,-1,-2,-999,-2,-2,-999,0,-2,-2,0,0,-2,0,-2,0,0,0,-2,-1,-1,1,1,0,0,-1,-1,-1,-1,-1,-1,-1,0,0,-1,0,-1,-1,0,-999,-1,-1,-1,-1,-1,-1,0,0,0,0,0,0,0,0,0,0,0,0,-2,-999,-999,-999,-999,-999,-1,-1,-2,-2,0,0,0,0,-1,-1,-999,-2,-2,0,0,-1,-2,-2,0,0,0,-1,-1,-1,-2],a=new c(new Uint8Array(a.getBytes())),s="OS/2,cmap,head,hhea,hmtx,maxp,name,post,loca,glyf,fpgm,prep,cvt ,CFF ".split(","),va=R(a.getBytes(4)),o=a.getUint16();a.getUint16();a.getUint16();a.getUint16();for(var A,
ta,B={"OS/2":null,cmap:null,head:null,hhea:null,hmtx:null,maxp:null,name:null,post:null},F,S=0;S<o;S++)F=g(a),0>s.indexOf(F.tag)||0!==F.length&&(B[F.tag]=F);if(s=!B["CFF "])(!B.glyf||!B.loca)&&m('Required "glyf" or "loca" tables are not found'),this.isOpenType=!1;else{if("OTTO"===va&&"CIDFontType2"!==f.type||!B.head||!B.hhea||!B.maxp||!B.post)return ta=new c(B["CFF "].data),A=new fa(ta,f),C(f),this.convert(b,A,f);delete B.glyf;delete B.loca;delete B.fpgm;delete B.prep;delete B["cvt "];this.isOpenType=
!0}B.maxp||m('Required "maxp" table is not found');a.pos=(a.start||0)+B.maxp.offset;var o=a.getInt32(),ua=a.getUint16(),M=0;65536<=o&&22<=B.maxp.length&&(a.pos+=8,2<a.getUint16()&&(B.maxp.data[14]=0,B.maxp.data[15]=2),a.pos+=4,M=a.getUint16());S=!1;"CIDFontType2"===f.type&&f.toUnicode&&"\x00"<f.toUnicode.get(0)&&(S=!0,ua++,B.maxp.data[4]=ua>>8,B.maxp.data[5]=ua&255);o=function(b,a,c){var f={functionsDefined:[],functionsUsed:[],functionsStackDeltas:[],tooComplexToFollowFunctions:!1,hintsValid:!0};
b&&l(b,f);a&&l(a,f);if(b&&(b=M,!f.tooComplexToFollowFunctions))if(f.functionsDefined.length>b)d("TT: more functions defined than expected"),f.hintsValid=!1;else for(var a=0,g=f.functionsUsed.length;a<g;a++){if(a>b){d("TT: invalid function id: "+a);f.hintsValid=!1;break}if(f.functionsUsed[a]&&!f.functionsDefined[a]){d("TT: undefined function: "+a);f.hintsValid=!1;break}}c&&c.length&1&&(b=new Uint8Array(c.length+1),b.set(c.data),c.data=b);return f.hintsValid}(B.fpgm,B.prep,B["cvt "],M);o||(delete B.fpgm,
delete B.prep,delete B["cvt "]);(function(b,a,c,d){a?(b.pos=(b.start?b.start:0)+a.offset,b.pos+=a.length-2,b=b.getUint16(),b>d&&(w("The numOfMetrics ("+b+") should not be greater than the numGlyphs ("+d+")"),b=d,a.data[34]=(b&65280)>>8,a.data[35]=b&255),a=d-b-(c.length-4*b>>1),0<a&&(a=new Uint8Array(c.length+2*a),a.set(c.data),c.data=a)):c&&(c.data=null)})(a,B.hhea,B.hmtx,ua);B.head||m('Required "head" table is not found');(function(b,a,c){var b=b.data,f=(b[0]<<24)+(b[1]<<16)+(b[2]<<8)+b[3];1!==f>>
16&&(w("Attempting to fix invalid version in head table: "+f),b[0]=0,b[1]=1,b[2]=0,b[3]=0);f=(b[50]<<8)+b[51];if(0>f||1<f)w("Attempting to fix invalid indexToLocFormat in head table: "+f),a+=1,c===a<<1?(b[50]=0,b[51]=0):c===a<<2?(b[50]=0,b[51]=1):d("Could not fix indexToLocFormat: "+f)})(B.head,ua,s?B.loca.length:0);var D={};s&&(D=k(B.loca,B.glyf,ua,(B.head.data[50]<<8)+B.head.data[51],o,S));B.hhea||m('Required "hhea" table is not found');0===B.hhea.data[10]&&0===B.hhea.data[11]&&(B.hhea.data[10]=
255,B.hhea.data[11]=255);o={unitsPerEm:(B.head.data[18]<<8)+B.head.data[19],yMax:(B.head.data[42]<<8)+B.head.data[43],yMin:(B.head.data[38]<<8)+B.head.data[39]-65536,ascent:(B.hhea.data[4]<<8)+B.hhea.data[5],descent:(B.hhea.data[6]<<8)+B.hhea.data[7]-65536};this.ascent=o.ascent/o.unitsPerEm;this.descent=o.descent/o.unitsPerEm;B.post&&!i(B.post,f,ua)&&(B.post=null);var wa=[],G,E=f.toUnicode,Va=f.widths,ma=E instanceof ea||65536===E.length;if("CIDFontType2"===f.type){var aa=f.cidToGidMap||[],$=0===
aa.length;f.cMap.forEach(function(b,a){z(65535>=a,"Max size of CID is 65,535");var c=-1;$?c=b:void 0!==aa[a]&&(c=aa[a]);0<=c&&c<ua&&r(c,b,a)&&(wa[b]=c)});S&&(wa[0]=ua-1)}else{var S=0<f.differences.length||!!f.baseEncodingName,ga=e(B.cmap,a,this.isSymbolicFont,S);F=ga.platformId;var H=ga.encodingId,ga=ga.mappings,la=ga.length;if(S&&(3===F&&1===H||1===F&&0===H)||-1===F&&-1===H&&ba[f.baseEncodingName]){var I=[];if("MacRomanEncoding"===f.baseEncodingName||"WinAnsiEncoding"===f.baseEncodingName)I=ba[f.baseEncodingName];
for(G=0;256>G;G++){var J;if(J=this.differences&&G in this.differences?this.differences[G]:G in I&&""!==I[G]?I[G]:ba.StandardEncoding[G]){var K,L=!1;3===F&&1===H?(K=q[J],L=!0):1===F&&0===H&&(K=ba.MacRomanEncoding.indexOf(J));for(var N=!1,S=0;S<la;++S)if(ga[S].charCode===K&&r(ga[S].glyphId,L?G:K,-1)){wa[G]=ga[S].glyphId;N=!0;break}!N&&f.glyphNames&&(S=f.glyphNames.indexOf(J),wa[G]=0<S&&r(S,-1,-1)?S:0)}}}else if(0===F&&0===H)for(S=0;S<la;++S)wa[ga[S].charCode]=ga[S].glyphId;else for(S=0;S<la;++S)G=ga[S].charCode&
255,wa[G]=ga[S].glyphId}0===wa.length&&(wa[0]=0);K=n(wa,f);this.toFontChar=K.toFontChar;B.cmap={tag:"cmap",data:u(K.charCodeToGlyphId,ua)};if(!B["OS/2"]||!t(B["OS/2"]))B["OS/2"]={tag:"OS/2",data:v(f,K.charCodeToGlyphId,o)};B.post||(B.post={tag:"post",data:x(f)});if(!s)try{ta=new c(B["CFF "].data);A=(new sa(ta,f)).parse();var V=new Wa(A);B["CFF "].data=V.compile()}catch(O){d("Failed to compile font "+f.loadedName)}B.name?(f=j(B.name),B.name.data=X(b,f)):B.name={tag:"name",data:X(this.name)};var b=
new Ua(va),W;for(W in B)b.addTable(W,B[W].data);return b.toArray()},convert:function(b,c,d){function f(b,a){var c=null,d;for(d in b)a===b[d]&&(c||(c=[]),c.push(d|0));return c}function e(b,a){for(var c in b)if(a===b[c])return c|0;i.charCodeToGlyphId[i.nextAvailableFontCharCode]=a;return i.nextAvailableFontCharCode++}d.fixedPitch=!1;var h=c.getGlyphMapping(d),i=n(h,d);this.toFontChar=i.toFontChar;var k=c.numGlyphs,j=c.seacs;if(V&&j&&j.length){var l=d.fontMatrix||D,r=c.getCharset(),p=Object.create(null),
m;for(m in j){m|=0;var q=j[m],s=ba.StandardEncoding[q[3]],B=r.indexOf(ba.StandardEncoding[q[2]]),s=r.indexOf(s);if(!(0>B||0>s)){var q={x:q[0]*l[0]+q[1]*l[2]+l[4],y:q[0]*l[1]+q[1]*l[3]+l[5]},t=f(h,m);if(t)for(var o=0,va=t.length;o<va;o++){var A=t[o],w=i.charCodeToGlyphId,F=e(w,B),w=e(w,s);p[A]={baseFontCharCode:F,accentFontCharCode:w,accentOffset:q}}}}d.seacMap=p}h=1/(d.fontMatrix||D)[0];j=new Ua("OTTO");j.addTable("CFF ",c.data);j.addTable("OS/2",v(d,i.charCodeToGlyphId));j.addTable("cmap",u(i.charCodeToGlyphId,
k));j.addTable("head","\x00\u0001\x00\x00\x00\x00\u0010\x00\x00\x00\x00\x00_\u000f<\u00f5\x00\x00"+g(h)+"\x00\x00\x00\x00\u009e\x0B~'\x00\x00\x00\x00\u009e\x0B~'\x00\x00"+g(d.descent)+"\u000f\u00ff"+g(d.ascent)+a(d.italicAngle?2:0)+"\x00\u0011\x00\x00\x00\x00\x00\x00");j.addTable("hhea","\x00\u0001\x00\x00"+g(d.ascent)+g(d.descent)+"\x00\x00\u00ff\u00ff\x00\x00\x00\x00\x00\x00"+g(d.capHeight)+g(Math.tan(d.italicAngle)*d.xHeight)+"\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"+a(k));j.addTable("hmtx",
function(){for(var b=c.charstrings,d=c.cff?c.cff.widths:null,f="\x00\x00\x00\x00",g=1;g<k;g++){var e=0;b?(e=b[g-1],e="width"in e?e.width:0):d&&(e=Math.ceil(d[g]||0));f+=a(e)+a(0)}return f}());j.addTable("maxp","\x00\x00P\x00"+a(k));j.addTable("name",X(b));j.addTable("post",x(d));return j.toArray()},buildToUnicode:function(b){if(b.toUnicode&&0!==b.toUnicode.length)return b.toUnicode;var a,c;if(!b.composite){a=[];var d=b.defaultEncoding.slice(),f=b.baseEncodingName,b=b.differences;for(c in b)d[c]=b[c];
for(c in d)if(b=d[c],""!==b)if(void 0===q[b]){var g=0;switch(b[0]){case "G":3===b.length&&(g=parseInt(b.substr(1),16));break;case "g":5===b.length&&(g=parseInt(b.substr(1),16));break;case "C":case "c":3<=b.length&&(g=+b.substr(1))}if(g){if(f&&g===+c){var e=ba[f];if(e&&(b=e[c])){a[c]=String.fromCharCode(q[b]);continue}}a[c]=String.fromCharCode(g)}}else a[c]=String.fromCharCode(q[b]);return new ha(a)}if(b.composite&&(b.cMap.builtInCMap&&!(b.cMap instanceof l)||"Adobe"===b.cidSystemInfo.registry&&("GB1"===
b.cidSystemInfo.ordering||"CNS1"===b.cidSystemInfo.ordering||"Japan1"===b.cidSystemInfo.ordering||"Korea1"===b.cidSystemInfo.ordering))){c=new k(b.cidSystemInfo.registry+"-"+b.cidSystemInfo.ordering+"-UCS2");var h=i.create(c,{url:PDFJS.cMapUrl,packed:PDFJS.cMapPacked},null);c=b.cMap;a=[];c.forEach(function(b,c){z(65535>=c,"Max size of CID is 65,535");var d=h.lookup(c);d&&(a[b]=String.fromCharCode((d.charCodeAt(0)<<8)+d.charCodeAt(1)))});return new ha(a)}return new ea(b.firstChar,b.lastChar)},get spaceWidth(){if("_shadowWidth"in
this)return this._shadowWidth;for(var b=["space","minus","one","i"],a,c=0,d=b.length;c<d;c++){a=b[c];if(a in this.widths){a=this.widths[a];break}a=q[a];var f=0;this.composite&&this.cMap.contains(a)&&(f=this.cMap.lookup(a));!f&&this.toUnicode&&(f=this.toUnicode.charCodeOf(a));0>=f&&(f=a);if(a=this.widths[f])break}return this._shadowWidth=a=a||this.defaultWidth},charToGlyph:function(b,a){var c,d,f,g=b;this.cMap&&this.cMap.contains(b)&&(g=this.cMap.lookup(b));d=this.widths[g];d=y(d)?d:this.defaultWidth;
var g=this.vmetrics&&this.vmetrics[g],e=this.toUnicode.get(b)||b;"number"===typeof e&&(e=String.fromCharCode(e));c=this.toFontChar[b]||b;this.missingFile&&(65520<=c&&65535>=c?c=0:62976<=c&&63743>=c&&(c=sc[c]||c));this.isType3Font&&(f=c);var h=null;this.seacMap&&this.seacMap[b]&&(h=this.seacMap[b],c=h.baseFontCharCode,h={fontChar:String.fromCharCode(h.accentFontCharCode),offset:h.accentOffset});c=String.fromCharCode(c);var i=this.glyphCache[b];if(!i||!i.matchesForCache(c,e,h,d,g,f,a))i=new Ka(c,e,
h,d,g,f,a),this.glyphCache[b]=i;return i},charsToGlyphs:function(b){var a=this.charsCache,c,d;if(a&&(c=a[b]))return c;a||(a=this.charsCache=Object.create(null));c=[];var f=0,g;if(this.cMap)for(g={};f<b.length;){this.cMap.readCharCode(b,f,g);d=g.charcode;var e=g.length,f=f+e,e=1===e&&32===b.charCodeAt(f-1);d=this.charToGlyph(d,e);c.push(d)}else for(f=0,g=b.length;f<g;++f)d=b.charCodeAt(f),d=this.charToGlyph(d,32===d),c.push(d);return a[b]=c}};return b}(),O=function(){function b(a){this.error=a;this.loadedName=
"g_font_error";this.loading=!1}b.prototype={charsToGlyphs:function(){return[]},exportData:function(){return{error:this.error}}};return b}(),ca=function(){function b(){this.lsb=this.width=0;this.flexing=!1;this.output=[];this.stack=[]}var a=[4],c=[5],f=[6],g=[7],e=[8],h=[12,35],i=[14],k=[21],j=[22],l=[30],n=[31];b.prototype={convert:function(b,r){for(var p=b.length,m=!1,q,s=0;s<p;s++)if(q=b[s],32>q){12===q&&(q=(q<<8)+b[++s]);switch(q){case 1:this.stack=[];break;case 3:this.stack=[];break;case 4:if(this.flexing){if(1>
this.stack.length){m=!0;break}this.stack.push(0,this.stack.pop());break}m=this.executeCommand(1,a);break;case 5:m=this.executeCommand(2,c);break;case 6:m=this.executeCommand(1,f);break;case 7:m=this.executeCommand(1,g);break;case 8:m=this.executeCommand(6,e);break;case 9:this.stack=[];break;case 10:if(1>this.stack.length){m=!0;break}q=this.stack.pop();m=this.convert(r[q],r);break;case 11:return m;case 13:if(2>this.stack.length){m=!0;break}m=this.stack.pop();this.lsb=q=this.stack.pop();this.width=
m;this.stack.push(m,q);m=this.executeCommand(2,j);break;case 14:this.output.push(i[0]);break;case 21:if(this.flexing)break;m=this.executeCommand(2,k);break;case 22:if(this.flexing){this.stack.push(0);break}m=this.executeCommand(1,j);break;case 30:m=this.executeCommand(4,l);break;case 31:m=this.executeCommand(4,n);break;case 3072:this.stack=[];break;case 3073:this.stack=[];break;case 3074:this.stack=[];break;case 3078:V?(this.seac=this.stack.splice(-4,4),m=this.executeCommand(0,i)):m=this.executeCommand(4,
i);break;case 3079:if(4>this.stack.length){m=!0;break}this.stack.pop();var m=this.stack.pop(),B=this.stack.pop();this.lsb=q=this.stack.pop();this.width=m;this.stack.push(m,q,B);m=this.executeCommand(3,k);break;case 3084:if(2>this.stack.length){m=!0;break}q=this.stack.pop();this.stack.push(this.stack.pop()/q);break;case 3088:if(2>this.stack.length){m=!0;break}q=this.stack.pop();B=this.stack.pop();0===q&&3===B?(q=this.stack.splice(this.stack.length-17,17),this.stack.push(q[2]+q[0],q[3]+q[1],q[4],q[5],
q[6],q[7],q[8],q[9],q[10],q[11],q[12],q[13],q[14]),m=this.executeCommand(13,h,!0),this.flexing=!1,this.stack.push(q[15],q[16])):1===q&&0===B&&(this.flexing=!0);break;case 3089:break;case 3105:this.stack=[];break;default:d('Unknown type 1 charstring command of "'+q+'"')}if(m)break}else q=246>=q?q-139:250>=q?256*(q-247)+b[++s]+108:254>=q?-(256*(q-251))-b[++s]-108:(b[++s]&255)<<24|(b[++s]&255)<<16|(b[++s]&255)<<8|(b[++s]&255)<<0,this.stack.push(q);return m},executeCommand:function(b,a,c){var d=this.stack.length;
if(b>d)return!0;for(var f=d-b,g=f;g<d;g++){var e=this.stack[g];e===(e|0)?this.output.push(28,e>>8&255,e&255):(e=65536*e|0,this.output.push(255,e>>24&255,e>>16&255,e>>8&255,e&255))}this.output.push.apply(this.output,a);c?this.stack.splice(f,b):this.stack.length=0;return!1}};return b}(),La=function(){function a(b){return 48<=b&&57>=b||65<=b&&70>=b||97<=b&&102>=b}function d(b,a,c){for(var a=a|0,f=b.length,g=new Uint8Array(f),e=0;e<f;e++){var h=b[e];g[e]=h^a>>8;a=52845*(h+a)+22719&65535}return Array.prototype.slice.call(g,
c)}function f(b){return 47===b||91===b||93===b||123===b||125===b||40===b||41===b}function g(b,f){if(f){var h=b.getBytes(),i=!(a(h[0])&&a(h[1])&&a(h[2])&&a(h[3])),k=c;if(i)h=d(h,e,4);else{var i=e|0,j=h.length,l=new Uint8Array(j>>>1),n,r;for(n=0,r=0;n<j;n++){var p=h[n];if(a(p)){n++;for(var q;n<j&&!a(q=h[n]);)n++;n<j&&(p=parseInt(String.fromCharCode(p,q),16),l[r++]=p^i>>8,i=52845*(p+i)+22719&65535)}}h=Array.prototype.slice.call(l,4,r)}b=new k(h)}this.stream=b;this.nextChar()}var e=55665;g.prototype=
{readNumberArray:function(){this.getToken();for(var b=[];;){var a=this.getToken();if(null===a||"]"===a||"}"===a)break;b.push(parseFloat(a||0))}return b},readNumber:function(){var b=this.getToken();return parseFloat(b||0)},readInt:function(){var b=this.getToken();return parseInt(b||0,10)|0},readBoolean:function(){return"true"===this.getToken()?1:0},nextChar:function(){return this.currentChar=this.stream.getByte()},getToken:function(){for(var a=!1,c=this.currentChar;;){if(-1===c)return null;if(a){if(10===
c||13===c)a=!1}else if(37===c)a=!0;else if(!b.isSpace(c))break;c=this.nextChar()}if(f(c))return this.nextChar(),String.fromCharCode(c);a="";do a+=String.fromCharCode(c),c=this.nextChar();while(0<=c&&!b.isSpace(c)&&!f(c));return a},extractFontProgram:function(){for(var b=this.stream,a=[],c=[],f={subrs:[],charstrings:[],properties:{privateData:{lenIV:4}}},g,e,h;null!==(g=this.getToken());)if("/"===g)switch(g=this.getToken(),g){case "CharStrings":this.getToken();this.getToken();this.getToken();for(this.getToken();;){g=
this.getToken();if(null===g||"end"===g)break;if("/"===g){var i=this.getToken();g=this.readInt();this.getToken();e=b.makeSubStream(b.pos,g);h=f.properties.privateData.lenIV;e=d(e.getBytes(),4330,h);b.skip(g);this.nextChar();g=this.getToken();"noaccess"===g&&this.getToken();c.push({glyph:i,encoded:e})}}break;case "Subrs":this.readInt();for(this.getToken();"dup"===this.getToken();)i=this.readInt(),g=this.readInt(),this.getToken(),e=b.makeSubStream(b.pos,g),h=f.properties.privateData.lenIV,e=d(e.getBytes(),
4330,h),b.skip(g),this.nextChar(),g=this.getToken(),"noaccess"===g&&this.getToken(),a[i]=e;break;case "BlueValues":case "OtherBlues":case "FamilyBlues":case "FamilyOtherBlues":this.readNumberArray();break;case "StemSnapH":case "StemSnapV":f.properties.privateData[g]=this.readNumberArray();break;case "StdHW":case "StdVW":f.properties.privateData[g]=this.readNumberArray()[0];break;case "BlueShift":case "lenIV":case "BlueFuzz":case "BlueScale":case "LanguageGroup":case "ExpansionFactor":f.properties.privateData[g]=
this.readNumber();break;case "ForceBold":f.properties.privateData[g]=this.readBoolean()}for(b=0;b<c.length;b++)i=c[b].glyph,e=c[b].encoded,g=new ca,e=g.convert(e,a),h=g.output,e&&(h=[14]),f.charstrings.push({glyphName:i,charstring:h,width:g.width,lsb:g.lsb,seac:g.seac});return f},extractFontHeader:function(b){for(var a;null!==(a=this.getToken());)if("/"===a)switch(a=this.getToken(),a){case "FontMatrix":var c=this.readNumberArray();b.fontMatrix=c;break;case "Encoding":var d=this.getToken();if(/^\d+$/.test(d)){c=
[];d=parseInt(d,10)|0;this.getToken();for(var f=0;f<d;f++){for(a=this.getToken();"dup"!==a&&"def"!==a;)if(a=this.getToken(),null===a)return;if("def"===a)break;a=this.readInt();this.getToken();var g=this.getToken();c[a]=g;this.getToken()}}else c=ba[d];b.builtInEncoding=c;break;case "FontBBox":c=this.readNumberArray(),b.ascent=c[3],b.descent=c[1],b.ascentScaled=!0}}};return g}(),Y=".notdef,space,exclam,quotedbl,numbersign,dollar,percent,ampersand,quoteright,parenleft,parenright,asterisk,plus,comma,hyphen,period,slash,zero,one,two,three,four,five,six,seven,eight,nine,colon,semicolon,less,equal,greater,question,at,A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,bracketleft,backslash,bracketright,asciicircum,underscore,quoteleft,a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,braceleft,bar,braceright,asciitilde,exclamdown,cent,sterling,fraction,yen,florin,section,currency,quotesingle,quotedblleft,guillemotleft,guilsinglleft,guilsinglright,fi,fl,endash,dagger,daggerdbl,periodcentered,paragraph,bullet,quotesinglbase,quotedblbase,quotedblright,guillemotright,ellipsis,perthousand,questiondown,grave,acute,circumflex,tilde,macron,breve,dotaccent,dieresis,ring,cedilla,hungarumlaut,ogonek,caron,emdash,AE,ordfeminine,Lslash,Oslash,OE,ordmasculine,ae,dotlessi,lslash,oslash,oe,germandbls,onesuperior,logicalnot,mu,trademark,Eth,onehalf,plusminus,Thorn,onequarter,divide,brokenbar,degree,thorn,threequarters,twosuperior,registered,minus,eth,multiply,threesuperior,copyright,Aacute,Acircumflex,Adieresis,Agrave,Aring,Atilde,Ccedilla,Eacute,Ecircumflex,Edieresis,Egrave,Iacute,Icircumflex,Idieresis,Igrave,Ntilde,Oacute,Ocircumflex,Odieresis,Ograve,Otilde,Scaron,Uacute,Ucircumflex,Udieresis,Ugrave,Yacute,Ydieresis,Zcaron,aacute,acircumflex,adieresis,agrave,aring,atilde,ccedilla,eacute,ecircumflex,edieresis,egrave,iacute,icircumflex,idieresis,igrave,ntilde,oacute,ocircumflex,odieresis,ograve,otilde,scaron,uacute,ucircumflex,udieresis,ugrave,yacute,ydieresis,zcaron,exclamsmall,Hungarumlautsmall,dollaroldstyle,dollarsuperior,ampersandsmall,Acutesmall,parenleftsuperior,parenrightsuperior,twodotenleader,onedotenleader,zerooldstyle,oneoldstyle,twooldstyle,threeoldstyle,fouroldstyle,fiveoldstyle,sixoldstyle,sevenoldstyle,eightoldstyle,nineoldstyle,commasuperior,threequartersemdash,periodsuperior,questionsmall,asuperior,bsuperior,centsuperior,dsuperior,esuperior,isuperior,lsuperior,msuperior,nsuperior,osuperior,rsuperior,ssuperior,tsuperior,ff,ffi,ffl,parenleftinferior,parenrightinferior,Circumflexsmall,hyphensuperior,Gravesmall,Asmall,Bsmall,Csmall,Dsmall,Esmall,Fsmall,Gsmall,Hsmall,Ismall,Jsmall,Ksmall,Lsmall,Msmall,Nsmall,Osmall,Psmall,Qsmall,Rsmall,Ssmall,Tsmall,Usmall,Vsmall,Wsmall,Xsmall,Ysmall,Zsmall,colonmonetary,onefitted,rupiah,Tildesmall,exclamdownsmall,centoldstyle,Lslashsmall,Scaronsmall,Zcaronsmall,Dieresissmall,Brevesmall,Caronsmall,Dotaccentsmall,Macronsmall,figuredash,hypheninferior,Ogoneksmall,Ringsmall,Cedillasmall,questiondownsmall,oneeighth,threeeighths,fiveeighths,seveneighths,onethird,twothirds,zerosuperior,foursuperior,fivesuperior,sixsuperior,sevensuperior,eightsuperior,ninesuperior,zeroinferior,oneinferior,twoinferior,threeinferior,fourinferior,fiveinferior,sixinferior,seveninferior,eightinferior,nineinferior,centinferior,dollarinferior,periodinferior,commainferior,Agravesmall,Aacutesmall,Acircumflexsmall,Atildesmall,Adieresissmall,Aringsmall,AEsmall,Ccedillasmall,Egravesmall,Eacutesmall,Ecircumflexsmall,Edieresissmall,Igravesmall,Iacutesmall,Icircumflexsmall,Idieresissmall,Ethsmall,Ntildesmall,Ogravesmall,Oacutesmall,Ocircumflexsmall,Otildesmall,Odieresissmall,OEsmall,Oslashsmall,Ugravesmall,Uacutesmall,Ucircumflexsmall,Udieresissmall,Yacutesmall,Thornsmall,Ydieresissmall,001.000,001.001,001.002,001.003,Black,Bold,Book,Light,Medium,Regular,Roman,Semibold".split(","),
ka=function(b,a,d){var f=d.length1,g=d.length2,e=a.peekBytes(6),h=128===e[0]&&1===e[1];h&&(a.skip(6),f=e[5]<<24|e[4]<<16|e[3]<<8|e[2]);f=new c(a.getBytes(f));(new La(f)).extractFontHeader(d);h&&(e=a.getBytes(6),g=e[5]<<24|e[4]<<16|e[3]<<8|e[2]);var a=new c(a.getBytes(g)),a=(new La(a,!0)).extractFontProgram(),i;for(i in a.properties)d[i]=a.properties[i];i=a.charstrings;g=this.getType2Charstrings(i);h=this.getType2Subrs(a.subrs);this.charstrings=i;this.data=this.wrap(b,g,this.charstrings,h,d);this.seacs=
this.getSeacs(a.charstrings)};ka.prototype={get numGlyphs(){return this.charstrings.length+1},getCharset:function(){for(var b=[".notdef"],a=this.charstrings,c=0;c<a.length;c++)b.push(a[c].glyphName);return b},getGlyphMapping:function(b){var a=this.charstrings,c=[".notdef"],d;for(d=0;d<a.length;d++)c.push(a[d].glyphName);if(a=b.builtInEncoding){var f={},g;for(g in a)d=c.indexOf(a[g]),0<=d&&(f[g]=d)}return x(b,f,c)},getSeacs:function(b){var a,c,d=[];for(a=0,c=b.length;a<c;a++){var f=b[a];f.seac&&(d[a+
1]=f.seac)}return d},getType2Charstrings:function(b){for(var a=[],c=0,d=b.length;c<d;c++)a.push(b[c].charstring);return a},getType2Subrs:function(b){var a=0,c=b.length,a=1133>c?107:33769>c?1131:32768,d=[],f;for(f=0;f<a;f++)d.push([11]);for(f=0;f<c;f++)d.push(b[f]);return d},wrap:function(b,a,c,d,f){var g=new Fa;g.header=new U(1,0,4,4);g.names=[b];var e=new cb;e.setByName("version",391);e.setByName("Notice",392);e.setByName("FullName",393);e.setByName("FamilyName",394);e.setByName("Weight",395);e.setByName("Encoding",
null);e.setByName("FontMatrix",f.fontMatrix);e.setByName("FontBBox",f.bbox);e.setByName("charset",null);e.setByName("CharStrings",null);e.setByName("Private",null);g.topDict=e;e=new Ba;e.add("Version 0.11");e.add("See original notice");e.add(b);e.add(b);e.add("Medium");g.strings=e;g.globalSubrIndex=new ia;for(var e=a.length,h=[0],b=0;b<e;b++){var i=Y.indexOf(c[b].glyphName);-1===i&&(i=0);h.push(i>>8&255,i&255)}g.charset=new aa(!1,0,[],h);c=new ia;c.add([139,14]);for(b=0;b<e;b++)c.add(a[b]);g.charStrings=
c;c=new X;c.setByName("Subrs",null);e="BlueValues,OtherBlues,FamilyBlues,FamilyOtherBlues,StemSnapH,StemSnapV,BlueShift,BlueFuzz,BlueScale,LanguageGroup,ExpansionFactor,ForceBold,StdHW,StdVW".split(",");for(b=0,a=e.length;b<a;b++)if(h=e[b],f.privateData.hasOwnProperty(h)){i=f.privateData[h];if(t(i))for(var k=i.length-1;0<k;k--)i[k]-=i[k-1];c.setByName(h,i)}g.topDict.privateDict=c;f=new ia;for(b=0,a=d.length;b<a;b++)f.add(d[b]);c.subrsIndex=f;return(new Wa(g)).compile()}};var fa=function(){function b(a,
c){this.properties=c;this.cff=(new sa(a,c)).parse();var f=new Wa(this.cff);this.seacs=this.cff.seacs;try{this.data=f.compile()}catch(g){d("Failed to compile font "+c.loadedName),this.data=a}}b.prototype={get numGlyphs(){return this.cff.charStrings.count},getCharset:function(){return this.cff.charset.charset},getGlyphMapping:function(){var b=this.cff,a=this.properties,c=b.charset.charset,d,f;if(a.composite){d=Object.create(null);if(b.isCIDFont)for(f=0;f<c.length;f++)b=a.cMap.charCodeOf(c[f]),d[b]=
f;else for(f=0;f<b.charStrings.count;f++)d[f]=f;return d}return d=x(a,b.encoding?b.encoding.encoding:null,c)}};return b}(),sa=function(){function b(a,c){this.bytes=a.getBytes();this.properties=c}var a=[null,{id:"hstem",min:2,stackClearing:!0,stem:!0},null,{id:"vstem",min:2,stackClearing:!0,stem:!0},{id:"vmoveto",min:1,stackClearing:!0},{id:"rlineto",min:2,resetStack:!0},{id:"hlineto",min:1,resetStack:!0},{id:"vlineto",min:1,resetStack:!0},{id:"rrcurveto",min:6,resetStack:!0},null,{id:"callsubr",min:1,
undefStack:!0},{id:"return",min:0,undefStack:!0},null,null,{id:"endchar",min:0,stackClearing:!0},null,null,null,{id:"hstemhm",min:2,stackClearing:!0,stem:!0},{id:"hintmask",min:0,stackClearing:!0},{id:"cntrmask",min:0,stackClearing:!0},{id:"rmoveto",min:2,stackClearing:!0},{id:"hmoveto",min:1,stackClearing:!0},{id:"vstemhm",min:2,stackClearing:!0,stem:!0},{id:"rcurveline",min:8,resetStack:!0},{id:"rlinecurve",min:8,resetStack:!0},{id:"vvcurveto",min:4,resetStack:!0},{id:"hhcurveto",min:4,resetStack:!0},
null,{id:"callgsubr",min:1,undefStack:!0},{id:"vhcurveto",min:4,resetStack:!0},{id:"hvcurveto",min:4,resetStack:!0}],c=[null,null,null,{id:"and",min:2,stackDelta:-1},{id:"or",min:2,stackDelta:-1},{id:"not",min:1,stackDelta:0},null,null,null,{id:"abs",min:1,stackDelta:0},{id:"add",min:2,stackDelta:-1,stackFn:function(b,a){b[a-2]+=b[a-1]}},{id:"sub",min:2,stackDelta:-1,stackFn:function(b,a){b[a-2]-=b[a-1]}},{id:"div",min:2,stackDelta:-1,stackFn:function(b,a){b[a-2]/=b[a-1]}},null,{id:"neg",min:1,stackDelta:0,
stackFn:function(b,a){b[a-1]=-b[a-1]}},{id:"eq",min:2,stackDelta:-1},null,null,{id:"drop",min:1,stackDelta:-1},null,{id:"put",min:2,stackDelta:-2},{id:"get",min:1,stackDelta:0},{id:"ifelse",min:4,stackDelta:-3},{id:"random",min:0,stackDelta:1},{id:"mul",min:2,stackDelta:-1,stackFn:function(b,a){b[a-2]*=b[a-1]}},null,{id:"sqrt",min:1,stackDelta:0},{id:"dup",min:1,stackDelta:1},{id:"exch",min:2,stackDelta:0},{id:"index",min:2,stackDelta:0},{id:"roll",min:3,stackDelta:-2},null,null,null,{id:"hflex",
min:7,resetStack:!0},{id:"flex",min:13,resetStack:!0},{id:"hflex1",min:9,resetStack:!0},{id:"flex1",min:11,resetStack:!0}];b.prototype={parse:function(){var b=this.properties,a=new Fa;this.cff=a;var c=this.parseHeader(),d=this.parseIndex(c.endPos),f=this.parseIndex(d.endPos),g=this.parseIndex(f.endPos),e=this.parseIndex(g.endPos),f=this.parseDict(f.obj.get(0)),f=this.createDict(cb,f,a.strings);a.header=c.obj;a.names=this.parseNameIndex(d.obj);a.strings=this.parseStringIndex(g.obj);a.topDict=f;a.globalSubrIndex=
e.obj;this.parsePrivateDict(a.topDict);a.isCIDFont=f.hasName("ROS");c=this.parseIndex(f.getByName("CharStrings")).obj;if(d=f.getByName("FontMatrix"))b.fontMatrix=d;if(d=f.getByName("FontBBox"))b.ascent=d[3],b.descent=d[1],b.ascentScaled=!0;if(a.isCIDFont){b=this.parseIndex(f.getByName("FDArray")).obj;d=0;for(g=b.count;d<g;++d){var h=b.get(d),h=this.createDict(cb,this.parseDict(h),a.strings);this.parsePrivateDict(h);a.fdArray.push(h)}b=null;d=this.parseCharsets(f.getByName("charset"),c.count,a.strings,
!0);a.fdSelect=this.parseFDSelect(f.getByName("FDSelect"),c.count)}else d=this.parseCharsets(f.getByName("charset"),c.count,a.strings,!1),b=this.parseEncoding(f.getByName("Encoding"),b,a.strings,d.charset);a.charset=d;a.encoding=b;e=this.parseCharStrings(c,f.privateDict.subrsIndex,e.obj,a.fdSelect,a.fdArray);a.charStrings=e.charStrings;a.seacs=e.seacs;a.widths=e.widths;return a},parseHeader:function(){for(var b=this.bytes,a=b.length,c=0;c<a&&1!==b[c];)++c;c>=a?m("Invalid CFF header"):0!==c&&(w("cff data is shifted"),
this.bytes=b=b.subarray(c));a=b[2];return{obj:new U(b[0],b[1],a,b[3]),endPos:a}},parseDict:function(b){function a(){var d=b[c++];if(30===d){for(var d="",f=["0","1","2","3","4","5","6","7","8","9",".","E","E-",null,"-"],g=b.length;c<g;){var e=b[c++],h=e>>4,e=e&15;if(15===h)break;d+=f[h];if(15===e)break;d+=f[e]}return parseFloat(d)}if(28===d)return d=b[c++],d=(d<<24|b[c++]<<16)>>16;if(29===d)return d=b[c++],d=d<<8|b[c++],d=d<<8|b[c++],d=d<<8|b[c++];if(32<=d&&246>=d)return d-139;if(247<=d&&250>=d)return 256*
(d-247)+b[c++]+108;if(251<=d&&254>=d)return-(256*(d-251))-b[c++]-108;m("255 is not a valid DICT command");return-1}for(var c=0,d=[],f=[],c=0,g=b.length;c<g;){var e=b[c];21>=e?(12===e&&(e=e<<8|b[++c]),f.push([e,d]),d=[],++c):d.push(a())}return f},parseIndex:function(b){var a=new ia,c=this.bytes,d=c[b++]<<8|c[b++],f=[],g=b,e,h;if(0!==d){var g=c[b++],i=b+(d+1)*g-1;for(e=0,h=d+1;e<h;++e){for(var k=0,j=0;j<g;++j)k<<=8,k+=c[b++];f.push(i+k)}g=f[d]}for(e=0,h=f.length-1;e<h;++e)a.add(c.subarray(f[e],f[e+
1]));return{obj:a,endPos:g}},parseNameIndex:function(b){for(var a=[],c=0,d=b.count;c<d;++c){for(var f=b.get(c),g=Math.min(f.length,127),e=[],h=0;h<g;++h){var i=f[h];e[h]=0===h&&0===i?i:33>i||126<i||91===i||93===i||40===i||41===i||123===i||125===i||60===i||62===i||47===i||37===i||35===i?95:i}a.push(R(e))}return a},parseStringIndex:function(b){for(var a=new Ba,c=0,d=b.count;c<d;++c){var f=b.get(c);a.add(R(f))}return a},createDict:function(b,a,c){for(var b=new b(c),c=0,d=a.length;c<d;++c){var f=a[c];
b.setByKey(f[0],f[1])}return b},parseCharString:function(b,f,g,e){if(10<b.callDepth)return!1;for(var h=b.stackSize,i=b.stack,k=f.length,j=0;j<k;){var l=f[j++],n=null;if(12===l)l=f[j++],0===l?(f[j-2]=139,f[j-1]=22,h=0):n=c[l];else if(28===l)i[h]=(f[j]<<24|f[j+1]<<16)>>16,j+=2,h++;else if(14===l){if(4<=h&&(h-=4,V))return b.seac=i.slice(h,h+4),!1;n=a[l]}else if(32<=l&&246>=l)i[h]=l-139,h++;else if(247<=l&&254>=l)i[h]=251>l?(l-247<<8)+f[j]+108:-(l-251<<8)-f[j]-108,j++,h++;else if(255===l)i[h]=(f[j]<<
24|f[j+1]<<16|f[j+2]<<8|f[j+3])/65536,j+=4,h++;else if(19===l||20===l)b.hints+=h>>1,j+=b.hints+7>>3,h%=2,n=a[l];else if(10===l||29===l){n=10===l?g:e;if(!n)return n=a[l],d("Missing subrsIndex for "+n.id),!1;var r=32768;1240>n.count?r=107:33900>n.count&&(r=1131);r=i[--h]+r;if(0>r||r>=n.count)return n=a[l],d("Out of bounds subrIndex for "+n.id),!1;b.stackSize=h;b.callDepth++;if(!this.parseCharString(b,n.get(r),g,e))return!1;b.callDepth--;h=b.stackSize;continue}else{if(11===l)return b.stackSize=h,!0;
n=a[l]}if(n){n.stem&&(b.hints+=h>>1);if("min"in n&&!b.undefStack&&h<n.min)return d("Not enough parameters for "+n.id+"; actual: "+h+", expected: "+n.min),!1;b.firstStackClearing&&n.stackClearing&&(b.firstStackClearing=!1,h-=n.min,2<=h&&n.stem?h%=2:1<h&&d("Found too many parameters for stack-clearing command"),0<h&&0<=i[h-1]&&(b.width=i[h-1]));"stackDelta"in n?("stackFn"in n&&n.stackFn(i,h),h+=n.stackDelta):n.stackClearing?h=0:n.resetStack?(h=0,b.undefStack=!1):n.undefStack&&(h=0,b.undefStack=!0,b.firstStackClearing=
!1)}}b.stackSize=h;return!0},parseCharStrings:function(b,a,c,f,g){for(var e=[],h=[],i=b.count,k=0;k<i;k++){var j=b.get(k),l={callDepth:0,stackSize:0,stack:[],undefStack:!0,hints:0,firstStackClearing:!0,seac:null,width:null},n=!0,r=null;if(f&&g.length){var p=f.getFDIndex(k);-1===p&&(d("Glyph index is not in fd select."),n=!1);p>=g.length&&(d("Invalid fd index for glyph index."),n=!1);n&&(r=g[p].privateDict.subrsIndex)}else a&&(r=a);n&&(n=this.parseCharString(l,j,r,c));null!==l.width&&(h[k]=l.width);
null!==l.seac&&(e[k]=l.seac);n||b.set(k,new Uint8Array([14]))}return{charStrings:b,seacs:e,widths:h}},emptyPrivateDictionary:function(b){var a=this.createDict(X,[],b.strings);b.setByKey(18,[0,0]);b.privateDict=a},parsePrivateDict:function(b){if(b.hasName("Private")){var a=b.getByName("Private");if(!t(a)||2!==a.length)b.removeByName("Private");else{var c=a[0],a=a[1];if(0===c||a>=this.bytes.length)this.emptyPrivateDictionary(b);else if(c=this.parseDict(this.bytes.subarray(a,a+c)),c=this.createDict(X,
c,b.strings),b.privateDict=c,c.getByName("Subrs")){var d=c.getByName("Subrs"),a=a+d;0===d||a>=this.bytes.length?this.emptyPrivateDictionary(b):(b=this.parseIndex(a),c.subrsIndex=b.obj)}}}else this.emptyPrivateDictionary(b)},parseCharsets:function(b,a,c,d){if(0===b)return new aa(!0,J,p);if(1===b)return new aa(!0,Q,v);if(2===b)return new aa(!0,E,n);var f=this.bytes,g=b,e=f[b++],h=[".notdef"],i,k,j,a=a-1;switch(e){case 0:for(j=0;j<a;j++)i=f[b++]<<8|f[b++],h.push(d?i:c.get(i));break;case 1:for(;h.length<=
a;){i=f[b++]<<8|f[b++];k=f[b++];for(j=0;j<=k;j++)h.push(d?i++:c.get(i++))}break;case 2:for(;h.length<=a;){i=f[b++]<<8|f[b++];k=f[b++]<<8|f[b++];for(j=0;j<=k;j++)h.push(d?i++:c.get(i++))}break;default:m("Unknown charset format")}b=f.subarray(g,b);return new aa(!1,e,h,b)},parseEncoding:function(b,a,c,d){var a={},f=this.bytes,g=!1,e,h,i=null;if(0===b||1===b){g=!0;c=(e=b)?ba.ExpertEncoding:ba.StandardEncoding;for(h=0,b=d.length;h<b;h++)f=c.indexOf(d[h]),-1!==f&&(a[f]=h)}else{i=b;e=f[b++];switch(e&127){case 0:var k=
f[b++];for(h=1;h<=k;h++)a[f[b++]]=h;break;case 1:var k=f[b++],j=1;for(h=0;h<k;h++)for(var l=f[b++],n=f[b++],r=l;r<=l+n;r++)a[r]=j++;break;default:m("Unknow encoding format: "+e+" in CFF")}k=b;if(e&128){f[i]&=127;j=f[b++];for(h=0;h<j;h++)l=f[b++],n=(f[b++]<<8)+(f[b++]&255),a[l]=d.indexOf(c.get(n))}i=f.subarray(i,k)}return new ga(g,e&127,a,i)},parseFDSelect:function(b,a){var c=b,d=this.bytes,f=d[b++],g=[];switch(f){case 0:for(f=0;f<a;++f){var e=d[b++];g.push(e)}break;case 3:e=d[b++]<<8|d[b++];for(f=
0;f<e;++f)for(var h=d[b++]<<8|d[b++],i=d[b++],k=d[b]<<8|d[b+1];h<k;++h)g.push(i);b+=2;break;default:m("Unknown fdselect format "+f)}return new Va(g,d.subarray(c,b))}};return b}(),Fa=function(){return function(){this.header=null;this.names=[];this.topDict=null;this.strings=new Ba;this.charStrings=this.charset=this.encoding=this.globalSubrIndex=null;this.fdArray=[];this.fdSelect=null;this.isCIDFont=!1}}(),U=function(){return function(b,a,c,d){this.major=b;this.minor=a;this.hdrSize=c;this.offSize=d}}(),
Ba=function(){function b(){this.strings=[]}b.prototype={get:function(b){return 0<=b&&390>=b?Y[b]:b-391<=this.strings.length?this.strings[b-391]:Y[0]},add:function(b){this.strings.push(b)},get count(){return this.strings.length}};return b}(),ia=function(){function b(){this.objects=[];this.length=0}b.prototype={add:function(b){this.length+=b.length;this.objects.push(b)},set:function(b,a){this.length+=a.length-this.objects[b].length;this.objects[b]=a},get:function(b){return this.objects[b]},get count(){return this.objects.length}};
return b}(),Ga=function(){function b(a,c){this.keyToNameMap=a.keyToNameMap;this.nameToKeyMap=a.nameToKeyMap;this.defaults=a.defaults;this.types=a.types;this.opcodes=a.opcodes;this.order=a.order;this.strings=c;this.values={}}b.prototype={setByKey:function(b,a){if(!(b in this.keyToNameMap))return!1;if(0===a.length)return!0;var c=this.types[b];if("num"===c||"sid"===c||"offset"===c)a=a[0];this.values[b]=a;return!0},setByName:function(b,a){b in this.nameToKeyMap||m('Invalid dictionary name "'+b+'"');this.values[this.nameToKeyMap[b]]=
a},hasName:function(b){return this.nameToKeyMap[b]in this.values},getByName:function(b){b in this.nameToKeyMap||m('Invalid dictionary name "'+b+'"');b=this.nameToKeyMap[b];return!(b in this.values)?this.defaults[b]:this.values[b]},removeByName:function(b){delete this.values[this.nameToKeyMap[b]]}};b.createTables=function(b){for(var a={keyToNameMap:{},nameToKeyMap:{},defaults:{},types:{},opcodes:{},order:[]},c=0,d=b.length;c<d;++c){var f=b[c],g=t(f[0])?(f[0][0]<<8)+f[0][1]:f[0];a.keyToNameMap[g]=f[1];
a.nameToKeyMap[f[1]]=g;a.types[g]=f[2];a.defaults[g]=f[3];a.opcodes[g]=t(f[0])?f[0]:[f[0]];a.order.push(g)}return a};return b}(),cb=function(){function b(d){null===c&&(c=Ga.createTables(a));Ga.call(this,c,d);this.privateDict=null}var a=[[[12,30],"ROS",["sid","sid","num"],null],[[12,20],"SyntheticBase","num",null],[0,"version","sid",null],[1,"Notice","sid",null],[[12,0],"Copyright","sid",null],[2,"FullName","sid",null],[3,"FamilyName","sid",null],[4,"Weight","sid",null],[[12,1],"isFixedPitch","num",
0],[[12,2],"ItalicAngle","num",0],[[12,3],"UnderlinePosition","num",-100],[[12,4],"UnderlineThickness","num",50],[[12,5],"PaintType","num",0],[[12,6],"CharstringType","num",2],[[12,7],"FontMatrix","num,num,num,num,num,num".split(","),[0.001,0,0,0.001,0,0]],[13,"UniqueID","num",null],[5,"FontBBox",["num","num","num","num"],[0,0,0,0]],[[12,8],"StrokeWidth","num",0],[14,"XUID","array",null],[15,"charset","offset",0],[16,"Encoding","offset",0],[17,"CharStrings","offset",0],[18,"Private",["offset","offset"],
null],[[12,21],"PostScript","sid",null],[[12,22],"BaseFontName","sid",null],[[12,23],"BaseFontBlend","delta",null],[[12,31],"CIDFontVersion","num",0],[[12,32],"CIDFontRevision","num",0],[[12,33],"CIDFontType","num",0],[[12,34],"CIDCount","num",8720],[[12,35],"UIDBase","num",null],[[12,37],"FDSelect","offset",null],[[12,36],"FDArray","offset",null],[[12,38],"FontName","sid",null]],c=null;b.prototype=Object.create(Ga.prototype);return b}(),X=function(){function b(d){null===c&&(c=Ga.createTables(a));
Ga.call(this,c,d);this.subrsIndex=null}var a=[[6,"BlueValues","delta",null],[7,"OtherBlues","delta",null],[8,"FamilyBlues","delta",null],[9,"FamilyOtherBlues","delta",null],[[12,9],"BlueScale","num",0.039625],[[12,10],"BlueShift","num",7],[[12,11],"BlueFuzz","num",1],[10,"StdHW","num",null],[11,"StdVW","num",null],[[12,12],"StemSnapH","delta",null],[[12,13],"StemSnapV","delta",null],[[12,14],"ForceBold","num",0],[[12,17],"LanguageGroup","num",0],[[12,18],"ExpansionFactor","num",0.06],[[12,19],"initialRandomSeed",
"num",0],[20,"defaultWidthX","num",0],[21,"nominalWidthX","num",0],[19,"Subrs","offset",null]],c=null;b.prototype=Object.create(Ga.prototype);return b}();J=0;Q=1;E=2;var aa=function(){return function(b,a,c,d){this.predefined=b;this.format=a;this.charset=c;this.raw=d}}(),ga=function(){return function(b,a,c,d){this.predefined=b;this.format=a;this.encoding=c;this.raw=d}}(),Va=function(){function b(a,c){this.fdSelect=a;this.raw=c}b.prototype={getFDIndex:function(b){return 0>b||b>=this.fdSelect.length?
-1:this.fdSelect[b]}};return b}(),la=function(){function b(){this.offsets={}}b.prototype={isTracking:function(b){return b in this.offsets},track:function(b,a){b in this.offsets&&m("Already tracking location of "+b);this.offsets[b]=a},offset:function(b){for(var a in this.offsets)this.offsets[a]+=b},setEntryLocation:function(b,a,c){b in this.offsets||m("Not tracking location of "+b);for(var c=c.data,b=this.offsets[b],d=0,f=a.length;d<f;++d){var g=5*d+b,e=g+1,h=g+2,i=g+3,k=g+4;(29!==c[g]||0!==c[e]||
0!==c[h]||0!==c[i]||0!==c[k])&&m("writing to an offset that is not empty");var j=a[d];c[g]=29;c[e]=j>>24&255;c[h]=j>>16&255;c[i]=j>>8&255;c[k]=j&255}}};return b}(),Wa=function(){function b(a){this.cff=a}b.prototype={compile:function(){var b=this.cff,a={data:[],length:0,add:function(b){this.data=this.data.concat(b);this.length=this.data.length}},c=this.compileHeader(b.header);a.add(c);c=this.compileNameIndex(b.names);a.add(c);if(b.isCIDFont&&b.topDict.hasName("FontMatrix")){c=b.topDict.getByName("FontMatrix");
b.topDict.removeByName("FontMatrix");for(var d=0,f=b.fdArray.length;d<f;d++){var g=b.fdArray[d],e=c.slice(0);g.hasName("FontMatrix")&&(e=h.transform(e,g.getByName("FontMatrix")));g.setByName("FontMatrix",e)}}d=this.compileTopDicts([b.topDict],a.length,b.isCIDFont);a.add(d.output);c=d.trackers[0];d=this.compileStringIndex(b.strings.strings);a.add(d);d=this.compileIndex(b.globalSubrIndex);a.add(d);b.encoding&&b.topDict.hasName("Encoding")&&(b.encoding.predefined?c.setEntryLocation("Encoding",[b.encoding.format],
a):(d=this.compileEncoding(b.encoding),c.setEntryLocation("Encoding",[a.length],a),a.add(d)));b.charset&&b.topDict.hasName("charset")&&(b.charset.predefined?c.setEntryLocation("charset",[b.charset.format],a):(d=this.compileCharset(b.charset),c.setEntryLocation("charset",[a.length],a),a.add(d)));d=this.compileCharStrings(b.charStrings);c.setEntryLocation("CharStrings",[a.length],a);a.add(d);b.isCIDFont&&(c.setEntryLocation("FDSelect",[a.length],a),d=this.compileFDSelect(b.fdSelect.raw),a.add(d),d=
this.compileTopDicts(b.fdArray,a.length,!0),c.setEntryLocation("FDArray",[a.length],a),a.add(d.output),this.compilePrivateDicts(b.fdArray,d.trackers,a));this.compilePrivateDicts([b.topDict],[c],a);a.add([0]);return a.data},encodeNumber:function(b){return parseFloat(b)===parseInt(b,10)&&!isNaN(b)?this.encodeInteger(b):this.encodeFloat(b)},encodeFloat:function(b){var a=b.toString(),c=/\.(\d*?)(?:9{5,20}|0{5,20})\d{0,2}(?:e(.+)|$)/.exec(a);c&&(a=parseFloat("1e"+((c[2]?+c[2]:0)+c[1].length)),a=(Math.round(b*
a)/a).toString());var b="",d;for(c=0,d=a.length;c<d;++c)var f=a[c],b="e"===f?b+("-"===a[++c]?"c":"b"):"."===f?b+"a":"-"===f?b+"e":b+f;b+=b.length&1?"f":"ff";a=[30];for(c=0,d=b.length;c<d;c+=2)a.push(parseInt(b.substr(c,2),16));return a},encodeInteger:function(b){-107<=b&&107>=b?b=[b+139]:108<=b&&1131>=b?(b=[b-108],b=[(b>>8)+247,b&255]):-1131<=b&&-108>=b?(b=-b-108,b=[(b>>8)+251,b&255]):b=-32768<=b&&32767>=b?[28,b>>8&255,b&255]:[29,b>>24&255,b>>16&255,b>>8&255,b&255];return b},compileHeader:function(b){return[b.major,
b.minor,b.hdrSize,b.offSize]},compileNameIndex:function(b){for(var a=new ia,c=0,d=b.length;c<d;++c)a.add(g(b[c]));return this.compileIndex(a)},compileTopDicts:function(b,a,c){for(var d=[],f=new ia,g=0,e=b.length;g<e;++g){var h=b[g];c&&(h.removeByName("CIDFontVersion"),h.removeByName("CIDFontRevision"),h.removeByName("CIDFontType"),h.removeByName("CIDCount"),h.removeByName("UIDBase"));var i=new la,h=this.compileDict(h,i);d.push(i);f.add(h);i.offset(a)}f=this.compileIndex(f,d);return{trackers:d,output:f}},
compilePrivateDicts:function(b,a,c){for(var d=0,f=b.length;d<f;++d){var g=b[d];z(g.privateDict&&g.hasName("Private"),"There must be an private dictionary.");var e=g.privateDict,g=new la,h=this.compileDict(e,g),i=c.length;g.offset(i);h.length||(i=0);a[d].setEntryLocation("Private",[h.length,i],c);c.add(h);e.subrsIndex&&e.hasName("Subrs")&&(e=this.compileIndex(e.subrsIndex),g.setEntryLocation("Subrs",[h.length],c),c.add(e))}},compileDict:function(b,a){for(var c=[],d=b.order,f=0;f<d.length;++f){var g=
d[f];if(g in b.values){var e=b.values[g],h=b.types[g];t(h)||(h=[h]);t(e)||(e=[e]);if(0!==e.length){for(var i=0,k=h.length;i<k;++i){var j=h[i],l=e[i];switch(j){case "num":case "sid":c=c.concat(this.encodeNumber(l));break;case "offset":j=b.keyToNameMap[g];a.isTracking(j)||a.track(j,c.length);c=c.concat([29,0,0,0,0]);break;case "array":case "delta":c=c.concat(this.encodeNumber(l));j=1;for(l=e.length;j<l;++j)c=c.concat(this.encodeNumber(e[j]));break;default:m("Unknown data type of "+j)}}c=c.concat(b.opcodes[g])}}}return c},
compileStringIndex:function(b){for(var a=new ia,c=0,d=b.length;c<d;++c)a.add(g(b[c]));return this.compileIndex(a)},compileGlobalSubrIndex:function(){this.out.writeByteArray(this.compileIndex(this.cff.globalSubrIndex))},compileCharStrings:function(b){return this.compileIndex(b)},compileCharset:function(b){return this.compileTypedArray(b.raw)},compileEncoding:function(b){return this.compileTypedArray(b.raw)},compileFDSelect:function(b){return this.compileTypedArray(b)},compileTypedArray:function(b){for(var a=
[],c=0,d=b.length;c<d;++c)a[c]=b[c];return a},compileIndex:function(b,a){var a=a||[],c=b.objects,d=c.length;if(0===d)return[0,0,0];var f=[d>>8&255,d&255],g=1,e;for(e=0;e<d;++e)g+=c[e].length;g=256>g?1:65536>g?2:16777216>g?3:4;f.push(g);var h=1;for(e=0;e<d+1;e++)1===g?f.push(h&255):2===g?f.push(h>>8&255,h&255):3===g?f.push(h>>16&255,h>>8&255,h&255):f.push(h>>>24&255,h>>16&255,h>>8&255,h&255),c[e]&&(h+=c[e].length);for(e=0;e<d;e++){a[e]&&a[e].offset(f.length);g=0;for(h=c[e].length;g<h;g++)f.push(c[e][g])}return f}};
return b}();"undefined"!==typeof navigator&&/Windows/.test(navigator.userAgent)&&(V=!0);"undefined"!==typeof navigator&&/Windows.*Chrome/.test(navigator.userAgent)&&(A=!0);a.SEAC_ANALYSIS_ENABLED=V;a.CFFCompiler=Wa;a.CFFIndex=ia;a.CFFParser=sa;a.CFFStrings=Ba;a.Encodings=ba;a.ErrorFont=O;a.FontFlags=W;a.Font=e;a.IdentityToUnicodeMap=ea;a.NormalizedUnicodes={"\u00a8":" \u0308","\u00af":" \u0304","\u00b4":" \u0301","\u00b5":"\u03bc","\u00b8":" \u0327","\u0132":"IJ","\u0133":"ij","\u013f":"L\u00b7",
"\u0140":"l\u00b7","\u0149":"\u02bcn","\u017f":"s","\u01c4":"D\u017d","\u01c5":"D\u017e","\u01c6":"d\u017e","\u01c7":"LJ","\u01c8":"Lj","\u01c9":"lj","\u01ca":"NJ","\u01cb":"Nj","\u01cc":"nj","\u01f1":"DZ","\u01f2":"Dz","\u01f3":"dz","\u02d8":" \u0306","\u02d9":" \u0307","\u02da":" \u030a","\u02db":" \u0328","\u02dc":" \u0303","\u02dd":" \u030b","\u037a":" \u0345","\u0384":" \u0301","\u03d0":"\u03b2","\u03d1":"\u03b8","\u03d2":"\u03a5","\u03d5":"\u03c6","\u03d6":"\u03c0","\u03f0":"\u03ba","\u03f1":"\u03c1",
"\u03f2":"\u03c2","\u03f4":"\u0398","\u03f5":"\u03b5","\u03f9":"\u03a3","\u0587":"\u0565\u0582","\u0675":"\u0627\u0674","\u0676":"\u0648\u0674","\u0677":"\u06c7\u0674","\u0678":"\u064a\u0674","\u0e33":"\u0e4d\u0e32","\u0eb3":"\u0ecd\u0eb2","\u0edc":"\u0eab\u0e99","\u0edd":"\u0eab\u0ea1","\u0f77":"\u0fb2\u0f81","\u0f79":"\u0fb3\u0f81","\u1e9a":"a\u02be","\u1fbd":" \u0313","\u1fbf":" \u0313","\u1fc0":" \u0342","\u1ffe":" \u0314","\u2002":" ","\u2003":" ","\u2004":" ","\u2005":" ","\u2006":" ","\u2008":" ",
"\u2009":" ","\u200a":" ","\u2017":" \u0333","\u2024":".","\u2025":"..","\u2026":"...","\u2033":"\u2032\u2032","\u2034":"\u2032\u2032\u2032","\u2036":"\u2035\u2035","\u2037":"\u2035\u2035\u2035","\u203c":"!!","\u203e":" \u0305","\u2047":"??","\u2048":"?!","\u2049":"!?","\u2057":"\u2032\u2032\u2032\u2032","\u205f":" ","\u20a8":"Rs","\u2100":"a/c","\u2101":"a/s","\u2103":"\u00b0C","\u2105":"c/o","\u2106":"c/u","\u2107":"\u0190","\u2109":"\u00b0F","\u2116":"No","\u2121":"TEL","\u2135":"\u05d0","\u2136":"\u05d1",
"\u2137":"\u05d2","\u2138":"\u05d3","\u213b":"FAX","\u2160":"I","\u2161":"II","\u2162":"III","\u2163":"IV","\u2164":"V","\u2165":"VI","\u2166":"VII","\u2167":"VIII","\u2168":"IX","\u2169":"X","\u216a":"XI","\u216b":"XII","\u216c":"L","\u216d":"C","\u216e":"D","\u216f":"M","\u2170":"i","\u2171":"ii","\u2172":"iii","\u2173":"iv","\u2174":"v","\u2175":"vi","\u2176":"vii","\u2177":"viii","\u2178":"ix","\u2179":"x","\u217a":"xi","\u217b":"xii","\u217c":"l","\u217d":"c","\u217e":"d","\u217f":"m","\u222c":"\u222b\u222b",
"\u222d":"\u222b\u222b\u222b","\u222f":"\u222e\u222e","\u2230":"\u222e\u222e\u222e","\u2474":"(1)","\u2475":"(2)","\u2476":"(3)","\u2477":"(4)","\u2478":"(5)","\u2479":"(6)","\u247a":"(7)","\u247b":"(8)","\u247c":"(9)","\u247d":"(10)","\u247e":"(11)","\u247f":"(12)","\u2480":"(13)","\u2481":"(14)","\u2482":"(15)","\u2483":"(16)","\u2484":"(17)","\u2485":"(18)","\u2486":"(19)","\u2487":"(20)","\u2488":"1.","\u2489":"2.","\u248a":"3.","\u248b":"4.","\u248c":"5.","\u248d":"6.","\u248e":"7.","\u248f":"8.",
"\u2490":"9.","\u2491":"10.","\u2492":"11.","\u2493":"12.","\u2494":"13.","\u2495":"14.","\u2496":"15.","\u2497":"16.","\u2498":"17.","\u2499":"18.","\u249a":"19.","\u249b":"20.","\u249c":"(a)","\u249d":"(b)","\u249e":"(c)","\u249f":"(d)","\u24a0":"(e)","\u24a1":"(f)","\u24a2":"(g)","\u24a3":"(h)","\u24a4":"(i)","\u24a5":"(j)","\u24a6":"(k)","\u24a7":"(l)","\u24a8":"(m)","\u24a9":"(n)","\u24aa":"(o)","\u24ab":"(p)","\u24ac":"(q)","\u24ad":"(r)","\u24ae":"(s)","\u24af":"(t)","\u24b0":"(u)","\u24b1":"(v)",
"\u24b2":"(w)","\u24b3":"(x)","\u24b4":"(y)","\u24b5":"(z)","\u2a0c":"\u222b\u222b\u222b\u222b","\u2a74":"::=","\u2a75":"==","\u2a76":"===","\u2e9f":"\u6bcd","\u2ef3":"\u9f9f","\u2f00":"\u4e00","\u2f01":"\u4e28","\u2f02":"\u4e36","\u2f03":"\u4e3f","\u2f04":"\u4e59","\u2f05":"\u4e85","\u2f06":"\u4e8c","\u2f07":"\u4ea0","\u2f08":"\u4eba","\u2f09":"\u513f","\u2f0a":"\u5165","\u2f0b":"\u516b","\u2f0c":"\u5182","\u2f0d":"\u5196","\u2f0e":"\u51ab","\u2f0f":"\u51e0","\u2f10":"\u51f5","\u2f11":"\u5200","\u2f12":"\u529b",
"\u2f13":"\u52f9","\u2f14":"\u5315","\u2f15":"\u531a","\u2f16":"\u5338","\u2f17":"\u5341","\u2f18":"\u535c","\u2f19":"\u5369","\u2f1a":"\u5382","\u2f1b":"\u53b6","\u2f1c":"\u53c8","\u2f1d":"\u53e3","\u2f1e":"\u56d7","\u2f1f":"\u571f","\u2f20":"\u58eb","\u2f21":"\u5902","\u2f22":"\u590a","\u2f23":"\u5915","\u2f24":"\u5927","\u2f25":"\u5973","\u2f26":"\u5b50","\u2f27":"\u5b80","\u2f28":"\u5bf8","\u2f29":"\u5c0f","\u2f2a":"\u5c22","\u2f2b":"\u5c38","\u2f2c":"\u5c6e","\u2f2d":"\u5c71","\u2f2e":"\u5ddb",
"\u2f2f":"\u5de5","\u2f30":"\u5df1","\u2f31":"\u5dfe","\u2f32":"\u5e72","\u2f33":"\u5e7a","\u2f34":"\u5e7f","\u2f35":"\u5ef4","\u2f36":"\u5efe","\u2f37":"\u5f0b","\u2f38":"\u5f13","\u2f39":"\u5f50","\u2f3a":"\u5f61","\u2f3b":"\u5f73","\u2f3c":"\u5fc3","\u2f3d":"\u6208","\u2f3e":"\u6236","\u2f3f":"\u624b","\u2f40":"\u652f","\u2f41":"\u6534","\u2f42":"\u6587","\u2f43":"\u6597","\u2f44":"\u65a4","\u2f45":"\u65b9","\u2f46":"\u65e0","\u2f47":"\u65e5","\u2f48":"\u66f0","\u2f49":"\u6708","\u2f4a":"\u6728",
"\u2f4b":"\u6b20","\u2f4c":"\u6b62","\u2f4d":"\u6b79","\u2f4e":"\u6bb3","\u2f4f":"\u6bcb","\u2f50":"\u6bd4","\u2f51":"\u6bdb","\u2f52":"\u6c0f","\u2f53":"\u6c14","\u2f54":"\u6c34","\u2f55":"\u706b","\u2f56":"\u722a","\u2f57":"\u7236","\u2f58":"\u723b","\u2f59":"\u723f","\u2f5a":"\u7247","\u2f5b":"\u7259","\u2f5c":"\u725b","\u2f5d":"\u72ac","\u2f5e":"\u7384","\u2f5f":"\u7389","\u2f60":"\u74dc","\u2f61":"\u74e6","\u2f62":"\u7518","\u2f63":"\u751f","\u2f64":"\u7528","\u2f65":"\u7530","\u2f66":"\u758b",
"\u2f67":"\u7592","\u2f68":"\u7676","\u2f69":"\u767d","\u2f6a":"\u76ae","\u2f6b":"\u76bf","\u2f6c":"\u76ee","\u2f6d":"\u77db","\u2f6e":"\u77e2","\u2f6f":"\u77f3","\u2f70":"\u793a","\u2f71":"\u79b8","\u2f72":"\u79be","\u2f73":"\u7a74","\u2f74":"\u7acb","\u2f75":"\u7af9","\u2f76":"\u7c73","\u2f77":"\u7cf8","\u2f78":"\u7f36","\u2f79":"\u7f51","\u2f7a":"\u7f8a","\u2f7b":"\u7fbd","\u2f7c":"\u8001","\u2f7d":"\u800c","\u2f7e":"\u8012","\u2f7f":"\u8033","\u2f80":"\u807f","\u2f81":"\u8089","\u2f82":"\u81e3",
"\u2f83":"\u81ea","\u2f84":"\u81f3","\u2f85":"\u81fc","\u2f86":"\u820c","\u2f87":"\u821b","\u2f88":"\u821f","\u2f89":"\u826e","\u2f8a":"\u8272","\u2f8b":"\u8278","\u2f8c":"\u864d","\u2f8d":"\u866b","\u2f8e":"\u8840","\u2f8f":"\u884c","\u2f90":"\u8863","\u2f91":"\u897e","\u2f92":"\u898b","\u2f93":"\u89d2","\u2f94":"\u8a00","\u2f95":"\u8c37","\u2f96":"\u8c46","\u2f97":"\u8c55","\u2f98":"\u8c78","\u2f99":"\u8c9d","\u2f9a":"\u8d64","\u2f9b":"\u8d70","\u2f9c":"\u8db3","\u2f9d":"\u8eab","\u2f9e":"\u8eca",
"\u2f9f":"\u8f9b","\u2fa0":"\u8fb0","\u2fa1":"\u8fb5","\u2fa2":"\u9091","\u2fa3":"\u9149","\u2fa4":"\u91c6","\u2fa5":"\u91cc","\u2fa6":"\u91d1","\u2fa7":"\u9577","\u2fa8":"\u9580","\u2fa9":"\u961c","\u2faa":"\u96b6","\u2fab":"\u96b9","\u2fac":"\u96e8","\u2fad":"\u9751","\u2fae":"\u975e","\u2faf":"\u9762","\u2fb0":"\u9769","\u2fb1":"\u97cb","\u2fb2":"\u97ed","\u2fb3":"\u97f3","\u2fb4":"\u9801","\u2fb5":"\u98a8","\u2fb6":"\u98db","\u2fb7":"\u98df","\u2fb8":"\u9996","\u2fb9":"\u9999","\u2fba":"\u99ac",
"\u2fbb":"\u9aa8","\u2fbc":"\u9ad8","\u2fbd":"\u9adf","\u2fbe":"\u9b25","\u2fbf":"\u9b2f","\u2fc0":"\u9b32","\u2fc1":"\u9b3c","\u2fc2":"\u9b5a","\u2fc3":"\u9ce5","\u2fc4":"\u9e75","\u2fc5":"\u9e7f","\u2fc6":"\u9ea5","\u2fc7":"\u9ebb","\u2fc8":"\u9ec3","\u2fc9":"\u9ecd","\u2fca":"\u9ed1","\u2fcb":"\u9ef9","\u2fcc":"\u9efd","\u2fcd":"\u9f0e","\u2fce":"\u9f13","\u2fcf":"\u9f20","\u2fd0":"\u9f3b","\u2fd1":"\u9f4a","\u2fd2":"\u9f52","\u2fd3":"\u9f8d","\u2fd4":"\u9f9c","\u2fd5":"\u9fa0","\u3036":"\u3012",
"\u3038":"\u5341","\u3039":"\u5344","\u303a":"\u5345","\u309b":" \u3099","\u309c":" \u309a","\u3131":"\u1100","\u3132":"\u1101","\u3133":"\u11aa","\u3134":"\u1102","\u3135":"\u11ac","\u3136":"\u11ad","\u3137":"\u1103","\u3138":"\u1104","\u3139":"\u1105","\u313a":"\u11b0","\u313b":"\u11b1","\u313c":"\u11b2","\u313d":"\u11b3","\u313e":"\u11b4","\u313f":"\u11b5","\u3140":"\u111a","\u3141":"\u1106","\u3142":"\u1107","\u3143":"\u1108","\u3144":"\u1121","\u3145":"\u1109","\u3146":"\u110a","\u3147":"\u110b",
"\u3148":"\u110c","\u3149":"\u110d","\u314a":"\u110e","\u314b":"\u110f","\u314c":"\u1110","\u314d":"\u1111","\u314e":"\u1112","\u314f":"\u1161","\u3150":"\u1162","\u3151":"\u1163","\u3152":"\u1164","\u3153":"\u1165","\u3154":"\u1166","\u3155":"\u1167","\u3156":"\u1168","\u3157":"\u1169","\u3158":"\u116a","\u3159":"\u116b","\u315a":"\u116c","\u315b":"\u116d","\u315c":"\u116e","\u315d":"\u116f","\u315e":"\u1170","\u315f":"\u1171","\u3160":"\u1172","\u3161":"\u1173","\u3162":"\u1174","\u3163":"\u1175",
"\u3164":"\u1160","\u3165":"\u1114","\u3166":"\u1115","\u3167":"\u11c7","\u3168":"\u11c8","\u3169":"\u11cc","\u316a":"\u11ce","\u316b":"\u11d3","\u316c":"\u11d7","\u316d":"\u11d9","\u316e":"\u111c","\u316f":"\u11dd","\u3170":"\u11df","\u3171":"\u111d","\u3172":"\u111e","\u3173":"\u1120","\u3174":"\u1122","\u3175":"\u1123","\u3176":"\u1127","\u3177":"\u1129","\u3178":"\u112b","\u3179":"\u112c","\u317a":"\u112d","\u317b":"\u112e","\u317c":"\u112f","\u317d":"\u1132","\u317e":"\u1136","\u317f":"\u1140",
"\u3180":"\u1147","\u3181":"\u114c","\u3182":"\u11f1","\u3183":"\u11f2","\u3184":"\u1157","\u3185":"\u1158","\u3186":"\u1159","\u3187":"\u1184","\u3188":"\u1185","\u3189":"\u1188","\u318a":"\u1191","\u318b":"\u1192","\u318c":"\u1194","\u318d":"\u119e","\u318e":"\u11a1","\u3200":"(\u1100)","\u3201":"(\u1102)","\u3202":"(\u1103)","\u3203":"(\u1105)","\u3204":"(\u1106)","\u3205":"(\u1107)","\u3206":"(\u1109)","\u3207":"(\u110b)","\u3208":"(\u110c)","\u3209":"(\u110e)","\u320a":"(\u110f)","\u320b":"(\u1110)",
"\u320c":"(\u1111)","\u320d":"(\u1112)","\u320e":"(\u1100\u1161)","\u320f":"(\u1102\u1161)","\u3210":"(\u1103\u1161)","\u3211":"(\u1105\u1161)","\u3212":"(\u1106\u1161)","\u3213":"(\u1107\u1161)","\u3214":"(\u1109\u1161)","\u3215":"(\u110b\u1161)","\u3216":"(\u110c\u1161)","\u3217":"(\u110e\u1161)","\u3218":"(\u110f\u1161)","\u3219":"(\u1110\u1161)","\u321a":"(\u1111\u1161)","\u321b":"(\u1112\u1161)","\u321c":"(\u110c\u116e)","\u321d":"(\u110b\u1169\u110c\u1165\u11ab)","\u321e":"(\u110b\u1169\u1112\u116e)",
"\u3220":"(\u4e00)","\u3221":"(\u4e8c)","\u3222":"(\u4e09)","\u3223":"(\u56db)","\u3224":"(\u4e94)","\u3225":"(\u516d)","\u3226":"(\u4e03)","\u3227":"(\u516b)","\u3228":"(\u4e5d)","\u3229":"(\u5341)","\u322a":"(\u6708)","\u322b":"(\u706b)","\u322c":"(\u6c34)","\u322d":"(\u6728)","\u322e":"(\u91d1)","\u322f":"(\u571f)","\u3230":"(\u65e5)","\u3231":"(\u682a)","\u3232":"(\u6709)","\u3233":"(\u793e)","\u3234":"(\u540d)","\u3235":"(\u7279)","\u3236":"(\u8ca1)","\u3237":"(\u795d)","\u3238":"(\u52b4)","\u3239":"(\u4ee3)",
"\u323a":"(\u547c)","\u323b":"(\u5b66)","\u323c":"(\u76e3)","\u323d":"(\u4f01)","\u323e":"(\u8cc7)","\u323f":"(\u5354)","\u3240":"(\u796d)","\u3241":"(\u4f11)","\u3242":"(\u81ea)","\u3243":"(\u81f3)","\u32c0":"1\u6708","\u32c1":"2\u6708","\u32c2":"3\u6708","\u32c3":"4\u6708","\u32c4":"5\u6708","\u32c5":"6\u6708","\u32c6":"7\u6708","\u32c7":"8\u6708","\u32c8":"9\u6708","\u32c9":"10\u6708","\u32ca":"11\u6708","\u32cb":"12\u6708","\u3358":"0\u70b9","\u3359":"1\u70b9","\u335a":"2\u70b9","\u335b":"3\u70b9",
"\u335c":"4\u70b9","\u335d":"5\u70b9","\u335e":"6\u70b9","\u335f":"7\u70b9","\u3360":"8\u70b9","\u3361":"9\u70b9","\u3362":"10\u70b9","\u3363":"11\u70b9","\u3364":"12\u70b9","\u3365":"13\u70b9","\u3366":"14\u70b9","\u3367":"15\u70b9","\u3368":"16\u70b9","\u3369":"17\u70b9","\u336a":"18\u70b9","\u336b":"19\u70b9","\u336c":"20\u70b9","\u336d":"21\u70b9","\u336e":"22\u70b9","\u336f":"23\u70b9","\u3370":"24\u70b9","\u33e0":"1\u65e5","\u33e1":"2\u65e5","\u33e2":"3\u65e5","\u33e3":"4\u65e5","\u33e4":"5\u65e5",
"\u33e5":"6\u65e5","\u33e6":"7\u65e5","\u33e7":"8\u65e5","\u33e8":"9\u65e5","\u33e9":"10\u65e5","\u33ea":"11\u65e5","\u33eb":"12\u65e5","\u33ec":"13\u65e5","\u33ed":"14\u65e5","\u33ee":"15\u65e5","\u33ef":"16\u65e5","\u33f0":"17\u65e5","\u33f1":"18\u65e5","\u33f2":"19\u65e5","\u33f3":"20\u65e5","\u33f4":"21\u65e5","\u33f5":"22\u65e5","\u33f6":"23\u65e5","\u33f7":"24\u65e5","\u33f8":"25\u65e5","\u33f9":"26\u65e5","\u33fa":"27\u65e5","\u33fb":"28\u65e5","\u33fc":"29\u65e5","\u33fd":"30\u65e5","\u33fe":"31\u65e5",
"\ufb00":"ff","\ufb01":"fi","\ufb02":"fl","\ufb03":"ffi","\ufb04":"ffl","\ufb05":"\u017ft","\ufb06":"st","\ufb13":"\u0574\u0576","\ufb14":"\u0574\u0565","\ufb15":"\u0574\u056b","\ufb16":"\u057e\u0576","\ufb17":"\u0574\u056d","\ufb4f":"\u05d0\u05dc","\ufb50":"\u0671","\ufb51":"\u0671","\ufb52":"\u067b","\ufb53":"\u067b","\ufb54":"\u067b","\ufb55":"\u067b","\ufb56":"\u067e","\ufb57":"\u067e","\ufb58":"\u067e","\ufb59":"\u067e","\ufb5a":"\u0680","\ufb5b":"\u0680","\ufb5c":"\u0680","\ufb5d":"\u0680",
"\ufb5e":"\u067a","\ufb5f":"\u067a","\ufb60":"\u067a","\ufb61":"\u067a","\ufb62":"\u067f","\ufb63":"\u067f","\ufb64":"\u067f","\ufb65":"\u067f","\ufb66":"\u0679","\ufb67":"\u0679","\ufb68":"\u0679","\ufb69":"\u0679","\ufb6a":"\u06a4","\ufb6b":"\u06a4","\ufb6c":"\u06a4","\ufb6d":"\u06a4","\ufb6e":"\u06a6","\ufb6f":"\u06a6","\ufb70":"\u06a6","\ufb71":"\u06a6","\ufb72":"\u0684","\ufb73":"\u0684","\ufb74":"\u0684","\ufb75":"\u0684","\ufb76":"\u0683","\ufb77":"\u0683","\ufb78":"\u0683","\ufb79":"\u0683",
"\ufb7a":"\u0686","\ufb7b":"\u0686","\ufb7c":"\u0686","\ufb7d":"\u0686","\ufb7e":"\u0687","\ufb7f":"\u0687","\ufb80":"\u0687","\ufb81":"\u0687","\ufb82":"\u068d","\ufb83":"\u068d","\ufb84":"\u068c","\ufb85":"\u068c","\ufb86":"\u068e","\ufb87":"\u068e","\ufb88":"\u0688","\ufb89":"\u0688","\ufb8a":"\u0698","\ufb8b":"\u0698","\ufb8c":"\u0691","\ufb8d":"\u0691","\ufb8e":"\u06a9","\ufb8f":"\u06a9","\ufb90":"\u06a9","\ufb91":"\u06a9","\ufb92":"\u06af","\ufb93":"\u06af","\ufb94":"\u06af","\ufb95":"\u06af",
"\ufb96":"\u06b3","\ufb97":"\u06b3","\ufb98":"\u06b3","\ufb99":"\u06b3","\ufb9a":"\u06b1","\ufb9b":"\u06b1","\ufb9c":"\u06b1","\ufb9d":"\u06b1","\ufb9e":"\u06ba","\ufb9f":"\u06ba","\ufba0":"\u06bb","\ufba1":"\u06bb","\ufba2":"\u06bb","\ufba3":"\u06bb","\ufba4":"\u06c0","\ufba5":"\u06c0","\ufba6":"\u06c1","\ufba7":"\u06c1","\ufba8":"\u06c1","\ufba9":"\u06c1","\ufbaa":"\u06be","\ufbab":"\u06be","\ufbac":"\u06be","\ufbad":"\u06be","\ufbae":"\u06d2","\ufbaf":"\u06d2","\ufbb0":"\u06d3","\ufbb1":"\u06d3",
"\ufbd3":"\u06ad","\ufbd4":"\u06ad","\ufbd5":"\u06ad","\ufbd6":"\u06ad","\ufbd7":"\u06c7","\ufbd8":"\u06c7","\ufbd9":"\u06c6","\ufbda":"\u06c6","\ufbdb":"\u06c8","\ufbdc":"\u06c8","\ufbdd":"\u0677","\ufbde":"\u06cb","\ufbdf":"\u06cb","\ufbe0":"\u06c5","\ufbe1":"\u06c5","\ufbe2":"\u06c9","\ufbe3":"\u06c9","\ufbe4":"\u06d0","\ufbe5":"\u06d0","\ufbe6":"\u06d0","\ufbe7":"\u06d0","\ufbe8":"\u0649","\ufbe9":"\u0649","\ufbea":"\u0626\u0627","\ufbeb":"\u0626\u0627","\ufbec":"\u0626\u06d5","\ufbed":"\u0626\u06d5",
"\ufbee":"\u0626\u0648","\ufbef":"\u0626\u0648","\ufbf0":"\u0626\u06c7","\ufbf1":"\u0626\u06c7","\ufbf2":"\u0626\u06c6","\ufbf3":"\u0626\u06c6","\ufbf4":"\u0626\u06c8","\ufbf5":"\u0626\u06c8","\ufbf6":"\u0626\u06d0","\ufbf7":"\u0626\u06d0","\ufbf8":"\u0626\u06d0","\ufbf9":"\u0626\u0649","\ufbfa":"\u0626\u0649","\ufbfb":"\u0626\u0649","\ufbfc":"\u06cc","\ufbfd":"\u06cc","\ufbfe":"\u06cc","\ufbff":"\u06cc","\ufc00":"\u0626\u062c","\ufc01":"\u0626\u062d","\ufc02":"\u0626\u0645","\ufc03":"\u0626\u0649",
"\ufc04":"\u0626\u064a","\ufc05":"\u0628\u062c","\ufc06":"\u0628\u062d","\ufc07":"\u0628\u062e","\ufc08":"\u0628\u0645","\ufc09":"\u0628\u0649","\ufc0a":"\u0628\u064a","\ufc0b":"\u062a\u062c","\ufc0c":"\u062a\u062d","\ufc0d":"\u062a\u062e","\ufc0e":"\u062a\u0645","\ufc0f":"\u062a\u0649","\ufc10":"\u062a\u064a","\ufc11":"\u062b\u062c","\ufc12":"\u062b\u0645","\ufc13":"\u062b\u0649","\ufc14":"\u062b\u064a","\ufc15":"\u062c\u062d","\ufc16":"\u062c\u0645","\ufc17":"\u062d\u062c","\ufc18":"\u062d\u0645",
"\ufc19":"\u062e\u062c","\ufc1a":"\u062e\u062d","\ufc1b":"\u062e\u0645","\ufc1c":"\u0633\u062c","\ufc1d":"\u0633\u062d","\ufc1e":"\u0633\u062e","\ufc1f":"\u0633\u0645","\ufc20":"\u0635\u062d","\ufc21":"\u0635\u0645","\ufc22":"\u0636\u062c","\ufc23":"\u0636\u062d","\ufc24":"\u0636\u062e","\ufc25":"\u0636\u0645","\ufc26":"\u0637\u062d","\ufc27":"\u0637\u0645","\ufc28":"\u0638\u0645","\ufc29":"\u0639\u062c","\ufc2a":"\u0639\u0645","\ufc2b":"\u063a\u062c","\ufc2c":"\u063a\u0645","\ufc2d":"\u0641\u062c",
"\ufc2e":"\u0641\u062d","\ufc2f":"\u0641\u062e","\ufc30":"\u0641\u0645","\ufc31":"\u0641\u0649","\ufc32":"\u0641\u064a","\ufc33":"\u0642\u062d","\ufc34":"\u0642\u0645","\ufc35":"\u0642\u0649","\ufc36":"\u0642\u064a","\ufc37":"\u0643\u0627","\ufc38":"\u0643\u062c","\ufc39":"\u0643\u062d","\ufc3a":"\u0643\u062e","\ufc3b":"\u0643\u0644","\ufc3c":"\u0643\u0645","\ufc3d":"\u0643\u0649","\ufc3e":"\u0643\u064a","\ufc3f":"\u0644\u062c","\ufc40":"\u0644\u062d","\ufc41":"\u0644\u062e","\ufc42":"\u0644\u0645",
"\ufc43":"\u0644\u0649","\ufc44":"\u0644\u064a","\ufc45":"\u0645\u062c","\ufc46":"\u0645\u062d","\ufc47":"\u0645\u062e","\ufc48":"\u0645\u0645","\ufc49":"\u0645\u0649","\ufc4a":"\u0645\u064a","\ufc4b":"\u0646\u062c","\ufc4c":"\u0646\u062d","\ufc4d":"\u0646\u062e","\ufc4e":"\u0646\u0645","\ufc4f":"\u0646\u0649","\ufc50":"\u0646\u064a","\ufc51":"\u0647\u062c","\ufc52":"\u0647\u0645","\ufc53":"\u0647\u0649","\ufc54":"\u0647\u064a","\ufc55":"\u064a\u062c","\ufc56":"\u064a\u062d","\ufc57":"\u064a\u062e",
"\ufc58":"\u064a\u0645","\ufc59":"\u064a\u0649","\ufc5a":"\u064a\u064a","\ufc5b":"\u0630\u0670","\ufc5c":"\u0631\u0670","\ufc5d":"\u0649\u0670","\ufc5e":" \u064c\u0651","\ufc5f":" \u064d\u0651","\ufc60":" \u064e\u0651","\ufc61":" \u064f\u0651","\ufc62":" \u0650\u0651","\ufc63":" \u0651\u0670","\ufc64":"\u0626\u0631","\ufc65":"\u0626\u0632","\ufc66":"\u0626\u0645","\ufc67":"\u0626\u0646","\ufc68":"\u0626\u0649","\ufc69":"\u0626\u064a","\ufc6a":"\u0628\u0631","\ufc6b":"\u0628\u0632","\ufc6c":"\u0628\u0645",
"\ufc6d":"\u0628\u0646","\ufc6e":"\u0628\u0649","\ufc6f":"\u0628\u064a","\ufc70":"\u062a\u0631","\ufc71":"\u062a\u0632","\ufc72":"\u062a\u0645","\ufc73":"\u062a\u0646","\ufc74":"\u062a\u0649","\ufc75":"\u062a\u064a","\ufc76":"\u062b\u0631","\ufc77":"\u062b\u0632","\ufc78":"\u062b\u0645","\ufc79":"\u062b\u0646","\ufc7a":"\u062b\u0649","\ufc7b":"\u062b\u064a","\ufc7c":"\u0641\u0649","\ufc7d":"\u0641\u064a","\ufc7e":"\u0642\u0649","\ufc7f":"\u0642\u064a","\ufc80":"\u0643\u0627","\ufc81":"\u0643\u0644",
"\ufc82":"\u0643\u0645","\ufc83":"\u0643\u0649","\ufc84":"\u0643\u064a","\ufc85":"\u0644\u0645","\ufc86":"\u0644\u0649","\ufc87":"\u0644\u064a","\ufc88":"\u0645\u0627","\ufc89":"\u0645\u0645","\ufc8a":"\u0646\u0631","\ufc8b":"\u0646\u0632","\ufc8c":"\u0646\u0645","\ufc8d":"\u0646\u0646","\ufc8e":"\u0646\u0649","\ufc8f":"\u0646\u064a","\ufc90":"\u0649\u0670","\ufc91":"\u064a\u0631","\ufc92":"\u064a\u0632","\ufc93":"\u064a\u0645","\ufc94":"\u064a\u0646","\ufc95":"\u064a\u0649","\ufc96":"\u064a\u064a",
"\ufc97":"\u0626\u062c","\ufc98":"\u0626\u062d","\ufc99":"\u0626\u062e","\ufc9a":"\u0626\u0645","\ufc9b":"\u0626\u0647","\ufc9c":"\u0628\u062c","\ufc9d":"\u0628\u062d","\ufc9e":"\u0628\u062e","\ufc9f":"\u0628\u0645","\ufca0":"\u0628\u0647","\ufca1":"\u062a\u062c","\ufca2":"\u062a\u062d","\ufca3":"\u062a\u062e","\ufca4":"\u062a\u0645","\ufca5":"\u062a\u0647","\ufca6":"\u062b\u0645","\ufca7":"\u062c\u062d","\ufca8":"\u062c\u0645","\ufca9":"\u062d\u062c","\ufcaa":"\u062d\u0645","\ufcab":"\u062e\u062c",
"\ufcac":"\u062e\u0645","\ufcad":"\u0633\u062c","\ufcae":"\u0633\u062d","\ufcaf":"\u0633\u062e","\ufcb0":"\u0633\u0645","\ufcb1":"\u0635\u062d","\ufcb2":"\u0635\u062e","\ufcb3":"\u0635\u0645","\ufcb4":"\u0636\u062c","\ufcb5":"\u0636\u062d","\ufcb6":"\u0636\u062e","\ufcb7":"\u0636\u0645","\ufcb8":"\u0637\u062d","\ufcb9":"\u0638\u0645","\ufcba":"\u0639\u062c","\ufcbb":"\u0639\u0645","\ufcbc":"\u063a\u062c","\ufcbd":"\u063a\u0645","\ufcbe":"\u0641\u062c","\ufcbf":"\u0641\u062d","\ufcc0":"\u0641\u062e",
"\ufcc1":"\u0641\u0645","\ufcc2":"\u0642\u062d","\ufcc3":"\u0642\u0645","\ufcc4":"\u0643\u062c","\ufcc5":"\u0643\u062d","\ufcc6":"\u0643\u062e","\ufcc7":"\u0643\u0644","\ufcc8":"\u0643\u0645","\ufcc9":"\u0644\u062c","\ufcca":"\u0644\u062d","\ufccb":"\u0644\u062e","\ufccc":"\u0644\u0645","\ufccd":"\u0644\u0647","\ufcce":"\u0645\u062c","\ufccf":"\u0645\u062d","\ufcd0":"\u0645\u062e","\ufcd1":"\u0645\u0645","\ufcd2":"\u0646\u062c","\ufcd3":"\u0646\u062d","\ufcd4":"\u0646\u062e","\ufcd5":"\u0646\u0645",
"\ufcd6":"\u0646\u0647","\ufcd7":"\u0647\u062c","\ufcd8":"\u0647\u0645","\ufcd9":"\u0647\u0670","\ufcda":"\u064a\u062c","\ufcdb":"\u064a\u062d","\ufcdc":"\u064a\u062e","\ufcdd":"\u064a\u0645","\ufcde":"\u064a\u0647","\ufcdf":"\u0626\u0645","\ufce0":"\u0626\u0647","\ufce1":"\u0628\u0645","\ufce2":"\u0628\u0647","\ufce3":"\u062a\u0645","\ufce4":"\u062a\u0647","\ufce5":"\u062b\u0645","\ufce6":"\u062b\u0647","\ufce7":"\u0633\u0645","\ufce8":"\u0633\u0647","\ufce9":"\u0634\u0645","\ufcea":"\u0634\u0647",
"\ufceb":"\u0643\u0644","\ufcec":"\u0643\u0645","\ufced":"\u0644\u0645","\ufcee":"\u0646\u0645","\ufcef":"\u0646\u0647","\ufcf0":"\u064a\u0645","\ufcf1":"\u064a\u0647","\ufcf2":"\u0640\u064e\u0651","\ufcf3":"\u0640\u064f\u0651","\ufcf4":"\u0640\u0650\u0651","\ufcf5":"\u0637\u0649","\ufcf6":"\u0637\u064a","\ufcf7":"\u0639\u0649","\ufcf8":"\u0639\u064a","\ufcf9":"\u063a\u0649","\ufcfa":"\u063a\u064a","\ufcfb":"\u0633\u0649","\ufcfc":"\u0633\u064a","\ufcfd":"\u0634\u0649","\ufcfe":"\u0634\u064a","\ufcff":"\u062d\u0649",
"\ufd00":"\u062d\u064a","\ufd01":"\u062c\u0649","\ufd02":"\u062c\u064a","\ufd03":"\u062e\u0649","\ufd04":"\u062e\u064a","\ufd05":"\u0635\u0649","\ufd06":"\u0635\u064a","\ufd07":"\u0636\u0649","\ufd08":"\u0636\u064a","\ufd09":"\u0634\u062c","\ufd0a":"\u0634\u062d","\ufd0b":"\u0634\u062e","\ufd0c":"\u0634\u0645","\ufd0d":"\u0634\u0631","\ufd0e":"\u0633\u0631","\ufd0f":"\u0635\u0631","\ufd10":"\u0636\u0631","\ufd11":"\u0637\u0649","\ufd12":"\u0637\u064a","\ufd13":"\u0639\u0649","\ufd14":"\u0639\u064a",
"\ufd15":"\u063a\u0649","\ufd16":"\u063a\u064a","\ufd17":"\u0633\u0649","\ufd18":"\u0633\u064a","\ufd19":"\u0634\u0649","\ufd1a":"\u0634\u064a","\ufd1b":"\u062d\u0649","\ufd1c":"\u062d\u064a","\ufd1d":"\u062c\u0649","\ufd1e":"\u062c\u064a","\ufd1f":"\u062e\u0649","\ufd20":"\u062e\u064a","\ufd21":"\u0635\u0649","\ufd22":"\u0635\u064a","\ufd23":"\u0636\u0649","\ufd24":"\u0636\u064a","\ufd25":"\u0634\u062c","\ufd26":"\u0634\u062d","\ufd27":"\u0634\u062e","\ufd28":"\u0634\u0645","\ufd29":"\u0634\u0631",
"\ufd2a":"\u0633\u0631","\ufd2b":"\u0635\u0631","\ufd2c":"\u0636\u0631","\ufd2d":"\u0634\u062c","\ufd2e":"\u0634\u062d","\ufd2f":"\u0634\u062e","\ufd30":"\u0634\u0645","\ufd31":"\u0633\u0647","\ufd32":"\u0634\u0647","\ufd33":"\u0637\u0645","\ufd34":"\u0633\u062c","\ufd35":"\u0633\u062d","\ufd36":"\u0633\u062e","\ufd37":"\u0634\u062c","\ufd38":"\u0634\u062d","\ufd39":"\u0634\u062e","\ufd3a":"\u0637\u0645","\ufd3b":"\u0638\u0645","\ufd3c":"\u0627\u064b","\ufd3d":"\u0627\u064b","\ufd50":"\u062a\u062c\u0645",
"\ufd51":"\u062a\u062d\u062c","\ufd52":"\u062a\u062d\u062c","\ufd53":"\u062a\u062d\u0645","\ufd54":"\u062a\u062e\u0645","\ufd55":"\u062a\u0645\u062c","\ufd56":"\u062a\u0645\u062d","\ufd57":"\u062a\u0645\u062e","\ufd58":"\u062c\u0645\u062d","\ufd59":"\u062c\u0645\u062d","\ufd5a":"\u062d\u0645\u064a","\ufd5b":"\u062d\u0645\u0649","\ufd5c":"\u0633\u062d\u062c","\ufd5d":"\u0633\u062c\u062d","\ufd5e":"\u0633\u062c\u0649","\ufd5f":"\u0633\u0645\u062d","\ufd60":"\u0633\u0645\u062d","\ufd61":"\u0633\u0645\u062c",
"\ufd62":"\u0633\u0645\u0645","\ufd63":"\u0633\u0645\u0645","\ufd64":"\u0635\u062d\u062d","\ufd65":"\u0635\u062d\u062d","\ufd66":"\u0635\u0645\u0645","\ufd67":"\u0634\u062d\u0645","\ufd68":"\u0634\u062d\u0645","\ufd69":"\u0634\u062c\u064a","\ufd6a":"\u0634\u0645\u062e","\ufd6b":"\u0634\u0645\u062e","\ufd6c":"\u0634\u0645\u0645","\ufd6d":"\u0634\u0645\u0645","\ufd6e":"\u0636\u062d\u0649","\ufd6f":"\u0636\u062e\u0645","\ufd70":"\u0636\u062e\u0645","\ufd71":"\u0637\u0645\u062d","\ufd72":"\u0637\u0645\u062d",
"\ufd73":"\u0637\u0645\u0645","\ufd74":"\u0637\u0645\u064a","\ufd75":"\u0639\u062c\u0645","\ufd76":"\u0639\u0645\u0645","\ufd77":"\u0639\u0645\u0645","\ufd78":"\u0639\u0645\u0649","\ufd79":"\u063a\u0645\u0645","\ufd7a":"\u063a\u0645\u064a","\ufd7b":"\u063a\u0645\u0649","\ufd7c":"\u0641\u062e\u0645","\ufd7d":"\u0641\u062e\u0645","\ufd7e":"\u0642\u0645\u062d","\ufd7f":"\u0642\u0645\u0645","\ufd80":"\u0644\u062d\u0645","\ufd81":"\u0644\u062d\u064a","\ufd82":"\u0644\u062d\u0649","\ufd83":"\u0644\u062c\u062c",
"\ufd84":"\u0644\u062c\u062c","\ufd85":"\u0644\u062e\u0645","\ufd86":"\u0644\u062e\u0645","\ufd87":"\u0644\u0645\u062d","\ufd88":"\u0644\u0645\u062d","\ufd89":"\u0645\u062d\u062c","\ufd8a":"\u0645\u062d\u0645","\ufd8b":"\u0645\u062d\u064a","\ufd8c":"\u0645\u062c\u062d","\ufd8d":"\u0645\u062c\u0645","\ufd8e":"\u0645\u062e\u062c","\ufd8f":"\u0645\u062e\u0645","\ufd92":"\u0645\u062c\u062e","\ufd93":"\u0647\u0645\u062c","\ufd94":"\u0647\u0645\u0645","\ufd95":"\u0646\u062d\u0645","\ufd96":"\u0646\u062d\u0649",
"\ufd97":"\u0646\u062c\u0645","\ufd98":"\u0646\u062c\u0645","\ufd99":"\u0646\u062c\u0649","\ufd9a":"\u0646\u0645\u064a","\ufd9b":"\u0646\u0645\u0649","\ufd9c":"\u064a\u0645\u0645","\ufd9d":"\u064a\u0645\u0645","\ufd9e":"\u0628\u062e\u064a","\ufd9f":"\u062a\u062c\u064a","\ufda0":"\u062a\u062c\u0649","\ufda1":"\u062a\u062e\u064a","\ufda2":"\u062a\u062e\u0649","\ufda3":"\u062a\u0645\u064a","\ufda4":"\u062a\u0645\u0649","\ufda5":"\u062c\u0645\u064a","\ufda6":"\u062c\u062d\u0649","\ufda7":"\u062c\u0645\u0649",
"\ufda8":"\u0633\u062e\u0649","\ufda9":"\u0635\u062d\u064a","\ufdaa":"\u0634\u062d\u064a","\ufdab":"\u0636\u062d\u064a","\ufdac":"\u0644\u062c\u064a","\ufdad":"\u0644\u0645\u064a","\ufdae":"\u064a\u062d\u064a","\ufdaf":"\u064a\u062c\u064a","\ufdb0":"\u064a\u0645\u064a","\ufdb1":"\u0645\u0645\u064a","\ufdb2":"\u0642\u0645\u064a","\ufdb3":"\u0646\u062d\u064a","\ufdb4":"\u0642\u0645\u062d","\ufdb5":"\u0644\u062d\u0645","\ufdb6":"\u0639\u0645\u064a","\ufdb7":"\u0643\u0645\u064a","\ufdb8":"\u0646\u062c\u062d",
"\ufdb9":"\u0645\u062e\u064a","\ufdba":"\u0644\u062c\u0645","\ufdbb":"\u0643\u0645\u0645","\ufdbc":"\u0644\u062c\u0645","\ufdbd":"\u0646\u062c\u062d","\ufdbe":"\u062c\u062d\u064a","\ufdbf":"\u062d\u062c\u064a","\ufdc0":"\u0645\u062c\u064a","\ufdc1":"\u0641\u0645\u064a","\ufdc2":"\u0628\u062d\u064a","\ufdc3":"\u0643\u0645\u0645","\ufdc4":"\u0639\u062c\u0645","\ufdc5":"\u0635\u0645\u0645","\ufdc6":"\u0633\u062e\u064a","\ufdc7":"\u0646\u062c\u064a","\ufe49":"\u203e","\ufe4a":"\u203e","\ufe4b":"\u203e",
"\ufe4c":"\u203e","\ufe4d":"_","\ufe4e":"_","\ufe4f":"_","\ufe80":"\u0621","\ufe81":"\u0622","\ufe82":"\u0622","\ufe83":"\u0623","\ufe84":"\u0623","\ufe85":"\u0624","\ufe86":"\u0624","\ufe87":"\u0625","\ufe88":"\u0625","\ufe89":"\u0626","\ufe8a":"\u0626","\ufe8b":"\u0626","\ufe8c":"\u0626","\ufe8d":"\u0627","\ufe8e":"\u0627","\ufe8f":"\u0628","\ufe90":"\u0628","\ufe91":"\u0628","\ufe92":"\u0628","\ufe93":"\u0629","\ufe94":"\u0629","\ufe95":"\u062a","\ufe96":"\u062a","\ufe97":"\u062a","\ufe98":"\u062a",
"\ufe99":"\u062b","\ufe9a":"\u062b","\ufe9b":"\u062b","\ufe9c":"\u062b","\ufe9d":"\u062c","\ufe9e":"\u062c","\ufe9f":"\u062c","\ufea0":"\u062c","\ufea1":"\u062d","\ufea2":"\u062d","\ufea3":"\u062d","\ufea4":"\u062d","\ufea5":"\u062e","\ufea6":"\u062e","\ufea7":"\u062e","\ufea8":"\u062e","\ufea9":"\u062f","\ufeaa":"\u062f","\ufeab":"\u0630","\ufeac":"\u0630","\ufead":"\u0631","\ufeae":"\u0631","\ufeaf":"\u0632","\ufeb0":"\u0632","\ufeb1":"\u0633","\ufeb2":"\u0633","\ufeb3":"\u0633","\ufeb4":"\u0633",
"\ufeb5":"\u0634","\ufeb6":"\u0634","\ufeb7":"\u0634","\ufeb8":"\u0634","\ufeb9":"\u0635","\ufeba":"\u0635","\ufebb":"\u0635","\ufebc":"\u0635","\ufebd":"\u0636","\ufebe":"\u0636","\ufebf":"\u0636","\ufec0":"\u0636","\ufec1":"\u0637","\ufec2":"\u0637","\ufec3":"\u0637","\ufec4":"\u0637","\ufec5":"\u0638","\ufec6":"\u0638","\ufec7":"\u0638","\ufec8":"\u0638","\ufec9":"\u0639","\ufeca":"\u0639","\ufecb":"\u0639","\ufecc":"\u0639","\ufecd":"\u063a","\ufece":"\u063a","\ufecf":"\u063a","\ufed0":"\u063a",
"\ufed1":"\u0641","\ufed2":"\u0641","\ufed3":"\u0641","\ufed4":"\u0641","\ufed5":"\u0642","\ufed6":"\u0642","\ufed7":"\u0642","\ufed8":"\u0642","\ufed9":"\u0643","\ufeda":"\u0643","\ufedb":"\u0643","\ufedc":"\u0643","\ufedd":"\u0644","\ufede":"\u0644","\ufedf":"\u0644","\ufee0":"\u0644","\ufee1":"\u0645","\ufee2":"\u0645","\ufee3":"\u0645","\ufee4":"\u0645","\ufee5":"\u0646","\ufee6":"\u0646","\ufee7":"\u0646","\ufee8":"\u0646","\ufee9":"\u0647","\ufeea":"\u0647","\ufeeb":"\u0647","\ufeec":"\u0647",
"\ufeed":"\u0648","\ufeee":"\u0648","\ufeef":"\u0649","\ufef0":"\u0649","\ufef1":"\u064a","\ufef2":"\u064a","\ufef3":"\u064a","\ufef4":"\u064a","\ufef5":"\u0644\u0622","\ufef6":"\u0644\u0622","\ufef7":"\u0644\u0623","\ufef8":"\u0644\u0623","\ufef9":"\u0644\u0625","\ufefa":"\u0644\u0625","\ufefb":"\u0644\u0627","\ufefc":"\u0644\u0627"};a.ToUnicodeMap=ha;a.Type1Parser=La;a.getFontType=o;a.reverseIfRtl=function(b){var a=b.length,c;if(!(c=1>=a)){c=b.charCodeAt(0);var d=$a[13];c>=d.begin&&c<d.end?c=!0:
(d=$a[11],c=c>=d.begin&&c<d.end?!0:!1);c=!c}if(c)return b;c="";for(a-=1;0<=a;a--)c+=b[a];return c};a.serifFonts={"Adobe Jenson":!0,"Adobe Text":!0,Albertus:!0,Aldus:!0,Alexandria:!0,Algerian:!0,"American Typewriter":!0,Antiqua:!0,Apex:!0,Arno:!0,Aster:!0,Aurora:!0,Baskerville:!0,Bell:!0,Bembo:!0,"Bembo Schoolbook":!0,Benguiat:!0,"Berkeley Old Style":!0,"Bernhard Modern":!0,"Berthold City":!0,Bodoni:!0,"Bauer Bodoni":!0,"Book Antiqua":!0,Bookman:!0,"Bordeaux Roman":!0,"Californian FB":!0,Calisto:!0,
Calvert:!0,Capitals:!0,Cambria:!0,Cartier:!0,Caslon:!0,Catull:!0,Centaur:!0,"Century Old Style":!0,"Century Schoolbook":!0,Chaparral:!0,"Charis SIL":!0,Cheltenham:!0,"Cholla Slab":!0,Clarendon:!0,Clearface:!0,Cochin:!0,Colonna:!0,"Computer Modern":!0,"Concrete Roman":!0,Constantia:!0,"Cooper Black":!0,Corona:!0,Ecotype:!0,Egyptienne:!0,Elephant:!0,Excelsior:!0,Fairfield:!0,"FF Scala":!0,Folkard:!0,Footlight:!0,FreeSerif:!0,"Friz Quadrata":!0,Garamond:!0,Gentium:!0,Georgia:!0,Gloucester:!0,"Goudy Old Style":!0,
"Goudy Schoolbook":!0,"Goudy Pro Font":!0,Granjon:!0,"Guardian Egyptian":!0,Heather:!0,Hercules:!0,"High Tower Text":!0,Hiroshige:!0,"Hoefler Text":!0,"Humana Serif":!0,Imprint:!0,"Ionic No. 5":!0,Janson:!0,Joanna:!0,Korinna:!0,Lexicon:!0,"Liberation Serif":!0,"Linux Libertine":!0,Literaturnaya:!0,Lucida:!0,"Lucida Bright":!0,Melior:!0,Memphis:!0,Miller:!0,Minion:!0,Modern:!0,"Mona Lisa":!0,"Mrs Eaves":!0,"MS Serif":!0,"Museo Slab":!0,"New York":!0,"Nimbus Roman":!0,"NPS Rawlinson Roadway":!0,Palatino:!0,
Perpetua:!0,Plantin:!0,"Plantin Schoolbook":!0,Playbill:!0,"Poor Richard":!0,"Rawlinson Roadway":!0,Renault:!0,Requiem:!0,Rockwell:!0,Roman:!0,"Rotis Serif":!0,Sabon:!0,Scala:!0,Seagull:!0,Sistina:!0,Souvenir:!0,STIX:!0,"Stone Informal":!0,"Stone Serif":!0,Sylfaen:!0,Times:!0,Trajan:!0,"Trinit\u00e9":!0,"Trump Mediaeval":!0,Utopia:!0,"Vale Type":!0,"Bitstream Vera":!0,"Vera Serif":!0,Versailles:!0,Wanted:!0,Weiss:!0,"Wide Latin":!0,Windsor:!0,XITS:!0};a.symbolsFonts={Dingbats:!0,Symbol:!0,ZapfDingbats:!0};
a.stdFontMap=Ta;a._enableSeacAnalysis=function(b){a.SEAC_ANALYSIS_ENABLED=V=b};I._setCoreFonts(a)});(function(a,e){e(a.pdfjsCoreFunction={},a.pdfjsSharedUtil,a.pdfjsCorePrimitives,a.pdfjsCorePsParser)})(this,function(a,e,O,P){var N=e.error,L=e.info,H=e.isArray,K=e.isBool,I=O.isDict,J=O.isStream,Q=P.PostScriptLexer,E=P.PostScriptParser,C=function(){return{getSampleArray:function(a,e,o,x){var m,w,t=1;for(m=0,w=a.length;m<w;m++)t*=a[m];t*=e;a=Array(t);w=e=0;var u=1/(Math.pow(2,o)-1),x=x.getBytes((t*
o+7)/8),y=0;for(m=0;m<t;m++){for(;e<o;)w<<=8,w|=x[y++],e+=8;e-=o;a[m]=(w>>e)*u;w&=(1<<e)-1}return a},getIR:function(a,e){var o=e.dict;o||(o=e);var x=[this.constructSampled,null,this.constructInterpolated,this.constructStiched,this.constructPostScript],m=o.get("FunctionType");(x=x[m])||N("Unknown type of function");return x.call(this,e,o,a)},fromIR:function(a){switch(a[0]){case 0:return this.constructSampledFromIR(a);case 2:return this.constructInterpolatedFromIR(a);case 3:return this.constructStichedFromIR(a);
default:return this.constructPostScriptFromIR(a)}},parse:function(a,e){return this.fromIR(this.getIR(a,e))},parseArray:function(a,e){if(!H(e))return this.parse(a,e);for(var o=[],x=0,m=e.length;x<m;x++){var w=a.fetchIfRef(e[x]);o.push(C.parse(a,w))}return function(a,e,h,m){for(var w=0,g=o.length;w<g;w++)o[w](a,e,h,m+w)}},constructSampled:function(a,e){function o(a){for(var d=a.length,g=[],c=0,b=0;b<d;b+=2)g[c]=[a[b],a[b+1]],++c;return g}var x=e.get("Domain"),m=e.get("Range");(!x||!m)&&N("No domain or range");
var w=x.length/2,t=m.length/2,x=o(x),m=o(m),u=e.get("Size"),y=e.get("BitsPerSample"),s=e.get("Order")||1;1!==s&&L("No support for cubic spline interpolation: "+s);s=e.get("Encode");if(!s)for(var s=[],M=0;M<w;++M)s.push(0),s.push(u[M]-1);var s=o(s),M=(M=e.get("Decode"))?o(M):m,g=this.getSampleArray(u,t,y,a);return[0,w,x,s,M,g,u,t,Math.pow(2,y)-1,m]},constructSampledFromIR:function(a){return function(e,o,x,m){var w=a[1],t=a[2],u=a[3],y=a[4],s=a[5],M=a[6],g=a[7],f=a[9],d=1<<w,k=new Float64Array(d),c=
new Uint32Array(d),b,i;for(i=0;i<d;i++)k[i]=1;var l=g,q=1;for(b=0;b<w;++b){var j=t[b][0],p=t[b][1];i=Math.min(Math.max(e[o+b],j),p);var v=u[b][0]+(i-j)*((u[b][1]-u[b][0])/(p-j)),j=M[b],v=Math.min(Math.max(v,0),j-1);i=v<j-1?Math.floor(v):v-1;var p=i+1-v,v=v-i,n=i*l,r=n+l;for(i=0;i<d;i++)i&q?(k[i]*=v,c[i]+=r):(k[i]*=p,c[i]+=n);l*=j;q<<=1}for(i=0;i<g;++i){for(b=e=0;b<d;b++)e+=s[c[b]+i]*k[b];e=y[i][0]+(e-0)*((y[i][1]-y[i][0])/1);x[m+i]=Math.min(Math.max(e,f[i][0]),f[i][1])}}},constructInterpolated:function(a,
e){var o=e.get("C0")||[0],x=e.get("C1")||[1],m=e.get("N");(!H(o)||!H(x))&&N("Illegal dictionary for interpolated function");for(var w=o.length,t=[],u=0;u<w;++u)t.push(x[u]-o[u]);return[2,o,t,m]},constructInterpolatedFromIR:function(a){var e=a[1],o=a[2],x=a[3],m=o.length;return function(a,t,u,y){a=1===x?a[t]:Math.pow(a[t],x);for(t=0;t<m;++t)u[y+t]=e[t]+a*o[t]}},constructStiched:function(a,e,o){(a=e.get("Domain"))||N("No domain");1!==a.length/2&&N("Bad domain for stiched function");for(var x=e.get("Functions"),
m=[],w=0,t=x.length;w<t;++w)m.push(C.getIR(o,o.fetchIfRef(x[w])));o=e.get("Bounds");e=e.get("Encode");return[3,a,o,e,m]},constructStichedFromIR:function(a){for(var e=a[1],o=a[2],x=a[3],a=a[4],m=[],w=new Float32Array(1),t=0,u=a.length;t<u;t++)m.push(C.fromIR(a[t]));return function(a,s,t,g){var a=a[s],s=e[0],f=e[1];a>f?a=f:a<s&&(a=s);s=0;for(f=o.length;s<f&&!(a<o[s]);++s);f=e[0];0<s&&(f=o[s-1]);var d=e[1];s<o.length&&(d=o[s]);var k=x[2*s],c=x[2*s+1];w[0]=f===d?k:k+(a-f)*(c-k)/(d-f);m[s](w,0,t,g)}},
constructPostScript:function(a,e){var o=e.get("Domain"),x=e.get("Range");o||N("No domain.");x||N("No range.");var m=new Q(a),m=(new E(m)).parse();return[4,o,x,m]},constructPostScriptFromIR:function(a){var e=a[1],o=a[2],a=a[3],C=(new D).compile(a,e,o);if(C)return new Function("src","srcOffset","dest","destOffset",C);L("Unable to compile PS function");var m=o.length>>1,w=e.length>>1,t=new x(a),u={},y=8192,s=new Float32Array(w);return function(a,g,f,d){var e,c,b="";for(e=0;e<w;e++)c=a[g+e],s[e]=c,b+=
c+"_";e=u[b];if(void 0!==e)f.set(e,d);else{var a=new Float32Array(m),g=t.execute(s),h=g.length-m;for(e=0;e<m;e++){c=g[h+e];var l=o[2*e];c<l?c=l:(l=o[2*e+1],c>l&&(c=l));a[e]=c}0<y&&(y--,u[b]=a);f.set(a,d)}}}}}(),o=function(){function a(e){this.stack=!e?[]:Array.prototype.slice.call(e,0)}a.prototype={push:function(a){100<=this.stack.length&&N("PostScript function stack overflow.");this.stack.push(a)},pop:function(){0>=this.stack.length&&N("PostScript function stack underflow.");return this.stack.pop()},
copy:function(a){100<=this.stack.length+a&&N("PostScript function stack overflow.");for(var e=this.stack,o=e.length-a,a=a-1;0<=a;a--,o++)e.push(e[o])},index:function(a){this.push(this.stack[this.stack.length-a-1])},roll:function(a,e){var o=this.stack,m=o.length-a,w=o.length-1,t=m+(e-Math.floor(e/a)*a),u,y,s;for(u=m,y=w;u<y;u++,y--)s=o[u],o[u]=o[y],o[y]=s;for(u=m,y=t-1;u<y;u++,y--)s=o[u],o[u]=o[y],o[y]=s;for(u=t,y=w;u<y;u++,y--)s=o[u],o[u]=o[y],o[y]=s}};return a}(),x=function(){function a(e){this.operators=
e}a.prototype={execute:function(a){for(var a=new o(a),e=0,x=this.operators,m=x.length,w,t;e<m;)if(w=x[e++],"number"===typeof w)a.push(w);else switch(w){case "jz":t=a.pop();(w=a.pop())||(e=t);break;case "j":e=w=a.pop();break;case "abs":w=a.pop();a.push(Math.abs(w));break;case "add":t=a.pop();w=a.pop();a.push(w+t);break;case "and":t=a.pop();w=a.pop();K(w)&&K(t)?a.push(w&&t):a.push(w&t);break;case "atan":w=a.pop();a.push(Math.atan(w));break;case "bitshift":t=a.pop();w=a.pop();0<w?a.push(w<<t):a.push(w>>
t);break;case "ceiling":w=a.pop();a.push(Math.ceil(w));break;case "copy":w=a.pop();a.copy(w);break;case "cos":w=a.pop();a.push(Math.cos(w));break;case "cvi":w=a.pop()|0;a.push(w);break;case "cvr":break;case "div":t=a.pop();w=a.pop();a.push(w/t);break;case "dup":a.copy(1);break;case "eq":t=a.pop();w=a.pop();a.push(w===t);break;case "exch":a.roll(2,1);break;case "exp":t=a.pop();w=a.pop();a.push(Math.pow(w,t));break;case "false":a.push(!1);break;case "floor":w=a.pop();a.push(Math.floor(w));break;case "ge":t=
a.pop();w=a.pop();a.push(w>=t);break;case "gt":t=a.pop();w=a.pop();a.push(w>t);break;case "idiv":t=a.pop();w=a.pop();a.push(w/t|0);break;case "index":w=a.pop();a.index(w);break;case "le":t=a.pop();w=a.pop();a.push(w<=t);break;case "ln":w=a.pop();a.push(Math.log(w));break;case "log":w=a.pop();a.push(Math.log(w)/Math.LN10);break;case "lt":t=a.pop();w=a.pop();a.push(w<t);break;case "mod":t=a.pop();w=a.pop();a.push(w%t);break;case "mul":t=a.pop();w=a.pop();a.push(w*t);break;case "ne":t=a.pop();w=a.pop();
a.push(w!==t);break;case "neg":w=a.pop();a.push(-w);break;case "not":w=a.pop();K(w)?a.push(!w):a.push(~w);break;case "or":t=a.pop();w=a.pop();K(w)&&K(t)?a.push(w||t):a.push(w|t);break;case "pop":a.pop();break;case "roll":t=a.pop();w=a.pop();a.roll(w,t);break;case "round":w=a.pop();a.push(Math.round(w));break;case "sin":w=a.pop();a.push(Math.sin(w));break;case "sqrt":w=a.pop();a.push(Math.sqrt(w));break;case "sub":t=a.pop();w=a.pop();a.push(w-t);break;case "true":a.push(!0);break;case "truncate":w=
a.pop();w=0>w?Math.ceil(w):Math.floor(w);a.push(w);break;case "xor":t=a.pop();w=a.pop();K(w)&&K(t)?a.push(w!==t):a.push(w^t);break;default:N("Unknown operator "+w)}return a.stack}};return a}(),D=function(){function a(g){this.type=g}function e(a,f,d){this.type="args";this.index=a;this.min=f;this.max=d}function o(a){this.type="literal";this.max=this.min=this.number=a}function x(a,f,d,e,c){this.type="binary";this.op=a;this.arg1=f;this.arg2=d;this.min=e;this.max=c}function m(a,f){this.type="max";this.arg=
a;this.min=a.min;this.max=f}function w(a,f,d){this.type="var";this.index=a;this.min=f;this.max=d}function t(a,f){this.type="definition";this.variable=a;this.arg=f}function u(){this.parts=[]}function y(a,f){if("literal"===f.type){if(0===f.number)return new o(0);if(1===f.number)return a;if("literal"===a.type)return new o(a.number*f.number)}if("literal"===a.type){if(0===a.number)return new o(0);if(1===a.number)return f}var d=Math.min(a.min*f.min,a.min*f.max,a.max*f.min,a.max*f.max),e=Math.max(a.min*
f.min,a.min*f.max,a.max*f.min,a.max*f.max);return new x("*",a,f,d,e)}function s(a,f){if("literal"===f.type){if(0===f.number)return a;if("literal"===a.type)return new o(a.number-f.number)}return"binary"===f.type&&"-"===f.op&&"literal"===a.type&&1===a.number&&"literal"===f.arg1.type&&1===f.arg1.number?f.arg2:new x("-",a,f,a.min-f.max,a.max-f.min)}function C(){}a.prototype.visit=function(){throw Error("abstract method");};e.prototype=Object.create(a.prototype);e.prototype.visit=function(a){a.visitArgument(this)};
o.prototype=Object.create(a.prototype);o.prototype.visit=function(a){a.visitLiteral(this)};x.prototype=Object.create(a.prototype);x.prototype.visit=function(a){a.visitBinaryOperation(this)};m.prototype=Object.create(a.prototype);m.prototype.visit=function(a){a.visitMin(this)};w.prototype=Object.create(a.prototype);w.prototype.visit=function(a){a.visitVariable(this)};t.prototype=Object.create(a.prototype);t.prototype.visit=function(a){a.visitVariableDefinition(this)};u.prototype={visitArgument:function(a){this.parts.push("Math.max(",
a.min,", Math.min(",a.max,", src[srcOffset + ",a.index,"]))")},visitVariable:function(a){this.parts.push("v",a.index)},visitLiteral:function(a){this.parts.push(a.number)},visitBinaryOperation:function(a){this.parts.push("(");a.arg1.visit(this);this.parts.push(" ",a.op," ");a.arg2.visit(this);this.parts.push(")")},visitVariableDefinition:function(a){this.parts.push("var ");a.variable.visit(this);this.parts.push(" = ");a.arg.visit(this);this.parts.push(";")},visitMin:function(a){this.parts.push("Math.min(");
a.arg.visit(this);this.parts.push(", ",a.max,")")},toString:function(){return this.parts.join("")}};C.prototype={compile:function(a,f,d){var k=[],c,b=[],i=f.length>>1,l=d.length>>1,q=0,j,p;for(c=0;c<i;c++)k.push(new e(c,f[2*c],f[2*c+1]));for(c=0,f=a.length;c<f;c++)if(i=a[c],"number"===typeof i)k.push(new o(i));else switch(i){case "add":if(2>k.length)return null;j=k.pop();i=k.pop();k.push("literal"===j.type&&0===j.number?i:"literal"===i.type&&0===i.number?j:"literal"===j.type&&"literal"===i.type?new o(i.number+
j.number):new x("+",i,j,i.min+j.min,i.max+j.max));break;case "cvr":if(1>k.length)return null;break;case "mul":if(2>k.length)return null;j=k.pop();i=k.pop();k.push(y(i,j));break;case "sub":if(2>k.length)return null;j=k.pop();i=k.pop();k.push(s(i,j));break;case "exch":if(2>k.length)return null;j=k.pop();i=k.pop();k.push(j,i);break;case "pop":if(1>k.length)return null;k.pop();break;case "index":if(1>k.length)return null;i=k.pop();if("literal"!==i.type)return null;i=i.number;if(0>i||(i|0)!==i||k.length<
i)return null;j=k[k.length-i-1];if("literal"===j.type||"var"===j.type){k.push(j);break}p=new w(q++,j.min,j.max);k[k.length-i-1]=p;k.push(p);b.push(new t(p,j));break;case "dup":if(1>k.length)return null;if("number"===typeof a[c+1]&&"gt"===a[c+2]&&a[c+3]===c+7&&"jz"===a[c+4]&&"pop"===a[c+5]&&a[c+6]===a[c+1]){i=k.pop();k.push(i.min>=a[c+1]?new o(a[c+1]):i.max<=a[c+1]?i:new m(i,a[c+1]));c+=6;break}j=k[k.length-1];if("literal"===j.type||"var"===j.type){k.push(j);break}p=new w(q++,j.min,j.max);k[k.length-
1]=p;k.push(p);b.push(new t(p,j));break;case "roll":if(2>k.length)return null;j=k.pop();i=k.pop();if("literal"!==j.type||"literal"!==i.type)return null;j=j.number;i=i.number;if(0>=i||(i|0)!==i||(j|0)!==j||k.length<i)return null;j=(j%i+i)%i;if(0===j)break;Array.prototype.push.apply(k,k.splice(k.length-i,i-j));break;default:return null}if(k.length!==l)return null;var v=[];b.forEach(function(b){var a=new u;b.visit(a);v.push(a.toString())});k.forEach(function(b,a){var c=new u;b.visit(c);var f=d[2*a],
e=d[2*a+1],c=[c.toString()];f>b.min&&(c.unshift("Math.max(",f,", "),c.push(")"));e<b.max&&(c.unshift("Math.min(",e,", "),c.push(")"));c.unshift("dest[destOffset + ",a,"] = ");c.push(";");v.push(c.join(""))});return v.join("\n")}};return C}();a.isPDFFunction=function(a){if("object"!==typeof a)return!1;if(!I(a))if(J(a))a=a.dict;else return!1;return a.has("FunctionType")};a.PDFFunction=C;a.PostScriptEvaluator=x;a.PostScriptCompiler=D});(function(a,e){e(a.pdfjsCoreColorSpace={},a.pdfjsSharedUtil,a.pdfjsCorePrimitives,
a.pdfjsCoreFunction,a.pdfjsCoreStream)})(this,function(a,e,O,P,N){var L=e.error,H=e.info,K=e.isArray,I=e.isString,J=e.shadow,Q=e.warn,E=O.isDict,C=O.isName,o=O.isStream,x=P.PDFFunction,D,G=function(){function a(){L("should not call ColorSpace constructor")}a.prototype={getRgb:function(a,f){var d=new Uint8Array(3);this.getRgbItem(a,f,d,0);return d},getRgbItem:function(){L("Should not call ColorSpace.getRgbItem")},getRgbBuffer:function(){L("Should not call ColorSpace.getRgbBuffer")},getOutputLength:function(){L("Should not call ColorSpace.getOutputLength")},
isPassthrough:function(){return!1},fillRgb:function(a,f,d,e,c,b,h,l,q){var j=f*d,p=null,m=1<<h,n=d!==c||f!==e,r;if(this.isPassthrough(h))p=l;else if(1===this.numComps&&j>m&&"DeviceGray"!==this.name&&"DeviceRGB"!==this.name){var s=8>=h?new Uint8Array(m):new Uint16Array(m),o;for(r=0;r<m;r++)s[r]=r;var t=new Uint8Array(3*m);this.getRgbBuffer(s,0,m,t,0,h,0);if(n){p=new Uint8Array(3*j);for(r=s=0;r<j;++r)o=3*l[r],p[s++]=t[o],p[s++]=t[o+1],p[s++]=t[o+2]}else for(r=m=0;r<j;++r)o=3*l[r],a[m++]=t[o],a[m++]=
t[o+1],a[m++]=t[o+2],m+=q}else n?(p=new Uint8Array(3*j),this.getRgbBuffer(l,0,j,p,0,h,0)):this.getRgbBuffer(l,0,e*b,a,0,h,q);if(p)if(n)D.resize(p,h,3,f,d,e,c,a,q);else{m=s=0;for(r=0,f=e*b;r<f;r++)a[m++]=p[s++],a[m++]=p[s++],a[m++]=p[s++],m+=q}},usesZeroToOneRange:!0};a.parse=function(e,f,d){e=a.parseToIR(e,f,d);return e instanceof h?e:a.fromIR(e)};a.fromIR=function(e){var f=K(e)?e[0]:e,d,k;switch(f){case "DeviceGrayCS":return this.singletons.gray;case "DeviceRgbCS":return this.singletons.rgb;case "DeviceCmykCS":return this.singletons.cmyk;
case "CalGrayCS":return f=e[1].WhitePoint,d=e[1].BlackPoint,k=e[1].Gamma,new u(f,d,k);case "CalRGBCS":return f=e[1].WhitePoint,d=e[1].BlackPoint,k=e[1].Gamma,new y(f,d,k,e[1].Matrix);case "PatternCS":return(e=e[1])&&(e=a.fromIR(e)),new z(e);case "IndexedCS":return f=e[2],d=e[3],new R(a.fromIR(e[1]),f,d);case "AlternateCS":return f=e[3],new h(e[1],a.fromIR(e[2]),x.fromIR(f));case "LabCS":return f=e[1].WhitePoint,d=e[1].BlackPoint,new s(f,d,e[1].Range);default:L("Unknown name "+f)}return null};a.parseToIR=
function(e,f,d){if(C(e)){var h=d.get("ColorSpace");E(h)&&(h=h.get(e.name))&&(e=h)}e=f.fetchIfRef(e);if(C(e))switch(this.mode=h=e.name,h){case "DeviceGray":case "G":return"DeviceGrayCS";case "DeviceRGB":case "RGB":return"DeviceRgbCS";case "DeviceCMYK":case "CMYK":return"DeviceCmykCS";case "Pattern":return["PatternCS",null];default:L("unrecognized colorspace "+h)}else if(K(e)){this.mode=h=f.fetchIfRef(e[0]).name;var c;switch(h){case "DeviceGray":case "G":return"DeviceGrayCS";case "DeviceRGB":case "RGB":return"DeviceRgbCS";
case "DeviceCMYK":case "CMYK":return"DeviceCmykCS";case "CalGray":return f=f.fetchIfRef(e[1]).getAll(),["CalGrayCS",f];case "CalRGB":return f=f.fetchIfRef(e[1]).getAll(),["CalRGBCS",f];case "ICCBased":e=f.fetchIfRef(e[1]).dict;h=e.get("N");if(c=e.get("Alternate")){f=a.parseToIR(c,f,d);if(a.fromIR(f).numComps===h)return f;Q("ICCBased color space: Ignoring incorrect /Alternate entry.")}if(1===h)return"DeviceGrayCS";if(3===h)return"DeviceRgbCS";if(4===h)return"DeviceCmykCS";break;case "Pattern":return(e=
e[1]||null)&&(e=a.parseToIR(e,f,d)),["PatternCS",e];case "Indexed":case "I":return d=a.parseToIR(e[1],f,d),h=f.fetchIfRef(e[2])+1,f=f.fetchIfRef(e[3]),o(f)&&(f=f.getBytes()),["IndexedCS",d,h,f];case "Separation":case "DeviceN":return c=f.fetchIfRef(e[1]),h=1,C(c)?h=1:K(c)&&(h=c.length),c=a.parseToIR(e[2],f,d),f=x.getIR(f,f.fetchIfRef(e[3])),["AlternateCS",h,c,f];case "Lab":return f=f.fetchIfRef(e[1]).getAll(),["LabCS",f];default:L('unimplemented color space object "'+h+'"')}}else L('unrecognized color space object: "'+
e+'"');return null};a.isDefaultDecode=function(a,f){if(!K(a))return!0;if(2*f!==a.length)return Q("The decode map is not the correct length"),!0;for(var d=0,e=a.length;d<e;d+=2)if(0!==a[d]||1!==a[d+1])return!1;return!0};a.singletons={get gray(){return J(this,"gray",new m)},get rgb(){return J(this,"rgb",new w)},get cmyk(){return J(this,"cmyk",new t)}};return a}(),h=function(){function a(e,f,d){this.name="Alternate";this.numComps=e;this.defaultColor=new Float32Array(e);for(var h=0;h<e;++h)this.defaultColor[h]=
1;this.base=f;this.tintFn=d;this.tmpBuf=new Float32Array(f.numComps)}a.prototype={getRgb:G.prototype.getRgb,getRgbItem:function(a,f,d,e){var c=this.tmpBuf;this.tintFn(a,f,c,0);this.base.getRgbItem(c,0,d,e)},getRgbBuffer:function(a,f,d,e,c,b,h){var l=this.tintFn,m=this.base,b=1/((1<<b)-1),j=m.numComps,p=m.usesZeroToOneRange,s=(m.isPassthrough(8)||!p)&&0===h,n=s?c:0,r=s?e:new Uint8Array(j*d),o=this.numComps,t=new Float32Array(o),u=new Float32Array(j),w;if(p)for(p=0;p<d;p++){for(w=0;w<o;w++)t[w]=a[f++]*
b;l(t,0,u,0);for(w=0;w<j;w++)r[n++]=255*u[w]}else for(p=0;p<d;p++){for(w=0;w<o;w++)t[w]=a[f++]*b;l(t,0,u,0);m.getRgbItem(u,0,r,n);n+=j}s||m.getRgbBuffer(r,0,d,e,c,8,h)},getOutputLength:function(a,f){return this.base.getOutputLength(a*this.base.numComps/this.numComps,f)},isPassthrough:G.prototype.isPassthrough,fillRgb:G.prototype.fillRgb,isDefaultDecode:function(a){return G.isDefaultDecode(a,this.numComps)},usesZeroToOneRange:!0};return a}(),z=function(){function a(e){this.name="Pattern";this.base=
e}a.prototype={};return a}(),R=function(){function a(e,f,d){this.name="Indexed";this.numComps=1;this.defaultColor=new Uint8Array([0]);this.base=e;this.highVal=f;var e=e.numComps*f,h;if(o(d))h=new Uint8Array(e),d=d.getBytes(e),h.set(d);else if(I(d)){h=new Uint8Array(e);for(f=0;f<e;++f)h[f]=d.charCodeAt(f)}else d instanceof Uint8Array||d instanceof Array?h=d:L("Unrecognized lookup table: "+d);this.lookup=h}a.prototype={getRgb:G.prototype.getRgb,getRgbItem:function(a,f,d,e){this.base.getRgbItem(this.lookup,
a[f]*this.base.numComps,d,e)},getRgbBuffer:function(a,f,d,e,c,b,h){for(var b=this.base,l=b.numComps,m=b.getOutputLength(l,h),j=this.lookup,p=0;p<d;++p){var s=a[f++]*l;b.getRgbBuffer(j,s,1,e,c,8,h);c+=m}},getOutputLength:function(a,f){return this.base.getOutputLength(a*this.base.numComps,f)},isPassthrough:G.prototype.isPassthrough,fillRgb:G.prototype.fillRgb,isDefaultDecode:function(){return!0},usesZeroToOneRange:!0};return a}(),m=function(){function a(){this.name="DeviceGray";this.numComps=1;this.defaultColor=
new Float32Array([0])}a.prototype={getRgb:G.prototype.getRgb,getRgbItem:function(a,f,d,e){a=255*a[f]|0;d[e]=d[e+1]=d[e+2]=0>a?0:255<a?255:a},getRgbBuffer:function(a,f,d,e,c,b,h){for(var b=255/((1<<b)-1),l=0;l<d;++l){var m=b*a[f++]|0;e[c++]=m;e[c++]=m;e[c++]=m;c+=h}},getOutputLength:function(a,f){return a*(3+f)},isPassthrough:G.prototype.isPassthrough,fillRgb:G.prototype.fillRgb,isDefaultDecode:function(a){return G.isDefaultDecode(a,this.numComps)},usesZeroToOneRange:!0};return a}(),w=function(){function a(){this.name=
"DeviceRGB";this.numComps=3;this.defaultColor=new Float32Array([0,0,0])}a.prototype={getRgb:G.prototype.getRgb,getRgbItem:function(a,f,d,e){var c=255*a[f]|0,b=255*a[f+1]|0,a=255*a[f+2]|0;d[e]=0>c?0:255<c?255:c;d[e+1]=0>b?0:255<b?255:b;d[e+2]=0>a?0:255<a?255:a},getRgbBuffer:function(a,f,d,e,c,b,h){if(8===b&&0===h)e.set(a.subarray(f,f+3*d),c);else for(var b=255/((1<<b)-1),l=0;l<d;++l)e[c++]=b*a[f++]|0,e[c++]=b*a[f++]|0,e[c++]=b*a[f++]|0,c+=h},getOutputLength:function(a,f){return a*(3+f)/3|0},isPassthrough:function(a){return 8===
a},fillRgb:G.prototype.fillRgb,isDefaultDecode:function(a){return G.isDefaultDecode(a,this.numComps)},usesZeroToOneRange:!0};return a}(),t=function(){function a(f,d,e,c,b){var g=f[d+0]*e,h=f[d+1]*e,m=f[d+2]*e,e=f[d+3]*e,f=g*(-4.387332384609988*g+54.48615194189176*h+18.82290502165302*m+212.25662451639585*e+-285.2331026137004)+h*(1.7149763477362134*h-5.6096736904047315*m+-17.873870861415444*e-5.497006427196366)+m*(-2.5217340131683033*m-21.248923337353073*e+17.5119270841813)+e*(-21.86122147463605*e-
189.48180835922747)+255|0,d=g*(8.841041422036149*g+60.118027045597366*h+6.871425592049007*m+31.159100130055922*e+-79.2970844816548)+h*(-15.310361306967817*h+17.575251261109482*m+131.35250912493976*e-190.9453302588951)+m*(4.444339102852739*m+9.8632861493405*e-24.86741582555878)+e*(-20.737325471181034*e-187.80453709719578)+255|0,g=g*(0.8842522430003296*g+8.078677503112928*h+30.89978309703729*m-0.23883238689178934*e+-14.183576799673286)+h*(10.49593273432072*h+63.02378494754052*m+50.606957656360734*e-
112.23884253719248)+m*(0.03296041114873217*m+115.60384449646641*e+-193.58209356861505)+e*(-22.33816807309886*e-180.12613974708367)+255|0;c[b]=255<f?255:0>f?0:f;c[b+1]=255<d?255:0>d?0:d;c[b+2]=255<g?255:0>g?0:g}function e(){this.name="DeviceCMYK";this.numComps=4;this.defaultColor=new Float32Array([0,0,0,1])}e.prototype={getRgb:G.prototype.getRgb,getRgbItem:function(f,d,e,c){a(f,d,1,e,c)},getRgbBuffer:function(f,d,e,c,b,g,h){for(var g=1/((1<<g)-1),m=0;m<e;m++)a(f,d,g,c,b),d+=4,b+=3+h},getOutputLength:function(a,
d){return a/4*(3+d)|0},isPassthrough:G.prototype.isPassthrough,fillRgb:G.prototype.fillRgb,isDefaultDecode:function(a){return G.isDefaultDecode(a,this.numComps)},usesZeroToOneRange:!0};return e}(),u=function(){function a(f,d,e){this.name="CalGray";this.numComps=1;this.defaultColor=new Float32Array([0]);f||L("WhitePoint missing - required for color space CalGray");d=d||[0,0,0];this.XW=f[0];this.YW=f[1];this.ZW=f[2];this.XB=d[0];this.YB=d[1];this.ZB=d[2];this.G=e||1;(0>this.XW||0>this.ZW||1!==this.YW)&&
L("Invalid WhitePoint components for "+this.name+", no fallback available");if(0>this.XB||0>this.YB||0>this.ZB)H("Invalid BlackPoint for "+this.name+", falling back to default"),this.XB=this.YB=this.ZB=0;(0!==this.XB||0!==this.YB||0!==this.ZB)&&Q(this.name+", BlackPoint: XB: "+this.XB+", YB: "+this.YB+", ZB: "+this.ZB+", only default values are supported.");1>this.G&&(H("Invalid Gamma: "+this.G+" for "+this.name+", falling back to default"),this.G=1)}function e(a,d,g,c,b,h){d=Math.pow(d[g]*h,a.G);
a=Math.max(295.8*Math.pow(a.YW*d,0.3333333333333333)-40.8,0)|0;c[b]=a;c[b+1]=a;c[b+2]=a}a.prototype={getRgb:G.prototype.getRgb,getRgbItem:function(a,d,h,c){e(this,a,d,h,c,1)},getRgbBuffer:function(a,d,h,c,b,i,l){for(var i=1/((1<<i)-1),m=0;m<h;++m)e(this,a,d,c,b,i),d+=1,b+=3+l},getOutputLength:function(a,d){return a*(3+d)},isPassthrough:G.prototype.isPassthrough,fillRgb:G.prototype.fillRgb,isDefaultDecode:function(a){return G.isDefaultDecode(a,this.numComps)},usesZeroToOneRange:!0};return a}(),y=function(){function a(b,
c,d,f){this.name="CalRGB";this.numComps=3;this.defaultColor=new Float32Array(3);b||L("WhitePoint missing - required for color space CalRGB");var c=c||new Float32Array(3),d=d||new Float32Array([1,1,1]),f=f||new Float32Array([1,0,0,0,1,0,0,0,1]),e=b[0],g=b[1],h=b[2];this.whitePoint=b;var b=c[0],i=c[1],j=c[2];this.blackPoint=c;this.GR=d[0];this.GG=d[1];this.GB=d[2];this.MXA=f[0];this.MYA=f[1];this.MZA=f[2];this.MXB=f[3];this.MYB=f[4];this.MZB=f[5];this.MXC=f[6];this.MYC=f[7];this.MZC=f[8];(0>e||0>h||
1!==g)&&L("Invalid WhitePoint components for "+this.name+", no fallback available");if(0>b||0>i||0>j)H("Invalid BlackPoint for "+this.name+" ["+b+", "+i+", "+j+"], falling back to default"),this.blackPoint=new Float32Array(3);if(0>this.GR||0>this.GG||0>this.GB)H("Invalid Gamma ["+this.GR+", "+this.GG+", "+this.GB+"] for "+this.name+", falling back to default"),this.GR=this.GG=this.GB=1;if(0>this.MXA||0>this.MYA||0>this.MZA||0>this.MXB||0>this.MYB||0>this.MZB||0>this.MXC||0>this.MYC||0>this.MZC)H("Invalid Matrix for "+
this.name+" ["+this.MXA+", "+this.MYA+", "+this.MZA+this.MXB+", "+this.MYB+", "+this.MZB+this.MXC+", "+this.MYC+", "+this.MZC+"], falling back to default"),this.MXA=this.MYB=this.MZC=1,this.MXB=this.MYA=this.MZA=this.MXC=this.MYC=this.MZB=0}function e(b,a,c){c[0]=b[0]*a[0]+b[1]*a[1]+b[2]*a[2];c[1]=b[3]*a[0]+b[4]*a[1]+b[5]*a[2];c[2]=b[6]*a[0]+b[7]*a[1]+b[8]*a[2]}function f(b){return 0.0031308>=b?d(0,1,12.92*b):d(0,1,1.055*Math.pow(b,1/2.4)-0.055)}function d(b,a,c){return Math.max(b,Math.min(a,c))}
function h(b){return 0>b?-h(-b):8<b?Math.pow((b+16)/116,3):b*n}function c(a,c,n,o,t,u){var w=d(0,1,c[n]*u),y=d(0,1,c[n+1]*u),n=d(0,1,c[n+2]*u),w=Math.pow(w,a.GR),c=Math.pow(y,a.GG),n=Math.pow(n,a.GB),u=a.MYA*w+a.MYB*c+a.MYC*n,x=a.MZA*w+a.MZB*c+a.MZC*n,y=p;y[0]=a.MXA*w+a.MXB*c+a.MXC*n;y[1]=u;y[2]=x;w=s;c=a.whitePoint;1===c[0]&&1===c[2]?(w[0]=y[0],w[1]=y[1],w[2]=y[2]):(e(b,y,w),y=j,y[0]=1*w[0]/c[0],y[1]=1*w[1]/c[1],y[2]=1*w[2]/c[2],e(i,y,w));y=p;n=a.blackPoint;0===n[0]&&0===n[1]&&0===n[2]?(y[0]=w[0],
y[1]=w[1],y[2]=w[2]):(a=h(0),u=h(n[0]),c=h(n[1]),n=h(n[2]),u=(1-a)/(1-u),c=(1-a)/(1-c),a=(1-a)/(1-n),y[0]=w[0]*u+(1-u),y[1]=w[1]*c+(1-c),y[2]=w[2]*a+(1-a));a=s;w=m;e(b,y,a);y=j;y[0]=0.95047*a[0]/w[0];y[1]=1*a[1]/w[1];y[2]=1.08883*a[2]/w[2];e(i,y,a);w=p;e(l,a,w);a=f(w[0]);y=f(w[1]);w=f(w[2]);o[t]=Math.round(255*a);o[t+1]=Math.round(255*y);o[t+2]=Math.round(255*w)}var b=new Float32Array([0.8951,0.2664,-0.1614,-0.7502,1.7135,0.0367,0.0389,-0.0685,1.0296]),i=new Float32Array([0.9869929,-0.1470543,0.1599627,
0.4323053,0.5183603,0.0492912,-0.0085287,0.0400428,0.9684867]),l=new Float32Array([3.2404542,-1.5371385,-0.4985314,-0.969266,1.8760108,0.041556,0.0556434,-0.2040259,1.0572252]),m=new Float32Array([1,1,1]),j=new Float32Array(3),p=new Float32Array(3),s=new Float32Array(3),n=Math.pow(24/116,3)/8;a.prototype={getRgb:function(b,a){var c=new Uint8Array(3);this.getRgbItem(b,a,c,0);return c},getRgbItem:function(b,a,d,f){c(this,b,a,d,f,1)},getRgbBuffer:function(b,a,d,f,e,g,h){for(var g=1/((1<<g)-1),i=0;i<
d;++i)c(this,b,a,f,e,g),a+=3,e+=3+h},getOutputLength:function(b,a){return b*(3+a)/3|0},isPassthrough:G.prototype.isPassthrough,fillRgb:G.prototype.fillRgb,isDefaultDecode:function(b){return G.isDefaultDecode(b,this.numComps)},usesZeroToOneRange:!0};return a}(),s=function(){function a(d,f,c){this.name="Lab";this.numComps=3;this.defaultColor=new Float32Array([0,0,0]);d||L("WhitePoint missing - required for color space Lab");f=f||[0,0,0];c=c||[-100,100,-100,100];this.XW=d[0];this.YW=d[1];this.ZW=d[2];
this.amin=c[0];this.amax=c[1];this.bmin=c[2];this.bmax=c[3];this.XB=f[0];this.YB=f[1];this.ZB=f[2];(0>this.XW||0>this.ZW||1!==this.YW)&&L("Invalid WhitePoint components, no fallback available");if(0>this.XB||0>this.YB||0>this.ZB)H("Invalid BlackPoint, falling back to default"),this.XB=this.YB=this.ZB=0;if(this.amin>this.amax||this.bmin>this.bmax)H("Invalid Range, falling back to defaults"),this.amin=-100,this.amax=100,this.bmin=-100,this.bmax=100}function e(a){return a>=6/29?a*a*a:108/841*(a-4/29)}
function f(a,f,c,b,h,l){var m=f[c],j=f[c+1],f=f[c+2];!1!==b&&(m=0+100*m/b,j=a.amin+j*(a.amax-a.amin)/b,f=a.bmin+f*(a.bmax-a.bmin)/b);j=j>a.amax?a.amax:j<a.amin?a.amin:j;f=f>a.bmax?a.bmax:f<a.bmin?a.bmin:f;b=(m+16)/116;m=b-f/200;j=a.XW*e(b+j/500);b=a.YW*e(b);m=a.ZW*e(m);1>a.ZW?(a=3.1339*j+-1.617*b+-0.4906*m,f=-0.9785*j+1.916*b+0.0333*m,j=0.072*j+-0.229*b+1.4057*m):(a=3.2406*j+-1.5372*b+-0.4986*m,f=-0.9689*j+1.8758*b+0.0415*m,j=0.0557*j+-0.204*b+1.057*m);h[l]=0>=a?0:1<=a?255:255*Math.sqrt(a)|0;h[l+
1]=0>=f?0:1<=f?255:255*Math.sqrt(f)|0;h[l+2]=0>=j?0:1<=j?255:255*Math.sqrt(j)|0}a.prototype={getRgb:G.prototype.getRgb,getRgbItem:function(a,e,c,b){f(this,a,e,!1,c,b)},getRgbBuffer:function(a,e,c,b,g,h,m){for(var h=(1<<h)-1,j=0;j<c;j++)f(this,a,e,h,b,g),e+=3,g+=3+m},getOutputLength:function(a,f){return a*(3+f)/3|0},isPassthrough:G.prototype.isPassthrough,fillRgb:G.prototype.fillRgb,isDefaultDecode:function(){return!0},usesZeroToOneRange:!1};return a}();a._setCoreImage=function(a){D=a.PDFImage};a.ColorSpace=
G;N._setCoreColorSpace(a)});(function(a,e){e(a.pdfjsCoreImage={},a.pdfjsSharedUtil,a.pdfjsCorePrimitives,a.pdfjsCoreColorSpace,a.pdfjsCoreStream,a.pdfjsCoreJpx)})(this,function(a,e,O,P,N,L){var H=e.ImageKind,K=e.assert,I=e.error,J=e.info,Q=e.isArray,E=e.warn,C=O.Name,o=O.isStream,x=P.ColorSpace,D=N.DecodeStream,G=N.Stream,h=N.JpegStream,z=L.JpxImage,e=function(){function a(e,m,o,y){if(y instanceof h&&y.isNativelyDecodable(m,o)){var s=y.dict.get("ColorSpace","CS"),s=x.parse(s,m,o),m=s.numComps;return e.sendWithPromise("JpegDecode",
[y.getIR(),m]).then(function(a){a=a.data;return new G(a,0,a.length,y.dict)})}return Promise.resolve(y)}function e(a,h,u,y,s,D,g){this.image=u;y=u.dict;if(y.has("Filter")){var f=y.get("Filter").name;"JPXDecode"===f?(f=new z,f.parseImageProperties(u.stream),u.stream.reset(),u.bitsPerComponent=f.bitsPerComponent,u.numComps=f.componentsCount):"JBIG2Decode"===f&&(u.bitsPerComponent=1,u.numComps=1)}this.width=y.get("Width","W");this.height=y.get("Height","H");(1>this.width||1>this.height)&&I("Invalid image width: "+
this.width+" or height: "+this.height);this.interpolate=y.get("Interpolate","I")||!1;this.imageMask=y.get("ImageMask","IM")||!1;this.matte=y.get("Matte")||!1;f=u.bitsPerComponent;f||(f=y.get("BitsPerComponent","BPC"))||(this.imageMask?f=1:I("Bits per component missing in image: "+this.imageMask));this.bpc=f;if(!this.imageMask){var d=y.get("ColorSpace","CS");if(!d)switch(J("JPX images (which do not require color spaces)"),u.numComps){case 1:d=C.get("DeviceGray");break;case 3:d=C.get("DeviceRGB");break;
case 4:d=C.get("DeviceCMYK");break;default:I("JPX images with "+this.numComps+" color components not supported.")}this.colorSpace=x.parse(d,a,h);this.numComps=this.colorSpace.numComps}this.decode=y.get("Decode","D");this.needsDecode=!1;if(this.decode&&(this.colorSpace&&!this.colorSpace.isDefaultDecode(this.decode)||g&&!x.isDefaultDecode(this.decode,1))){this.needsDecode=!0;u=(1<<f)-1;this.decodeCoefficients=[];this.decodeAddends=[];for(y=g=0;g<this.decode.length;g+=2,++y)f=this.decode[g],this.decodeCoefficients[y]=
this.decode[g+1]-f,this.decodeAddends[y]=u*f}s?this.smask=new e(a,h,s,!1):D&&(o(D)?D.dict.get("ImageMask","IM")?this.mask=new e(a,h,D,!1,null,null,!0):E("Ignoring /Mask in image without /ImageMask."):this.mask=D)}e.buildImage=function(h,t,u,y,s){var x=a(h,t,u,y),g;g=y.dict.get("SMask");y=y.dict.get("Mask");g?(g=a(h,t,u,g),h=Promise.resolve(null)):(g=Promise.resolve(null),y?o(y)?h=a(h,t,u,y):Q(y)?h=Promise.resolve(y):(E("Unsupported mask format."),h=Promise.resolve(null)):h=Promise.resolve(null));
return Promise.all([x,g,h]).then(function(a){return new e(t,u,a[0],s,a[1],a[2])})};e.resize=function(a,e,h,m,s,o,g,f,d){1!==h&&3!==h&&I("Unsupported component count for resizing.");var k=o*g*h,e=f?f:8>=e?new Uint8Array(k):16>=e?new Uint16Array(k):new Uint32Array(k),c=m/o,s=s/g,f=0,b,k=new Uint16Array(o),i=m*h;1!==d&&(d=0);for(m=0;m<o;m++)k[m]=Math.floor(m*c)*h;if(1===h)for(h=0;h<g;h++){c=Math.floor(h*s)*i;for(m=0;m<o;m++)b=c+k[m],e[f++]=a[b]}else if(3===h)for(h=0;h<g;h++){c=Math.floor(h*s)*i;for(m=
0;m<o;m++)b=c+k[m],e[f++]=a[b++],e[f++]=a[b++],e[f++]=a[b++],f+=d}return e};e.createMask=function(a,e,h,m,s){var o=(e+7>>3)*h,g=a.byteLength;if(m&&(!s||o===g))m=a;else if(s){m=new Uint8Array(o);m.set(a);for(a=g;a<o;a++)m[a]=255}else m=new Uint8Array(g),m.set(a);if(s)for(a=0;a<g;a++)m[a]=~m[a];return{data:m,width:e,height:h}};e.prototype={get drawWidth(){return Math.max(this.width,this.smask&&this.smask.width||0,this.mask&&this.mask.width||0)},get drawHeight(){return Math.max(this.height,this.smask&&
this.smask.height||0,this.mask&&this.mask.height||0)},decodeBuffer:function(a){var e=this.bpc,h=this.numComps,m=this.decodeAddends,s=this.decodeCoefficients,o=(1<<e)-1,g;if(1===e)for(e=0,g=a.length;e<g;e++)a[e]=+!a[e];else{var f=0;for(e=0,g=this.width*this.height;e<g;e++)for(var d=0;d<h;d++){var k=a,c=f,b=a[f],b=m[d]+b*s[d];k[c]=0>b?0:b>o?o:b;f++}}},getComponents:function(a){var e=this.bpc;if(8===e)return a;var h=this.width,m=this.height,s=this.numComps,o=h*m*s,g=0,f=8>=e?new Uint8Array(o):16>=e?
new Uint16Array(o):new Uint32Array(o),h=h*s,d=(1<<e)-1,s=0,k;if(1===e)for(o=0;o<m;o++){d=s+(h&-8);for(e=s+h;s<d;)k=a[g++],f[s]=k>>7&1,f[s+1]=k>>6&1,f[s+2]=k>>5&1,f[s+3]=k>>4&1,f[s+4]=k>>3&1,f[s+5]=k>>2&1,f[s+6]=k>>1&1,f[s+7]=k&1,s+=8;if(s<e){k=a[g++];for(d=128;s<e;)f[s++]=+!!(k&d),d>>=1}}else for(s=k=m=0;s<o;++s){0===s%h&&(m=k=0);for(;m<e;)k=k<<8|a[g++],m+=8;var m=m-e,c=k>>m;f[s]=0>c?0:c>d?d:c;k&=(1<<m)-1}return f},fillOpacity:function(a,h,o,y,s){var x=this.smask,g=this.mask,f,d,k;if(x){if(s=x.width,
d=x.height,f=new Uint8Array(s*d),x.fillGrayBuffer(f),s!==h||d!==o)f=e.resize(f,x.bpc,1,s,d,h,o)}else if(g)if(g instanceof e){s=g.width;d=g.height;f=new Uint8Array(s*d);g.numComps=1;g.fillGrayBuffer(f);for(x=0,k=s*d;x<k;++x)f[x]=255-f[x];if(s!==h||d!==o)f=e.resize(f,g.bpc,1,s,d,h,o)}else if(Q(g)){f=new Uint8Array(h*o);d=this.numComps;for(x=0,k=h*o;x<k;++x){for(var c=0,b=x*d,o=0;o<d;++o){var i=s[b+o],l=2*o;if(i<g[l]||i>g[l+1]){c=255;break}}f[x]=c}}else I("Unknown mask format.");if(f)for(x=0,o=3,k=h*
y;x<k;++x,o+=4)a[o]=f[x];else for(x=0,o=3,k=h*y;x<k;++x,o+=4)a[o]=255},undoPreblend:function(a,e,h){var m=this.smask&&this.smask.matte;if(m)for(var o=this.colorSpace.getRgb(m,0),m=o[0],x=o[1],o=o[2],e=4*e*h,g,f,d,h=0;h<e;h+=4)g=a[h+3],0===g?(a[h]=255,a[h+1]=255,a[h+2]=255):(d=255/g,g=(a[h]-m)*d+m,f=(a[h+1]-x)*d+x,d=(a[h+2]-o)*d+o,a[h]=0>=g?0:255<=g?255:g|0,a[h+1]=0>=f?0:255<=f?255:f|0,a[h+2]=0>=d?0:255<=d?255:d|0)},createImageData:function(a){var e=this.drawWidth,m=this.drawHeight,o={width:e,height:m},
s=this.width,x=this.height,g=this.bpc,f=s*this.numComps*g+7>>3,d;if(!a){var k;"DeviceGray"===this.colorSpace.name&&1===g?k=H.GRAYSCALE_1BPP:"DeviceRGB"===this.colorSpace.name&&8===g&&!this.needsDecode&&(k=H.RGB_24BPP);if(k&&!this.smask&&!this.mask&&e===s&&m===x){o.kind=k;d=this.getImageBytes(x*f);this.image instanceof D?o.data=d:(e=new Uint8Array(d.length),e.set(d),o.data=e);if(this.needsDecode){K(k===H.GRAYSCALE_1BPP);e=o.data;m=0;for(s=e.length;m<s;m++)e[m]^=255}return o}if(this.image instanceof
h&&!this.smask&&!this.mask&&("DeviceGray"===this.colorSpace.name||"DeviceRGB"===this.colorSpace.name||"DeviceCMYK"===this.colorSpace.name))return o.kind=H.RGB_24BPP,o.data=this.getImageBytes(x*f,e,m,!0),o}d=this.getImageBytes(x*f);k=0|d.length/f*m/x;d=this.getComponents(d);!a&&!this.smask&&!this.mask?(o.kind=H.RGB_24BPP,o.data=new Uint8Array(3*e*m),a=0,f=!1):(o.kind=H.RGBA_32BPP,o.data=new Uint8Array(4*e*m),a=1,f=!0,this.fillOpacity(o.data,e,m,k,d));this.needsDecode&&this.decodeBuffer(d);this.colorSpace.fillRgb(o.data,
s,x,e,m,k,g,d,a);f&&this.undoPreblend(o.data,e,k);return o},fillGrayBuffer:function(a){var e=this.numComps;1!==e&&I("Reading gray scale from a color image: "+e);var h=this.width,m=this.height,o=this.bpc,e=this.getComponents(this.getImageBytes(m*(h*e*o+7>>3)));if(1===o)if(h*=m,this.needsDecode)for(o=0;o<h;++o)a[o]=e[o]-1&255;else for(o=0;o<h;++o)a[o]=-e[o]&255;else{this.needsDecode&&this.decodeBuffer(e);h*=m;m=255/((1<<o)-1);for(o=0;o<h;++o)a[o]=m*e[o]|0}},getImageBytes:function(a,e,h,m){this.image.reset();
this.image.drawWidth=e||this.width;this.image.drawHeight=h||this.height;this.image.forceRGB=!!m;return this.image.getBytes(a)}};return e}();a.PDFImage=e;P._setCoreImage(a)});(function(a,e){e(a.pdfjsCorePattern={},a.pdfjsSharedUtil,a.pdfjsCorePrimitives,a.pdfjsCoreFunction,a.pdfjsCoreColorSpace)})(this,function(a,e,O,P,N){var L,H,K,I,J,Q,E,C,o,x=e.UNSUPPORTED_FEATURES,D=e.MissingDataException,G=e.Util,h=e.assert,z=e.error,R=e.info,m=e.warn,w=O.isStream,t=P.PDFFunction,u=N.ColorSpace;J=3;Q=4;E=5;C=
6;o=7;e=function(){function a(){z("should not call Pattern constructor")}a.prototype={getPattern:function(a){z("Should not call Pattern.getStyle: "+a)}};a.parseShading=function(a,e,g,f,d){var h=w(a)?a.dict:a,c=h.get("ShadingType");try{switch(c){case 2:case J:return new L(h,e,g,f);case Q:case E:case C:case o:return new H(a,e,g,f);default:throw Error("Unsupported ShadingType: "+c);}}catch(b){if(b instanceof D)throw b;d.send("UnsupportedFeature",{featureId:x.shadingPattern});m(b);return new K}};return a}();
L=void 0;H=void 0;K=void 0;I=void 0;I=1.0E-6;L=function(){function a(e,h,g,f){this.matrix=h;this.coordsArr=e.get("Coords");this.shadingType=e.get("ShadingType");this.type="Pattern";h=e.get("ColorSpace","CS");this.cs=h=u.parse(h,g,f);var f=0,d=1;if(e.has("Domain"))var k=e.get("Domain"),f=k[0],d=k[1];var c=k=!1;e.has("Extend")&&(c=e.get("Extend"),k=c[0],c=c[1]);if(this.shadingType===J&&(!k||!c)){var b=this.coordsArr[0],i=this.coordsArr[1],l=this.coordsArr[2],o=this.coordsArr[3],j=this.coordsArr[4],
p=this.coordsArr[5],b=Math.sqrt((b-o)*(b-o)+(i-j)*(i-j));l<=p+b&&p<=l+b&&m("Unsupported radial gradient.")}this.extendStart=k;this.extendEnd=c;l=e.get("Function");l=t.parseArray(g,l);p=d-f;b=p/10;g=this.colorStops=[];if(f>=d||0>=b)R("Bad shading domain.");else{for(var i=new Float32Array(h.numComps),o=new Float32Array(1),v,j=f;j<=d;j+=b)o[0]=j,l(o,0,i,0),v=h.getRgb(i,0),v=G.makeCssRgb(v[0],v[1],v[2]),g.push([(j-f)/p,v]);f="transparent";e.has("Background")&&(v=h.getRgb(e.get("Background"),0),f=G.makeCssRgb(v[0],
v[1],v[2]));k||(g.unshift([0,f]),g[1][0]+=I);c||(g[g.length-1][0]-=I,g.push([1,f]));this.colorStops=g}}a.prototype={getIR:function(){var a=this.coordsArr,e=this.shadingType,g,f,d,h,c;2===e?(f=[a[0],a[1]],d=[a[2],a[3]],c=h=null,g="axial"):e===J?(f=[a[0],a[1]],d=[a[3],a[4]],h=a[2],c=a[5],g="radial"):z("getPattern type unknown: "+e);if(a=this.matrix)f=G.applyTransform(f,a),d=G.applyTransform(d,a),e===J&&(e=G.singularValueDecompose2dScale(a),h*=e[0],c*=e[1]);return["RadialAxial",g,this.colorStops,f,d,
h,c]}};return a}();H=function(){function a(c,b){this.stream=c;this.context=b;this.bufferLength=this.buffer=0;this.tmpCompsBuf=new Float32Array(b.numComps);var d=b.colorSpace.numComps;this.tmpCsCompsBuf=b.colorFn?new Float32Array(d):this.tmpCompsBuf}function e(a){for(var b=a.coords[0][0],d=a.coords[0][1],f=b,g=d,h=1,k=a.coords.length;h<k;h++)var m=a.coords[h][0],n=a.coords[h][1],b=b>m?m:b,d=d>n?n:d,f=f<m?m:f,g=g<n?n:g;a.bounds=[b,d,f,g]}function m(c,b,i,l){h(w(c),"Mesh data is not a stream");var q=
c.dict;this.matrix=b;this.shadingType=q.get("ShadingType");this.type="Pattern";this.bbox=q.get("BBox");b=q.get("ColorSpace","CS");this.cs=b=u.parse(b,i,l);this.background=q.has("Background")?b.getRgb(q.get("Background"),0):null;i=(l=q.get("Function"))?t.parseArray(i,l):null;this.coords=[];this.colors=[];this.figures=[];i={bitsPerCoordinate:q.get("BitsPerCoordinate"),bitsPerComponent:q.get("BitsPerComponent"),bitsPerFlag:q.get("BitsPerFlag"),decode:q.get("Decode"),colorFn:i,colorSpace:b,numComps:i?
1:b.numComps};c=new a(c,i);i=!1;switch(this.shadingType){case Q:for(var q=this.coords,b=this.colors,l=[],j=[],p=0;c.hasData;){var v=c.readFlag(),n=c.readCoordinate(),r=c.readComponents();if(0===p){h(0<=v&&2>=v,"Unknown type4 flag");switch(v){case 0:p=3;break;case 1:j.push(j[j.length-2],j[j.length-1]);p=1;break;case 2:j.push(j[j.length-3],j[j.length-1]),p=1}l.push(v)}j.push(q.length);q.push(n);b.push(r);p--;c.align()}this.figures.push({type:"triangles",coords:new Int32Array(j),colors:new Int32Array(j)});
break;case E:q=q.get("VerticesPerRow")|0;h(2<=q,"Invalid VerticesPerRow");b=this.coords;l=this.colors;for(j=[];c.hasData;)p=c.readCoordinate(),v=c.readComponents(),j.push(b.length),b.push(p),l.push(v);this.figures.push({type:"lattice",coords:new Int32Array(j),colors:new Int32Array(j),verticesPerRow:q});break;case C:i=this.coords;q=this.colors;b=new Int32Array(16);for(l=new Int32Array(4);c.hasData;){v=c.readFlag();h(0<=v&&3>=v,"Unknown type6 flag");j=i.length;for(n=0,r=0!==v?8:12;n<r;n++)i.push(c.readCoordinate());
p=q.length;for(n=0,r=0!==v?2:4;n<r;n++)q.push(c.readComponents());var B;switch(v){case 0:b[12]=j+3;b[13]=j+4;b[14]=j+5;b[15]=j+6;b[8]=j+2;b[11]=j+7;b[4]=j+1;b[7]=j+8;b[0]=j;b[1]=j+11;b[2]=j+10;b[3]=j+9;l[2]=p+1;l[3]=p+2;l[0]=p;l[1]=p+3;break;case 1:v=b[12];n=b[13];r=b[14];B=b[15];b[12]=B;b[13]=j+0;b[14]=j+1;b[15]=j+2;b[8]=r;b[11]=j+3;b[4]=n;b[7]=j+4;b[0]=v;b[1]=j+7;b[2]=j+6;b[3]=j+5;v=l[2];n=l[3];l[2]=n;l[3]=p;l[0]=v;l[1]=p+1;break;case 2:v=b[15];n=b[11];b[12]=b[3];b[13]=j+0;b[14]=j+1;b[15]=j+2;b[8]=
b[7];b[11]=j+3;b[4]=n;b[7]=j+4;b[0]=v;b[1]=j+7;b[2]=j+6;b[3]=j+5;v=l[3];l[2]=l[1];l[3]=p;l[0]=v;l[1]=p+1;break;case 3:b[12]=b[0],b[13]=j+0,b[14]=j+1,b[15]=j+2,b[8]=b[1],b[11]=j+3,b[4]=b[2],b[7]=j+4,b[0]=b[3],b[1]=j+7,b[2]=j+6,b[3]=j+5,l[2]=l[0],l[3]=p,l[0]=l[1],l[1]=p+1}b[5]=i.length;i.push([(-4*i[b[0]][0]-i[b[15]][0]+6*(i[b[4]][0]+i[b[1]][0])-2*(i[b[12]][0]+i[b[3]][0])+3*(i[b[13]][0]+i[b[7]][0]))/9,(-4*i[b[0]][1]-i[b[15]][1]+6*(i[b[4]][1]+i[b[1]][1])-2*(i[b[12]][1]+i[b[3]][1])+3*(i[b[13]][1]+i[b[7]][1]))/
9]);b[6]=i.length;i.push([(-4*i[b[3]][0]-i[b[12]][0]+6*(i[b[2]][0]+i[b[7]][0])-2*(i[b[0]][0]+i[b[15]][0])+3*(i[b[4]][0]+i[b[14]][0]))/9,(-4*i[b[3]][1]-i[b[12]][1]+6*(i[b[2]][1]+i[b[7]][1])-2*(i[b[0]][1]+i[b[15]][1])+3*(i[b[4]][1]+i[b[14]][1]))/9]);b[9]=i.length;i.push([(-4*i[b[12]][0]-i[b[3]][0]+6*(i[b[8]][0]+i[b[13]][0])-2*(i[b[0]][0]+i[b[15]][0])+3*(i[b[11]][0]+i[b[1]][0]))/9,(-4*i[b[12]][1]-i[b[3]][1]+6*(i[b[8]][1]+i[b[13]][1])-2*(i[b[0]][1]+i[b[15]][1])+3*(i[b[11]][1]+i[b[1]][1]))/9]);b[10]=i.length;
i.push([(-4*i[b[15]][0]-i[b[0]][0]+6*(i[b[11]][0]+i[b[14]][0])-2*(i[b[12]][0]+i[b[3]][0])+3*(i[b[2]][0]+i[b[8]][0]))/9,(-4*i[b[15]][1]-i[b[0]][1]+6*(i[b[11]][1]+i[b[14]][1])-2*(i[b[12]][1]+i[b[3]][1])+3*(i[b[2]][1]+i[b[8]][1]))/9]);this.figures.push({type:"patch",coords:new Int32Array(b),colors:new Int32Array(l)})}i=!0;break;case o:i=this.coords;q=this.colors;b=new Int32Array(16);for(l=new Int32Array(4);c.hasData;){v=c.readFlag();h(0<=v&&3>=v,"Unknown type7 flag");j=i.length;for(n=0,r=0!==v?12:16;n<
r;n++)i.push(c.readCoordinate());p=q.length;for(n=0,r=0!==v?2:4;n<r;n++)q.push(c.readComponents());switch(v){case 0:b[12]=j+3;b[13]=j+4;b[14]=j+5;b[15]=j+6;b[8]=j+2;b[9]=j+13;b[10]=j+14;b[11]=j+7;b[4]=j+1;b[5]=j+12;b[6]=j+15;b[7]=j+8;b[0]=j;b[1]=j+11;b[2]=j+10;b[3]=j+9;l[2]=p+1;l[3]=p+2;l[0]=p;l[1]=p+3;break;case 1:v=b[12];n=b[13];r=b[14];B=b[15];b[12]=B;b[13]=j+0;b[14]=j+1;b[15]=j+2;b[8]=r;b[9]=j+9;b[10]=j+10;b[11]=j+3;b[4]=n;b[5]=j+8;b[6]=j+11;b[7]=j+4;b[0]=v;b[1]=j+7;b[2]=j+6;b[3]=j+5;v=l[2];n=
l[3];l[2]=n;l[3]=p;l[0]=v;l[1]=p+1;break;case 2:v=b[15];n=b[11];b[12]=b[3];b[13]=j+0;b[14]=j+1;b[15]=j+2;b[8]=b[7];b[9]=j+9;b[10]=j+10;b[11]=j+3;b[4]=n;b[5]=j+8;b[6]=j+11;b[7]=j+4;b[0]=v;b[1]=j+7;b[2]=j+6;b[3]=j+5;v=l[3];l[2]=l[1];l[3]=p;l[0]=v;l[1]=p+1;break;case 3:b[12]=b[0],b[13]=j+0,b[14]=j+1,b[15]=j+2,b[8]=b[1],b[9]=j+9,b[10]=j+10,b[11]=j+3,b[4]=b[2],b[5]=j+8,b[6]=j+11,b[7]=j+4,b[0]=b[3],b[1]=j+7,b[2]=j+6,b[3]=j+5,l[2]=l[0],l[3]=p,l[0]=l[1],l[1]=p+1}this.figures.push({type:"patch",coords:new Int32Array(b),
colors:new Int32Array(l)})}i=!0;break;default:z("Unsupported mesh type.")}if(i){e(this);c=0;for(i=this.figures.length;c<i;c++){q=c;p=this.figures[q];h("patch"===p.type,"Unexpected patch mesh figure");b=this.coords;l=this.colors;j=p.coords;p=p.colors;v=Math.min(b[j[0]][0],b[j[3]][0],b[j[12]][0],b[j[15]][0]);n=Math.min(b[j[0]][1],b[j[3]][1],b[j[12]][1],b[j[15]][1]);B=Math.max(b[j[0]][0],b[j[3]][0],b[j[12]][0],b[j[15]][0]);r=Math.max(b[j[0]][1],b[j[3]][1],b[j[12]][1],b[j[15]][1]);v=Math.ceil((B-v)*d/
(this.bounds[2]-this.bounds[0]));v=Math.max(g,Math.min(f,v));n=Math.ceil((r-n)*d/(this.bounds[3]-this.bounds[1]));n=Math.max(g,Math.min(f,n));r=v+1;B=new Int32Array((n+1)*r);for(var x=new Int32Array((n+1)*r),A=0,D=new Uint8Array(3),H=new Uint8Array(3),I=l[p[0]],G=l[p[1]],J=l[p[2]],K=l[p[3]],L=k(n),N=k(v),M=0;M<=n;M++){D[0]=(I[0]*(n-M)+J[0]*M)/n|0;D[1]=(I[1]*(n-M)+J[1]*M)/n|0;D[2]=(I[2]*(n-M)+J[2]*M)/n|0;H[0]=(G[0]*(n-M)+K[0]*M)/n|0;H[1]=(G[1]*(n-M)+K[1]*M)/n|0;H[2]=(G[2]*(n-M)+K[2]*M)/n|0;for(var O=
0;O<=v;O++,A++)if(!(0===M||M===n)||!(0===O||O===v)){for(var P=0,R=0,ha=0,ea=0;3>=ea;ea++)for(var ca=0;3>=ca;ca++,ha++)var ja=L[M][ea]*N[O][ca],P=P+b[j[ha]][0]*ja,R=R+b[j[ha]][1]*ja;B[A]=b.length;b.push([P,R]);x[A]=l.length;P=new Uint8Array(3);P[0]=(D[0]*(v-O)+H[0]*O)/v|0;P[1]=(D[1]*(v-O)+H[1]*O)/v|0;P[2]=(D[2]*(v-O)+H[2]*O)/v|0;l.push(P)}}B[0]=j[0];x[0]=p[0];B[v]=j[3];x[v]=p[1];B[r*n]=j[12];x[r*n]=p[2];B[r*n+v]=j[15];x[r*n+v]=p[3];this.figures[q]={type:"lattice",coords:B,colors:x,verticesPerRow:r}}}e(this);
b=this.coords;l=new Float32Array(2*b.length);for(c=0,q=0,i=b.length;c<i;c++)j=b[c],l[q++]=j[0],l[q++]=j[1];this.coords=l;b=this.colors;l=new Uint8Array(3*b.length);for(c=0,q=0,i=b.length;c<i;c++)j=b[c],l[q++]=j[0],l[q++]=j[1],l[q++]=j[2];this.colors=l;b=this.figures;for(c=0,i=b.length;c<i;c++){q=b[c];l=q.coords;p=q.colors;for(q=0,j=l.length;q<j;q++)l[q]*=2,p[q]*=3}}a.prototype={get hasData(){if(this.stream.end)return this.stream.pos<this.stream.end;if(0<this.bufferLength)return!0;var a=this.stream.getByte();
if(0>a)return!1;this.buffer=a;this.bufferLength=8;return!0},readBits:function(a){var b=this.buffer,d=this.bufferLength;if(32===a){if(0===d)return(this.stream.getByte()<<24|this.stream.getByte()<<16|this.stream.getByte()<<8|this.stream.getByte())>>>0;b=b<<24|this.stream.getByte()<<16|this.stream.getByte()<<8|this.stream.getByte();a=this.stream.getByte();this.buffer=a&(1<<d)-1;return(b<<8-d|(a&255)>>d)>>>0}if(8===a&&0===d)return this.stream.getByte();for(;d<a;)b=b<<8|this.stream.getByte(),d+=8;this.bufferLength=
d-=a;this.buffer=b&(1<<d)-1;return b>>d},align:function(){this.bufferLength=this.buffer=0},readFlag:function(){return this.readBits(this.context.bitsPerFlag)},readCoordinate:function(){var a=this.context.bitsPerCoordinate,b=this.readBits(a),d=this.readBits(a),f=this.context.decode,a=32>a?1/((1<<a)-1):2.3283064365386963E-10;return[b*a*(f[1]-f[0])+f[0],d*a*(f[3]-f[2])+f[2]]},readComponents:function(){for(var a=this.context.numComps,b=this.context.bitsPerComponent,d=32>b?1/((1<<b)-1):2.3283064365386963E-10,
f=this.context.decode,e=this.tmpCompsBuf,g=0,h=4;g<a;g++,h+=2){var k=this.readBits(b);e[g]=k*d*(f[h+1]-f[h])+f[h]}a=this.tmpCsCompsBuf;this.context.colorFn&&this.context.colorFn(e,0,a,0);return this.context.colorSpace.getRgb(a,0)}};var g=3,f=20,d=20,k=function(){var a=[];return function(b){if(!a[b]){for(var d=[],f=0;f<=b;f++){var e=f/b,g=1-e;d.push(new Float32Array([g*g*g,3*e*g*g,3*e*e*g,e*e*e]))}a[b]=d}return a[b]}}();m.prototype={getIR:function(){return["Mesh",this.shadingType,this.coords,this.colors,
this.figures,this.bounds,this.matrix,this.bbox,this.background]}};return m}();K=function(){function a(){this.type="Pattern"}a.prototype={getIR:function(){return["Dummy"]}};return a}();a.Pattern=e;a.getTilingPatternIR=function(a,e,h){var g=e.get("Matrix"),f=e.get("BBox"),d=e.get("XStep"),k=e.get("YStep"),c=e.get("PaintType"),e=e.get("TilingType");return["TilingPattern",h,a,g,f,d,k,c,e]}});(function(a,e){e(a.pdfjsCoreEvaluator={},a.pdfjsSharedUtil,a.pdfjsCorePrimitives,a.pdfjsCoreStream,a.pdfjsCoreParser,
a.pdfjsCoreImage,a.pdfjsCoreColorSpace,a.pdfjsCoreMurmurHash3,a.pdfjsCoreFonts,a.pdfjsCoreFunction,a.pdfjsCorePattern,a.pdfjsCoreCMap,a.pdfjsCoreMetrics,a.pdfjsCoreBidi)})(this,function(a,e,O,P,N,L,H,K,I,J,Q,E,C){var o=e.FONT_IDENTITY_MATRIX,x=e.IDENTITY_MATRIX,D=e.UNSUPPORTED_FEATURES,G=e.ImageKind,h=e.OPS,z=e.TextRenderingMode,R=e.Util,m=e.assert,w=e.createPromiseCapability,t=e.error,u=e.info,y=e.isArray,s=e.isNum,M=e.isString,g=e.warn,f=O.Dict,d=O.Name,k=O.isCmd,c=O.isDict,b=O.isName,i=O.isRef,
l=O.isStream,q=P.DecodeStream,j=P.JpegStream,p=N.Lexer,v=N.Parser,n=N.isEOF,r=L.PDFImage,B=H.ColorSpace,F=K.MurmurHash3_64,A=I.Encodings,$=I.ErrorFont,V=I.FontFlags,W=I.Font,ba=I.IdentityToUnicodeMap,Ta=I.NormalizedUnicodes,ab=I.ToUnicodeMap,pb=I.getFontType,qb=I.reverseIfRtl,ca=I.serifFonts,$a=I.symbolsFonts,qa=I.stdFontMap,Ka=J.isPDFFunction,ha=J.PDFFunction,ea=Q.Pattern,Ua=Q.getTilingPatternIR,ja=E.CMapFactory,bb=E.IdentityCMap,La=C.Metrics,e=function(){function a(b,c,d,f,e,g,h){this.pdfManager=
b;this.xref=c;this.handler=d;this.pageIndex=f;this.uniquePrefix=e;this.idCounters=g;this.fontCache=h}function e(){this.reset()}e.prototype={check:function(){if(100>++this.checked)return!1;this.checked=0;return this.endTime<=Date.now()},reset:function(){this.endTime=Date.now()+20;this.checked=0}};var k=Promise.resolve();a.prototype={hasBlendModes:function(a){if(!c(a))return!1;var d=Object.create(null);a.objId&&(d[a.objId]=!0);for(a=[a];a.length;){var f,e=a.shift(),g=e.get("ExtGState");if(c(g))for(f in g=
g.getAll(),g){var h=g[f].BM;if(b(h)&&"Normal"!==h.name)return!0}e=e.get("XObject");if(c(e))for(f in e=e.getAll(),e)if(g=e[f],l(g)){if(g.dict.objId){if(d[g.dict.objId])continue;d[g.dict.objId]=!0}g=g.dict.get("Resources");if(c(g)&&(!g.objId||!d[g.objId]))a.push(g),g.objId&&(d[g.objId]=!0)}}return!1},buildFormXObject:function(a,c,d,f,e,g){var i=c.dict.getArray("Matrix"),j=c.dict.getArray("BBox"),k=c.dict.get("Group");if(k){var l={matrix:i,bbox:j,smask:d,isolated:!1,knockout:!1},n=k.get("S"),m;b(n)&&
"Transparency"===n.name&&(l.isolated=k.get("I")||!1,l.knockout=k.get("K")||!1,m=k.has("CS")?B.parse(k.get("CS"),this.xref,a):null);d&&d.backdrop&&(m=m||B.singletons.rgb,d.backdrop=m.getRgb(d.backdrop,0));f.addOp(h.beginGroup,[l])}f.addOp(h.paintFormXObjectBegin,[i,j]);return this.getOperatorList(c,e,c.dict.get("Resources")||a,f,g).then(function(){f.addOp(h.paintFormXObjectEnd,[]);k&&f.addOp(h.endGroup,[l])})},buildPaintImageXObject:function(b,a,c,d,f,e){var i=this,k=a.dict,l=k.get("Width","W"),n=
k.get("Height","H");if(!l||!s(l)||!n||!s(n))g("Image dimensions are missing, or not numbers.");else if(-1!==PDFJS.maxImageSize&&l*n>PDFJS.maxImageSize)g("Image exceeded maximum allowed size and was removed.");else if(k.get("ImageMask","IM")){var b=k.get("Width","W"),c=k.get("Height","H"),m=a.getBytes((b+7>>3)*c),k=k.get("Decode","D"),a=r.createMask(m,b,c,a instanceof q,!!k&&0<k[0]);a.cached=!0;l=[a];d.addOp(h.paintImageMaskXObject,l);f&&(e[f]={fn:h.paintImageMaskXObject,args:l})}else if(m=k.get("SMask",
"SM")||!1,k=k.get("Mask")||!1,c&&!m&&!k&&!(a instanceof j)&&200>l+n)a=(new r(this.xref,b,a,c,null,null)).createImageData(!0),d.addOp(h.paintInlineImageXObject,[a]);else{var o="img_"+(this.uniquePrefix||"")+ ++this.idCounters.obj;d.addDependency(o);l=[o,l,n];!m&&!k&&a instanceof j&&a.isNativelySupported(this.xref,b)?(d.addOp(h.paintJpegXObject,l),this.handler.send("obj",[o,this.pageIndex,"JpegStream",a.getIR()])):(r.buildImage(i.handler,i.xref,b,a,c).then(function(a){a=a.createImageData(!1);i.handler.send("obj",
[o,i.pageIndex,"Image",a],[a.data.buffer])}).then(void 0,function(a){g("Unable to decode image: "+a);i.handler.send("obj",[o,i.pageIndex,"Image",null])}),d.addOp(h.paintImageXObject,l),f&&(e[f]={fn:h.paintImageXObject,args:l}))}},handleSMask:function(a,b,c,d,f){var e=a.get("G"),g={subtype:a.get("S").name,backdrop:a.get("BC")},a=a.get("TR");if(Ka(a)){for(var a=ha.parse(this.xref,a),h=new Uint8Array(256),i=new Float32Array(1),j=0;255>j;j++)i[0]=j/255,a(i,0,i,0),h[j]=255*i[0]|0;g.transferMap=h}return this.buildFormXObject(b,
e,g,c,d,f.state.clone())},handleTilingType:function(a,b,c,d,e,g,h){var i=new ka,c=[e.get("Resources"),c],c=f.merge(this.xref,c);return this.getOperatorList(d,h,c,i).then(function(){g.addDependencies(i.dependencies);g.addOp(a,Ua({fnArray:i.fnArray,argsArray:i.argsArray},e,b))})},handleSetFont:function(a,b,c,d,f,e){var g;b&&(b=b.slice(),g=b[0].name);var h=this;return this.loadFont(g,c,this.xref,a).then(function(b){return!b.font.isType3Font?b:b.loadType3Data(h,a,d,f).then(function(){return b},function(a){h.handler.send("UnsupportedFeature",
{featureId:D.font});return new Y("g_font_error",new $("Type3 font load error: "+a),b.font)})}).then(function(a){e.font=a.font;a.send(h.handler);return a.loadedName})},handleText:function(a,b){var c=b.font,d=c.charsToGlyphs(a),f=!!(b.textRenderingMode&z.ADD_TO_PATH_FLAG);if(c.data&&(f||PDFJS.disableFontFace))for(var f=function(a){if(!c.renderer.hasBuiltPath(a)){var b=c.renderer.getPathJs(a);this.handler.send("commonobj",[c.loadedName+"_path_"+a,"FontPath",b])}}.bind(this),e=0,g=d.length;e<g;e++){var h=
d[e];f(h.fontChar);(h=h.accent)&&h.fontChar&&f(h.fontChar)}return d},setGState:function(a,d,f,e,i,j){var k=[],d=d.map,l=this,n=Promise.resolve(),m;for(m in d){var o=d[m];switch(m){case "Type":break;case "LW":case "LC":case "LJ":case "ML":case "D":case "RI":case "FL":case "CA":case "ca":k.push([m,o]);break;case "Font":n=n.then(function(){return l.handleSetFont(a,null,o[0],f,e,j.state).then(function(a){f.addDependency(a);k.push([m,[a,o[1]]])})});break;case "BM":k.push([m,o]);break;case "SMask":if(b(o)&&
"None"===o.name){k.push([m,!1]);break}var p=i.fetchIfRef(o);c(p)?(n=n.then(function(){return l.handleSMask(p,a,f,e,j)}),k.push([m,!0])):g("Unsupported SMask type");break;case "OP":case "op":case "OPM":case "BG":case "BG2":case "UCR":case "UCR2":case "TR":case "TR2":case "HT":case "SM":case "SA":case "AIS":case "TK":u("graphic state operator "+m);break;default:u("Unknown graphic state operator "+m)}}return n.then(function(){0<=k.length&&f.addOp(h.setGState,[k])})},loadFont:function(a,b,d,f){function e(){return Promise.resolve(new Y("g_font_error",
new $("Font "+a+" is not available"),b))}if(b)m(i(b)),f=b;else if(f=f.get("Font"))f=f.getRaw(a);else return g("fontRes not available"),e();if(!f)return g("fontRef not available"),e();if(this.fontCache.has(f))return this.fontCache.get(f);b=d.fetchIfRef(f);if(!c(b))return e();if(b.translated)return b.translated;var h=w(),j=this.preEvaluateFont(b,d),k=j.descriptor,l=f.num+"_"+f.gen;if(c(k)){k.fontAliases||(k.fontAliases=Object.create(null));l=k.fontAliases;k=j.hash;if(l[k]){var n=l[k].aliasRef;if(n&&
this.fontCache.has(n))return this.fontCache.putAlias(f,n),this.fontCache.get(f)}l[k]||(l[k]={fontID:W.getFontID()});l[k].aliasRef=f;l=l[k].fontID}(k=c(f))||this.fontCache.put(f,h.promise);b.loadedName="g_"+this.pdfManager.docId+"_f"+(k?a.replace(/\W/g,""):l);b.translated=h.promise;var o;try{o=Promise.resolve(this.translateFont(j,d))}catch(p){o=Promise.reject(p)}var r=this;o.then(function(a){void 0!==a.fontType&&(d.stats.fontTypes[a.fontType]=!0);h.resolve(new Y(b.loadedName,a,b))},function(a){r.handler.send("UnsupportedFeature",
{featureId:D.font});try{var c=j.descriptor,f=c&&c.get("FontFile3"),e=f&&f.get("Subtype"),g=pb(j.type,e&&e.name);d.stats.fontTypes[g]=!0}catch(i){}h.resolve(new Y(b.loadedName,new $(a instanceof Error?a.message:a),b))});return h.promise},buildPath:function(a,b,c){var d=a.length-1;c||(c=[]);0>d||a.fnArray[d]!==h.constructPath?a.addOp(h.constructPath,[[b],c]):(a=a.argsArray[d],a[0].push(b),Array.prototype.push.apply(a[1],c))},handleColorN:function(a,c,d,f,e,g,h,i){var j=d[d.length-1],k;if(b(j)&&(k=e.get(j.name))){e=
l(k)?k.dict:k;j=e.get("PatternType");if(1===j)return i=f.base?f.base.getRgb(d,0):null,this.handleTilingType(c,i,g,k,e,a,h);return 2===j?(h=e.get("Shading"),k=e.get("Matrix"),k=ea.parseShading(h,k,i,g,this.handler),a.addOp(c,k.getIR()),Promise.resolve()):Promise.reject("Unknown PatternType: "+j)}a.addOp(c,d);return Promise.resolve()},getOperatorList:function(a,d,i,j,n){var o=this,p=this.xref,r={};m(j);var i=i||f.empty,q=i.get("XObject")||f.empty,A=i.get("Pattern")||f.empty,v=new fa(n||new Fa),w=new U(a,
p,v),x=new e;return new Promise(function na(a,f){d.ensureNotTerminated();x.reset();for(var e,n={},F;!(e=x.check());){n.args=null;if(!w.read(n))break;e=n.args;F=n.fn;switch(F|0){case h.paintXObject:if(e[0].code)break;var y=e[0].name;if(!y){g("XObject must be referred to by name.");continue}if(void 0!==r[y]){j.addOp(r[y].fn,r[y].args);e=null;continue}var z=q.get(y);if(z){m(l(z),"XObject should be a stream");var D=z.dict.get("Subtype");m(b(D),"XObject should have a Name subtype");if("Form"===D.name)return v.save(),
o.buildFormXObject(i,z,null,j,d,v.state.clone()).then(function(){v.restore();na(a,f)},f);if("Image"===D.name){o.buildPaintImageXObject(i,z,!1,j,y,r);e=null;continue}else if("PS"===D.name){u("Ignored XObject subtype PS");continue}else t("Unhandled XObject subtype "+D.name)}break;case h.setFont:var C=e[1];return o.handleSetFont(i,e,null,j,d,v.state).then(function(b){j.addDependency(b);j.addOp(h.setFont,[b,C]);na(a,f)},f);case h.endInlineImage:if(F=e[0].cacheKey)if(y=r[F],void 0!==y){j.addOp(y.fn,y.args);
e=null;continue}o.buildPaintImageXObject(i,e[0],!0,j,F,r);e=null;continue;case h.showText:e[0]=o.handleText(e[0],v.state);break;case h.showSpacedText:var y=e[0],z=[],D=y.length,E=v.state;for(F=0;F<D;++F){var H=y[F];M(H)?Array.prototype.push.apply(z,o.handleText(H,E)):s(H)&&z.push(H)}e[0]=z;F=h.showText;break;case h.nextLineShowText:j.addOp(h.nextLine);e[0]=o.handleText(e[0],v.state);F=h.showText;break;case h.nextLineSetSpacingShowText:j.addOp(h.nextLine);j.addOp(h.setWordSpacing,[e.shift()]);j.addOp(h.setCharSpacing,
[e.shift()]);e[0]=o.handleText(e[0],v.state);F=h.showText;break;case h.setTextRenderingMode:v.state.textRenderingMode=e[0];break;case h.setFillColorSpace:v.state.fillColorSpace=B.parse(e[0],p,i);continue;case h.setStrokeColorSpace:v.state.strokeColorSpace=B.parse(e[0],p,i);continue;case h.setFillColor:F=v.state.fillColorSpace;e=F.getRgb(e,0);F=h.setFillRGBColor;break;case h.setStrokeColor:F=v.state.strokeColorSpace;e=F.getRgb(e,0);F=h.setStrokeRGBColor;break;case h.setFillGray:v.state.fillColorSpace=
B.singletons.gray;e=B.singletons.gray.getRgb(e,0);F=h.setFillRGBColor;break;case h.setStrokeGray:v.state.strokeColorSpace=B.singletons.gray;e=B.singletons.gray.getRgb(e,0);F=h.setStrokeRGBColor;break;case h.setFillCMYKColor:v.state.fillColorSpace=B.singletons.cmyk;e=B.singletons.cmyk.getRgb(e,0);F=h.setFillRGBColor;break;case h.setStrokeCMYKColor:v.state.strokeColorSpace=B.singletons.cmyk;e=B.singletons.cmyk.getRgb(e,0);F=h.setStrokeRGBColor;break;case h.setFillRGBColor:v.state.fillColorSpace=B.singletons.rgb;
e=B.singletons.rgb.getRgb(e,0);break;case h.setStrokeRGBColor:v.state.strokeColorSpace=B.singletons.rgb;e=B.singletons.rgb.getRgb(e,0);break;case h.setFillColorN:F=v.state.fillColorSpace;if("Pattern"===F.name)return o.handleColorN(j,h.setFillColorN,e,F,A,i,d,p).then(function(){na(a,f)},f);e=F.getRgb(e,0);F=h.setFillRGBColor;break;case h.setStrokeColorN:F=v.state.strokeColorSpace;if("Pattern"===F.name)return o.handleColorN(j,h.setStrokeColorN,e,F,A,i,d,p).then(function(){na(a,f)},f);e=F.getRgb(e,0);
F=h.setStrokeRGBColor;break;case h.shadingFill:(F=i.get("Shading"))||t("No shading resource found");(e=F.get(e[0].name))||t("No shading object found");e=[ea.parseShading(e,null,p,i,o.handler).getIR()];F=h.shadingFill;break;case h.setGState:y=e[0];z=i.get("ExtGState");if(!c(z)||!z.has(y.name))break;n=z.get(y.name);return o.setGState(i,n,j,d,p,v).then(function(){na(a,f)},f);case h.moveTo:case h.lineTo:case h.curveTo:case h.curveTo2:case h.curveTo3:case h.closePath:o.buildPath(j,F,e);continue;case h.rectangle:o.buildPath(j,
F,e);continue;case h.markPoint:case h.markPointProps:case h.beginMarkedContent:case h.beginMarkedContentProps:case h.endMarkedContent:case h.beginCompat:case h.endCompat:continue}j.addOp(F,e)}if(e)k.then(function(){na(a,f)},f);else{for(F=0,n=w.savedStatesDepth;F<n;F++)j.addOp(h.restore,[]);a()}})},getTextContent:function(a,d,g,i,j){function n(){if(A.initialized)return A;var a=G.font;a.loadedName in u.styles||(u.styles[a.loadedName]={fontFamily:a.fallbackName,ascent:a.ascent,descent:a.descent,vertical:a.vertical});
A.fontName=a.loadedName;var b=[G.fontSize*G.textHScale,0,0,G.fontSize,0,G.textRise];if(a.isType3Font&&G.fontMatrix!==o&&1===G.fontSize){var c=a.bbox[3]-a.bbox[1];0<c&&(c*=G.fontMatrix[3],b[3]*=c)}b=R.transform(G.ctm,R.transform(G.textMatrix,b));A.transform=b;a.vertical?(A.width=Math.sqrt(b[0]*b[0]+b[1]*b[1]),A.height=0,A.vertical=!0):(A.width=0,A.height=Math.sqrt(b[2]*b[2]+b[3]*b[3]),A.vertical=!1);var c=G.textLineMatrix[0],d=G.textLineMatrix[1],b=Math.sqrt(c*c+d*d),c=G.ctm[0],d=G.ctm[1],c=Math.sqrt(c*
c+d*d);A.textAdvanceScale=c*b;A.lastAdvanceWidth=0;A.lastAdvanceHeight=0;(b=a.spaceWidth/1E3*G.fontSize)?(A.spaceWidth=b,A.fakeSpaceMin=b*v,A.fakeMultiSpaceMin=b*w,A.fakeMultiSpaceMax=b*F,A.textRunBreakAllowed=!a.isMonospace):(A.spaceWidth=0,A.fakeSpaceMin=Infinity,A.fakeMultiSpaceMin=Infinity,A.fakeMultiSpaceMax=0,A.textRunBreakAllowed=!1);A.initialized=!0;return A}function p(a){var b=a.str.join(""),b=PDFJS.bidi(b,-1,a.vertical),c;if(j){for(var d=b.str,f=0,e=d.length;f<e&&32<=(c=d.charCodeAt(f))&&
127>=c;)f++;c=f<e?d.replace(t," "):d}else c=b.str;return{str:c,dir:b.dir,width:a.width,height:a.height,transform:a.transform,fontName:a.fontName}}function r(a,b){return z.loadFont(a,b,D,g).then(function(a){G.font=a.font;G.fontMatrix=a.font.fontMatrix||o})}function q(a){for(var b=G.font,c=n(),d=0,f=0,a=b.charsToGlyphs(a),e=0;e<a.length;e++){var g=a[e],h=null,h=b.vertical?g.vmetric?g.vmetric[0]:g.width:g.width,i=g.unicode;void 0!==Ta[i]&&(i=Ta[i]);var i=qb(i),j=G.charSpacing;g.isSpace&&(g=G.wordSpacing,
j+=g,0<g&&s(g,c.str));var k=g=0;b.vertical?(k=h*G.fontMatrix[0]*G.fontSize+j,f+=k):(g=(h*G.fontMatrix[0]*G.fontSize+j)*G.textHScale,d+=g);G.translateTextMatrix(g,k);c.str.push(i)}b.vertical?(c.lastAdvanceHeight=f,c.height+=Math.abs(f*c.textAdvanceScale)):(c.lastAdvanceWidth=d,c.width+=d*c.textAdvanceScale);return c}function s(a,b){if(!(a<A.fakeSpaceMin))if(a<A.fakeMultiSpaceMin)b.push(" ");else for(var c=Math.round(a/A.spaceWidth);0<c--;)b.push(" ")}function B(){A.initialized&&(u.items.push(p(A)),
A.initialized=!1,A.str.length=0)}var i=i||new fa(new sa),t=/\s/g,u={items:[],styles:Object.create(null)},A={initialized:!1,str:[],width:0,height:0,vertical:!1,lastAdvanceWidth:0,lastAdvanceHeight:0,textAdvanceScale:0,spaceWidth:0,fakeSpaceMin:Infinity,fakeMultiSpaceMin:Infinity,fakeMultiSpaceMax:-0.0,textRunBreakAllowed:!1,transform:null,fontName:null},v=0.3,w=1.5,F=4,z=this,D=this.xref,g=D.fetchIfRef(g)||f.empty,C=null,E,H,I=new U(a,D,i),G,$=new e;return new Promise(function db(a,e){d.ensureNotTerminated();
$.reset();for(var o,p={},t=[];!(o=$.check());){t.length=0;p.args=t;if(!I.read(p))break;G=i.state;o=p.fn;t=p.args;switch(o|0){case h.setFont:return B(),G.fontSize=t[1],r(t[0].name).then(function(){db(a,e)},e);case h.setTextRise:B();G.textRise=t[0];break;case h.setHScale:B();G.textHScale=t[0]/100;break;case h.setLeading:B();G.leading=t[0];break;case h.moveText:var v=!G.font?!1:0===(G.font.vertical?t[0]:t[1]);o=t[0]-t[1];if(v&&A.initialized&&0<o&&o<=A.fakeMultiSpaceMax){G.translateTextLineMatrix(t[0],
t[1]);A.width+=t[0]-A.lastAdvanceWidth;A.height+=t[1]-A.lastAdvanceHeight;s(t[0]-A.lastAdvanceWidth-(t[1]-A.lastAdvanceHeight),A.str);break}B();G.translateTextLineMatrix(t[0],t[1]);G.textMatrix=G.textLineMatrix.slice();break;case h.setLeadingMoveText:B();G.leading=-t[1];G.translateTextLineMatrix(t[0],t[1]);G.textMatrix=G.textLineMatrix.slice();break;case h.nextLine:B();G.carriageReturn();break;case h.setTextMatrix:B();G.setTextMatrix(t[0],t[1],t[2],t[3],t[4],t[5]);G.setTextLineMatrix(t[0],t[1],t[2],
t[3],t[4],t[5]);break;case h.setCharSpacing:G.charSpacing=t[0];break;case h.setWordSpacing:G.wordSpacing=t[0];break;case h.beginText:B();G.textMatrix=x.slice();G.textLineMatrix=x.slice();break;case h.showSpacedText:for(var v=t[0],w,F=0,D=v.length;F<D;F++)if("string"===typeof v[F])q(v[F]);else{n();o=v[F]*G.fontSize/1E3;var X=!1;G.font.vertical?(w=o*(G.textHScale*G.textMatrix[2]+G.textMatrix[3]),G.translateTextMatrix(0,o),X=A.textRunBreakAllowed&&o>A.fakeMultiSpaceMax,X||(A.height+=w)):(o=-o,w=o*(G.textHScale*
G.textMatrix[0]+G.textMatrix[1]),G.translateTextMatrix(o,0),X=A.textRunBreakAllowed&&o>A.fakeMultiSpaceMax,X||(A.width+=w));X?B():0<o&&s(o,A.str)}break;case h.showText:q(t[0]);break;case h.nextLineShowText:B();G.carriageReturn();q(t[0]);break;case h.nextLineSetSpacingShowText:B();G.wordSpacing=t[0];G.charSpacing=t[1];G.carriageReturn();q(t[2]);break;case h.paintXObject:B();if(t[0].code)break;C||(C=g.get("XObject")||f.empty);var J=t[0].name;if(E===J){H&&(R.appendToArray(u.items,H.items),R.extendObj(u.styles,
H.styles));break}o=C.get(J);if(!o)break;m(l(o),"XObject should be a stream");v=o.dict.get("Subtype");m(b(v),"XObject should have a Name subtype");if("Form"!==v.name){E=J;H=null;break}i.save();p=o.dict.get("Matrix");y(p)&&6===p.length&&i.transform(p);return z.getTextContent(o,d,o.dict.get("Resources")||g,i,j).then(function(b){R.appendToArray(u.items,b.items);R.extendObj(u.styles,b.styles);i.restore();E=J;H=b;db(a,e)},e);case h.setGState:B();o=t[0];v=g.get("ExtGState");if(!c(v)||!v.has(o.name))break;
o=v.get(o.name);var v=null,K;for(K in o)"Font"===K&&(m(!v),v=o[K]);if(v)return G.fontSize=v[1],r(v[0]).then(function(){db(a,e)},e)}}o?k.then(function(){db(a,e)},e):(B(),a(u))})},extractDataStructures:function(a,d,f,e){if(d=a.get("ToUnicode")||d.get("ToUnicode"))e.toUnicode=this.readToUnicode(d);e.composite&&(d=a.get("CIDSystemInfo"),c(d)&&(e.cidSystemInfo={registry:d.get("Registry"),ordering:d.get("Ordering"),supplement:d.get("Supplement")}),d=a.get("CIDToGIDMap"),l(d)&&(e.cidToGidMap=this.readCidToGidMap(d)));
var d=[],g=null,h;if(a.has("Encoding")){h=a.get("Encoding");if(c(h)){if(g=h.get("BaseEncoding"),g=b(g)?g.name:null,h.has("Differences")){h=h.get("Differences");for(var j=0,k=0,n=h.length;k<n;k++){var m=h[k];s(m)?j=m:b(m)?d[j++]=m.name:i(m)?h[k--]=f.fetch(m):t("Invalid entry in 'Differences' array: "+m)}}}else b(h)?g=h.name:t("Encoding is not a Name nor a Dict");"MacRomanEncoding"!==g&&"MacExpertEncoding"!==g&&"WinAnsiEncoding"!==g&&(g=null)}g?e.defaultEncoding=A[g].slice():(h="TrueType"===e.type?
A.WinAnsiEncoding:A.StandardEncoding,e.flags&V.Symbolic&&(h=A.MacRomanEncoding,e.file||(/Symbol/i.test(e.name)?h=A.SymbolSetEncoding:/Dingbats/i.test(e.name)&&(h=A.ZapfDingbatsEncoding))),e.defaultEncoding=h);e.differences=d;e.baseEncodingName=g;e.dict=a},readToUnicode:function(a){if(b(a))return a=ja.create(a,{url:PDFJS.cMapUrl,packed:PDFJS.cMapPacked},null),a instanceof bb?new ba(0,65535):new ab(a.getMap());if(l(a)){a=ja.create(a,{url:PDFJS.cMapUrl,packed:PDFJS.cMapPacked},null);if(a instanceof bb)return new ba(0,
65535);var c=Array(a.length);a.forEach(function(a,b){for(var d=[],f=0;f<b.length;f+=2){var e=b.charCodeAt(f)<<8|b.charCodeAt(f+1);if(55296!==(e&63488))d.push(e);else{var f=f+2,g=b.charCodeAt(f)<<8|b.charCodeAt(f+1);d.push(((e&1023)<<10)+(g&1023)+65536)}}c[a]=String.fromCharCode.apply(String,d)});return new ab(c)}return null},readCidToGidMap:function(a){for(var a=a.getBytes(),b=[],c=0,d=a.length;c<d;c++){var f=a[c++]<<8|a[c];0!==f&&(b[c>>1]=f)}return b},extractWidths:function(a,c,d,f){var e=[],g=0,
h=[],i,j,k,l,n,m,o;if(f.composite){g=a.get("DW")||1E3;if(o=a.get("W"))for(j=0,k=o.length;j<k;j++)if(d=o[j++],m=c.fetchIfRef(o[j]),y(m))for(l=0,n=m.length;l<n;l++)e[d++]=m[l];else{n=o[++j];for(l=d;l<=m;l++)e[l]=n}if(f.vertical&&(o=a.get("DW2")||[880,-1E3],i=[o[1],0.5*g,o[0]],o=a.get("W2")))for(j=0,k=o.length;j<k;j++)if(d=o[j++],m=c.fetchIfRef(o[j]),y(m))for(l=0,n=m.length;l<n;l++)h[d++]=[m[l++],m[l++],m[l]];else{a=[o[++j],o[++j],o[++j]];for(l=d;l<=m;l++)h[l]=a}}else if(c=f.firstChar,o=a.get("Widths")){l=
c;for(j=0,k=o.length;j<k;j++)e[l++]=o[j];g=parseFloat(d.get("MissingWidth"))||0}else a=a.get("BaseFont"),b(a)&&(g=this.getBaseFontMetrics(a.name),e=this.buildCharCodeToWidth(g.widths,f),g=g.defaultWidth);var a=!0,c=g,p;for(p in e)if(j=e[p])if(c){if(c!==j){a=!1;break}}else c=j;a&&(f.flags|=V.FixedPitch);f.defaultWidth=g;f.widths=e;f.defaultVMetrics=i;f.vmetrics=h},isSerifFont:function(a){a=a.split("-")[0];return a in ca||-1!==a.search(/serif/gi)},getBaseFontMetrics:function(a){var b=0,c=[],d=!1,f=
qa[a]||a;f in La||(f=this.isSerifFont(a)?"Times-Roman":"Helvetica");a=La[f];s(a)?(b=a,d=!0):c=a;return{defaultWidth:b,monospace:d,widths:c}},buildCharCodeToWidth:function(a,b){for(var c=Object.create(null),d=b.differences,f=b.defaultEncoding,e=0;256>e;e++)e in d&&a[d[e]]?c[e]=a[d[e]]:e in f&&a[f[e]]&&(c[e]=a[f[e]]);return c},preEvaluateFont:function(a,d){var f=a,e=a.get("Subtype");m(b(e),"invalid font Subtype");var g=!1,h;"Type0"===e.name&&((e=a.get("DescendantFonts"))||t("Descendant fonts are not specified"),
a=y(e)?d.fetchIfRef(e[0]):e,e=a.get("Subtype"),m(b(e),"invalid font Subtype"),g=!0);var j=a.get("FontDescriptor");if(j){var k=new F;h=f.getRaw("Encoding");if(b(h))k.update(h.name);else if(i(h))k.update(h.num+"_"+h.gen);else if(c(h))for(var n=h.getKeys(),o=0,p=n.length;o<p;o++){var r=h.getRaw(n[o]);b(r)?k.update(r.name):i(r)?k.update(r.num+"_"+r.gen):y(r)&&k.update(r.length.toString())}h=a.get("ToUnicode")||f.get("ToUnicode");l(h)?(h=h.str||h,h=h.buffer?new Uint8Array(h.buffer.buffer,0,h.bufferLength):
new Uint8Array(h.bytes.buffer,h.start,h.end-h.start),k.update(h)):b(h)&&k.update(h.name);if(h=a.get("Widths")||f.get("Widths"))h=new Uint8Array((new Uint32Array(h)).buffer),k.update(h)}return{descriptor:j,dict:a,baseDict:f,composite:g,type:e.name,hash:k?k.hexdigest():""}},translateFont:function(a,c){var e=a.baseDict,g=a.dict,h=a.composite,i=a.descriptor,j=a.type,k=h?65535:255;if(!i)if("Type3"===j)i=new f(null),i.set("FontName",d.get(j)),i.set("FontBBox",g.get("FontBBox"));else{e=g.get("BaseFont");
b(e)||t("Base font is not specified");var e=e.name.replace(/[,_]/g,"-"),i=this.getBaseFontMetrics(e),l=e.split("-")[0],l=(this.isSerifFont(l)?V.Serif:0)|(i.monospace?V.FixedPitch:0)|($a[l]?V.Symbolic:V.Nonsymbolic),k={type:j,name:e,widths:i.widths,defaultWidth:i.defaultWidth,flags:l,firstChar:0,lastChar:k};this.extractDataStructures(g,g,c,k);k.widths=this.buildCharCodeToWidth(i.widths,k);return new W(e,null,k)}var n=g.get("FirstChar")||0,p=g.get("LastChar")||k,l=i.get("FontName"),r=g.get("BaseFont");
M(l)&&(l=d.get(l));M(r)&&(r=d.get(r));if("Type3"!==j){var q=l&&l.name,s=r&&r.name;q!==s&&(u("The FontDescriptor's FontName is \""+q+'" but should be the same as the Font\'s BaseFont "'+s+'"'),q&&s&&0===s.indexOf(q)&&(l=r))}l=l||r;m(b(l),"invalid font name");if((r=i.get("FontFile","FontFile2","FontFile3"))&&r.dict){var B=r.dict.get("Subtype");B&&(B=B.name);var A=r.dict.get("Length1"),v=r.dict.get("Length2")}k={type:j,name:l.name,subtype:B,file:r,length1:A,length2:v,loadedName:e.loadedName,composite:h,
wideChars:h,fixedPitch:!1,fontMatrix:g.get("FontMatrix")||o,firstChar:n||0,lastChar:p||k,bbox:i.get("FontBBox"),ascent:i.get("Ascent"),descent:i.get("Descent"),xHeight:i.get("XHeight"),capHeight:i.get("CapHeight"),flags:i.get("Flags"),italicAngle:i.get("ItalicAngle"),coded:!1};h&&(h=e.get("Encoding"),b(h)&&(k.cidEncoding=h.name),k.cMap=ja.create(h,{url:PDFJS.cMapUrl,packed:PDFJS.cMapPacked},null),k.vertical=k.cMap.vertical);this.extractDataStructures(g,e,c,k);this.extractWidths(g,c,i,k);"Type3"===
j&&(k.isType3Font=!0);return new W(l.name,r,k)}};return a}(),Y=function(){function a(b,c,d){this.loadedName=b;this.font=c;this.dict=d;this.type3Loaded=null;this.sent=!1}a.prototype={send:function(a){if(!this.sent){var b=this.font.exportData();a.send("commonobj",[this.loadedName,"Font",b]);this.sent=!0}},loadType3Data:function(a,b,c,d){m(this.font.isType3Font);if(this.type3Loaded)return this.type3Loaded;for(var f=this.font,e=Promise.resolve(),h=this.dict.get("CharProcs").getAll(),i=this.dict.get("Resources")||
b,b=Object.keys(h),j={},k=0,l=b.length;k<l;++k)e=e.then(function(b){var f=h[b],e=new ka;return a.getOperatorList(f,d,i,e).then(function(){j[b]=e.getIR();c.addDependencies(e.dependencies)},function(){g('Type3 font resource "'+b+'" is not available');var a=new ka;j[b]=a.getIR()})}.bind(this,b[k]));return this.type3Loaded=e.then(function(){f.charProcOperatorList=j})}};return a}(),ka=function(){function a(b,c,d){this.messageHandler=c;this.fnArray=[];this.argsArray=[];this.dependencies={};this._totalLength=
0;this.pageIndex=d;this.intent=b}a.prototype={get length(){return this.argsArray.length},get totalLength(){return this._totalLength+this.length},addOp:function(a,b){this.fnArray.push(a);this.argsArray.push(b);this.messageHandler&&(1E3<=this.fnArray.length?this.flush():995<=this.fnArray.length&&(a===h.restore||a===h.endText)&&this.flush())},addDependency:function(a){a in this.dependencies||(this.dependencies[a]=!0,this.addOp(h.dependency,[a]))},addDependencies:function(a){for(var b in a)this.addDependency(b)},
addOpList:function(a){R.extendObj(this.dependencies,a.dependencies);for(var b=0,c=a.length;b<c;b++)this.addOp(a.fnArray[b],a.argsArray[b])},getIR:function(){return{fnArray:this.fnArray,argsArray:this.argsArray,length:this.length}},flush:function(a){"oplist"!==this.intent&&(new Ba).optimize(this);for(var b=[],c=this.fnArray,d=this.argsArray,f=0,e=this.length;f<e;f++)switch(c[f]){case h.paintInlineImageXObject:case h.paintInlineImageXObjectGroup:case h.paintImageMaskXObject:var g=d[f][0];g.cached||
b.push(g.data.buffer)}c=this.length;this._totalLength+=c;this.messageHandler.send("RenderPageChunk",{operatorList:{fnArray:this.fnArray,argsArray:this.argsArray,lastChunk:a,length:c},pageIndex:this.pageIndex,intent:this.intent},b);this.dependencies={};this.fnArray.length=0;this.argsArray.length=0}};return a}(),fa=function(){function a(b){this.state=b;this.stateStack=[]}a.prototype={save:function(){var a=this.state;this.stateStack.push(this.state);this.state=a.clone()},restore:function(){var a=this.stateStack.pop();
a&&(this.state=a)},transform:function(a){this.state.ctm=R.transform(this.state.ctm,a)}};return a}(),sa=function(){function a(){this.ctm=new Float32Array(x);this.fontSize=0;this.font=null;this.fontMatrix=o;this.textMatrix=x.slice();this.textLineMatrix=x.slice();this.leading=this.wordSpacing=this.charSpacing=0;this.textHScale=1;this.textRise=0}a.prototype={setTextMatrix:function(a,b,c,d,f,e){var g=this.textMatrix;g[0]=a;g[1]=b;g[2]=c;g[3]=d;g[4]=f;g[5]=e},setTextLineMatrix:function(a,b,c,d,f,e){var g=
this.textLineMatrix;g[0]=a;g[1]=b;g[2]=c;g[3]=d;g[4]=f;g[5]=e},translateTextMatrix:function(a,b){var c=this.textMatrix;c[4]=c[0]*a+c[2]*b+c[4];c[5]=c[1]*a+c[3]*b+c[5]},translateTextLineMatrix:function(a,b){var c=this.textLineMatrix;c[4]=c[0]*a+c[2]*b+c[4];c[5]=c[1]*a+c[3]*b+c[5]},calcRenderMatrix:function(a){return R.transform(a,R.transform(this.textMatrix,[this.fontSize*this.textHScale,0,0,this.fontSize,0,this.textRise]))},carriageReturn:function(){this.translateTextLineMatrix(0,-this.leading);this.textMatrix=
this.textLineMatrix.slice()},clone:function(){var a=Object.create(this);a.textMatrix=this.textMatrix.slice();a.textLineMatrix=this.textLineMatrix.slice();a.fontMatrix=this.fontMatrix.slice();return a}};return a}(),Fa=function(){function a(){this.ctm=new Float32Array(x);this.font=null;this.textRenderingMode=z.FILL;this.strokeColorSpace=this.fillColorSpace=B.singletons.gray}a.prototype={clone:function(){return Object.create(this)}};return a}(),U=function(){function a(c,d,f){this.parser=new v(new p(c,
b),!1,d);this.stateManager=f;this.nonProcessedArgs=[]}var b={w:{id:h.setLineWidth,numArgs:1,variableArgs:!1},J:{id:h.setLineCap,numArgs:1,variableArgs:!1},j:{id:h.setLineJoin,numArgs:1,variableArgs:!1},M:{id:h.setMiterLimit,numArgs:1,variableArgs:!1},d:{id:h.setDash,numArgs:2,variableArgs:!1},ri:{id:h.setRenderingIntent,numArgs:1,variableArgs:!1},i:{id:h.setFlatness,numArgs:1,variableArgs:!1},gs:{id:h.setGState,numArgs:1,variableArgs:!1},q:{id:h.save,numArgs:0,variableArgs:!1},Q:{id:h.restore,numArgs:0,
variableArgs:!1},cm:{id:h.transform,numArgs:6,variableArgs:!1},m:{id:h.moveTo,numArgs:2,variableArgs:!1},l:{id:h.lineTo,numArgs:2,variableArgs:!1},c:{id:h.curveTo,numArgs:6,variableArgs:!1},v:{id:h.curveTo2,numArgs:4,variableArgs:!1},y:{id:h.curveTo3,numArgs:4,variableArgs:!1},h:{id:h.closePath,numArgs:0,variableArgs:!1},re:{id:h.rectangle,numArgs:4,variableArgs:!1},S:{id:h.stroke,numArgs:0,variableArgs:!1},s:{id:h.closeStroke,numArgs:0,variableArgs:!1},f:{id:h.fill,numArgs:0,variableArgs:!1},F:{id:h.fill,
numArgs:0,variableArgs:!1},"f*":{id:h.eoFill,numArgs:0,variableArgs:!1},B:{id:h.fillStroke,numArgs:0,variableArgs:!1},"B*":{id:h.eoFillStroke,numArgs:0,variableArgs:!1},b:{id:h.closeFillStroke,numArgs:0,variableArgs:!1},"b*":{id:h.closeEOFillStroke,numArgs:0,variableArgs:!1},n:{id:h.endPath,numArgs:0,variableArgs:!1},W:{id:h.clip,numArgs:0,variableArgs:!1},"W*":{id:h.eoClip,numArgs:0,variableArgs:!1},BT:{id:h.beginText,numArgs:0,variableArgs:!1},ET:{id:h.endText,numArgs:0,variableArgs:!1},Tc:{id:h.setCharSpacing,
numArgs:1,variableArgs:!1},Tw:{id:h.setWordSpacing,numArgs:1,variableArgs:!1},Tz:{id:h.setHScale,numArgs:1,variableArgs:!1},TL:{id:h.setLeading,numArgs:1,variableArgs:!1},Tf:{id:h.setFont,numArgs:2,variableArgs:!1},Tr:{id:h.setTextRenderingMode,numArgs:1,variableArgs:!1},Ts:{id:h.setTextRise,numArgs:1,variableArgs:!1},Td:{id:h.moveText,numArgs:2,variableArgs:!1},TD:{id:h.setLeadingMoveText,numArgs:2,variableArgs:!1},Tm:{id:h.setTextMatrix,numArgs:6,variableArgs:!1},"T*":{id:h.nextLine,numArgs:0,variableArgs:!1},
Tj:{id:h.showText,numArgs:1,variableArgs:!1},TJ:{id:h.showSpacedText,numArgs:1,variableArgs:!1},"'":{id:h.nextLineShowText,numArgs:1,variableArgs:!1},'"':{id:h.nextLineSetSpacingShowText,numArgs:3,variableArgs:!1},d0:{id:h.setCharWidth,numArgs:2,variableArgs:!1},d1:{id:h.setCharWidthAndBounds,numArgs:6,variableArgs:!1},CS:{id:h.setStrokeColorSpace,numArgs:1,variableArgs:!1},cs:{id:h.setFillColorSpace,numArgs:1,variableArgs:!1},SC:{id:h.setStrokeColor,numArgs:4,variableArgs:!0},SCN:{id:h.setStrokeColorN,
numArgs:33,variableArgs:!0},sc:{id:h.setFillColor,numArgs:4,variableArgs:!0},scn:{id:h.setFillColorN,numArgs:33,variableArgs:!0},G:{id:h.setStrokeGray,numArgs:1,variableArgs:!1},g:{id:h.setFillGray,numArgs:1,variableArgs:!1},RG:{id:h.setStrokeRGBColor,numArgs:3,variableArgs:!1},rg:{id:h.setFillRGBColor,numArgs:3,variableArgs:!1},K:{id:h.setStrokeCMYKColor,numArgs:4,variableArgs:!1},k:{id:h.setFillCMYKColor,numArgs:4,variableArgs:!1},sh:{id:h.shadingFill,numArgs:1,variableArgs:!1},BI:{id:h.beginInlineImage,
numArgs:0,variableArgs:!1},ID:{id:h.beginImageData,numArgs:0,variableArgs:!1},EI:{id:h.endInlineImage,numArgs:1,variableArgs:!1},Do:{id:h.paintXObject,numArgs:1,variableArgs:!1},MP:{id:h.markPoint,numArgs:1,variableArgs:!1},DP:{id:h.markPointProps,numArgs:2,variableArgs:!1},BMC:{id:h.beginMarkedContent,numArgs:1,variableArgs:!1},BDC:{id:h.beginMarkedContentProps,numArgs:2,variableArgs:!1},EMC:{id:h.endMarkedContent,numArgs:0,variableArgs:!1},BX:{id:h.beginCompat,numArgs:0,variableArgs:!1},EX:{id:h.endCompat,
numArgs:0,variableArgs:!1},BM:null,BD:null,"true":null,fa:null,fal:null,fals:null,"false":null,nu:null,nul:null,"null":null};a.prototype={get savedStatesDepth(){return this.stateManager.stateStack.length},read:function(a){for(var c=a.args;;){var d=this.parser.getObj();if(k(d)){var e=d.cmd,d=b[e];if(!d){g('Unknown command "'+e+'"');continue}var e=d.id,h=d.numArgs,i=null!==c?c.length:0;if(d.variableArgs)i>h&&u("Command "+e+": expected [0,"+h+"] args, but received "+i+" args");else{if(i!==h){for(d=this.nonProcessedArgs;i>
h;)d.push(c.shift()),i--;for(;i<h&&0!==d.length;)c||(c=[]),c.unshift(d.pop()),i++}if(i<h){u("Command "+e+": because expected "+h+" args, but received "+i+" args; skipping");c=null;continue}}this.preprocessCommand(e,c);a.fn=e;a.args=c;return!0}if(n(d))return!1;null!==d&&(c||(c=[]),c.push(d instanceof f?d.getAll():d),m(33>=c.length,"Too many arguments"))}},preprocessCommand:function(a,b){switch(a|0){case h.save:this.stateManager.save();break;case h.restore:this.stateManager.restore();break;case h.transform:this.stateManager.transform(b)}}};
return a}(),Ba=function(){function a(b,c,d){for(var f=0,e=c.length-1;f<e;f++)var g=c[f],b=b[g]||(b[g]=[]);b[c[c.length-1]]=d}function b(){}var c=[];a(c,[h.save,h.transform,h.paintInlineImageXObject,h.restore],function(a){for(var b=a.fnArray,c=a.argsArray,d=a.iCurr,a=d-3,f=d-2,d=d-1,e=a+4,g=b.length;e+3<g&&!(b[e]!==h.save||b[e+1]!==h.transform||b[e+2]!==h.paintInlineImageXObject||b[e+3]!==h.restore);)e+=4;g=Math.min((e-a)/4,200);if(10>g)return e;var i=0,e=[],j=0,k=1,l=1,n;for(n=0;n<g;n++){var m=c[f+
(n<<2)],o=c[d+(n<<2)][0];1E3<k+o.width&&(i=Math.max(i,k),l+=j+2,j=k=0);e.push({transform:m,x:k,y:l,w:o.width,h:o.height});k+=o.width+2;j=Math.max(j,o.height)}f=Math.max(i,k)+1;j=l+j+1;l=new Uint8Array(4*f*j);i=f<<2;for(n=0;n<g;n++){var k=c[d+(n<<2)][0].data,m=e[n].w<<2,o=0,p=e[n].x+e[n].y*f<<2;l.set(k.subarray(0,m),p-i);for(var r=0,q=e[n].h;r<q;r++)l.set(k.subarray(o,o+m),p),o+=m,p+=i;for(l.set(k.subarray(o-m,o),p);0<=p;)k[p-4]=k[p],k[p-3]=k[p+1],k[p-2]=k[p+2],k[p-1]=k[p+3],k[p+m]=k[p+m-4],k[p+m+
1]=k[p+m-3],k[p+m+2]=k[p+m-2],k[p+m+3]=k[p+m-1],p-=i}b.splice(a,4*g,h.paintInlineImageXObjectGroup);c.splice(a,4*g,[{width:f,height:j,kind:G.RGBA_32BPP,data:l},e]);return a+1});a(c,[h.save,h.transform,h.paintImageMaskXObject,h.restore],function(a){for(var b=a.fnArray,c=a.argsArray,d=a.iCurr,a=d-3,f=d-2,d=d-1,e=a+4,g=b.length;e+3<g&&!(b[e]!==h.save||b[e+1]!==h.transform||b[e+2]!==h.paintImageMaskXObject||b[e+3]!==h.restore);)e+=4;for(var g=(e-a)/4,i=a+2,j=0;j<g;j++){var k=c[i+4*j];if((k=1===k.length&&
k[0])&&1===k.width&&1===k.height&&(!k.data.length||1===k.data.length&&0===k.data[0]))b[i+4*j]=h.paintSolidColorImageMask;else break}g-=j;if(10>g)return e;var l=!1,k=c[d][0];if(0===c[f][1]&&0===c[f][2])for(var l=!0,n=c[f][0],m=c[f][3],j=f+4,o=d+4,e=1;e<g;e++,j+=4,o+=4)if(i=c[j],c[o][0]!==k||i[0]!==n||0!==i[1]||0!==i[2]||i[3]!==m){10>e?l=!1:g=e;break}if(l){g=Math.min(g,1E3);d=new Float32Array(2*g);j=f;for(e=0;e<g;e++,j+=4)i=c[j],d[e<<1]=i[4],d[(e<<1)+1]=i[5];b.splice(a,4*g,h.paintImageMaskXObjectRepeat);
c.splice(a,4*g,[k,n,m,d])}else{g=Math.min(g,100);n=[];for(e=0;e<g;e++)i=c[f+(e<<2)],m=c[d+(e<<2)][0],n.push({data:m.data,width:m.width,height:m.height,transform:i});b.splice(a,4*g,h.paintImageMaskXObjectGroup);c.splice(a,4*g,[n])}return a+1});a(c,[h.save,h.transform,h.paintImageXObject,h.restore],function(a){var b=a.fnArray,c=a.argsArray,d=a.iCurr,a=d-3,e=d-2;if(0!==c[e][1]||0!==c[e][2])return d+1;for(var d=c[d-1][0],f=c[e][0],g=c[e][3],i=a+4,j=b.length;i+3<j&&!(b[i]!==h.save||b[i+1]!==h.transform||
b[i+2]!==h.paintImageXObject||b[i+3]!==h.restore);){if(c[i+1][0]!==f||0!==c[i+1][1]||0!==c[i+1][2]||c[i+1][3]!==g)break;if(c[i+2][0]!==d)break;i+=4}j=Math.min((i-a)/4,1E3);if(3>j)return i;for(var i=new Float32Array(2*j),k=0;k<j;k++,e+=4){var l=c[e];i[k<<1]=l[4];i[(k<<1)+1]=l[5]}d=[d,f,g,i];b.splice(a,4*j,h.paintImageXObjectRepeat);c.splice(a,4*j,d);return a+1});a(c,[h.beginText,h.setFont,h.setTextMatrix,h.showText,h.endText],function(a){for(var b=a.fnArray,c=a.argsArray,d=a.iCurr,e=d-4,f=d-3,g=d-
2,i=d-1,j=c[f][0],k=c[f][1],l=e+5,a=b.length;l+4<a&&!(b[l]!==h.beginText||b[l+1]!==h.setFont||b[l+2]!==h.setTextMatrix||b[l+3]!==h.showText||b[l+4]!==h.endText);){if(c[l+1][0]!==j||c[l+1][1]!==k)break;l+=5}a=Math.min((l-e)/5,1E3);if(3>a)return l;l=e;4<=e&&b[e-4]===b[f]&&b[e-3]===b[g]&&b[e-2]===b[i]&&b[e-1]===b[d]&&c[e-4][0]===j&&c[e-4][1]===k&&(a++,l-=5);d=l+4;for(e=1;e<a;e++)b.splice(d,3),c.splice(d,3),d+=2;return d+1});b.prototype={optimize:function(a){for(var b=a.fnArray,a={iCurr:0,fnArray:b,argsArray:a.argsArray},
d,e=0,f=b.length;e<f;)d=(d||c)[b[e]],"function"===typeof d?(a.iCurr=e,e=d(a),d=void 0,f=a.fnArray.length):e++}};return b}();a.OperatorList=ka;a.PartialEvaluator=e});(function(a,e){e(a.pdfjsCoreAnnotation={},a.pdfjsSharedUtil,a.pdfjsCorePrimitives,a.pdfjsCoreStream,a.pdfjsCoreColorSpace,a.pdfjsCoreObj,a.pdfjsCoreEvaluator)})(this,function(a,e,O,P,N,L,H){function K(){}var I=e.AnnotationBorderStyleType,J=e.AnnotationFlag,Q=e.AnnotationType,E=e.OPS,C=e.Util,o=e.isArray,x=e.isInt,D=e.isValidUrl,G=e.stringToBytes,
h=e.stringToPDFString,z=e.stringToUTF8String,R=e.warn,m=O.Dict,w=O.isDict,t=O.isName,u=P.Stream,y=N.ColorSpace,s=L.ObjectLoader,M=H.OperatorList;K.prototype={create:function(a,e){var f=a.fetchIfRef(e);if(w(f)){var h=f.get("Subtype"),h=t(h)?h.name:"",m={dict:f,ref:e};switch(h){case "Link":return new b(m);case "Text":return new c(m);case "Widget":return f=C.getInheritableProperty(f,"FT"),t(f)&&"Tx"===f.name?new k(m):new d(m);case "Popup":return new i(m);case "Highlight":return new l(m);case "Underline":return new q(m);
case "Squiggly":return new j(m);case "StrikeOut":return new p(m);default:return R('Unimplemented annotation type "'+h+'", falling back to base annotation'),new g(m)}}}};var g=function(){function a(b,c,d){var e=C.getAxialAlignedBoundingBox(c,d),c=e[0],d=e[1],f=e[2],e=e[3];if(c===f||d===e)return[1,0,0,1,b[0],b[1]];f=(b[2]-b[0])/(f-c);e=(b[3]-b[1])/(e-d);return[f,0,0,e,b[0]-c*f,b[1]-d*e]}function b(a){var c=a.dict;this.setFlags(c.get("F"));this.setRectangle(c.get("Rect"));this.setColor(c.get("C"));this.setBorderStyle(c);
var d;var e=c.get("AP");if(w(e))if(e=e.get("N"),w(e)){var f=c.get("AS");f&&e.has(f.name)&&(d=e.get(f.name))}else d=e;else d=void 0;this.appearance=d;this.data={};this.data.id=a.ref.toString();this.data.subtype=c.get("Subtype").name;this.data.annotationFlags=this.flags;this.data.rect=this.rectangle;this.data.color=this.color;this.data.borderStyle=this.borderStyle;this.data.hasAppearance=!!this.appearance}b.prototype={get viewable(){return this.flags?!this.hasFlag(J.INVISIBLE)&&!this.hasFlag(J.HIDDEN)&&
!this.hasFlag(J.NOVIEW):!0},get printable(){return this.flags?this.hasFlag(J.PRINT)&&!this.hasFlag(J.INVISIBLE)&&!this.hasFlag(J.HIDDEN):!1},setFlags:function(a){this.flags=x(a)?a:0},hasFlag:function(a){return this.flags?0<(this.flags&a):!1},setRectangle:function(a){this.rectangle=o(a)&&4===a.length?C.normalizeRect(a):[0,0,0,0]},setColor:function(a){var b=new Uint8Array(3);if(o(a))switch(a.length){case 0:this.color=null;break;case 1:y.singletons.gray.getRgbItem(a,0,b,0);this.color=b;break;case 3:y.singletons.rgb.getRgbItem(a,
0,b,0);this.color=b;break;case 4:y.singletons.cmyk.getRgbItem(a,0,b,0);this.color=b;break;default:this.color=b}else this.color=b},setBorderStyle:function(a){this.borderStyle=new f;if(w(a))if(a.has("BS")){var a=a.get("BS"),b;if(!a.has("Type")||t(b=a.get("Type"))&&"Border"===b.name)this.borderStyle.setWidth(a.get("W")),this.borderStyle.setStyle(a.get("S")),this.borderStyle.setDashArray(a.get("D"))}else a.has("Border")?(b=a.get("Border"),o(b)&&3<=b.length&&(this.borderStyle.setHorizontalCornerRadius(b[0]),
this.borderStyle.setVerticalCornerRadius(b[1]),this.borderStyle.setWidth(b[2]),4===b.length&&this.borderStyle.setDashArray(b[3]))):this.borderStyle.setWidth(0)},loadResources:function(a){return new Promise(function(b,c){this.appearance.dict.getAsync("Resources").then(function(d){d?(new s(d.map,a,d.xref)).load().then(function(){b(d)},c):b()},c)}.bind(this))},getOperatorList:function(b,c){if(!this.appearance)return Promise.resolve(new M);var d=this.data,e=this.appearance.dict,f=this.loadResources("ExtGState,ColorSpace,Pattern,Shading,XObject,Font".split(",")),
g=e.get("BBox")||[0,0,1,1],h=e.get("Matrix")||[1,0,0,1,0,0],i=a(d.rect,g,h),j=this;return f.then(function(a){var e=new M;e.addOp(E.beginAnnotation,[d.rect,i,h]);return b.getOperatorList(j.appearance,c,a,e).then(function(){e.addOp(E.endAnnotation,[]);j.appearance.reset();return e})})}};b.appendToOperatorList=function(a,b,c,d,e){for(var f=[],g=0,h=a.length;g<h;++g)("display"===e&&a[g].viewable||"print"===e&&a[g].printable)&&f.push(a[g].getOperatorList(c,d));return Promise.all(f).then(function(a){b.addOp(E.beginAnnotations,
[]);for(var c=0,d=a.length;c<d;++c)b.addOpList(a[c]);b.addOp(E.endAnnotations,[])})};return b}(),f=function(){function a(){this.width=1;this.style=I.SOLID;this.dashArray=[3];this.verticalCornerRadius=this.horizontalCornerRadius=0}a.prototype={setWidth:function(a){a===(a|0)&&(this.width=a)},setStyle:function(a){if(a)switch(a.name){case "S":this.style=I.SOLID;break;case "D":this.style=I.DASHED;break;case "B":this.style=I.BEVELED;break;case "I":this.style=I.INSET;break;case "U":this.style=I.UNDERLINE}},
setDashArray:function(a){if(o(a)&&0<a.length){for(var b=!0,c=!0,d=0,e=a.length;d<e;d++){var f=a[d];if(0<=+f)0<f&&(c=!1);else{b=!1;break}}b&&!c?this.dashArray=a:this.width=0}else a&&(this.width=0)},setHorizontalCornerRadius:function(a){a===(a|0)&&(this.horizontalCornerRadius=a)},setVerticalCornerRadius:function(a){a===(a|0)&&(this.verticalCornerRadius=a)}};return a}(),d=function(){function a(b){g.call(this,b);var c=b.dict,d=this.data;d.annotationType=Q.WIDGET;d.fieldValue=h(C.getInheritableProperty(c,
"V")||"");d.alternativeText=h(c.get("TU")||"");d.defaultAppearance=C.getInheritableProperty(c,"DA")||"";var e=C.getInheritableProperty(c,"FT");d.fieldType=t(e)?e.name:"";d.fieldFlags=C.getInheritableProperty(c,"Ff")||0;this.fieldResources=C.getInheritableProperty(c,"DR")||m.empty;"Sig"===d.fieldType&&(R("unimplemented annotation type: Widget signature"),this.setFlags(J.HIDDEN));for(var e=[],f=c,b=b.ref;f;){var c=f.get("Parent"),i=f.getRaw("Parent");if(f=f.get("T"))e.unshift(h(f));else if(c&&b){var f=
c.get("Kids"),j,k;for(j=0,k=f.length;j<k;j++){var l=f[j];if(l.num===b.num&&l.gen===b.gen)break}e.unshift("`"+j)}f=c;b=i}d.fullName=e.join(".")}C.inherit(a,g,{});return a}(),k=function(){function a(b){d.call(this,b);this.data.textAlignment=C.getInheritableProperty(b.dict,"Q");this.data.hasHtml=!this.data.hasAppearance&&!!this.data.fieldValue}C.inherit(a,d,{getOperatorList:function(a,b){if(this.appearance)return g.prototype.getOperatorList.call(this,a,b);var c=new M,d=this.data;if(!d.defaultAppearance)return Promise.resolve(c);
d=new u(G(d.defaultAppearance));return a.getOperatorList(d,b,this.fieldResources,c).then(function(){return c})}});return a}(),c=function(){function a(c){g.call(this,c);this.data.annotationType=Q.TEXT;this.data.hasHtml=!0;c=c.dict;this.data.hasAppearance?this.data.name="NoIcon":(this.data.rect[1]=this.data.rect[3]-b,this.data.rect[2]=this.data.rect[0]+b,this.data.name=c.has("Name")?c.get("Name").name:"Note");c.has("C")||(this.data.color=null);this.data.hasPopup=c.has("Popup");this.data.hasPopup||(this.data.title=
h(c.get("T")||""),this.data.contents=h(c.get("Contents")||""),this.data.hasHtml=this.data.title||this.data.contents)}var b=22;C.inherit(a,g,{});return a}(),b=function(){function a(b){g.call(this,b);var c=b.dict,b=this.data;b.annotationType=Q.LINK;b.hasHtml=!0;var d=c.get("A");if(d&&w(d))if(c=d.get("S").name,"URI"===c){var e=d.get("URI");t(e)?e="/"+e.name:e&&(e=e&&0===e.indexOf("www.")?"http://"+e:e);D(e,!1)||(e="");try{b.url=z(e)}catch(f){b.url=e}}else"GoTo"===c?b.dest=d.get("D"):"GoToR"===c?(c=d.get("F"),
w(c)&&(e=c.get("F")||""),D(e,!1)||(e=""),b.url=e,b.dest=d.get("D")):"Named"===c?b.action=d.get("N").name:R("unrecognized link type: "+c);else c.has("Dest")&&(e=c.get("Dest"),b.dest=t(e)?e.name:e)}C.inherit(a,g,{});return a}(),i=function(){function a(b){g.call(this,b);this.data.annotationType=Q.POPUP;var b=b.dict,c=b.get("Parent");c?(this.data.parentId=b.getRaw("Parent").toString(),this.data.title=h(c.get("T")||""),this.data.contents=h(c.get("Contents")||""),c.has("C")?(this.setColor(c.get("C")),this.data.color=
this.color):this.data.color=null,this.data.hasHtml=this.data.title||this.data.contents):R("Popup annotation has a missing or invalid parent annotation.")}C.inherit(a,g,{});return a}(),l=function(){function a(b){g.call(this,b);this.data.annotationType=Q.HIGHLIGHT;this.data.hasHtml=!0;this.data.borderStyle.setWidth(0)}C.inherit(a,g,{});return a}(),q=function(){function a(b){g.call(this,b);this.data.annotationType=Q.UNDERLINE;this.data.hasHtml=!0;this.data.borderStyle.setWidth(0)}C.inherit(a,g,{});return a}(),
j=function(){function a(b){g.call(this,b);this.data.annotationType=Q.SQUIGGLY;this.data.hasHtml=!0;this.data.borderStyle.setWidth(0)}C.inherit(a,g,{});return a}(),p=function(){function a(b){g.call(this,b);this.data.annotationType=Q.STRIKEOUT;this.data.hasHtml=!0;this.data.borderStyle.setWidth(0)}C.inherit(a,g,{});return a}();a.Annotation=g;a.AnnotationBorderStyle=f;a.AnnotationFactory=K});(function(a,e){e(a.pdfjsCoreDocument={},a.pdfjsSharedUtil,a.pdfjsCorePrimitives,a.pdfjsCoreStream,a.pdfjsCoreObj,
a.pdfjsCoreParser,a.pdfjsCoreCrypto,a.pdfjsCoreEvaluator,a.pdfjsCoreAnnotation)})(this,function(a,e,O,P,N,L,H,K,I){var J=e.MissingDataException,Q=e.Util,E=e.assert,C=e.error,o=e.info,x=e.isArray,D=e.isArrayBuffer,G=e.isString,h=e.shadow,z=e.stringToBytes,R=e.stringToPDFString,m=e.warn,w=O.Dict,t=O.isDict,u=O.isName,y=O.isStream,s=P.NullStream,M=P.Stream,g=P.StreamsSequenceStream,f=N.Catalog,d=N.ObjectLoader,k=N.XRef,c=L.Lexer,b=L.Linearization,i=H.calculateMD5,l=K.OperatorList,q=K.PartialEvaluator,
j=I.Annotation,p=I.AnnotationFactory,v=function(){function a(b,c,d,e,f,g){this.pdfManager=b;this.pageIndex=d;this.pageDict=e;this.xref=c;this.ref=f;this.fontCache=g;this.idCounters={obj:0};this.resourcesPromise=null}var b=[0,0,612,792];a.prototype={getPageProp:function(a){return this.pageDict.get(a)},getInheritedPageProp:function(a){for(var b=this.pageDict,c=null,d=0;b;){var e=b.get(a);e&&(c||(c=[]),c.push(e));if(100<++d){m("Page_getInheritedPageProp: maximum loop count exceeded.");break}b=b.get("Parent")}return!c?
w.empty:1===c.length||!t(c[0])||100<d?c[0]:w.merge(this.xref,c)},get content(){return this.getPageProp("Contents")},get resources(){return h(this,"resources",this.getInheritedPageProp("Resources"))},get mediaBox(){var a=this.getInheritedPageProp("MediaBox");if(!x(a)||4!==a.length)a=b;return h(this,"mediaBox",a)},get view(){var a=this.mediaBox,b=this.getInheritedPageProp("CropBox");if(!x(b)||4!==b.length)return h(this,"view",a);b=Q.intersect(b,a);return!b?h(this,"view",a):h(this,"view",b)},get rotate(){var a=
this.getInheritedPageProp("Rotate")||0;0!==a%90?a=0:360<=a?a%=360:0>a&&(a=(a%360+360)%360);return h(this,"rotate",a)},getContentStream:function(){var a=this.content;if(x(a)){var b=this.xref,c,d=a.length,e=[];for(c=0;c<d;++c)e.push(b.fetchIfRef(a[c]));a=new g(e)}else a=y(a)?a:new s;return a},loadResources:function(a){this.resourcesPromise||(this.resourcesPromise=this.pdfManager.ensure(this,"resources"));return this.resourcesPromise.then(function(){return(new d(this.resources.map,a,this.xref)).load()}.bind(this))},
getOperatorList:function(a,b,c){var d=this,e=this.pdfManager,f=e.ensure(this,"getContentStream",[]),g=this.loadResources("ExtGState,ColorSpace,Pattern,Shading,XObject,Font".split(",")),h=new q(e,this.xref,a,this.pageIndex,"p"+this.pageIndex+"_",this.idCounters,this.fontCache),f=Promise.all([f,g]).then(function(e){var e=e[0],f=new l(c,a,d.pageIndex);a.send("StartRenderPage",{transparency:h.hasBlendModes(d.resources),pageIndex:d.pageIndex,intent:c});return h.getOperatorList(e,b,d.resources,f).then(function(){return f})}),
e=e.ensure(this,"annotations");return Promise.all([f,e]).then(function(a){var d=a[0],a=a[1];return 0===a.length?(d.flush(!0),d):j.appendToOperatorList(a,d,h,b,c).then(function(){d.flush(!0);return d})})},extractTextContent:function(a,b){var c={on:function(){},send:function(){}},d=this,e=this.pdfManager,f=e.ensure(this,"getContentStream",[]),g=this.loadResources(["ExtGState","XObject","Font"]);return Promise.all([f,g]).then(function(f){f=f[0];return(new q(e,d.xref,c,d.pageIndex,"p"+d.pageIndex+"_",
d.idCounters,d.fontCache)).getTextContent(f,a,d.resources,null,b)})},getAnnotationsData:function(a){for(var b=this.annotations,c=[],d=0,e=b.length;d<e;++d)(!a||"display"===a&&b[d].viewable||"print"===a&&b[d].printable)&&c.push(b[d].data);return c},get annotations(){for(var a=[],b=this.getInheritedPageProp("Annots")||[],c=new p,d=0,e=b.length;d<e;++d){var f=c.create(this.xref,b[d]);f&&a.push(f)}return h(this,"annotations",a)}};return a}(),e=function(){function a(b,c,e){y(c)?d.call(this,b,c,e):D(c)?
d.call(this,b,new M(c),e):C("PDFDocument: Unknown argument type")}function d(a,b,c){E(0<b.length,"stream must have data");this.pdfManager=a;this.stream=b;this.xref=new k(this.stream,c,a)}function e(a,b,c,d){var f=a.pos,g=a.end,h=[];f+c>g&&(c=g-f);for(g=0;g<c;++g)h.push(String.fromCharCode(a.getByte()));c=h.join("");a.pos=f;b=d?c.lastIndexOf(b):c.indexOf(b);if(-1===b)return!1;a.pos+=b;return!0}var g={get entries(){return h(this,"entries",{Title:G,Author:G,Subject:G,Keywords:G,Creator:G,Producer:G,
CreationDate:G,ModDate:G,Trapped:u})}};a.prototype={parse:function(a){this.setup(a);a=this.catalog.catDict.get("Version");u(a)&&(this.pdfFormatVersion=a.name);try{if(this.acroForm=this.catalog.catDict.get("AcroForm")){this.xfa=this.acroForm.get("XFA");var b=this.acroForm.get("Fields");if((!b||!x(b)||0===b.length)&&!this.xfa)this.acroForm=null}}catch(c){o("Something wrong with AcroForm entry"),this.acroForm=null}},get linearization(){var a=null;if(this.stream.length)try{a=b.create(this.stream)}catch(c){if(c instanceof
J)throw c;o(c)}return h(this,"linearization",a)},get startXRef(){var a=this.stream,b=0;if(this.linearization)a.reset(),e(a,"endobj",1024)&&(b=a.pos+6);else{for(var d=!1,f=a.end;!d&&0<f;)f-=1015,0>f&&(f=0),a.pos=f,d=e(a,"startxref",1024,!0);if(d){a.skip(9);do b=a.getByte();while(c.isSpace(b));for(d="";32<=b&&57>=b;)d+=String.fromCharCode(b),b=a.getByte();b=parseInt(d,10);isNaN(b)&&(b=0)}}return h(this,"startXRef",b)},get mainXRefEntriesOffset(){var a=0,b=this.linearization;b&&(a=b.mainXRefEntriesOffset);
return h(this,"mainXRefEntriesOffset",a)},checkHeader:function(){var a=this.stream;a.reset();if(e(a,"%PDF-",1024)){a.moveStart();for(var b="",c;32<(c=a.getByte())&&!(12<=b.length);)b+=String.fromCharCode(c);this.pdfFormatVersion||(this.pdfFormatVersion=b.substring(5))}},parseStartXRef:function(){this.xref.setStartXRef(this.startXRef)},setup:function(a){this.xref.parse(a);var b=this;this.catalog=new f(this.pdfManager,this.xref,{createPage:function(a,c,d,e){return new v(b.pdfManager,b.xref,a,c,d,e)}})},
get numPages(){var a=this.linearization;return h(this,"numPages",a?a.numPages:this.catalog.numPages)},get documentInfo(){var a={PDFFormatVersion:this.pdfFormatVersion,IsAcroFormPresent:!!this.acroForm,IsXFAPresent:!!this.xfa},b;try{b=this.xref.trailer.get("Info")}catch(c){o("The document information dictionary is invalid.")}if(b){var d=g.entries,e;for(e in d)if(b.has(e)){var f=b.get(e);d[e](f)?a[e]="string"!==typeof f?f:R(f):o('Bad value in document info for "'+e+'"')}}return h(this,"documentInfo",
a)},get fingerprint(){var a,b="";(a=this.xref.trailer.get("ID"))&&x(a)&&a[0]&&G(a[0])&&"\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"!==a[0]?a=z(a[0]):(this.stream.ensureRange&&this.stream.ensureRange(0,Math.min(1024,this.stream.end)),a=i(this.stream.bytes.subarray(0,1024),0,1024));for(var c=0,d=a.length;c<d;c++)var e=a[c].toString(16),b=b+(1===e.length?"0"+e:e);return h(this,"fingerprint",b)},getPage:function(a){return this.catalog.getPage(a)},cleanup:function(){return this.catalog.cleanup()}};
return a}();a.Page=v;a.PDFDocument=e});(function(a,e){e(a.pdfjsCorePdfManager={},a.pdfjsSharedUtil,a.pdfjsCoreStream,a.pdfjsCoreChunkedStream,a.pdfjsCoreDocument)})(this,function(a,e,O,P,N){var L=e.NotImplementedException,H=e.MissingDataException,K=e.createPromiseCapability,I=e.Util,J=O.Stream,Q=P.ChunkedStreamManager,E=N.PDFDocument,C=function(){function a(){throw Error("Cannot initialize BaseManagerManager");}a.prototype={get docId(){return this._docId},onLoadedStream:function(){throw new L;},ensureDoc:function(a,
e){return this.ensure(this.pdfDocument,a,e)},ensureXRef:function(a,e){return this.ensure(this.pdfDocument.xref,a,e)},ensureCatalog:function(a,e){return this.ensure(this.pdfDocument.catalog,a,e)},getPage:function(a){return this.pdfDocument.getPage(a)},cleanup:function(){return this.pdfDocument.cleanup()},ensure:function(){return new L},requestRange:function(){return new L},requestLoadedStream:function(){return new L},sendProgressiveData:function(){return new L},updatePassword:function(a){this.pdfDocument.xref.password=
this.password=a;this._passwordChangedCapability&&this._passwordChangedCapability.resolve()},passwordChanged:function(){this._passwordChangedCapability=K();return this._passwordChangedCapability.promise},terminate:function(){return new L}};return a}(),e=function(){function a(e,o,C){this._docId=e;e=new J(o);this.pdfDocument=new E(this,e,C);this._loadedStreamCapability=K();this._loadedStreamCapability.resolve(e)}I.inherit(a,C,{ensure:function(a,e,o){return new Promise(function(h,z){try{var C=a[e],m;
m="function"===typeof C?C.apply(a,o):C;h(m)}catch(w){z(w)}})},requestRange:function(){return Promise.resolve()},requestLoadedStream:function(){},onLoadedStream:function(){return this._loadedStreamCapability.promise},terminate:function(){}});return a}(),O=function(){function a(e,o,C){this._docId=e;this.msgHandler=C;this.streamManager=new Q(o.length,o.rangeChunkSize,o.url,{msgHandler:C,httpHeaders:o.httpHeaders,withCredentials:o.withCredentials,chunkedViewerLoading:o.chunkedViewerLoading,disableAutoFetch:o.disableAutoFetch,
initialData:o.initialData});this.pdfDocument=new E(this,this.streamManager.getStream(),o.password)}I.inherit(a,C,{ensure:function(a,e,o){var h=this;return new Promise(function(z,C){function m(){try{var w,t=a[e];w="function"===typeof t?t.apply(a,o):t;z(w)}catch(u){u instanceof H?h.streamManager.requestRange(u.begin,u.end).then(m,C):C(u)}}m()})},requestRange:function(a,e){return this.streamManager.requestRange(a,e)},requestLoadedStream:function(){this.streamManager.requestAllChunks()},sendProgressiveData:function(a){this.streamManager.onReceiveData({chunk:a})},
onLoadedStream:function(){return this.streamManager.onLoadedStream()},terminate:function(){this.streamManager.abort()}});return a}();a.LocalPdfManager=e;a.NetworkPdfManager=O});(function(a,e){e(a.pdfjsCoreWorker={},a.pdfjsSharedUtil,a.pdfjsCorePrimitives,a.pdfjsCorePdfManager,a.pdfjsSharedGlobal)})(this,function(a,e,O,P,N){function L(){if(!("console"in u)){var a={};u.console={log:function(){var a=Array.prototype.slice.call(arguments);u.postMessage({targetName:"main",action:"console_log",data:a})},
error:function(){var a=Array.prototype.slice.call(arguments);u.postMessage({targetName:"main",action:"console_error",data:a});throw"pdf.js execution error";},time:function(d){a[d]=Date.now()},timeEnd:function(d){var e=a[d];e||G("Unknown timer name "+d);this.log("Timer:",d,Date.now()-e)}}}var e=new I("worker","main",self);M.setup(e,self);e.send("ready",null)}var H=e.UNSUPPORTED_FEATURES,K=e.InvalidPDFException,I=e.MessageHandler,J=e.MissingPDFException,Q=e.UnexpectedResponseException,E=e.PasswordException,
C=e.PasswordResponses,o=e.UnknownErrorException,x=e.XRefParseException,D=e.createPromiseCapability,G=e.error,h=e.info,z=e.isInt,R=e.warn,m=O.Ref,w=P.LocalPdfManager,t=P.NetworkPdfManager,u=N.globalScope,y=N.PDFJS,s=function(){function a(e){this.name=e;this.terminated=!1;this._capability=D()}a.prototype={get finished(){return this._capability.promise},finish:function(){this._capability.resolve()},terminate:function(){this.terminated=!0},ensureNotTerminated:function(){if(this.terminated)throw Error("Worker task was terminated");
}};return a}(),M=y.WorkerMessageHandler={setup:function(a,e){var d=!1;a.on("test",function(e){d||(d=!0,e instanceof Uint8Array?(e=255===e[0],a.postMessageTransfers=e,"response"in new XMLHttpRequest?a.send("test",{supportTypedArray:!0,supportTransfers:e}):a.send("test",!1)):a.send("test","main",!1))});a.on("GetDocRequest",function(a){return M.createDocumentHandler(a,e)})},createDocumentHandler:function(a,e){function d(){if(l)throw Error("Worker was terminated");}function k(a){a.finish();a=j.indexOf(a);
j.splice(a,1)}function c(a){var b=D(),c=function(){var a=i.ensureDoc("numPages"),c=i.ensureDoc("fingerprint"),e=i.ensureXRef("encrypt");Promise.all([a,c,e]).then(function(a){b.resolve({numPages:a[0],fingerprint:a[1],encrypted:!!a[2]})},d)},d=function(a){b.reject(a)};i.ensureDoc("checkHeader",[]).then(function(){i.ensureDoc("parseStartXRef",[]).then(function(){i.ensureDoc("parse",[a]).then(c,d)},d)},d);return b.promise}function b(a){var b=D(),c,d=a.source,e=a.disableRange;if(d.data){try{c=new w(p,
d.data,d.password),b.resolve(c)}catch(f){b.reject(f)}return b.promise}if(d.chunkedViewerLoading){try{c=new t(p,d,n),b.resolve(c)}catch(g){b.reject(g)}return b.promise}var h=new ca(d.url,{httpHeaders:d.httpHeaders,withCredentials:d.withCredentials}),i=[],j=h.requestFull({onHeadersReceived:function(){if(!e){var a=h.getRequestXhr(j);if("bytes"===a.getResponseHeader("Accept-Ranges")&&"identity"===(a.getResponseHeader("Content-Encoding")||"identity"))if(a=a.getResponseHeader("Content-Length"),a=parseInt(a,
10),z(a)&&(d.length=a,!(a<=2*d.rangeChunkSize))){h.isStreamingRequest(j)?d.disableAutoFetch=!0:h.abortRequest(j);try{c=new t(p,d,n),b.resolve(c)}catch(f){b.reject(f)}q=null}}},onProgressiveData:d.disableStream?null:function(a){c?c.sendProgressiveData(a):i.push(a)},onDone:function(a){if(!c){if(null===a){var e=0,f=0;i.forEach(function(a){e+=a.byteLength});d.length&&e!==d.length&&R("reported HTTP length is different from actual");var g=new Uint8Array(e);i.forEach(function(a){g.set(new Uint8Array(a),
f);f+=a.byteLength});a=g.buffer}else a=a.chunk;try{c=new w(p,a,d.password),b.resolve(c)}catch(h){b.reject(h)}q=null}},onError:function(a){404===a||0===a&&/^file:/.test(d.url)?(a=new J('Missing PDF "'+d.url+'".'),n.send("MissingPDF",a)):(a=new Q("Unexpected server response ("+a+') while retrieving PDF "'+d.url+'".',a),n.send("UnexpectedResponse",a));q=null},onProgress:function(a){n.send("DocProgress",{loaded:a.loaded,total:a.lengthComputable?a.total:d.length})}});q=function(){h.abortRequest(j)};return b.promise}
var i,l=!1,q=null,j=[],p=a.docId,u=a.docId+"_worker",n=new I(u,p,e),r=function(a){var e=function(a){d();n.send("GetDoc",{pdfInfo:a})},f=function(a){a instanceof E?a.code===C.NEED_PASSWORD?n.send("NeedPassword",a):a.code===C.INCORRECT_PASSWORD&&n.send("IncorrectPassword",a):a instanceof K?n.send("InvalidPDF",a):a instanceof J?n.send("MissingPDF",a):a instanceof Q?n.send("UnexpectedResponse",a):n.send("UnknownError",new o(a.message,a.toString()))};d();y.maxImageSize=void 0===a.maxImageSize?-1:a.maxImageSize;
y.disableFontFace=a.disableFontFace;y.disableCreateObjectURL=a.disableCreateObjectURL;y.verbosity=a.verbosity;y.cMapUrl=void 0===a.cMapUrl?null:a.cMapUrl;y.cMapPacked=!0===a.cMapPacked;b(a).then(function(a){if(l)throw a.terminate(),Error("Worker was terminated");i=a;n.send("PDFManagerReady",null);i.onLoadedStream().then(function(a){n.send("DataLoaded",{length:a.bytes.byteLength})})}).then(function V(){d();c(!1).then(e,function(a){d();a instanceof x?(i.requestLoadedStream(),i.onLoadedStream().then(function(){d();
c(!0).then(e,f)})):(a instanceof E&&i.passwordChanged().then(V),f(a))},f)},f)};n.on("GetPage",function(a){return i.getPage(a.pageIndex).then(function(a){var b=i.ensure(a,"rotate"),c=i.ensure(a,"ref"),a=i.ensure(a,"view");return Promise.all([b,c,a]).then(function(a){return{rotate:a[0],ref:a[1],view:a[2]}})})});n.on("GetPageIndex",function(a){a=new m(a.ref.num,a.ref.gen);return i.pdfDocument.catalog.getPageIndex(a)});n.on("GetDestinations",function(){return i.ensureCatalog("destinations")});n.on("GetDestination",
function(a){return i.ensureCatalog("getDestination",[a.id])});n.on("GetAttachments",function(){return i.ensureCatalog("attachments")});n.on("GetJavaScript",function(){return i.ensureCatalog("javaScript")});n.on("GetOutline",function(){return i.ensureCatalog("documentOutline")});n.on("GetMetadata",function(){return Promise.all([i.ensureDoc("documentInfo"),i.ensureCatalog("metadata")])});n.on("GetData",function(){i.requestLoadedStream();return i.onLoadedStream().then(function(a){return a.bytes})});
n.on("GetStats",function(){return i.pdfDocument.xref.stats});n.on("UpdatePassword",function(a){i.updatePassword(a)});n.on("GetAnnotations",function(a){return i.getPage(a.pageIndex).then(function(b){return i.ensure(b,"getAnnotationsData",[a.intent])})});n.on("RenderPageRequest",function(a){var b=a.pageIndex;i.getPage(b).then(function(c){var d=new s("RenderPageRequest: page "+b);j.push(d);var e=b+1,f=Date.now();c.getOperatorList(n,d,a.intent).then(function(a){k(d);h("page="+e+" - getOperatorList: time="+
(Date.now()-f)+"ms, len="+a.totalLength)},function(b){k(d);d.terminated||(n.send("UnsupportedFeature",{featureId:H.unknown}),n.send("PageError",{pageNum:e,error:"string"===typeof b?{message:b,stack:"worker.js: while trying to getPage() and getOperatorList()"}:"object"===typeof b?{message:b.message||b.toString(),stack:b.stack||"worker.js: while trying to getPage() and getOperatorList()"}:{message:"Unknown exception type: "+typeof b,stack:"worker.js: while trying to getPage() and getOperatorList()"},
intent:a.intent}))})})},this);n.on("GetTextContent",function(a){var b=a.pageIndex,c=a.normalizeWhitespace;return i.getPage(b).then(function(a){var d=new s("GetTextContent: page "+b);j.push(d);var e=b+1,f=Date.now();return a.extractTextContent(d,c).then(function(a){k(d);h("text indexing: page="+e+" - time="+(Date.now()-f)+"ms");return a},function(a){k(d);if(!d.terminated)throw a;})})});n.on("Cleanup",function(){return i.cleanup()});n.on("Terminate",function(){l=!0;i&&(i.terminate(),i=null);q&&q();
var a=[];j.forEach(function(b){a.push(b.finished);b.terminate()});return Promise.all(a).then(function(){n.destroy();n=null})});n.on("Ready",function(){r(a);a=null});return u}};"undefined"===typeof window&&!("undefined"!==typeof module&&module.require)&&L();a.WorkerTask=s;a.WorkerMessageHandler=M})}).call("undefined"===typeof window?this:window);!PDFJS.workerSrc&&"undefined"!==typeof document&&(PDFJS.workerSrc=function(){var ca=document.currentScript.src;return ca&&ca.replace(/\.js$/i,".worker.js")}());
